/********************************************************************************
** Form generated from reading UI file 'encoding.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENCODING_H
#define UI_ENCODING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_encodingDialog
{
public:
    QGridLayout *gridLayout_3;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelPhase;
    QLabel *label_2;
    QProgressBar *progressBar;
    QLabel *labelETA;
    QLabel *label_26;
    QHBoxLayout *horizontalLayout1;
    QCheckBox *checkBoxShutdown;
    QSpacerItem *spacerItem;
    QLabel *labelPrio;
    QComboBox *comboBoxPriority;
    QHBoxLayout *horizontalLayout2;
    QCheckBox *checkBoxKeepOpen;
    QSpacerItem *spacerItem1;
    QHBoxLayout *horizontalLayout;
    QCheckBox *checkBoxDeleteStats;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *labelFileName;
    QLineEdit *lineEditFN;
    QSpacerItem *verticalSpacer2;
    QHBoxLayout *horizontalLayout3;
    QPushButton *pushButton1;
    QSpacerItem *spacerItem2;
    QPushButton *pushButton2;
    QWidget *tab_2;
    QGridLayout *gridLayout_2;
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout1;
    QGroupBox *groupBox;
    QGridLayout *gridLayout2;
    QLabel *labelVidCodec;
    QLabel *label_6;
    QLabel *labelContainer;
    QLabel *labelAudCodec;
    QLabel *label_8;
    QLabel *label_4;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout3;
    QLabel *label_20;
    QLabel *label_22;
    QLabel *labelTotalSize;
    QLabel *labelAudioSize;
    QLabel *label_18;
    QLabel *labelVideoSize;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout4;
    QLabel *label_16;
    QLabel *labelFrame;
    QLabel *label_10;
    QLabel *label_14;
    QLabel *labelVidBitrate;
    QLabel *labelQz;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout5;
    QLabel *label_24;
    QLabel *labelElapsed;
    QLabel *labelDummy;
    QLabel *labelFps;
    QLabel *label_28;

    void setupUi(QDialog *encodingDialog)
    {
        if (encodingDialog->objectName().isEmpty())
            encodingDialog->setObjectName(QString::fromUtf8("encodingDialog"));
        encodingDialog->resize(502, 344);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(encodingDialog->sizePolicy().hasHeightForWidth());
        encodingDialog->setSizePolicy(sizePolicy);
        encodingDialog->setSizeIncrement(QSize(1, 1));
        gridLayout_3 = new QGridLayout(encodingDialog);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        tabWidget = new QTabWidget(encodingDialog);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy1);
        tab = new QWidget();
        tab->setObjectName(QString::fromUtf8("tab"));
        verticalLayout = new QVBoxLayout(tab);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        labelPhase = new QLabel(tab);
        labelPhase->setObjectName(QString::fromUtf8("labelPhase"));

        gridLayout->addWidget(labelPhase, 0, 1, 1, 1);

        label_2 = new QLabel(tab);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        progressBar = new QProgressBar(tab);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setValue(0);
        progressBar->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(progressBar, 2, 0, 1, 2);

        labelETA = new QLabel(tab);
        labelETA->setObjectName(QString::fromUtf8("labelETA"));

        gridLayout->addWidget(labelETA, 1, 1, 1, 1);

        label_26 = new QLabel(tab);
        label_26->setObjectName(QString::fromUtf8("label_26"));

        gridLayout->addWidget(label_26, 1, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        horizontalLayout1 = new QHBoxLayout();
        horizontalLayout1->setObjectName(QString::fromUtf8("horizontalLayout1"));
        checkBoxShutdown = new QCheckBox(tab);
        checkBoxShutdown->setObjectName(QString::fromUtf8("checkBoxShutdown"));

        horizontalLayout1->addWidget(checkBoxShutdown);

        spacerItem = new QSpacerItem(48, 17, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout1->addItem(spacerItem);

        labelPrio = new QLabel(tab);
        labelPrio->setObjectName(QString::fromUtf8("labelPrio"));

        horizontalLayout1->addWidget(labelPrio);

        comboBoxPriority = new QComboBox(tab);
        comboBoxPriority->addItem(QString());
        comboBoxPriority->addItem(QString());
        comboBoxPriority->addItem(QString());
        comboBoxPriority->addItem(QString());
        comboBoxPriority->addItem(QString());
        comboBoxPriority->setObjectName(QString::fromUtf8("comboBoxPriority"));

        horizontalLayout1->addWidget(comboBoxPriority);


        verticalLayout->addLayout(horizontalLayout1);

        horizontalLayout2 = new QHBoxLayout();
        horizontalLayout2->setObjectName(QString::fromUtf8("horizontalLayout2"));
        checkBoxKeepOpen = new QCheckBox(tab);
        checkBoxKeepOpen->setObjectName(QString::fromUtf8("checkBoxKeepOpen"));

        horizontalLayout2->addWidget(checkBoxKeepOpen);

        spacerItem1 = new QSpacerItem(48, 17, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout2->addItem(spacerItem1);


        verticalLayout->addLayout(horizontalLayout2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        checkBoxDeleteStats = new QCheckBox(tab);
        checkBoxDeleteStats->setObjectName(QString::fromUtf8("checkBoxDeleteStats"));

        horizontalLayout->addWidget(checkBoxDeleteStats);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        labelFileName = new QLabel(tab);
        labelFileName->setObjectName(QString::fromUtf8("labelFileName"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(labelFileName->sizePolicy().hasHeightForWidth());
        labelFileName->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(labelFileName);

        lineEditFN = new QLineEdit(tab);
        lineEditFN->setObjectName(QString::fromUtf8("lineEditFN"));
        lineEditFN->setReadOnly(true);

        horizontalLayout_2->addWidget(lineEditFN);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer2 = new QSpacerItem(20, 8, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer2);

        horizontalLayout3 = new QHBoxLayout();
        horizontalLayout3->setObjectName(QString::fromUtf8("horizontalLayout3"));
        pushButton1 = new QPushButton(tab);
        pushButton1->setObjectName(QString::fromUtf8("pushButton1"));

        horizontalLayout3->addWidget(pushButton1);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout3->addItem(spacerItem2);

        pushButton2 = new QPushButton(tab);
        pushButton2->setObjectName(QString::fromUtf8("pushButton2"));

        horizontalLayout3->addWidget(pushButton2);


        verticalLayout->addLayout(horizontalLayout3);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QString::fromUtf8("tab_2"));
        gridLayout_2 = new QGridLayout(tab_2);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout1 = new QGridLayout();
        gridLayout1->setSpacing(12);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(tab_2);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        QSizePolicy sizePolicy3(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy3.setHorizontalStretch(1);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy3);
        groupBox->setMinimumSize(QSize(200, 0));
        gridLayout2 = new QGridLayout(groupBox);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QString::fromUtf8("gridLayout2"));
        gridLayout2->setContentsMargins(9, 9, 9, 9);
        labelVidCodec = new QLabel(groupBox);
        labelVidCodec->setObjectName(QString::fromUtf8("labelVidCodec"));

        gridLayout2->addWidget(labelVidCodec, 1, 1, 1, 1);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout2->addWidget(label_6, 2, 0, 1, 1);

        labelContainer = new QLabel(groupBox);
        labelContainer->setObjectName(QString::fromUtf8("labelContainer"));

        gridLayout2->addWidget(labelContainer, 3, 1, 1, 1);

        labelAudCodec = new QLabel(groupBox);
        labelAudCodec->setObjectName(QString::fromUtf8("labelAudCodec"));

        gridLayout2->addWidget(labelAudCodec, 2, 1, 1, 1);

        label_8 = new QLabel(groupBox);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout2->addWidget(label_8, 3, 0, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout2->addWidget(label_4, 1, 0, 1, 1);


        gridLayout1->addWidget(groupBox, 0, 0, 1, 1);

        groupBox_3 = new QGroupBox(tab_2);
        groupBox_3->setObjectName(QString::fromUtf8("groupBox_3"));
        QSizePolicy sizePolicy4(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy4);
        groupBox_3->setMinimumSize(QSize(200, 0));
        gridLayout3 = new QGridLayout(groupBox_3);
        gridLayout3->setSpacing(6);
        gridLayout3->setObjectName(QString::fromUtf8("gridLayout3"));
        gridLayout3->setContentsMargins(9, 9, 9, 9);
        label_20 = new QLabel(groupBox_3);
        label_20->setObjectName(QString::fromUtf8("label_20"));

        gridLayout3->addWidget(label_20, 1, 0, 1, 1);

        label_22 = new QLabel(groupBox_3);
        label_22->setObjectName(QString::fromUtf8("label_22"));

        gridLayout3->addWidget(label_22, 2, 0, 1, 1);

        labelTotalSize = new QLabel(groupBox_3);
        labelTotalSize->setObjectName(QString::fromUtf8("labelTotalSize"));

        gridLayout3->addWidget(labelTotalSize, 2, 1, 1, 1);

        labelAudioSize = new QLabel(groupBox_3);
        labelAudioSize->setObjectName(QString::fromUtf8("labelAudioSize"));

        gridLayout3->addWidget(labelAudioSize, 1, 1, 1, 1);

        label_18 = new QLabel(groupBox_3);
        label_18->setObjectName(QString::fromUtf8("label_18"));

        gridLayout3->addWidget(label_18, 0, 0, 1, 1);

        labelVideoSize = new QLabel(groupBox_3);
        labelVideoSize->setObjectName(QString::fromUtf8("labelVideoSize"));
        labelVideoSize->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout3->addWidget(labelVideoSize, 0, 1, 1, 1);


        gridLayout1->addWidget(groupBox_3, 1, 0, 1, 1);

        groupBox_2 = new QGroupBox(tab_2);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        sizePolicy3.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy3);
        groupBox_2->setMinimumSize(QSize(220, 0));
        gridLayout4 = new QGridLayout(groupBox_2);
        gridLayout4->setSpacing(6);
        gridLayout4->setObjectName(QString::fromUtf8("gridLayout4"));
        gridLayout4->setContentsMargins(9, 9, 9, 9);
        label_16 = new QLabel(groupBox_2);
        label_16->setObjectName(QString::fromUtf8("label_16"));

        gridLayout4->addWidget(label_16, 2, 0, 1, 1);

        labelFrame = new QLabel(groupBox_2);
        labelFrame->setObjectName(QString::fromUtf8("labelFrame"));
        labelFrame->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout4->addWidget(labelFrame, 0, 1, 1, 1);

        label_10 = new QLabel(groupBox_2);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        gridLayout4->addWidget(label_10, 0, 0, 1, 1);

        label_14 = new QLabel(groupBox_2);
        label_14->setObjectName(QString::fromUtf8("label_14"));

        gridLayout4->addWidget(label_14, 1, 0, 1, 1);

        labelVidBitrate = new QLabel(groupBox_2);
        labelVidBitrate->setObjectName(QString::fromUtf8("labelVidBitrate"));

        gridLayout4->addWidget(labelVidBitrate, 2, 1, 1, 1);

        labelQz = new QLabel(groupBox_2);
        labelQz->setObjectName(QString::fromUtf8("labelQz"));

        gridLayout4->addWidget(labelQz, 1, 1, 1, 1);


        gridLayout1->addWidget(groupBox_2, 0, 1, 1, 1);

        groupBox_4 = new QGroupBox(tab_2);
        groupBox_4->setObjectName(QString::fromUtf8("groupBox_4"));
        sizePolicy4.setHeightForWidth(groupBox_4->sizePolicy().hasHeightForWidth());
        groupBox_4->setSizePolicy(sizePolicy4);
        groupBox_4->setMinimumSize(QSize(220, 0));
        gridLayout5 = new QGridLayout(groupBox_4);
        gridLayout5->setSpacing(6);
        gridLayout5->setObjectName(QString::fromUtf8("gridLayout5"));
        gridLayout5->setContentsMargins(9, 9, 9, 9);
        label_24 = new QLabel(groupBox_4);
        label_24->setObjectName(QString::fromUtf8("label_24"));

        gridLayout5->addWidget(label_24, 0, 0, 1, 1);

        labelElapsed = new QLabel(groupBox_4);
        labelElapsed->setObjectName(QString::fromUtf8("labelElapsed"));

        gridLayout5->addWidget(labelElapsed, 0, 1, 1, 1);

        labelDummy = new QLabel(groupBox_4);
        labelDummy->setObjectName(QString::fromUtf8("labelDummy"));

        gridLayout5->addWidget(labelDummy, 1, 0, 1, 1);

        labelFps = new QLabel(groupBox_4);
        labelFps->setObjectName(QString::fromUtf8("labelFps"));

        gridLayout5->addWidget(labelFps, 2, 1, 1, 1);

        label_28 = new QLabel(groupBox_4);
        label_28->setObjectName(QString::fromUtf8("label_28"));

        gridLayout5->addWidget(label_28, 2, 0, 1, 1);


        gridLayout1->addWidget(groupBox_4, 1, 1, 1, 1);


        vboxLayout->addLayout(gridLayout1);


        gridLayout_2->addLayout(vboxLayout, 0, 0, 1, 1);

        tabWidget->addTab(tab_2, QString());

        gridLayout_3->addWidget(tabWidget, 0, 0, 1, 1);


        retranslateUi(encodingDialog);

        tabWidget->setCurrentIndex(0);
        comboBoxPriority->setCurrentIndex(2);
        pushButton2->setDefault(true);


        QMetaObject::connectSlotsByName(encodingDialog);
    } // setupUi

    void retranslateUi(QDialog *encodingDialog)
    {
        encodingDialog->setWindowTitle(QCoreApplication::translate("encodingDialog", "Encoding...", nullptr));
        labelPhase->setText(QCoreApplication::translate("encodingDialog", "None", nullptr));
        label_2->setText(QCoreApplication::translate("encodingDialog", "Phase:", nullptr));
        labelETA->setText(QCoreApplication::translate("encodingDialog", "Unknown", nullptr));
        label_26->setText(QCoreApplication::translate("encodingDialog", "Time Remaining:", nullptr));
        checkBoxShutdown->setText(QCoreApplication::translate("encodingDialog", "Shut down computer when finished", nullptr));
        labelPrio->setText(QCoreApplication::translate("encodingDialog", "Priority:", nullptr));
        comboBoxPriority->setItemText(0, QCoreApplication::translate("encodingDialog", "High", nullptr));
        comboBoxPriority->setItemText(1, QCoreApplication::translate("encodingDialog", "Above Normal", nullptr));
        comboBoxPriority->setItemText(2, QCoreApplication::translate("encodingDialog", "Normal", nullptr));
        comboBoxPriority->setItemText(3, QCoreApplication::translate("encodingDialog", "Below Normal", nullptr));
        comboBoxPriority->setItemText(4, QCoreApplication::translate("encodingDialog", "Low", nullptr));

        checkBoxKeepOpen->setText(QCoreApplication::translate("encodingDialog", "Keep dialog open when finished", nullptr));
        checkBoxDeleteStats->setText(QCoreApplication::translate("encodingDialog", "Delete first pass log files", nullptr));
        labelFileName->setText(QCoreApplication::translate("encodingDialog", "Output File:", nullptr));
        pushButton1->setText(QCoreApplication::translate("encodingDialog", "Minimize to Tray", nullptr));
        pushButton2->setText(QCoreApplication::translate("encodingDialog", "Pause / Abort", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("encodingDialog", "Main", nullptr));
        groupBox->setTitle(QString());
        labelVidCodec->setText(QCoreApplication::translate("encodingDialog", "None", nullptr));
        label_6->setText(QCoreApplication::translate("encodingDialog", "Audio Codec:", nullptr));
        labelContainer->setText(QCoreApplication::translate("encodingDialog", "Unknown", nullptr));
        labelAudCodec->setText(QCoreApplication::translate("encodingDialog", "None", nullptr));
        label_8->setText(QCoreApplication::translate("encodingDialog", "Container:", nullptr));
        label_4->setText(QCoreApplication::translate("encodingDialog", "Video Codec:", nullptr));
        groupBox_3->setTitle(QString());
        label_20->setText(QCoreApplication::translate("encodingDialog", "Audio Size:", nullptr));
        label_22->setText(QCoreApplication::translate("encodingDialog", "Total Size:", nullptr));
        labelTotalSize->setText(QCoreApplication::translate("encodingDialog", "0 MB", nullptr));
        labelAudioSize->setText(QCoreApplication::translate("encodingDialog", "0 MB", nullptr));
        label_18->setText(QCoreApplication::translate("encodingDialog", "Video Size:", nullptr));
        labelVideoSize->setText(QCoreApplication::translate("encodingDialog", "0 MB", nullptr));
        groupBox_2->setTitle(QString());
        label_16->setText(QCoreApplication::translate("encodingDialog", "Average Bitrate:", nullptr));
        labelFrame->setText(QCoreApplication::translate("encodingDialog", "0", nullptr));
        label_10->setText(QCoreApplication::translate("encodingDialog", "Processed Frames:", nullptr));
        label_14->setText(QCoreApplication::translate("encodingDialog", "Quantiser:", nullptr));
        labelVidBitrate->setText(QCoreApplication::translate("encodingDialog", "0 kB/s", nullptr));
        labelQz->setText(QCoreApplication::translate("encodingDialog", "0", nullptr));
        groupBox_4->setTitle(QString());
        label_24->setText(QCoreApplication::translate("encodingDialog", "Elapsed:", nullptr));
        labelElapsed->setText(QCoreApplication::translate("encodingDialog", "00:00:00", nullptr));
        labelFps->setText(QCoreApplication::translate("encodingDialog", "0", nullptr));
        label_28->setText(QCoreApplication::translate("encodingDialog", "Frames/sec:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("encodingDialog", "Advanced", nullptr));
    } // retranslateUi

};

namespace Ui {
    class encodingDialog: public Ui_encodingDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ENCODING_H
