/********************************************************************************
** Form generated from reading UI file 'cubicLUT.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUBICLUT_H
#define UI_CUBICLUT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_cubicLUTDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBoxMask;
    QGridLayout *gridLayout_2;
    QPushButton *pushButtonLoadHaldCLUT;
    QLineEdit *lineEditFile;
    QPushButton *pushButtonLoadCube;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *cubicLUTDialog)
    {
        if (cubicLUTDialog->objectName().isEmpty())
            cubicLUTDialog->setObjectName(QString::fromUtf8("cubicLUTDialog"));
        cubicLUTDialog->resize(585, 424);
        verticalLayout = new QVBoxLayout(cubicLUTDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        groupBoxMask = new QGroupBox(cubicLUTDialog);
        groupBoxMask->setObjectName(QString::fromUtf8("groupBoxMask"));
        gridLayout_2 = new QGridLayout(groupBoxMask);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        gridLayout_2->setContentsMargins(-1, -1, -1, 0);
        pushButtonLoadHaldCLUT = new QPushButton(groupBoxMask);
        pushButtonLoadHaldCLUT->setObjectName(QString::fromUtf8("pushButtonLoadHaldCLUT"));

        gridLayout_2->addWidget(pushButtonLoadHaldCLUT, 1, 0, 1, 1);

        lineEditFile = new QLineEdit(groupBoxMask);
        lineEditFile->setObjectName(QString::fromUtf8("lineEditFile"));
        lineEditFile->setEnabled(false);
        lineEditFile->setMinimumSize(QSize(80, 0));

        gridLayout_2->addWidget(lineEditFile, 1, 2, 1, 1);

        pushButtonLoadCube = new QPushButton(groupBoxMask);
        pushButtonLoadCube->setObjectName(QString::fromUtf8("pushButtonLoadCube"));

        gridLayout_2->addWidget(pushButtonLoadCube, 1, 1, 1, 1);


        verticalLayout->addWidget(groupBoxMask);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(cubicLUTDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(cubicLUTDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(cubicLUTDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(pushButtonLoadHaldCLUT, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, graphicsView);
        QWidget::setTabOrder(graphicsView, lineEditFile);

        retranslateUi(cubicLUTDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), cubicLUTDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), cubicLUTDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(cubicLUTDialog);
    } // setupUi

    void retranslateUi(QDialog *cubicLUTDialog)
    {
        cubicLUTDialog->setWindowTitle(QCoreApplication::translate("cubicLUTDialog", "3D LUT", nullptr));
        groupBoxMask->setTitle(QCoreApplication::translate("cubicLUTDialog", "Mask", nullptr));
        pushButtonLoadHaldCLUT->setText(QCoreApplication::translate("cubicLUTDialog", "Load HaldCLUT", nullptr));
        pushButtonLoadCube->setText(QCoreApplication::translate("cubicLUTDialog", "Load Cube", nullptr));
    } // retranslateUi

};

namespace Ui {
    class cubicLUTDialog: public Ui_cubicLUTDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CUBICLUT_H
