/********************************************************************************
** Form generated from reading UI file 'mainfilter.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINFILTER_H
#define UI_MAINFILTER_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_mainFilterDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *listsGrid;
    QListWidget *listWidgetActive;
    QListWidget *listFilterCategory;
    QLabel *labelAvailable;
    QSpacerItem *listsSeparator;
    QLabel *labelActive;
    QListWidget *listWidgetAvailable;
    QSpacerItem *bottomSpacer;
    QHBoxLayout *bottomBox;
    QLabel *labelAcceptHint;
    QSpacerItem *bboxSpacer;
    QPushButton *pushButtonPreview;
    QPushButton *buttonClose;

    void setupUi(QDialog *mainFilterDialog)
    {
        if (mainFilterDialog->objectName().isEmpty())
            mainFilterDialog->setObjectName(QString::fromUtf8("mainFilterDialog"));
        mainFilterDialog->resize(913, 500);
        mainFilterDialog->setMinimumSize(QSize(0, 0));
        vboxLayout = new QVBoxLayout(mainFilterDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        listsGrid = new QGridLayout();
        listsGrid->setSpacing(6);
        listsGrid->setObjectName(QString::fromUtf8("listsGrid"));
        listsGrid->setContentsMargins(0, 0, 0, 0);
        listWidgetActive = new QListWidget(mainFilterDialog);
        listWidgetActive->setObjectName(QString::fromUtf8("listWidgetActive"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(listWidgetActive->sizePolicy().hasHeightForWidth());
        listWidgetActive->setSizePolicy(sizePolicy);
        listWidgetActive->setMinimumSize(QSize(340, 360));
        listWidgetActive->setSpacing(2);

        listsGrid->addWidget(listWidgetActive, 1, 5, 4, 2);

        listFilterCategory = new QListWidget(mainFilterDialog);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-transform.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-transition.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-interlacing.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-colors.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem3->setIcon(icon3);
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-noise.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem4->setIcon(icon4);
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-sharpness.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem5->setIcon(icon5);
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-subtitles.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem6->setIcon(icon6);
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-opengl.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem7 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem7->setIcon(icon7);
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-artistic.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem8 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem8->setIcon(icon8);
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/filter-category-misc.png"), QSize(), QIcon::Normal, QIcon::Off);
        QListWidgetItem *__qlistwidgetitem9 = new QListWidgetItem(listFilterCategory);
        __qlistwidgetitem9->setIcon(icon9);
        listFilterCategory->setObjectName(QString::fromUtf8("listFilterCategory"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(listFilterCategory->sizePolicy().hasHeightForWidth());
        listFilterCategory->setSizePolicy(sizePolicy1);
        listFilterCategory->setMinimumSize(QSize(100, 360));
        listFilterCategory->setSelectionBehavior(QAbstractItemView::SelectRows);
        listFilterCategory->setIconSize(QSize(24, 24));
        listFilterCategory->setResizeMode(QListView::Adjust);
        listFilterCategory->setSpacing(3);

        listsGrid->addWidget(listFilterCategory, 1, 0, 4, 2);

        labelAvailable = new QLabel(mainFilterDialog);
        labelAvailable->setObjectName(QString::fromUtf8("labelAvailable"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(labelAvailable->sizePolicy().hasHeightForWidth());
        labelAvailable->setSizePolicy(sizePolicy2);
        labelAvailable->setTextFormat(Qt::RichText);

        listsGrid->addWidget(labelAvailable, 0, 2, 1, 1);

        listsSeparator = new QSpacerItem(12, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        listsGrid->addItem(listsSeparator, 1, 4, 1, 1);

        labelActive = new QLabel(mainFilterDialog);
        labelActive->setObjectName(QString::fromUtf8("labelActive"));
        sizePolicy2.setHeightForWidth(labelActive->sizePolicy().hasHeightForWidth());
        labelActive->setSizePolicy(sizePolicy2);

        listsGrid->addWidget(labelActive, 0, 5, 1, 1);

        listWidgetAvailable = new QListWidget(mainFilterDialog);
        listWidgetAvailable->setObjectName(QString::fromUtf8("listWidgetAvailable"));
        sizePolicy.setHeightForWidth(listWidgetAvailable->sizePolicy().hasHeightForWidth());
        listWidgetAvailable->setSizePolicy(sizePolicy);
        listWidgetAvailable->setMinimumSize(QSize(340, 360));
        listWidgetAvailable->setSpacing(2);

        listsGrid->addWidget(listWidgetAvailable, 1, 2, 4, 2);


        vboxLayout->addLayout(listsGrid);

        bottomSpacer = new QSpacerItem(707, 16, QSizePolicy::Minimum, QSizePolicy::Fixed);

        vboxLayout->addItem(bottomSpacer);

        bottomBox = new QHBoxLayout();
        bottomBox->setSpacing(6);
        bottomBox->setObjectName(QString::fromUtf8("bottomBox"));
        bottomBox->setContentsMargins(0, 0, 0, 0);
        labelAcceptHint = new QLabel(mainFilterDialog);
        labelAcceptHint->setObjectName(QString::fromUtf8("labelAcceptHint"));

        bottomBox->addWidget(labelAcceptHint);

        bboxSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        bottomBox->addItem(bboxSpacer);

        pushButtonPreview = new QPushButton(mainFilterDialog);
        pushButtonPreview->setObjectName(QString::fromUtf8("pushButtonPreview"));
        QIcon icon10;
        icon10.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/thumbnail.png"), QSize(), QIcon::Normal, QIcon::Off);
        pushButtonPreview->setIcon(icon10);

        bottomBox->addWidget(pushButtonPreview);

        buttonClose = new QPushButton(mainFilterDialog);
        buttonClose->setObjectName(QString::fromUtf8("buttonClose"));
        QIcon icon11;
        icon11.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/close.png"), QSize(), QIcon::Normal, QIcon::Off);
        buttonClose->setIcon(icon11);

        bottomBox->addWidget(buttonClose);


        vboxLayout->addLayout(bottomBox);

        QWidget::setTabOrder(listFilterCategory, listWidgetAvailable);
        QWidget::setTabOrder(listWidgetAvailable, listWidgetActive);
        QWidget::setTabOrder(listWidgetActive, pushButtonPreview);
        QWidget::setTabOrder(pushButtonPreview, buttonClose);

        retranslateUi(mainFilterDialog);

        listFilterCategory->setCurrentRow(-1);
        buttonClose->setDefault(true);


        QMetaObject::connectSlotsByName(mainFilterDialog);
    } // setupUi

    void retranslateUi(QDialog *mainFilterDialog)
    {
        mainFilterDialog->setWindowTitle(QCoreApplication::translate("mainFilterDialog", "Video Filter Manager", nullptr));

        const bool __sortingEnabled = listFilterCategory->isSortingEnabled();
        listFilterCategory->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listFilterCategory->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("mainFilterDialog", "Transform", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = listFilterCategory->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("mainFilterDialog", "Transition", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = listFilterCategory->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("mainFilterDialog", "Interlacing", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = listFilterCategory->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("mainFilterDialog", "Colors", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = listFilterCategory->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("mainFilterDialog", "Noise", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = listFilterCategory->item(5);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("mainFilterDialog", "Sharpness", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = listFilterCategory->item(6);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("mainFilterDialog", "Subtitles", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = listFilterCategory->item(7);
        ___qlistwidgetitem7->setText(QCoreApplication::translate("mainFilterDialog", "OpenGl", nullptr));
        QListWidgetItem *___qlistwidgetitem8 = listFilterCategory->item(8);
        ___qlistwidgetitem8->setText(QCoreApplication::translate("mainFilterDialog", "Artistic", nullptr));
        QListWidgetItem *___qlistwidgetitem9 = listFilterCategory->item(9);
        ___qlistwidgetitem9->setText(QCoreApplication::translate("mainFilterDialog", "Miscellaneous", nullptr));
        listFilterCategory->setSortingEnabled(__sortingEnabled);

        labelAvailable->setText(QCoreApplication::translate("mainFilterDialog", "<big><b>Available Filters</b></big>", nullptr));
        labelActive->setText(QCoreApplication::translate("mainFilterDialog", "<big><b>Active Filters</b></big>", nullptr));
        labelAcceptHint->setText(QCoreApplication::translate("mainFilterDialog", "Press Ctrl + Enter to accept the dialog", nullptr));
        pushButtonPreview->setText(QCoreApplication::translate("mainFilterDialog", "&Preview", nullptr));
        buttonClose->setText(QCoreApplication::translate("mainFilterDialog", "&Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class mainFilterDialog: public Ui_mainFilterDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINFILTER_H
