/********************************************************************************
** Form generated from reading UI file 'fitToSize.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FITTOSIZE_H
#define UI_FITTOSIZE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_fitToSizeDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QSpinBox *spinBoxWidth;
    QSpacerItem *spacerItem;
    QLabel *label_2;
    QSpinBox *spinBoxHeight;
    QSpacerItem *spacerItem1;
    QComboBox *comboBoxRoundup;
    QHBoxLayout *hboxLayout1;
    QLabel *label_6;
    QComboBox *comboBoxAlgo;
    QSpacerItem *spacerItem2;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout2;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout3;
    QLabel *label_8;
    QSpacerItem *spacerItem3;
    QLabel *label_5;
    QSpacerItem *spacerItem4;
    QLabel *label_9;
    QSlider *horizontalSlider;
    QSpinBox *percentageSpinBox;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QComboBox *comboBoxPad;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QLabel *labelStretchSize;
    QLabel *labelInputSize;
    QLabel *labelCurrentInputDimensions;
    QLabel *labelResizedTo;
    QLabel *labelStretchError;
    QLabel *labelRequiredPadding;
    QLabel *labelPadding;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacerItem5;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *fitToSizeDialog)
    {
        if (fitToSizeDialog->objectName().isEmpty())
            fitToSizeDialog->setObjectName(QString::fromUtf8("fitToSizeDialog"));
        fitToSizeDialog->resize(604, 445);
        vboxLayout = new QVBoxLayout(fitToSizeDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        groupBox = new QGroupBox(fitToSizeDialog);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        vboxLayout1 = new QVBoxLayout(groupBox);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        hboxLayout->addWidget(label);

        spinBoxWidth = new QSpinBox(groupBox);
        spinBoxWidth->setObjectName(QString::fromUtf8("spinBoxWidth"));
        spinBoxWidth->setMinimum(16);
        spinBoxWidth->setMaximum(8192);
        spinBoxWidth->setSingleStep(2);

        hboxLayout->addWidget(spinBoxWidth);

        spacerItem = new QSpacerItem(30, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        hboxLayout->addWidget(label_2);

        spinBoxHeight = new QSpinBox(groupBox);
        spinBoxHeight->setObjectName(QString::fromUtf8("spinBoxHeight"));
        spinBoxHeight->setMinimum(16);
        spinBoxHeight->setMaximum(8192);
        spinBoxHeight->setSingleStep(2);

        hboxLayout->addWidget(spinBoxHeight);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem1);

        comboBoxRoundup = new QComboBox(groupBox);
        comboBoxRoundup->addItem(QString());
        comboBoxRoundup->addItem(QString());
        comboBoxRoundup->addItem(QString());
        comboBoxRoundup->addItem(QString());
        comboBoxRoundup->setObjectName(QString::fromUtf8("comboBoxRoundup"));
        comboBoxRoundup->setMinimumSize(QSize(256, 0));

        hboxLayout->addWidget(comboBoxRoundup);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        label_6 = new QLabel(groupBox);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        hboxLayout1->addWidget(label_6);

        comboBoxAlgo = new QComboBox(groupBox);
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->setObjectName(QString::fromUtf8("comboBoxAlgo"));

        hboxLayout1->addWidget(comboBoxAlgo);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem2);


        vboxLayout1->addLayout(hboxLayout1);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(fitToSizeDialog);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        vboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(12);
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(6);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        vboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName(QString::fromUtf8("hboxLayout3"));
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        hboxLayout3->addWidget(label_8);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout3->addItem(spacerItem3);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        hboxLayout3->addWidget(label_5);

        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout3->addItem(spacerItem4);

        label_9 = new QLabel(groupBox_2);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        hboxLayout3->addWidget(label_9);


        vboxLayout3->addLayout(hboxLayout3);

        horizontalSlider = new QSlider(groupBox_2);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setMinimum(0);
        horizontalSlider->setMaximum(100);
        horizontalSlider->setValue(0);
        horizontalSlider->setOrientation(Qt::Horizontal);

        vboxLayout3->addWidget(horizontalSlider);


        hboxLayout2->addLayout(vboxLayout3);

        percentageSpinBox = new QSpinBox(groupBox_2);
        percentageSpinBox->setObjectName(QString::fromUtf8("percentageSpinBox"));
        percentageSpinBox->setMinimum(0);
        percentageSpinBox->setMaximum(100);
        percentageSpinBox->setValue(0);

        hboxLayout2->addWidget(percentageSpinBox);


        vboxLayout2->addLayout(hboxLayout2);


        verticalLayout->addLayout(vboxLayout2);


        vboxLayout->addWidget(groupBox_2);

        groupBox_4 = new QGroupBox(fitToSizeDialog);
        groupBox_4->setObjectName(QString::fromUtf8("groupBox_4"));
        verticalLayout_3 = new QVBoxLayout(groupBox_4);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        comboBoxPad = new QComboBox(groupBox_4);
        comboBoxPad->addItem(QString());
        comboBoxPad->addItem(QString());
        comboBoxPad->setObjectName(QString::fromUtf8("comboBoxPad"));

        horizontalLayout->addWidget(comboBoxPad);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout);


        vboxLayout->addWidget(groupBox_4);

        groupBox_3 = new QGroupBox(fitToSizeDialog);
        groupBox_3->setObjectName(QString::fromUtf8("groupBox_3"));
        verticalLayout_2 = new QVBoxLayout(groupBox_3);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        labelStretchSize = new QLabel(groupBox_3);
        labelStretchSize->setObjectName(QString::fromUtf8("labelStretchSize"));

        gridLayout->addWidget(labelStretchSize, 1, 1, 1, 1);

        labelInputSize = new QLabel(groupBox_3);
        labelInputSize->setObjectName(QString::fromUtf8("labelInputSize"));

        gridLayout->addWidget(labelInputSize, 0, 1, 1, 1);

        labelCurrentInputDimensions = new QLabel(groupBox_3);
        labelCurrentInputDimensions->setObjectName(QString::fromUtf8("labelCurrentInputDimensions"));

        gridLayout->addWidget(labelCurrentInputDimensions, 0, 0, 1, 1);

        labelResizedTo = new QLabel(groupBox_3);
        labelResizedTo->setObjectName(QString::fromUtf8("labelResizedTo"));

        gridLayout->addWidget(labelResizedTo, 1, 0, 1, 1);

        labelStretchError = new QLabel(groupBox_3);
        labelStretchError->setObjectName(QString::fromUtf8("labelStretchError"));

        gridLayout->addWidget(labelStretchError, 1, 2, 1, 1);

        labelRequiredPadding = new QLabel(groupBox_3);
        labelRequiredPadding->setObjectName(QString::fromUtf8("labelRequiredPadding"));

        gridLayout->addWidget(labelRequiredPadding, 2, 0, 1, 1);

        labelPadding = new QLabel(groupBox_3);
        labelPadding->setObjectName(QString::fromUtf8("labelPadding"));

        gridLayout->addWidget(labelPadding, 2, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 3, 1, 1);


        verticalLayout_2->addLayout(gridLayout);


        vboxLayout->addWidget(groupBox_3);

        spacerItem5 = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        vboxLayout->addItem(spacerItem5);

        buttonBox = new QDialogButtonBox(fitToSizeDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);

        QWidget::setTabOrder(spinBoxWidth, spinBoxHeight);
        QWidget::setTabOrder(spinBoxHeight, comboBoxRoundup);
        QWidget::setTabOrder(comboBoxRoundup, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, percentageSpinBox);
        QWidget::setTabOrder(percentageSpinBox, comboBoxAlgo);

        retranslateUi(fitToSizeDialog);
        QObject::connect(buttonBox, SIGNAL(rejected()), fitToSizeDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(fitToSizeDialog);
    } // setupUi

    void retranslateUi(QDialog *fitToSizeDialog)
    {
        fitToSizeDialog->setWindowTitle(QCoreApplication::translate("fitToSizeDialog", "Fit to size", nullptr));
        groupBox->setTitle(QCoreApplication::translate("fitToSizeDialog", "Output settings", nullptr));
        label->setText(QCoreApplication::translate("fitToSizeDialog", "Width:", nullptr));
        label_2->setText(QCoreApplication::translate("fitToSizeDialog", "Height:", nullptr));
        comboBoxRoundup->setItemText(0, QCoreApplication::translate("fitToSizeDialog", "No rounding", nullptr));
        comboBoxRoundup->setItemText(1, QCoreApplication::translate("fitToSizeDialog", "Round to the Nearest Multiple of 16", nullptr));
        comboBoxRoundup->setItemText(2, QCoreApplication::translate("fitToSizeDialog", "Round to the Nearest Multiple of 8", nullptr));
        comboBoxRoundup->setItemText(3, QCoreApplication::translate("fitToSizeDialog", "Round to the Nearest Multiple of 4", nullptr));

        label_6->setText(QCoreApplication::translate("fitToSizeDialog", "Resize Method:", nullptr));
        comboBoxAlgo->setItemText(0, QCoreApplication::translate("fitToSizeDialog", "Bilinear", nullptr));
        comboBoxAlgo->setItemText(1, QCoreApplication::translate("fitToSizeDialog", "Bicubic", nullptr));
        comboBoxAlgo->setItemText(2, QCoreApplication::translate("fitToSizeDialog", "Lanczos-3", nullptr));
        comboBoxAlgo->setItemText(3, QCoreApplication::translate("fitToSizeDialog", "Spline", nullptr));

        groupBox_2->setTitle(QCoreApplication::translate("fitToSizeDialog", "Aspect ratio tolerance", nullptr));
        label_8->setText(QCoreApplication::translate("fitToSizeDialog", "0%", nullptr));
        label_5->setText(QCoreApplication::translate("fitToSizeDialog", "Percent", nullptr));
        label_9->setText(QCoreApplication::translate("fitToSizeDialog", "100%", nullptr));
        groupBox_4->setTitle(QCoreApplication::translate("fitToSizeDialog", "Padding", nullptr));
        comboBoxPad->setItemText(0, QCoreApplication::translate("fitToSizeDialog", "black bars", nullptr));
        comboBoxPad->setItemText(1, QCoreApplication::translate("fitToSizeDialog", "echo", nullptr));

        groupBox_3->setTitle(QCoreApplication::translate("fitToSizeDialog", "Details", nullptr));
        labelStretchSize->setText(QString());
        labelInputSize->setText(QString());
        labelCurrentInputDimensions->setText(QCoreApplication::translate("fitToSizeDialog", "Current input dimensions:", nullptr));
        labelResizedTo->setText(QCoreApplication::translate("fitToSizeDialog", "Resized to:", nullptr));
        labelStretchError->setText(QString());
        labelRequiredPadding->setText(QCoreApplication::translate("fitToSizeDialog", "Required padding:", nullptr));
        labelPadding->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class fitToSizeDialog: public Ui_fitToSizeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FITTOSIZE_H
