/****************************************************************************
** Meta object code from reading C++ file 'Q_mainfilter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../avidemux/qt4/ADM_userInterfaces/ADM_filters/Q_mainfilter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Q_mainfilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_FilterItemEventFilter_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FilterItemEventFilter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FilterItemEventFilter_t qt_meta_stringdata_FilterItemEventFilter = {
    {
QT_MOC_LITERAL(0, 0, 21) // "FilterItemEventFilter"

    },
    "FilterItemEventFilter"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FilterItemEventFilter[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void FilterItemEventFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject FilterItemEventFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_FilterItemEventFilter.data,
    qt_meta_data_FilterItemEventFilter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FilterItemEventFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FilterItemEventFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FilterItemEventFilter.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FilterItemEventFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_FilterItemDelegate_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FilterItemDelegate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FilterItemDelegate_t qt_meta_stringdata_FilterItemDelegate = {
    {
QT_MOC_LITERAL(0, 0, 18) // "FilterItemDelegate"

    },
    "FilterItemDelegate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FilterItemDelegate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void FilterItemDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject FilterItemDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<QItemDelegate::staticMetaObject>(),
    qt_meta_stringdata_FilterItemDelegate.data,
    qt_meta_data_FilterItemDelegate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FilterItemDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FilterItemDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FilterItemDelegate.stringdata0))
        return static_cast<void*>(this);
    return QItemDelegate::qt_metacast(_clname);
}

int FilterItemDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QItemDelegate::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_filtermainWindow_t {
    QByteArrayData data[27];
    char stringdata0[309];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_filtermainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_filtermainWindow_t qt_meta_stringdata_filtermainWindow = {
    {
QT_MOC_LITERAL(0, 0, 16), // "filtermainWindow"
QT_MOC_LITERAL(1, 17, 3), // "add"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 1), // "b"
QT_MOC_LITERAL(4, 24, 6), // "moveUp"
QT_MOC_LITERAL(5, 31, 8), // "moveDown"
QT_MOC_LITERAL(6, 40, 13), // "togglePartial"
QT_MOC_LITERAL(7, 54, 11), // "makePartial"
QT_MOC_LITERAL(8, 66, 14), // "absolvePartial"
QT_MOC_LITERAL(9, 81, 13), // "toggleEnabled"
QT_MOC_LITERAL(10, 95, 9), // "duplicate"
QT_MOC_LITERAL(11, 105, 6), // "remove"
QT_MOC_LITERAL(12, 112, 9), // "configure"
QT_MOC_LITERAL(13, 122, 17), // "activeDoubleClick"
QT_MOC_LITERAL(14, 140, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(15, 157, 4), // "item"
QT_MOC_LITERAL(16, 162, 14), // "allDoubleClick"
QT_MOC_LITERAL(17, 177, 17), // "filterFamilyClick"
QT_MOC_LITERAL(18, 195, 7), // "preview"
QT_MOC_LITERAL(19, 203, 12), // "closePreview"
QT_MOC_LITERAL(20, 216, 7), // "addSlot"
QT_MOC_LITERAL(21, 224, 12), // "removeAction"
QT_MOC_LITERAL(22, 237, 15), // "configureAction"
QT_MOC_LITERAL(23, 253, 15), // "duplicateAction"
QT_MOC_LITERAL(24, 269, 21), // "activeListContextMenu"
QT_MOC_LITERAL(25, 291, 3), // "pos"
QT_MOC_LITERAL(26, 295, 13) // "rowsMovedSlot"

    },
    "filtermainWindow\0add\0\0b\0moveUp\0moveDown\0"
    "togglePartial\0makePartial\0absolvePartial\0"
    "toggleEnabled\0duplicate\0remove\0configure\0"
    "activeDoubleClick\0QListWidgetItem*\0"
    "item\0allDoubleClick\0filterFamilyClick\0"
    "preview\0closePreview\0addSlot\0removeAction\0"
    "configureAction\0duplicateAction\0"
    "activeListContextMenu\0pos\0rowsMovedSlot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_filtermainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  124,    2, 0x0a /* Public */,
       4,    0,  127,    2, 0x0a /* Public */,
       5,    0,  128,    2, 0x0a /* Public */,
       6,    0,  129,    2, 0x0a /* Public */,
       7,    0,  130,    2, 0x0a /* Public */,
       8,    0,  131,    2, 0x0a /* Public */,
       9,    0,  132,    2, 0x0a /* Public */,
      10,    0,  133,    2, 0x0a /* Public */,
      11,    1,  134,    2, 0x0a /* Public */,
      12,    1,  137,    2, 0x0a /* Public */,
      13,    1,  140,    2, 0x0a /* Public */,
      16,    1,  143,    2, 0x0a /* Public */,
      17,    1,  146,    2, 0x0a /* Public */,
      17,    1,  149,    2, 0x0a /* Public */,
      18,    1,  152,    2, 0x0a /* Public */,
      19,    0,  155,    2, 0x0a /* Public */,
      20,    0,  156,    2, 0x0a /* Public */,
      21,    0,  157,    2, 0x0a /* Public */,
      22,    0,  158,    2, 0x0a /* Public */,
      23,    0,  159,    2, 0x0a /* Public */,
      24,    1,  160,    2, 0x0a /* Public */,
      26,    0,  163,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   25,
    QMetaType::Void,

       0        // eod
};

void filtermainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<filtermainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->add((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->moveUp(); break;
        case 2: _t->moveDown(); break;
        case 3: _t->togglePartial(); break;
        case 4: _t->makePartial(); break;
        case 5: _t->absolvePartial(); break;
        case 6: _t->toggleEnabled(); break;
        case 7: _t->duplicate(); break;
        case 8: _t->remove((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->configure((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->activeDoubleClick((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 11: _t->allDoubleClick((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 12: _t->filterFamilyClick((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 13: _t->filterFamilyClick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->preview((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->closePreview(); break;
        case 16: _t->addSlot(); break;
        case 17: _t->removeAction(); break;
        case 18: _t->configureAction(); break;
        case 19: _t->duplicateAction(); break;
        case 20: _t->activeListContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 21: _t->rowsMovedSlot(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject filtermainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_filtermainWindow.data,
    qt_meta_data_filtermainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *filtermainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *filtermainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_filtermainWindow.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int filtermainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 22;
    }
    return _id;
}
struct qt_meta_stringdata_filterquickWindow_t {
    QByteArrayData data[10];
    char stringdata0[92];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_filterquickWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_filterquickWindow_t qt_meta_stringdata_filterquickWindow = {
    {
QT_MOC_LITERAL(0, 0, 17), // "filterquickWindow"
QT_MOC_LITERAL(1, 18, 3), // "add"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 1), // "b"
QT_MOC_LITERAL(4, 25, 14), // "allDoubleClick"
QT_MOC_LITERAL(5, 40, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(6, 57, 4), // "item"
QT_MOC_LITERAL(7, 62, 7), // "addSlot"
QT_MOC_LITERAL(8, 70, 12), // "searchChange"
QT_MOC_LITERAL(9, 83, 8) // "newValue"

    },
    "filterquickWindow\0add\0\0b\0allDoubleClick\0"
    "QListWidgetItem*\0item\0addSlot\0"
    "searchChange\0newValue"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_filterquickWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x0a /* Public */,
       4,    1,   37,    2, 0x0a /* Public */,
       7,    0,   40,    2, 0x0a /* Public */,
       8,    1,   41,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    9,

       0        // eod
};

void filterquickWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<filterquickWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->add((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->allDoubleClick((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 2: _t->addSlot(); break;
        case 3: _t->searchChange((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject filterquickWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_filterquickWindow.data,
    qt_meta_data_filterquickWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *filterquickWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *filterquickWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_filterquickWindow.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int filterquickWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
