/********************************************************************************
** Form generated from reading UI file 'license.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LICENSE_H
#define UI_LICENSE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_licenseDialog
{
public:
    QVBoxLayout *vboxLayout;
    QTextEdit *licenseTextEdit;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QPushButton *okButton;

    void setupUi(QDialog *licenseDialog)
    {
        if (licenseDialog->objectName().isEmpty())
            licenseDialog->setObjectName(QString::fromUtf8("licenseDialog"));
        licenseDialog->resize(624, 422);
        vboxLayout = new QVBoxLayout(licenseDialog);
#ifndef Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        licenseTextEdit = new QTextEdit(licenseDialog);
        licenseTextEdit->setObjectName(QString::fromUtf8("licenseTextEdit"));
        licenseTextEdit->setFrameShape(QFrame::StyledPanel);
        licenseTextEdit->setAutoFormatting(QTextEdit::AutoNone);
        licenseTextEdit->setReadOnly(true);

        vboxLayout->addWidget(licenseTextEdit);

        hboxLayout = new QHBoxLayout();
#ifndef Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        spacerItem = new QSpacerItem(131, 31, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        okButton = new QPushButton(licenseDialog);
        okButton->setObjectName(QString::fromUtf8("okButton"));

        hboxLayout->addWidget(okButton);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(licenseDialog);
        QObject::connect(okButton, SIGNAL(clicked()), licenseDialog, SLOT(accept()));

        QMetaObject::connectSlotsByName(licenseDialog);
    } // setupUi

    void retranslateUi(QDialog *licenseDialog)
    {
        licenseDialog->setWindowTitle(QCoreApplication::translate("licenseDialog", "License", nullptr));
        okButton->setText(QCoreApplication::translate("licenseDialog", "OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class licenseDialog: public Ui_licenseDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LICENSE_H
