/********************************************************************************
** Form generated from reading UI file 'delogoHQ.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DELOGOHQ_H
#define UI_DELOGOHQ_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_delogoHQDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBoxMask;
    QGridLayout *gridLayout_2;
    QPushButton *pushButtonSave;
    QLineEdit *lineEditImage;
    QPushButton *pushButtonLoad;
    QGroupBox *groupBoxPostProc;
    QGridLayout *gridLayout;
    QLabel *labelGradient;
    QLabel *labelBlur;
    QSpinBox *spinBoxGradient;
    QSlider *horizontalSliderBlur;
    QSlider *horizontalSliderGradient;
    QSpinBox *spinBoxBlur;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *delogoHQDialog)
    {
        if (delogoHQDialog->objectName().isEmpty())
            delogoHQDialog->setObjectName(QString::fromUtf8("delogoHQDialog"));
        delogoHQDialog->resize(641, 456);
        verticalLayout = new QVBoxLayout(delogoHQDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        groupBoxMask = new QGroupBox(delogoHQDialog);
        groupBoxMask->setObjectName(QString::fromUtf8("groupBoxMask"));
        gridLayout_2 = new QGridLayout(groupBoxMask);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        gridLayout_2->setContentsMargins(-1, -1, -1, 0);
        pushButtonSave = new QPushButton(groupBoxMask);
        pushButtonSave->setObjectName(QString::fromUtf8("pushButtonSave"));

        gridLayout_2->addWidget(pushButtonSave, 1, 0, 1, 1);

        lineEditImage = new QLineEdit(groupBoxMask);
        lineEditImage->setObjectName(QString::fromUtf8("lineEditImage"));
        lineEditImage->setEnabled(false);
        lineEditImage->setMinimumSize(QSize(80, 0));

        gridLayout_2->addWidget(lineEditImage, 1, 2, 1, 1);

        pushButtonLoad = new QPushButton(groupBoxMask);
        pushButtonLoad->setObjectName(QString::fromUtf8("pushButtonLoad"));

        gridLayout_2->addWidget(pushButtonLoad, 1, 1, 1, 1);


        verticalLayout->addWidget(groupBoxMask);

        groupBoxPostProc = new QGroupBox(delogoHQDialog);
        groupBoxPostProc->setObjectName(QString::fromUtf8("groupBoxPostProc"));
        gridLayout = new QGridLayout(groupBoxPostProc);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        labelGradient = new QLabel(groupBoxPostProc);
        labelGradient->setObjectName(QString::fromUtf8("labelGradient"));

        gridLayout->addWidget(labelGradient, 0, 4, 1, 1);

        labelBlur = new QLabel(groupBoxPostProc);
        labelBlur->setObjectName(QString::fromUtf8("labelBlur"));

        gridLayout->addWidget(labelBlur, 0, 0, 1, 1);

        spinBoxGradient = new QSpinBox(groupBoxPostProc);
        spinBoxGradient->setObjectName(QString::fromUtf8("spinBoxGradient"));
        spinBoxGradient->setMaximum(100);
        spinBoxGradient->setSingleStep(1);

        gridLayout->addWidget(spinBoxGradient, 0, 6, 1, 1);

        horizontalSliderBlur = new QSlider(groupBoxPostProc);
        horizontalSliderBlur->setObjectName(QString::fromUtf8("horizontalSliderBlur"));
        horizontalSliderBlur->setMaximum(100);
        horizontalSliderBlur->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderBlur, 0, 1, 1, 1);

        horizontalSliderGradient = new QSlider(groupBoxPostProc);
        horizontalSliderGradient->setObjectName(QString::fromUtf8("horizontalSliderGradient"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(horizontalSliderGradient->sizePolicy().hasHeightForWidth());
        horizontalSliderGradient->setSizePolicy(sizePolicy);
        horizontalSliderGradient->setMaximum(100);
        horizontalSliderGradient->setSingleStep(1);
        horizontalSliderGradient->setPageStep(10);
        horizontalSliderGradient->setOrientation(Qt::Horizontal);
        horizontalSliderGradient->setTickPosition(QSlider::NoTicks);
        horizontalSliderGradient->setTickInterval(1);

        gridLayout->addWidget(horizontalSliderGradient, 0, 5, 1, 1);

        spinBoxBlur = new QSpinBox(groupBoxPostProc);
        spinBoxBlur->setObjectName(QString::fromUtf8("spinBoxBlur"));
        spinBoxBlur->setMaximum(100);

        gridLayout->addWidget(spinBoxBlur, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(30, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);


        verticalLayout->addWidget(groupBoxPostProc);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(delogoHQDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(delogoHQDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(delogoHQDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Help|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(pushButtonSave, pushButtonLoad);
        QWidget::setTabOrder(pushButtonLoad, horizontalSliderBlur);
        QWidget::setTabOrder(horizontalSliderBlur, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, graphicsView);
        QWidget::setTabOrder(graphicsView, lineEditImage);

        retranslateUi(delogoHQDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), delogoHQDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), delogoHQDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(delogoHQDialog);
    } // setupUi

    void retranslateUi(QDialog *delogoHQDialog)
    {
        delogoHQDialog->setWindowTitle(QCoreApplication::translate("delogoHQDialog", "DelogoHQ", nullptr));
        groupBoxMask->setTitle(QCoreApplication::translate("delogoHQDialog", "Mask", nullptr));
        pushButtonSave->setText(QCoreApplication::translate("delogoHQDialog", "Save current frame...", nullptr));
        pushButtonLoad->setText(QCoreApplication::translate("delogoHQDialog", "Load mask", nullptr));
        groupBoxPostProc->setTitle(QCoreApplication::translate("delogoHQDialog", "Post-processing", nullptr));
        labelGradient->setText(QCoreApplication::translate("delogoHQDialog", "Gradient", nullptr));
        labelBlur->setText(QCoreApplication::translate("delogoHQDialog", "Blur", nullptr));
    } // retranslateUi

};

namespace Ui {
    class delogoHQDialog: public Ui_delogoHQDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DELOGOHQ_H
