// automatically generated by admSerialization.py, do not edit!
extern const ADM_paramList logo_param[]={
 {"x",offsetof(logo,x),"uint32_t",ADM_param_uint32_t},
 {"y",offsetof(logo,y),"uint32_t",ADM_param_uint32_t},
 {"alpha",offsetof(logo,alpha),"uint32_t",ADM_param_uint32_t},
 {"logoImageFile",offsetof(logo,logoImageFile),"std::string",ADM_param_stdstring},
 {"fade",offsetof(logo,fade),"uint32_t",ADM_param_uint32_t},
 {"scale",offsetof(logo,scale),"float",ADM_param_float},
{NULL,0,NULL}
};
