/********************************************************************************
** Form generated from reading UI file 'props.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROPS_H
#define UI_PROPS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_propsDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBoxVideo;
    QGridLayout *gridLayout;
    QLabel *label4CC;
    QLabel *label4CCValue;
    QLabel *labelImageSize;
    QLabel *labelImageSizeValue;
    QLabel *labelAspectRatio;
    QLabel *labelAspectRatioValue;
    QLabel *labelFrameRate;
    QLabel *labelFrameRateValue;
    QLabel *labelVideoBitrate;
    QLabel *labelVideoBitrateValue;
    QLabel *labelVideoDuration;
    QLabel *labelVideoDurationValue;
    QFrame *line;
    QLabel *labelPixelFormat;
    QLabel *labelPixelFormatValue;
    QLabel *labelColorRange;
    QLabel *labelColorRangeValue;
    QLabel *labelColorPrimaries;
    QLabel *labelColorPrimariesValue;
    QLabel *labelTransferCharacteristics;
    QLabel *labelTransferCharacteristicsValue;
    QLabel *labelColorSpace;
    QLabel *labelColorSpaceValue;
    QGroupBox *groupBoxExtradata;
    QGridLayout *gridLayout1;
    QLabel *labelExtraDataSizeValue;
    QLabel *labelExtraDataSize;
    QLineEdit *lineEditExtraData;
    QLabel *labelExtraData;
    QGroupBox *groupBoxAudio;
    QGridLayout *gridLayout2;
    QLabel *labelACodec;
    QLabel *labelACodecName;
    QLabel *labelChannels;
    QLabel *labelChannelsValue;
    QLabel *labelAudioBitrate;
    QLabel *labelAudioBitrateValue;
    QLabel *labelFrequency;
    QLabel *labelFrequencyValue;
    QLabel *labelAudioDuration;
    QLabel *labelAudioDurationValue;
    QHBoxLayout *horizontalLayout;
    QPushButton *pushButton_c2c;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushButton_ok;

    void setupUi(QDialog *propsDialog)
    {
        if (propsDialog->objectName().isEmpty())
            propsDialog->setObjectName(QString::fromUtf8("propsDialog"));
        propsDialog->resize(400, 586);
        verticalLayout = new QVBoxLayout(propsDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        groupBoxVideo = new QGroupBox(propsDialog);
        groupBoxVideo->setObjectName(QString::fromUtf8("groupBoxVideo"));
        groupBoxVideo->setFlat(false);
        gridLayout = new QGridLayout(groupBoxVideo);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        label4CC = new QLabel(groupBoxVideo);
        label4CC->setObjectName(QString::fromUtf8("label4CC"));

        gridLayout->addWidget(label4CC, 0, 0, 1, 1);

        label4CCValue = new QLabel(groupBoxVideo);
        label4CCValue->setObjectName(QString::fromUtf8("label4CCValue"));

        gridLayout->addWidget(label4CCValue, 0, 1, 1, 1);

        labelImageSize = new QLabel(groupBoxVideo);
        labelImageSize->setObjectName(QString::fromUtf8("labelImageSize"));

        gridLayout->addWidget(labelImageSize, 1, 0, 1, 1);

        labelImageSizeValue = new QLabel(groupBoxVideo);
        labelImageSizeValue->setObjectName(QString::fromUtf8("labelImageSizeValue"));

        gridLayout->addWidget(labelImageSizeValue, 1, 1, 1, 1);

        labelAspectRatio = new QLabel(groupBoxVideo);
        labelAspectRatio->setObjectName(QString::fromUtf8("labelAspectRatio"));

        gridLayout->addWidget(labelAspectRatio, 2, 0, 1, 1);

        labelAspectRatioValue = new QLabel(groupBoxVideo);
        labelAspectRatioValue->setObjectName(QString::fromUtf8("labelAspectRatioValue"));

        gridLayout->addWidget(labelAspectRatioValue, 2, 1, 1, 1);

        labelFrameRate = new QLabel(groupBoxVideo);
        labelFrameRate->setObjectName(QString::fromUtf8("labelFrameRate"));

        gridLayout->addWidget(labelFrameRate, 3, 0, 1, 1);

        labelFrameRateValue = new QLabel(groupBoxVideo);
        labelFrameRateValue->setObjectName(QString::fromUtf8("labelFrameRateValue"));

        gridLayout->addWidget(labelFrameRateValue, 3, 1, 1, 1);

        labelVideoBitrate = new QLabel(groupBoxVideo);
        labelVideoBitrate->setObjectName(QString::fromUtf8("labelVideoBitrate"));

        gridLayout->addWidget(labelVideoBitrate, 4, 0, 1, 1);

        labelVideoBitrateValue = new QLabel(groupBoxVideo);
        labelVideoBitrateValue->setObjectName(QString::fromUtf8("labelVideoBitrateValue"));

        gridLayout->addWidget(labelVideoBitrateValue, 4, 1, 1, 1);

        labelVideoDuration = new QLabel(groupBoxVideo);
        labelVideoDuration->setObjectName(QString::fromUtf8("labelVideoDuration"));

        gridLayout->addWidget(labelVideoDuration, 5, 0, 1, 1);

        labelVideoDurationValue = new QLabel(groupBoxVideo);
        labelVideoDurationValue->setObjectName(QString::fromUtf8("labelVideoDurationValue"));

        gridLayout->addWidget(labelVideoDurationValue, 5, 1, 1, 1);

        line = new QFrame(groupBoxVideo);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(line, 6, 0, 1, 2);

        labelPixelFormat = new QLabel(groupBoxVideo);
        labelPixelFormat->setObjectName(QString::fromUtf8("labelPixelFormat"));

        gridLayout->addWidget(labelPixelFormat, 7, 0, 1, 1);

        labelPixelFormatValue = new QLabel(groupBoxVideo);
        labelPixelFormatValue->setObjectName(QString::fromUtf8("labelPixelFormatValue"));

        gridLayout->addWidget(labelPixelFormatValue, 7, 1, 1, 1);

        labelColorRange = new QLabel(groupBoxVideo);
        labelColorRange->setObjectName(QString::fromUtf8("labelColorRange"));

        gridLayout->addWidget(labelColorRange, 8, 0, 1, 1);

        labelColorRangeValue = new QLabel(groupBoxVideo);
        labelColorRangeValue->setObjectName(QString::fromUtf8("labelColorRangeValue"));

        gridLayout->addWidget(labelColorRangeValue, 8, 1, 1, 1);

        labelColorPrimaries = new QLabel(groupBoxVideo);
        labelColorPrimaries->setObjectName(QString::fromUtf8("labelColorPrimaries"));

        gridLayout->addWidget(labelColorPrimaries, 9, 0, 1, 1);

        labelColorPrimariesValue = new QLabel(groupBoxVideo);
        labelColorPrimariesValue->setObjectName(QString::fromUtf8("labelColorPrimariesValue"));

        gridLayout->addWidget(labelColorPrimariesValue, 9, 1, 1, 1);

        labelTransferCharacteristics = new QLabel(groupBoxVideo);
        labelTransferCharacteristics->setObjectName(QString::fromUtf8("labelTransferCharacteristics"));

        gridLayout->addWidget(labelTransferCharacteristics, 10, 0, 1, 1);

        labelTransferCharacteristicsValue = new QLabel(groupBoxVideo);
        labelTransferCharacteristicsValue->setObjectName(QString::fromUtf8("labelTransferCharacteristicsValue"));

        gridLayout->addWidget(labelTransferCharacteristicsValue, 10, 1, 1, 1);

        labelColorSpace = new QLabel(groupBoxVideo);
        labelColorSpace->setObjectName(QString::fromUtf8("labelColorSpace"));

        gridLayout->addWidget(labelColorSpace, 11, 0, 1, 1);

        labelColorSpaceValue = new QLabel(groupBoxVideo);
        labelColorSpaceValue->setObjectName(QString::fromUtf8("labelColorSpaceValue"));

        gridLayout->addWidget(labelColorSpaceValue, 11, 1, 1, 1);


        verticalLayout->addWidget(groupBoxVideo);

        groupBoxExtradata = new QGroupBox(propsDialog);
        groupBoxExtradata->setObjectName(QString::fromUtf8("groupBoxExtradata"));
        gridLayout1 = new QGridLayout(groupBoxExtradata);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        labelExtraDataSizeValue = new QLabel(groupBoxExtradata);
        labelExtraDataSizeValue->setObjectName(QString::fromUtf8("labelExtraDataSizeValue"));

        gridLayout1->addWidget(labelExtraDataSizeValue, 0, 1, 1, 1);

        labelExtraDataSize = new QLabel(groupBoxExtradata);
        labelExtraDataSize->setObjectName(QString::fromUtf8("labelExtraDataSize"));

        gridLayout1->addWidget(labelExtraDataSize, 0, 0, 1, 1);

        lineEditExtraData = new QLineEdit(groupBoxExtradata);
        lineEditExtraData->setObjectName(QString::fromUtf8("lineEditExtraData"));
        lineEditExtraData->setReadOnly(true);

        gridLayout1->addWidget(lineEditExtraData, 1, 1, 1, 1);

        labelExtraData = new QLabel(groupBoxExtradata);
        labelExtraData->setObjectName(QString::fromUtf8("labelExtraData"));

        gridLayout1->addWidget(labelExtraData, 1, 0, 1, 1);


        verticalLayout->addWidget(groupBoxExtradata);

        groupBoxAudio = new QGroupBox(propsDialog);
        groupBoxAudio->setObjectName(QString::fromUtf8("groupBoxAudio"));
        groupBoxAudio->setFlat(false);
        gridLayout2 = new QGridLayout(groupBoxAudio);
        gridLayout2->setSpacing(6);
        gridLayout2->setObjectName(QString::fromUtf8("gridLayout2"));
        gridLayout2->setContentsMargins(9, 9, 9, 9);
        labelACodec = new QLabel(groupBoxAudio);
        labelACodec->setObjectName(QString::fromUtf8("labelACodec"));

        gridLayout2->addWidget(labelACodec, 0, 0, 1, 1);

        labelACodecName = new QLabel(groupBoxAudio);
        labelACodecName->setObjectName(QString::fromUtf8("labelACodecName"));

        gridLayout2->addWidget(labelACodecName, 0, 1, 1, 1);

        labelChannels = new QLabel(groupBoxAudio);
        labelChannels->setObjectName(QString::fromUtf8("labelChannels"));

        gridLayout2->addWidget(labelChannels, 1, 0, 1, 1);

        labelChannelsValue = new QLabel(groupBoxAudio);
        labelChannelsValue->setObjectName(QString::fromUtf8("labelChannelsValue"));

        gridLayout2->addWidget(labelChannelsValue, 1, 1, 1, 1);

        labelAudioBitrate = new QLabel(groupBoxAudio);
        labelAudioBitrate->setObjectName(QString::fromUtf8("labelAudioBitrate"));

        gridLayout2->addWidget(labelAudioBitrate, 2, 0, 1, 1);

        labelAudioBitrateValue = new QLabel(groupBoxAudio);
        labelAudioBitrateValue->setObjectName(QString::fromUtf8("labelAudioBitrateValue"));

        gridLayout2->addWidget(labelAudioBitrateValue, 2, 1, 1, 1);

        labelFrequency = new QLabel(groupBoxAudio);
        labelFrequency->setObjectName(QString::fromUtf8("labelFrequency"));

        gridLayout2->addWidget(labelFrequency, 3, 0, 1, 1);

        labelFrequencyValue = new QLabel(groupBoxAudio);
        labelFrequencyValue->setObjectName(QString::fromUtf8("labelFrequencyValue"));

        gridLayout2->addWidget(labelFrequencyValue, 3, 1, 1, 1);

        labelAudioDuration = new QLabel(groupBoxAudio);
        labelAudioDuration->setObjectName(QString::fromUtf8("labelAudioDuration"));

        gridLayout2->addWidget(labelAudioDuration, 4, 0, 1, 1);

        labelAudioDurationValue = new QLabel(groupBoxAudio);
        labelAudioDurationValue->setObjectName(QString::fromUtf8("labelAudioDurationValue"));

        gridLayout2->addWidget(labelAudioDurationValue, 4, 1, 1, 1);


        verticalLayout->addWidget(groupBoxAudio);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        pushButton_c2c = new QPushButton(propsDialog);
        pushButton_c2c->setObjectName(QString::fromUtf8("pushButton_c2c"));

        horizontalLayout->addWidget(pushButton_c2c);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pushButton_ok = new QPushButton(propsDialog);
        pushButton_ok->setObjectName(QString::fromUtf8("pushButton_ok"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pushButton_ok->sizePolicy().hasHeightForWidth());
        pushButton_ok->setSizePolicy(sizePolicy);
        pushButton_ok->setLayoutDirection(Qt::RightToLeft);

        horizontalLayout->addWidget(pushButton_ok);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(propsDialog);
        QObject::connect(pushButton_ok, SIGNAL(clicked()), propsDialog, SLOT(accept()));

        pushButton_ok->setDefault(true);


        QMetaObject::connectSlotsByName(propsDialog);
    } // setupUi

    void retranslateUi(QDialog *propsDialog)
    {
        propsDialog->setWindowTitle(QCoreApplication::translate("propsDialog", "Properties", nullptr));
        groupBoxVideo->setTitle(QCoreApplication::translate("propsDialog", "Video", nullptr));
        label4CC->setText(QCoreApplication::translate("propsDialog", "Codec 4CC:", nullptr));
        label4CCValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelImageSize->setText(QCoreApplication::translate("propsDialog", "Image Size:", nullptr));
        labelImageSizeValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelAspectRatio->setText(QCoreApplication::translate("propsDialog", "Aspect Ratio:", nullptr));
        labelAspectRatioValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelFrameRate->setText(QCoreApplication::translate("propsDialog", "Frame Rate:", nullptr));
        labelFrameRateValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelVideoBitrate->setText(QCoreApplication::translate("propsDialog", "Average Bitrate:", nullptr));
        labelVideoBitrateValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelVideoDuration->setText(QCoreApplication::translate("propsDialog", "Total Duration:", nullptr));
        labelVideoDurationValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelPixelFormat->setText(QCoreApplication::translate("propsDialog", "Pixel format:", nullptr));
        labelPixelFormatValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelColorRange->setText(QCoreApplication::translate("propsDialog", "Color range:", nullptr));
        labelColorRangeValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelColorPrimaries->setText(QCoreApplication::translate("propsDialog", "Color primaries:", nullptr));
        labelColorPrimariesValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelTransferCharacteristics->setText(QCoreApplication::translate("propsDialog", "Transfer characteristics:", nullptr));
        labelTransferCharacteristicsValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelColorSpace->setText(QCoreApplication::translate("propsDialog", "Color space:", nullptr));
        labelColorSpaceValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        groupBoxExtradata->setTitle(QCoreApplication::translate("propsDialog", "Video Codec Extradata", nullptr));
        labelExtraDataSizeValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelExtraDataSize->setText(QCoreApplication::translate("propsDialog", "Size:", nullptr));
        labelExtraData->setText(QCoreApplication::translate("propsDialog", "Extradata:", nullptr));
        groupBoxAudio->setTitle(QCoreApplication::translate("propsDialog", "Audio", nullptr));
        labelACodec->setText(QCoreApplication::translate("propsDialog", "Codec:", nullptr));
        labelACodecName->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelChannels->setText(QCoreApplication::translate("propsDialog", "Channels:", nullptr));
        labelChannelsValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelAudioBitrate->setText(QCoreApplication::translate("propsDialog", "Bitrate:", nullptr));
        labelAudioBitrateValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelFrequency->setText(QCoreApplication::translate("propsDialog", "Frequency:", nullptr));
        labelFrequencyValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        labelAudioDuration->setText(QCoreApplication::translate("propsDialog", "Total Duration:", nullptr));
        labelAudioDurationValue->setText(QCoreApplication::translate("propsDialog", "n/a", nullptr));
        pushButton_c2c->setText(QCoreApplication::translate("propsDialog", "Copy to Clipboard", nullptr));
        pushButton_ok->setText(QCoreApplication::translate("propsDialog", "OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class propsDialog: public Ui_propsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PROPS_H
