/****************************************************************************
** Meta object code from reading C++ file 'Q_x265.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../avidemux_plugins/ADM_videoEncoder/x265/qt4/Q_x265.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Q_x265.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_x265Dialog_t {
    QByteArrayData data[27];
    char stringdata0[620];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_x265Dialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_x265Dialog_t qt_meta_stringdata_x265Dialog = {
    {
QT_MOC_LITERAL(0, 0, 10), // "x265Dialog"
QT_MOC_LITERAL(1, 11, 40), // "useAdvancedConfigurationCheck..."
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 7), // "checked"
QT_MOC_LITERAL(4, 61, 22), // "meSpinBox_valueChanged"
QT_MOC_LITERAL(5, 84, 5), // "value"
QT_MOC_LITERAL(6, 90, 21), // "meSlider_valueChanged"
QT_MOC_LITERAL(7, 112, 29), // "refFramesSpinBox_valueChanged"
QT_MOC_LITERAL(8, 142, 30), // "maxBFramesSpinBox_valueChanged"
QT_MOC_LITERAL(9, 173, 37), // "bFrameRefComboBox_currentInde..."
QT_MOC_LITERAL(10, 211, 5), // "index"
QT_MOC_LITERAL(11, 217, 40), // "encodingModeComboBox_currentI..."
QT_MOC_LITERAL(12, 258, 28), // "quantiserSlider_valueChanged"
QT_MOC_LITERAL(13, 287, 29), // "quantiserSpinBox_valueChanged"
QT_MOC_LITERAL(14, 317, 25), // "rectInterCheckBox_toggled"
QT_MOC_LITERAL(15, 343, 37), // "targetRateControlSpinBox_valu..."
QT_MOC_LITERAL(16, 381, 24), // "rdoqSpinBox_valueChanged"
QT_MOC_LITERAL(17, 406, 22), // "cuTreeCheckBox_toggled"
QT_MOC_LITERAL(18, 429, 26), // "aqVarianceCheckBox_toggled"
QT_MOC_LITERAL(19, 456, 41), // "configurationComboBox_current..."
QT_MOC_LITERAL(20, 498, 20), // "saveAsButton_pressed"
QT_MOC_LITERAL(21, 519, 20), // "deleteButton_pressed"
QT_MOC_LITERAL(22, 540, 16), // "updatePresetList"
QT_MOC_LITERAL(23, 557, 11), // "const char*"
QT_MOC_LITERAL(24, 569, 6), // "select"
QT_MOC_LITERAL(25, 576, 27), // "toogleAdvancedConfiguration"
QT_MOC_LITERAL(26, 604, 15) // "advancedEnabled"

    },
    "x265Dialog\0useAdvancedConfigurationCheckBox_toggled\0"
    "\0checked\0meSpinBox_valueChanged\0value\0"
    "meSlider_valueChanged\0"
    "refFramesSpinBox_valueChanged\0"
    "maxBFramesSpinBox_valueChanged\0"
    "bFrameRefComboBox_currentIndexChanged\0"
    "index\0encodingModeComboBox_currentIndexChanged\0"
    "quantiserSlider_valueChanged\0"
    "quantiserSpinBox_valueChanged\0"
    "rectInterCheckBox_toggled\0"
    "targetRateControlSpinBox_valueChanged\0"
    "rdoqSpinBox_valueChanged\0"
    "cuTreeCheckBox_toggled\0"
    "aqVarianceCheckBox_toggled\0"
    "configurationComboBox_currentIndexChanged\0"
    "saveAsButton_pressed\0deleteButton_pressed\0"
    "updatePresetList\0const char*\0select\0"
    "toogleAdvancedConfiguration\0advancedEnabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_x265Dialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  114,    2, 0x08 /* Private */,
       4,    1,  117,    2, 0x08 /* Private */,
       6,    1,  120,    2, 0x08 /* Private */,
       7,    1,  123,    2, 0x08 /* Private */,
       8,    1,  126,    2, 0x08 /* Private */,
       9,    1,  129,    2, 0x08 /* Private */,
      11,    1,  132,    2, 0x08 /* Private */,
      12,    1,  135,    2, 0x08 /* Private */,
      13,    1,  138,    2, 0x08 /* Private */,
      14,    1,  141,    2, 0x08 /* Private */,
      15,    1,  144,    2, 0x08 /* Private */,
      16,    1,  147,    2, 0x08 /* Private */,
      17,    1,  150,    2, 0x08 /* Private */,
      18,    1,  153,    2, 0x08 /* Private */,
      19,    1,  156,    2, 0x08 /* Private */,
      20,    0,  159,    2, 0x08 /* Private */,
      21,    0,  160,    2, 0x08 /* Private */,
      22,    1,  161,    2, 0x08 /* Private */,
      22,    0,  164,    2, 0x28 /* Private | MethodCloned */,
      25,    1,  165,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool, 0x80000000 | 23,   24,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::Bool,   26,

       0        // eod
};

void x265Dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<x265Dialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->useAdvancedConfigurationCheckBox_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->meSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->meSlider_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->refFramesSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->maxBFramesSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->bFrameRefComboBox_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->encodingModeComboBox_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->quantiserSlider_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->quantiserSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->rectInterCheckBox_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->targetRateControlSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->rdoqSpinBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->cuTreeCheckBox_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->aqVarianceCheckBox_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->configurationComboBox_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->saveAsButton_pressed(); break;
        case 16: _t->deleteButton_pressed(); break;
        case 17: { bool _r = _t->updatePresetList((*reinterpret_cast< const char*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->updatePresetList();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->toogleAdvancedConfiguration((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject x265Dialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_x265Dialog.data,
    qt_meta_data_x265Dialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *x265Dialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *x265Dialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_x265Dialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int x265Dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
