/********************************************************************************
** Form generated from reading UI file 'lumaStab.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LUMASTAB_H
#define UI_LUMASTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_lumaStabDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    ADM_SliderIndicator *horizontalSliderFilterLength;
    ADM_SliderIndicator *horizontalSliderSceneThreshold;
    QLabel *labelFilterLength;
    QLabel *labelChromaShiftAngle;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QLabel *labelFrames;
    QLineEdit *lineEditNewScene;
    QCheckBox *checkBoxChroma;
    ADM_SliderIndicator *horizontalSliderCBRatio;
    QSpacerItem *horizontalSpacer_5;
    QProgressBar *progressBarScene;
    QLabel *labelAdjust;
    QLabel *labelPreferContrast;
    QSpacerItem *horizontalSpacer_4;
    QLabel *labelPreferBrightness;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *lumaStabDialog)
    {
        if (lumaStabDialog->objectName().isEmpty())
            lumaStabDialog->setObjectName(QString::fromUtf8("lumaStabDialog"));
        lumaStabDialog->resize(579, 327);
        verticalLayout = new QVBoxLayout(lumaStabDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSliderFilterLength = new ADM_SliderIndicator(lumaStabDialog);
        horizontalSliderFilterLength->setObjectName(QString::fromUtf8("horizontalSliderFilterLength"));
        horizontalSliderFilterLength->setMinimum(2);
        horizontalSliderFilterLength->setMaximum(256);
        horizontalSliderFilterLength->setPageStep(20);
        horizontalSliderFilterLength->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderFilterLength, 1, 1, 1, 3);

        horizontalSliderSceneThreshold = new ADM_SliderIndicator(lumaStabDialog);
        horizontalSliderSceneThreshold->setObjectName(QString::fromUtf8("horizontalSliderSceneThreshold"));
        horizontalSliderSceneThreshold->setMaximum(100);
        horizontalSliderSceneThreshold->setPageStep(10);
        horizontalSliderSceneThreshold->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderSceneThreshold, 5, 1, 1, 3);

        labelFilterLength = new QLabel(lumaStabDialog);
        labelFilterLength->setObjectName(QString::fromUtf8("labelFilterLength"));

        gridLayout->addWidget(labelFilterLength, 1, 0, 1, 1);

        labelChromaShiftAngle = new QLabel(lumaStabDialog);
        labelChromaShiftAngle->setObjectName(QString::fromUtf8("labelChromaShiftAngle"));

        gridLayout->addWidget(labelChromaShiftAngle, 5, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 5, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 5, 5, 1, 1);

        labelFrames = new QLabel(lumaStabDialog);
        labelFrames->setObjectName(QString::fromUtf8("labelFrames"));

        gridLayout->addWidget(labelFrames, 1, 4, 1, 1);

        lineEditNewScene = new QLineEdit(lumaStabDialog);
        lineEditNewScene->setObjectName(QString::fromUtf8("lineEditNewScene"));
        lineEditNewScene->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lineEditNewScene->sizePolicy().hasHeightForWidth());
        lineEditNewScene->setSizePolicy(sizePolicy);
        lineEditNewScene->setMaximumSize(QSize(48, 16777215));

        gridLayout->addWidget(lineEditNewScene, 6, 4, 1, 1);

        checkBoxChroma = new QCheckBox(lumaStabDialog);
        checkBoxChroma->setObjectName(QString::fromUtf8("checkBoxChroma"));

        gridLayout->addWidget(checkBoxChroma, 7, 0, 1, 1);

        horizontalSliderCBRatio = new ADM_SliderIndicator(lumaStabDialog);
        horizontalSliderCBRatio->setObjectName(QString::fromUtf8("horizontalSliderCBRatio"));
        horizontalSliderCBRatio->setMaximum(100);
        horizontalSliderCBRatio->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderCBRatio, 3, 1, 1, 3);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 2, 5, 1, 1);

        progressBarScene = new QProgressBar(lumaStabDialog);
        progressBarScene->setObjectName(QString::fromUtf8("progressBarScene"));
        progressBarScene->setEnabled(false);
        progressBarScene->setValue(24);
        progressBarScene->setFormat(QString::fromUtf8(""));

        gridLayout->addWidget(progressBarScene, 6, 1, 1, 3);

        labelAdjust = new QLabel(lumaStabDialog);
        labelAdjust->setObjectName(QString::fromUtf8("labelAdjust"));

        gridLayout->addWidget(labelAdjust, 2, 0, 1, 1);

        labelPreferContrast = new QLabel(lumaStabDialog);
        labelPreferContrast->setObjectName(QString::fromUtf8("labelPreferContrast"));

        gridLayout->addWidget(labelPreferContrast, 2, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 2, 2, 1, 1);

        labelPreferBrightness = new QLabel(lumaStabDialog);
        labelPreferBrightness->setObjectName(QString::fromUtf8("labelPreferBrightness"));

        gridLayout->addWidget(labelPreferBrightness, 2, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(lumaStabDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(lumaStabDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(lumaStabDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(lumaStabDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), lumaStabDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), lumaStabDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(lumaStabDialog);
    } // setupUi

    void retranslateUi(QDialog *lumaStabDialog)
    {
        lumaStabDialog->setWindowTitle(QCoreApplication::translate("lumaStabDialog", "Luma stabilizer", nullptr));
        labelFilterLength->setText(QCoreApplication::translate("lumaStabDialog", "Filter length", nullptr));
        labelChromaShiftAngle->setText(QCoreApplication::translate("lumaStabDialog", "Scene threshold", nullptr));
        labelFrames->setText(QCoreApplication::translate("lumaStabDialog", "frames", nullptr));
        checkBoxChroma->setText(QCoreApplication::translate("lumaStabDialog", "Adjust chroma", nullptr));
        labelAdjust->setText(QCoreApplication::translate("lumaStabDialog", "Adjust target", nullptr));
        labelPreferContrast->setText(QCoreApplication::translate("lumaStabDialog", "Prefer contrast", nullptr));
        labelPreferBrightness->setText(QCoreApplication::translate("lumaStabDialog", "Prefer brightness", nullptr));
    } // retranslateUi

};

namespace Ui {
    class lumaStabDialog: public Ui_lumaStabDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LUMASTAB_H
