/****************************************************************************
** Meta object code from reading C++ file 'Q_encoding.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../avidemux/qt4/ADM_userInterfaces/ADM_dialog/Q_encoding.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Q_encoding.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DIA_encodingQt4_t {
    QByteArrayData data[14];
    char stringdata0[181];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DIA_encodingQt4_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DIA_encodingQt4_t qt_meta_stringdata_DIA_encodingQt4 = {
    {
QT_MOC_LITERAL(0, 0, 15), // "DIA_encodingQt4"
QT_MOC_LITERAL(1, 16, 20), // "useTrayButtonPressed"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 18), // "pauseButtonPressed"
QT_MOC_LITERAL(4, 57, 15), // "priorityChanged"
QT_MOC_LITERAL(5, 73, 13), // "priorityLevel"
QT_MOC_LITERAL(6, 87, 15), // "shutdownChanged"
QT_MOC_LITERAL(7, 103, 5), // "state"
QT_MOC_LITERAL(8, 109, 15), // "keepOpenChanged"
QT_MOC_LITERAL(9, 125, 18), // "deleteStatsChanged"
QT_MOC_LITERAL(10, 144, 10), // "closeEvent"
QT_MOC_LITERAL(11, 155, 12), // "QCloseEvent*"
QT_MOC_LITERAL(12, 168, 5), // "event"
QT_MOC_LITERAL(13, 174, 6) // "reject"

    },
    "DIA_encodingQt4\0useTrayButtonPressed\0"
    "\0pauseButtonPressed\0priorityChanged\0"
    "priorityLevel\0shutdownChanged\0state\0"
    "keepOpenChanged\0deleteStatsChanged\0"
    "closeEvent\0QCloseEvent*\0event\0reject"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DIA_encodingQt4[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x0a /* Public */,
       3,    0,   55,    2, 0x0a /* Public */,
       4,    1,   56,    2, 0x0a /* Public */,
       6,    1,   59,    2, 0x0a /* Public */,
       8,    1,   62,    2, 0x0a /* Public */,
       9,    1,   65,    2, 0x0a /* Public */,
      10,    1,   68,    2, 0x0a /* Public */,
      13,    0,   71,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,

       0        // eod
};

void DIA_encodingQt4::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DIA_encodingQt4 *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->useTrayButtonPressed(); break;
        case 1: _t->pauseButtonPressed(); break;
        case 2: _t->priorityChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->shutdownChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->keepOpenChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->deleteStatsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->closeEvent((*reinterpret_cast< QCloseEvent*(*)>(_a[1]))); break;
        case 7: _t->reject(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DIA_encodingQt4::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_DIA_encodingQt4.data,
    qt_meta_data_DIA_encodingQt4,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DIA_encodingQt4::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DIA_encodingQt4::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DIA_encodingQt4.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DIA_encodingBase"))
        return static_cast< DIA_encodingBase*>(this);
    return QDialog::qt_metacast(_clname);
}

int DIA_encodingQt4::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
