/********************************************************************************
** Form generated from reading UI file 'artPosterize.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTPOSTERIZE_H
#define UI_ARTPOSTERIZE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artPosterizeDialog
{
public:
    QGridLayout *gridLayout;
    ADM_flyNavSlider *horizontalSlider;
    QSpacerItem *spacerItem;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *toolboxLayout;
    QGridLayout *gridLayout1;
    QLabel *label;
    QSpacerItem *spacerItem1;
    QSlider *horizontalSliderLevels;
    QSpinBox *spinBoxLevels;

    void setupUi(QDialog *artPosterizeDialog)
    {
        if (artPosterizeDialog->objectName().isEmpty())
            artPosterizeDialog->setObjectName(QString::fromUtf8("artPosterizeDialog"));
        artPosterizeDialog->resize(505, 475);
        gridLayout = new QGridLayout(artPosterizeDialog);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        horizontalSlider = new ADM_flyNavSlider(artPosterizeDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSlider, 5, 0, 1, 4);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(spacerItem, 7, 3, 1, 1);

        graphicsView = new QGraphicsView(artPosterizeDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));

        gridLayout->addWidget(graphicsView, 6, 0, 1, 4);

        buttonBox = new QDialogButtonBox(artPosterizeDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 8, 0, 1, 4);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        gridLayout->addLayout(toolboxLayout, 4, 0, 1, 1);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        label = new QLabel(artPosterizeDialog);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout1->addWidget(label, 0, 0, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacerItem1, 0, 3, 1, 1);

        horizontalSliderLevels = new QSlider(artPosterizeDialog);
        horizontalSliderLevels->setObjectName(QString::fromUtf8("horizontalSliderLevels"));
        horizontalSliderLevels->setMinimum(2);
        horizontalSliderLevels->setMaximum(64);
        horizontalSliderLevels->setPageStep(20);
        horizontalSliderLevels->setOrientation(Qt::Horizontal);

        gridLayout1->addWidget(horizontalSliderLevels, 0, 1, 1, 1);

        spinBoxLevels = new QSpinBox(artPosterizeDialog);
        spinBoxLevels->setObjectName(QString::fromUtf8("spinBoxLevels"));
        spinBoxLevels->setMinimum(2);
        spinBoxLevels->setMaximum(64);

        gridLayout1->addWidget(spinBoxLevels, 0, 2, 1, 1);


        gridLayout->addLayout(gridLayout1, 2, 0, 2, 4);

        QWidget::setTabOrder(horizontalSliderLevels, spinBoxLevels);
        QWidget::setTabOrder(spinBoxLevels, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, graphicsView);

        retranslateUi(artPosterizeDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artPosterizeDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artPosterizeDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artPosterizeDialog);
    } // setupUi

    void retranslateUi(QDialog *artPosterizeDialog)
    {
        artPosterizeDialog->setWindowTitle(QCoreApplication::translate("artPosterizeDialog", "Posterize", nullptr));
        label->setText(QCoreApplication::translate("artPosterizeDialog", "Levels", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artPosterizeDialog: public Ui_artPosterizeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTPOSTERIZE_H
