/****************************************************************************
** Meta object code from reading C++ file 'DIA_flyDialogQt4.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../avidemux/qt4/ADM_UIs/include/DIA_flyDialogQt4.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'DIA_flyDialogQt4.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ADM_flyDialog_t {
    QByteArrayData data[12];
    char stringdata0[149];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ADM_flyDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ADM_flyDialog_t qt_meta_stringdata_ADM_flyDialog = {
    {
QT_MOC_LITERAL(0, 0, 13), // "ADM_flyDialog"
QT_MOC_LITERAL(1, 14, 9), // "nextImage"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 13), // "backOneMinute"
QT_MOC_LITERAL(4, 39, 12), // "fwdOneMinute"
QT_MOC_LITERAL(5, 52, 18), // "gotoSelectionStart"
QT_MOC_LITERAL(6, 71, 16), // "gotoSelectionEnd"
QT_MOC_LITERAL(7, 88, 4), // "play"
QT_MOC_LITERAL(8, 93, 6), // "status"
QT_MOC_LITERAL(9, 100, 19), // "peekOriginalPressed"
QT_MOC_LITERAL(10, 120, 20), // "peekOriginalReleased"
QT_MOC_LITERAL(11, 141, 7) // "timeout"

    },
    "ADM_flyDialog\0nextImage\0\0backOneMinute\0"
    "fwdOneMinute\0gotoSelectionStart\0"
    "gotoSelectionEnd\0play\0status\0"
    "peekOriginalPressed\0peekOriginalReleased\0"
    "timeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ADM_flyDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x0a /* Public */,
       3,    0,   60,    2, 0x0a /* Public */,
       4,    0,   61,    2, 0x0a /* Public */,
       5,    0,   62,    2, 0x0a /* Public */,
       6,    0,   63,    2, 0x0a /* Public */,
       7,    1,   64,    2, 0x0a /* Public */,
       9,    0,   67,    2, 0x0a /* Public */,
      10,    0,   68,    2, 0x0a /* Public */,
      11,    0,   69,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ADM_flyDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ADM_flyDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->nextImage();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->backOneMinute(); break;
        case 2: _t->fwdOneMinute(); break;
        case 3: _t->gotoSelectionStart(); break;
        case 4: _t->gotoSelectionEnd(); break;
        case 5: _t->play((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->peekOriginalPressed(); break;
        case 7: _t->peekOriginalReleased(); break;
        case 8: _t->timeout(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ADM_flyDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_ADM_flyDialog.data,
    qt_meta_data_ADM_flyDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ADM_flyDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ADM_flyDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ADM_flyDialog.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ADM_flyDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
struct qt_meta_stringdata_ADM_flyDialogYuv_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ADM_flyDialogYuv_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ADM_flyDialogYuv_t qt_meta_stringdata_ADM_flyDialogYuv = {
    {
QT_MOC_LITERAL(0, 0, 16) // "ADM_flyDialogYuv"

    },
    "ADM_flyDialogYuv"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ADM_flyDialogYuv[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ADM_flyDialogYuv::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ADM_flyDialogYuv::staticMetaObject = { {
    QMetaObject::SuperData::link<ADM_flyDialog::staticMetaObject>(),
    qt_meta_stringdata_ADM_flyDialogYuv.data,
    qt_meta_data_ADM_flyDialogYuv,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ADM_flyDialogYuv::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ADM_flyDialogYuv::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ADM_flyDialogYuv.stringdata0))
        return static_cast<void*>(this);
    return ADM_flyDialog::qt_metacast(_clname);
}

int ADM_flyDialogYuv::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ADM_flyDialog::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ADM_flyDialogRgb_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ADM_flyDialogRgb_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ADM_flyDialogRgb_t qt_meta_stringdata_ADM_flyDialogRgb = {
    {
QT_MOC_LITERAL(0, 0, 16) // "ADM_flyDialogRgb"

    },
    "ADM_flyDialogRgb"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ADM_flyDialogRgb[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ADM_flyDialogRgb::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ADM_flyDialogRgb::staticMetaObject = { {
    QMetaObject::SuperData::link<ADM_flyDialog::staticMetaObject>(),
    qt_meta_stringdata_ADM_flyDialogRgb.data,
    qt_meta_data_ADM_flyDialogRgb,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ADM_flyDialogRgb::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ADM_flyDialogRgb::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ADM_flyDialogRgb.stringdata0))
        return static_cast<void*>(this);
    return ADM_flyDialog::qt_metacast(_clname);
}

int ADM_flyDialogRgb::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ADM_flyDialog::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
