/********************************************************************************
** Form generated from reading UI file 'logo.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOGO_H
#define UI_LOGO_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_logoDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayoutPos;
    QPushButton *pushButtonSelect;
    QFrame *line;
    QLabel *labelImage;
    QSpacerItem *horizontalSpacerPath;
    QHBoxLayout *horizontalLayoutImage;
    QLabel *labelX;
    QSpinBox *spinX;
    QLabel *labelY;
    QSpinBox *spinY;
    QLabel *labelScale;
    QDoubleSpinBox *spinScale;
    QLabel *labelAlpha;
    QSpinBox *spinAlpha;
    QLabel *labelFadeInOut;
    QDoubleSpinBox *spinFadeInOut;
    QSpacerItem *horizontalSpacerImage;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *logoDialog)
    {
        if (logoDialog->objectName().isEmpty())
            logoDialog->setObjectName(QString::fromUtf8("logoDialog"));
        logoDialog->resize(603, 516);
        verticalLayout = new QVBoxLayout(logoDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayoutPos = new QHBoxLayout();
        horizontalLayoutPos->setObjectName(QString::fromUtf8("horizontalLayoutPos"));
        pushButtonSelect = new QPushButton(logoDialog);
        pushButtonSelect->setObjectName(QString::fromUtf8("pushButtonSelect"));

        horizontalLayoutPos->addWidget(pushButtonSelect);

        line = new QFrame(logoDialog);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::VLine);
        line->setFrameShadow(QFrame::Sunken);

        horizontalLayoutPos->addWidget(line);

        labelImage = new QLabel(logoDialog);
        labelImage->setObjectName(QString::fromUtf8("labelImage"));

        horizontalLayoutPos->addWidget(labelImage);

        horizontalSpacerPath = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutPos->addItem(horizontalSpacerPath);


        verticalLayout->addLayout(horizontalLayoutPos);

        horizontalLayoutImage = new QHBoxLayout();
        horizontalLayoutImage->setObjectName(QString::fromUtf8("horizontalLayoutImage"));
        labelX = new QLabel(logoDialog);
        labelX->setObjectName(QString::fromUtf8("labelX"));

        horizontalLayoutImage->addWidget(labelX);

        spinX = new QSpinBox(logoDialog);
        spinX->setObjectName(QString::fromUtf8("spinX"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(spinX->sizePolicy().hasHeightForWidth());
        spinX->setSizePolicy(sizePolicy);

        horizontalLayoutImage->addWidget(spinX);

        labelY = new QLabel(logoDialog);
        labelY->setObjectName(QString::fromUtf8("labelY"));
        labelY->setTextFormat(Qt::PlainText);

        horizontalLayoutImage->addWidget(labelY);

        spinY = new QSpinBox(logoDialog);
        spinY->setObjectName(QString::fromUtf8("spinY"));
        sizePolicy.setHeightForWidth(spinY->sizePolicy().hasHeightForWidth());
        spinY->setSizePolicy(sizePolicy);

        horizontalLayoutImage->addWidget(spinY);

        labelScale = new QLabel(logoDialog);
        labelScale->setObjectName(QString::fromUtf8("labelScale"));

        horizontalLayoutImage->addWidget(labelScale);

        spinScale = new QDoubleSpinBox(logoDialog);
        spinScale->setObjectName(QString::fromUtf8("spinScale"));
        spinScale->setMinimum(0.010000000000000);
        spinScale->setMaximum(100.000000000000000);
        spinScale->setSingleStep(0.010000000000000);
        spinScale->setValue(1.000000000000000);

        horizontalLayoutImage->addWidget(spinScale);

        labelAlpha = new QLabel(logoDialog);
        labelAlpha->setObjectName(QString::fromUtf8("labelAlpha"));
        labelAlpha->setTextFormat(Qt::PlainText);

        horizontalLayoutImage->addWidget(labelAlpha);

        spinAlpha = new QSpinBox(logoDialog);
        spinAlpha->setObjectName(QString::fromUtf8("spinAlpha"));
        sizePolicy.setHeightForWidth(spinAlpha->sizePolicy().hasHeightForWidth());
        spinAlpha->setSizePolicy(sizePolicy);

        horizontalLayoutImage->addWidget(spinAlpha);

        labelFadeInOut = new QLabel(logoDialog);
        labelFadeInOut->setObjectName(QString::fromUtf8("labelFadeInOut"));
        labelFadeInOut->setTextFormat(Qt::PlainText);

        horizontalLayoutImage->addWidget(labelFadeInOut);

        spinFadeInOut = new QDoubleSpinBox(logoDialog);
        spinFadeInOut->setObjectName(QString::fromUtf8("spinFadeInOut"));
        sizePolicy.setHeightForWidth(spinFadeInOut->sizePolicy().hasHeightForWidth());
        spinFadeInOut->setSizePolicy(sizePolicy);

        horizontalLayoutImage->addWidget(spinFadeInOut);

        horizontalSpacerImage = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutImage->addItem(horizontalSpacerImage);


        verticalLayout->addLayout(horizontalLayoutImage);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(logoDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(logoDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(logoDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(logoDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), logoDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), logoDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(logoDialog);
    } // setupUi

    void retranslateUi(QDialog *logoDialog)
    {
        logoDialog->setWindowTitle(QCoreApplication::translate("logoDialog", "Logo", nullptr));
        pushButtonSelect->setText(QCoreApplication::translate("logoDialog", "Select Image...", nullptr));
        labelImage->setText(QCoreApplication::translate("logoDialog", "No image selected", nullptr));
        labelX->setText(QCoreApplication::translate("logoDialog", "X", nullptr));
        labelY->setText(QCoreApplication::translate("logoDialog", "Y", nullptr));
        labelScale->setText(QCoreApplication::translate("logoDialog", "Scaling", nullptr));
        labelAlpha->setText(QCoreApplication::translate("logoDialog", "Alpha", nullptr));
        labelFadeInOut->setText(QCoreApplication::translate("logoDialog", "Fade-in/out", nullptr));
    } // retranslateUi

};

namespace Ui {
    class logoDialog: public Ui_logoDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LOGO_H
