/****************************************************************************
** Meta object code from reading C++ file 'Q_logo.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../avidemux_plugins/ADM_videoFilters6/logo/qt4/Q_logo.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Q_logo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ADM_LogoCanvas_t {
    QByteArrayData data[5];
    char stringdata0[38];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ADM_LogoCanvas_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ADM_LogoCanvas_t qt_meta_stringdata_ADM_LogoCanvas = {
    {
QT_MOC_LITERAL(0, 0, 14), // "ADM_LogoCanvas"
QT_MOC_LITERAL(1, 15, 11), // "movedSignal"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 4), // "newx"
QT_MOC_LITERAL(4, 33, 4) // "newy"

    },
    "ADM_LogoCanvas\0movedSignal\0\0newx\0newy"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ADM_LogoCanvas[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    4,

       0        // eod
};

void ADM_LogoCanvas::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ADM_LogoCanvas *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->movedSignal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ADM_LogoCanvas::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ADM_LogoCanvas::movedSignal)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ADM_LogoCanvas::staticMetaObject = { {
    QMetaObject::SuperData::link<ADM_QCanvas::staticMetaObject>(),
    qt_meta_stringdata_ADM_LogoCanvas.data,
    qt_meta_data_ADM_LogoCanvas,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ADM_LogoCanvas::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ADM_LogoCanvas::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ADM_LogoCanvas.stringdata0))
        return static_cast<void*>(this);
    return ADM_QCanvas::qt_metacast(_clname);
}

int ADM_LogoCanvas::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ADM_QCanvas::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ADM_LogoCanvas::movedSignal(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_Ui_logoWindow_t {
    QByteArrayData data[13];
    char stringdata0[99];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Ui_logoWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Ui_logoWindow_t qt_meta_stringdata_Ui_logoWindow = {
    {
QT_MOC_LITERAL(0, 0, 13), // "Ui_logoWindow"
QT_MOC_LITERAL(1, 14, 6), // "gather"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 5), // "logo*"
QT_MOC_LITERAL(4, 28, 5), // "param"
QT_MOC_LITERAL(5, 34, 12), // "sliderUpdate"
QT_MOC_LITERAL(6, 47, 3), // "foo"
QT_MOC_LITERAL(7, 51, 12), // "valueChanged"
QT_MOC_LITERAL(8, 64, 5), // "moved"
QT_MOC_LITERAL(9, 70, 1), // "x"
QT_MOC_LITERAL(10, 72, 1), // "y"
QT_MOC_LITERAL(11, 74, 12), // "scaleChanged"
QT_MOC_LITERAL(12, 87, 11) // "imageSelect"

    },
    "Ui_logoWindow\0gather\0\0logo*\0param\0"
    "sliderUpdate\0foo\0valueChanged\0moved\0"
    "x\0y\0scaleChanged\0imageSelect"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Ui_logoWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x0a /* Public */,
       5,    1,   52,    2, 0x08 /* Private */,
       7,    1,   55,    2, 0x08 /* Private */,
       7,    1,   58,    2, 0x08 /* Private */,
       8,    2,   61,    2, 0x08 /* Private */,
      11,    1,   66,    2, 0x08 /* Private */,
      12,    0,   69,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Double,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   10,
    QMetaType::Void, QMetaType::Double,    6,
    QMetaType::Void,

       0        // eod
};

void Ui_logoWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Ui_logoWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->gather((*reinterpret_cast< logo*(*)>(_a[1]))); break;
        case 1: _t->sliderUpdate((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 4: _t->moved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->scaleChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 6: _t->imageSelect(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Ui_logoWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_Ui_logoWindow.data,
    qt_meta_data_Ui_logoWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Ui_logoWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ui_logoWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Ui_logoWindow.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ui_logoWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
