/********************************************************************************
** Form generated from reading UI file 'colorTemp.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORTEMP_H
#define UI_COLORTEMP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_colorTempDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelTemperature;
    QLabel *labelChromaShiftAngle;
    QSlider *horizontalSliderTemperature;
    QSlider *horizontalSliderAngle;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QDoubleSpinBox *doubleSpinBoxTemperature;
    QDoubleSpinBox *doubleSpinBoxAngle;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *colorTempDialog)
    {
        if (colorTempDialog->objectName().isEmpty())
            colorTempDialog->setObjectName(QString::fromUtf8("colorTempDialog"));
        colorTempDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(colorTempDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        labelTemperature = new QLabel(colorTempDialog);
        labelTemperature->setObjectName(QString::fromUtf8("labelTemperature"));

        gridLayout->addWidget(labelTemperature, 1, 0, 1, 1);

        labelChromaShiftAngle = new QLabel(colorTempDialog);
        labelChromaShiftAngle->setObjectName(QString::fromUtf8("labelChromaShiftAngle"));

        gridLayout->addWidget(labelChromaShiftAngle, 2, 0, 1, 1);

        horizontalSliderTemperature = new QSlider(colorTempDialog);
        horizontalSliderTemperature->setObjectName(QString::fromUtf8("horizontalSliderTemperature"));
        horizontalSliderTemperature->setMinimum(-100);
        horizontalSliderTemperature->setMaximum(100);
        horizontalSliderTemperature->setPageStep(20);
        horizontalSliderTemperature->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderTemperature, 1, 1, 1, 1);

        horizontalSliderAngle = new QSlider(colorTempDialog);
        horizontalSliderAngle->setObjectName(QString::fromUtf8("horizontalSliderAngle"));
        horizontalSliderAngle->setMaximum(180);
        horizontalSliderAngle->setPageStep(20);
        horizontalSliderAngle->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderAngle, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 3, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 3, 1, 1);

        doubleSpinBoxTemperature = new QDoubleSpinBox(colorTempDialog);
        doubleSpinBoxTemperature->setObjectName(QString::fromUtf8("doubleSpinBoxTemperature"));
        doubleSpinBoxTemperature->setMinimum(-1.000000000000000);
        doubleSpinBoxTemperature->setMaximum(1.000000000000000);
        doubleSpinBoxTemperature->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxTemperature, 1, 2, 1, 1);

        doubleSpinBoxAngle = new QDoubleSpinBox(colorTempDialog);
        doubleSpinBoxAngle->setObjectName(QString::fromUtf8("doubleSpinBoxAngle"));
        doubleSpinBoxAngle->setMaximum(180.000000000000000);

        gridLayout->addWidget(doubleSpinBoxAngle, 2, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(colorTempDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(colorTempDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(colorTempDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(colorTempDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), colorTempDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), colorTempDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(colorTempDialog);
    } // setupUi

    void retranslateUi(QDialog *colorTempDialog)
    {
        colorTempDialog->setWindowTitle(QCoreApplication::translate("colorTempDialog", "Color Temperature", nullptr));
        labelTemperature->setText(QCoreApplication::translate("colorTempDialog", "Color temperature", nullptr));
        labelChromaShiftAngle->setText(QCoreApplication::translate("colorTempDialog", "Chroma shift angle", nullptr));
    } // retranslateUi

};

namespace Ui {
    class colorTempDialog: public Ui_colorTempDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLORTEMP_H
