/********************************************************************************
** Form generated from reading UI file 'resizing.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESIZING_H
#define UI_RESIZING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_resizeDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout1;
    QCheckBox *lockArCheckBox;
    QHBoxLayout *hboxLayout;
    QLabel *label_4;
    QComboBox *comboBoxSource;
    QSpacerItem *spacerItem;
    QLabel *label_3;
    QComboBox *comboBoxDestination;
    QSpacerItem *spacerItem1;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout1;
    QLabel *label;
    QSpinBox *spinBoxWidth;
    QSpacerItem *spacerItem2;
    QLabel *label_2;
    QSpinBox *spinBoxHeight;
    QSpacerItem *spacerItem3;
    QComboBox *comboBoxRoundup;
    QSpacerItem *spacerItem4;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout2;
    QVBoxLayout *vboxLayout4;
    QHBoxLayout *hboxLayout3;
    QLabel *label_8;
    QSpacerItem *spacerItem5;
    QLabel *label_5;
    QSpacerItem *spacerItem6;
    QLabel *label_9;
    QSlider *horizontalSlider;
    QSpinBox *percentageSpinBox;
    QHBoxLayout *hboxLayout4;
    QLabel *label_10;
    QLabel *labelErrorXY;
    QSpacerItem *horizontalSpacer;
    QLabel *labelOutAR;
    QLabel *labelOutArFloat;
    QLabel *labelOutArDef;
    QSpacerItem *spacerItem7;
    QHBoxLayout *hboxLayout5;
    QLabel *label_6;
    QComboBox *comboBoxAlgo;
    QSpacerItem *spacerItem8;
    QSpacerItem *spacerItem9;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *resizeDialog)
    {
        if (resizeDialog->objectName().isEmpty())
            resizeDialog->setObjectName(QString::fromUtf8("resizeDialog"));
        resizeDialog->resize(591, 429);
        vboxLayout = new QVBoxLayout(resizeDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        groupBox_2 = new QGroupBox(resizeDialog);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        vboxLayout1 = new QVBoxLayout(groupBox_2);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        lockArCheckBox = new QCheckBox(groupBox_2);
        lockArCheckBox->setObjectName(QString::fromUtf8("lockArCheckBox"));

        vboxLayout1->addWidget(lockArCheckBox);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        hboxLayout->addWidget(label_4);

        comboBoxSource = new QComboBox(groupBox_2);
        comboBoxSource->addItem(QString());
        comboBoxSource->setObjectName(QString::fromUtf8("comboBoxSource"));

        hboxLayout->addWidget(comboBoxSource);

        spacerItem = new QSpacerItem(30, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        hboxLayout->addWidget(label_3);

        comboBoxDestination = new QComboBox(groupBox_2);
        comboBoxDestination->addItem(QString());
        comboBoxDestination->setObjectName(QString::fromUtf8("comboBoxDestination"));

        hboxLayout->addWidget(comboBoxDestination);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem1);


        vboxLayout1->addLayout(hboxLayout);


        vboxLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(resizeDialog);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        vboxLayout2 = new QVBoxLayout(groupBox);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        hboxLayout1->addWidget(label);

        spinBoxWidth = new QSpinBox(groupBox);
        spinBoxWidth->setObjectName(QString::fromUtf8("spinBoxWidth"));
        spinBoxWidth->setMinimum(16);
        spinBoxWidth->setMaximum(8192);
        spinBoxWidth->setSingleStep(2);

        hboxLayout1->addWidget(spinBoxWidth);

        spacerItem2 = new QSpacerItem(30, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        hboxLayout1->addWidget(label_2);

        spinBoxHeight = new QSpinBox(groupBox);
        spinBoxHeight->setObjectName(QString::fromUtf8("spinBoxHeight"));
        spinBoxHeight->setMinimum(16);
        spinBoxHeight->setMaximum(8192);
        spinBoxHeight->setSingleStep(2);

        hboxLayout1->addWidget(spinBoxHeight);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem3);

        comboBoxRoundup = new QComboBox(groupBox);
        comboBoxRoundup->addItem(QString());
        comboBoxRoundup->addItem(QString());
        comboBoxRoundup->addItem(QString());
        comboBoxRoundup->addItem(QString());
        comboBoxRoundup->setObjectName(QString::fromUtf8("comboBoxRoundup"));
        comboBoxRoundup->setMinimumSize(QSize(256, 0));

        hboxLayout1->addWidget(comboBoxRoundup);


        vboxLayout2->addLayout(hboxLayout1);

        spacerItem4 = new QSpacerItem(312, 4, QSizePolicy::Minimum, QSizePolicy::Fixed);

        vboxLayout2->addItem(spacerItem4);

        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(6);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        vboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setSpacing(12);
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        vboxLayout4 = new QVBoxLayout();
        vboxLayout4->setSpacing(6);
        vboxLayout4->setObjectName(QString::fromUtf8("vboxLayout4"));
        vboxLayout4->setContentsMargins(0, 0, 0, 0);
        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setObjectName(QString::fromUtf8("hboxLayout3"));
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        label_8 = new QLabel(groupBox);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        hboxLayout3->addWidget(label_8);

        spacerItem5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout3->addItem(spacerItem5);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        hboxLayout3->addWidget(label_5);

        spacerItem6 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout3->addItem(spacerItem6);

        label_9 = new QLabel(groupBox);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        hboxLayout3->addWidget(label_9);


        vboxLayout4->addLayout(hboxLayout3);

        horizontalSlider = new QSlider(groupBox);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setMinimum(1);
        horizontalSlider->setMaximum(200);
        horizontalSlider->setValue(100);
        horizontalSlider->setOrientation(Qt::Horizontal);

        vboxLayout4->addWidget(horizontalSlider);


        hboxLayout2->addLayout(vboxLayout4);

        percentageSpinBox = new QSpinBox(groupBox);
        percentageSpinBox->setObjectName(QString::fromUtf8("percentageSpinBox"));
        percentageSpinBox->setMinimum(1);
        percentageSpinBox->setMaximum(200);
        percentageSpinBox->setValue(100);

        hboxLayout2->addWidget(percentageSpinBox);


        vboxLayout3->addLayout(hboxLayout2);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(6);
        hboxLayout4->setObjectName(QString::fromUtf8("hboxLayout4"));
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
        label_10 = new QLabel(groupBox);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        hboxLayout4->addWidget(label_10);

        labelErrorXY = new QLabel(groupBox);
        labelErrorXY->setObjectName(QString::fromUtf8("labelErrorXY"));

        hboxLayout4->addWidget(labelErrorXY);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout4->addItem(horizontalSpacer);

        labelOutAR = new QLabel(groupBox);
        labelOutAR->setObjectName(QString::fromUtf8("labelOutAR"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelOutAR->sizePolicy().hasHeightForWidth());
        labelOutAR->setSizePolicy(sizePolicy);
        labelOutAR->setText(QString::fromUtf8("Aspect Ratio:"));

        hboxLayout4->addWidget(labelOutAR);

        labelOutArFloat = new QLabel(groupBox);
        labelOutArFloat->setObjectName(QString::fromUtf8("labelOutArFloat"));

        hboxLayout4->addWidget(labelOutArFloat);

        labelOutArDef = new QLabel(groupBox);
        labelOutArDef->setObjectName(QString::fromUtf8("labelOutArDef"));

        hboxLayout4->addWidget(labelOutArDef);


        vboxLayout3->addLayout(hboxLayout4);


        vboxLayout2->addLayout(vboxLayout3);


        vboxLayout->addWidget(groupBox);

        spacerItem7 = new QSpacerItem(332, 6, QSizePolicy::Minimum, QSizePolicy::Fixed);

        vboxLayout->addItem(spacerItem7);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setSpacing(6);
        hboxLayout5->setObjectName(QString::fromUtf8("hboxLayout5"));
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        label_6 = new QLabel(resizeDialog);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        hboxLayout5->addWidget(label_6);

        comboBoxAlgo = new QComboBox(resizeDialog);
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->setObjectName(QString::fromUtf8("comboBoxAlgo"));

        hboxLayout5->addWidget(comboBoxAlgo);

        spacerItem8 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout5->addItem(spacerItem8);


        vboxLayout->addLayout(hboxLayout5);

        spacerItem9 = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        vboxLayout->addItem(spacerItem9);

        buttonBox = new QDialogButtonBox(resizeDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);

        QWidget::setTabOrder(lockArCheckBox, comboBoxSource);
        QWidget::setTabOrder(comboBoxSource, comboBoxDestination);
        QWidget::setTabOrder(comboBoxDestination, spinBoxWidth);
        QWidget::setTabOrder(spinBoxWidth, spinBoxHeight);
        QWidget::setTabOrder(spinBoxHeight, comboBoxRoundup);
        QWidget::setTabOrder(comboBoxRoundup, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, percentageSpinBox);
        QWidget::setTabOrder(percentageSpinBox, comboBoxAlgo);

        retranslateUi(resizeDialog);
        QObject::connect(buttonBox, SIGNAL(rejected()), resizeDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(resizeDialog);
    } // setupUi

    void retranslateUi(QDialog *resizeDialog)
    {
        resizeDialog->setWindowTitle(QCoreApplication::translate("resizeDialog", "Resize", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("resizeDialog", "Aspect Ratio", nullptr));
        lockArCheckBox->setText(QCoreApplication::translate("resizeDialog", "Lock Aspect Ratio", nullptr));
        label_4->setText(QCoreApplication::translate("resizeDialog", "Source PAR:", nullptr));
        comboBoxSource->setItemText(0, QCoreApplication::translate("resizeDialog", "1:1 (square pixels)", nullptr));

        label_3->setText(QCoreApplication::translate("resizeDialog", "Destination PAR:", nullptr));
        comboBoxDestination->setItemText(0, QCoreApplication::translate("resizeDialog", "1:1 (square pixels)", nullptr));

        groupBox->setTitle(QCoreApplication::translate("resizeDialog", "Resize Dimensions", nullptr));
        label->setText(QCoreApplication::translate("resizeDialog", "Width:", nullptr));
        label_2->setText(QCoreApplication::translate("resizeDialog", "Height:", nullptr));
        comboBoxRoundup->setItemText(0, QCoreApplication::translate("resizeDialog", "No rounding", nullptr));
        comboBoxRoundup->setItemText(1, QCoreApplication::translate("resizeDialog", "Round to the Nearest Multiple of 16", nullptr));
        comboBoxRoundup->setItemText(2, QCoreApplication::translate("resizeDialog", "Round to the Nearest Multiple of 8", nullptr));
        comboBoxRoundup->setItemText(3, QCoreApplication::translate("resizeDialog", "Round to the Nearest Multiple of 4", nullptr));

        label_8->setText(QCoreApplication::translate("resizeDialog", "1%", nullptr));
        label_5->setText(QCoreApplication::translate("resizeDialog", "Percent", nullptr));
        label_9->setText(QCoreApplication::translate("resizeDialog", "200%", nullptr));
        label_10->setText(QCoreApplication::translate("resizeDialog", "Error X / Y:", nullptr));
        labelErrorXY->setText(QCoreApplication::translate("resizeDialog", "0.00 / 0.00", nullptr));
        labelOutArFloat->setText(QCoreApplication::translate("resizeDialog", "0.0000", nullptr));
        labelOutArDef->setText(QCoreApplication::translate("resizeDialog", "(00:00)", nullptr));
        label_6->setText(QCoreApplication::translate("resizeDialog", "Resize Method:", nullptr));
        comboBoxAlgo->setItemText(0, QCoreApplication::translate("resizeDialog", "Bilinear", nullptr));
        comboBoxAlgo->setItemText(1, QCoreApplication::translate("resizeDialog", "Bicubic", nullptr));
        comboBoxAlgo->setItemText(2, QCoreApplication::translate("resizeDialog", "Lanczos-3", nullptr));
        comboBoxAlgo->setItemText(3, QCoreApplication::translate("resizeDialog", "Spline", nullptr));
        comboBoxAlgo->setItemText(4, QCoreApplication::translate("resizeDialog", "Nearest neighbor", nullptr));

    } // retranslateUi

};

namespace Ui {
    class resizeDialog: public Ui_resizeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_RESIZING_H
