/********************************************************************************
** Form generated from reading UI file 'eq2.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EQ2_H
#define UI_EQ2_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_eq2Dialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayoutPanel;
    QVBoxLayout *verticalLayoutCBS;
    QLabel *labelContrast;
    ADM_SliderIndicator *horizontalSliderContrast;
    QLabel *labelBrightness;
    ADM_SliderIndicator *horizontalSliderBrightness;
    QLabel *labelSaturation;
    ADM_SliderIndicator *horizontalSliderSaturation;
    QFrame *line;
    QVBoxLayout *verticalLayoutGamma;
    QLabel *labelGamma;
    QGridLayout *centerGrid;
    ADM_SliderIndicator *horizontalSliderBlue;
    ADM_SliderIndicator *horizontalSliderRed;
    QLabel *labelWeight;
    ADM_SliderIndicator *horizontalSliderGreen;
    QLabel *labelBlue;
    ADM_SliderIndicator *horizontalSliderInitial;
    ADM_SliderIndicator *horizontalSliderWeight;
    QLabel *labelRed;
    QLabel *labelInitial;
    QLabel *labelGreen;
    QFrame *line_2;
    QGraphicsView *graphicsViewHistogram;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *eq2Dialog)
    {
        if (eq2Dialog->objectName().isEmpty())
            eq2Dialog->setObjectName(QString::fromUtf8("eq2Dialog"));
        eq2Dialog->resize(763, 505);
        verticalLayout_2 = new QVBoxLayout(eq2Dialog);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayoutPanel = new QHBoxLayout();
        horizontalLayoutPanel->setObjectName(QString::fromUtf8("horizontalLayoutPanel"));
        verticalLayoutCBS = new QVBoxLayout();
        verticalLayoutCBS->setSpacing(6);
        verticalLayoutCBS->setObjectName(QString::fromUtf8("verticalLayoutCBS"));
        verticalLayoutCBS->setContentsMargins(0, 0, 0, 0);
        labelContrast = new QLabel(eq2Dialog);
        labelContrast->setObjectName(QString::fromUtf8("labelContrast"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelContrast->sizePolicy().hasHeightForWidth());
        labelContrast->setSizePolicy(sizePolicy);

        verticalLayoutCBS->addWidget(labelContrast);

        horizontalSliderContrast = new ADM_SliderIndicator(eq2Dialog);
        horizontalSliderContrast->setObjectName(QString::fromUtf8("horizontalSliderContrast"));
        horizontalSliderContrast->setMinimum(-200);
        horizontalSliderContrast->setMaximum(200);
        horizontalSliderContrast->setOrientation(Qt::Horizontal);

        verticalLayoutCBS->addWidget(horizontalSliderContrast);

        labelBrightness = new QLabel(eq2Dialog);
        labelBrightness->setObjectName(QString::fromUtf8("labelBrightness"));

        verticalLayoutCBS->addWidget(labelBrightness);

        horizontalSliderBrightness = new ADM_SliderIndicator(eq2Dialog);
        horizontalSliderBrightness->setObjectName(QString::fromUtf8("horizontalSliderBrightness"));
        horizontalSliderBrightness->setMinimum(-100);
        horizontalSliderBrightness->setMaximum(100);
        horizontalSliderBrightness->setOrientation(Qt::Horizontal);

        verticalLayoutCBS->addWidget(horizontalSliderBrightness);

        labelSaturation = new QLabel(eq2Dialog);
        labelSaturation->setObjectName(QString::fromUtf8("labelSaturation"));

        verticalLayoutCBS->addWidget(labelSaturation);

        horizontalSliderSaturation = new ADM_SliderIndicator(eq2Dialog);
        horizontalSliderSaturation->setObjectName(QString::fromUtf8("horizontalSliderSaturation"));
        horizontalSliderSaturation->setMaximum(300);
        horizontalSliderSaturation->setOrientation(Qt::Horizontal);
        horizontalSliderSaturation->setTickInterval(1);

        verticalLayoutCBS->addWidget(horizontalSliderSaturation);


        horizontalLayoutPanel->addLayout(verticalLayoutCBS);

        line = new QFrame(eq2Dialog);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::VLine);
        line->setFrameShadow(QFrame::Sunken);

        horizontalLayoutPanel->addWidget(line);

        verticalLayoutGamma = new QVBoxLayout();
        verticalLayoutGamma->setObjectName(QString::fromUtf8("verticalLayoutGamma"));
        labelGamma = new QLabel(eq2Dialog);
        labelGamma->setObjectName(QString::fromUtf8("labelGamma"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelGamma->sizePolicy().hasHeightForWidth());
        labelGamma->setSizePolicy(sizePolicy1);
        labelGamma->setTextFormat(Qt::RichText);
        labelGamma->setAlignment(Qt::AlignCenter);

        verticalLayoutGamma->addWidget(labelGamma);

        centerGrid = new QGridLayout();
        centerGrid->setSpacing(6);
        centerGrid->setObjectName(QString::fromUtf8("centerGrid"));
        centerGrid->setContentsMargins(0, 0, 0, 0);
        horizontalSliderBlue = new ADM_SliderIndicator(eq2Dialog);
        horizontalSliderBlue->setObjectName(QString::fromUtf8("horizontalSliderBlue"));
        QSizePolicy sizePolicy2(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(horizontalSliderBlue->sizePolicy().hasHeightForWidth());
        horizontalSliderBlue->setSizePolicy(sizePolicy2);
        horizontalSliderBlue->setMaximum(300);
        horizontalSliderBlue->setOrientation(Qt::Horizontal);

        centerGrid->addWidget(horizontalSliderBlue, 3, 1, 1, 1);

        horizontalSliderRed = new ADM_SliderIndicator(eq2Dialog);
        horizontalSliderRed->setObjectName(QString::fromUtf8("horizontalSliderRed"));
        sizePolicy2.setHeightForWidth(horizontalSliderRed->sizePolicy().hasHeightForWidth());
        horizontalSliderRed->setSizePolicy(sizePolicy2);
        horizontalSliderRed->setMaximum(300);
        horizontalSliderRed->setOrientation(Qt::Horizontal);

        centerGrid->addWidget(horizontalSliderRed, 1, 1, 1, 1);

        labelWeight = new QLabel(eq2Dialog);
        labelWeight->setObjectName(QString::fromUtf8("labelWeight"));

        centerGrid->addWidget(labelWeight, 4, 0, 1, 1);

        horizontalSliderGreen = new ADM_SliderIndicator(eq2Dialog);
        horizontalSliderGreen->setObjectName(QString::fromUtf8("horizontalSliderGreen"));
        sizePolicy2.setHeightForWidth(horizontalSliderGreen->sizePolicy().hasHeightForWidth());
        horizontalSliderGreen->setSizePolicy(sizePolicy2);
        horizontalSliderGreen->setMaximum(300);
        horizontalSliderGreen->setOrientation(Qt::Horizontal);

        centerGrid->addWidget(horizontalSliderGreen, 2, 1, 1, 1);

        labelBlue = new QLabel(eq2Dialog);
        labelBlue->setObjectName(QString::fromUtf8("labelBlue"));

        centerGrid->addWidget(labelBlue, 3, 0, 1, 1);

        horizontalSliderInitial = new ADM_SliderIndicator(eq2Dialog);
        horizontalSliderInitial->setObjectName(QString::fromUtf8("horizontalSliderInitial"));
        sizePolicy2.setHeightForWidth(horizontalSliderInitial->sizePolicy().hasHeightForWidth());
        horizontalSliderInitial->setSizePolicy(sizePolicy2);
        horizontalSliderInitial->setMaximum(300);
        horizontalSliderInitial->setOrientation(Qt::Horizontal);

        centerGrid->addWidget(horizontalSliderInitial, 0, 1, 1, 1);

        horizontalSliderWeight = new ADM_SliderIndicator(eq2Dialog);
        horizontalSliderWeight->setObjectName(QString::fromUtf8("horizontalSliderWeight"));
        sizePolicy2.setHeightForWidth(horizontalSliderWeight->sizePolicy().hasHeightForWidth());
        horizontalSliderWeight->setSizePolicy(sizePolicy2);
        horizontalSliderWeight->setMaximum(300);
        horizontalSliderWeight->setOrientation(Qt::Horizontal);

        centerGrid->addWidget(horizontalSliderWeight, 4, 1, 1, 1);

        labelRed = new QLabel(eq2Dialog);
        labelRed->setObjectName(QString::fromUtf8("labelRed"));

        centerGrid->addWidget(labelRed, 1, 0, 1, 1);

        labelInitial = new QLabel(eq2Dialog);
        labelInitial->setObjectName(QString::fromUtf8("labelInitial"));

        centerGrid->addWidget(labelInitial, 0, 0, 1, 1);

        labelGreen = new QLabel(eq2Dialog);
        labelGreen->setObjectName(QString::fromUtf8("labelGreen"));

        centerGrid->addWidget(labelGreen, 2, 0, 1, 1);


        verticalLayoutGamma->addLayout(centerGrid);


        horizontalLayoutPanel->addLayout(verticalLayoutGamma);

        line_2 = new QFrame(eq2Dialog);
        line_2->setObjectName(QString::fromUtf8("line_2"));
        line_2->setFrameShape(QFrame::VLine);
        line_2->setFrameShadow(QFrame::Sunken);

        horizontalLayoutPanel->addWidget(line_2);

        graphicsViewHistogram = new QGraphicsView(eq2Dialog);
        graphicsViewHistogram->setObjectName(QString::fromUtf8("graphicsViewHistogram"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(graphicsViewHistogram->sizePolicy().hasHeightForWidth());
        graphicsViewHistogram->setSizePolicy(sizePolicy3);
        graphicsViewHistogram->setMinimumSize(QSize(256, 128));
        graphicsViewHistogram->setMaximumSize(QSize(256, 128));
        graphicsViewHistogram->setFocusPolicy(Qt::NoFocus);
        graphicsViewHistogram->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewHistogram->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        horizontalLayoutPanel->addWidget(graphicsViewHistogram);


        verticalLayout_2->addLayout(horizontalLayoutPanel);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout_2->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(eq2Dialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout_2->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(eq2Dialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout_2->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(eq2Dialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(eq2Dialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), eq2Dialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), eq2Dialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(eq2Dialog);
    } // setupUi

    void retranslateUi(QDialog *eq2Dialog)
    {
        eq2Dialog->setWindowTitle(QCoreApplication::translate("eq2Dialog", "Contrast", nullptr));
        labelContrast->setText(QCoreApplication::translate("eq2Dialog", "Contrast", nullptr));
        labelBrightness->setText(QCoreApplication::translate("eq2Dialog", "Brightness", nullptr));
        labelSaturation->setText(QCoreApplication::translate("eq2Dialog", "Saturation", nullptr));
        labelGamma->setText(QCoreApplication::translate("eq2Dialog", "<b>Gamma</b>", nullptr));
        labelWeight->setText(QCoreApplication::translate("eq2Dialog", "Weight", nullptr));
        labelBlue->setText(QCoreApplication::translate("eq2Dialog", "Blue", nullptr));
        labelRed->setText(QCoreApplication::translate("eq2Dialog", "Red", nullptr));
        labelInitial->setText(QCoreApplication::translate("eq2Dialog", "Initial", nullptr));
        labelGreen->setText(QCoreApplication::translate("eq2Dialog", "Green", nullptr));
    } // retranslateUi

};

namespace Ui {
    class eq2Dialog: public Ui_eq2Dialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_EQ2_H
