/********************************************************************************
** Form generated from reading UI file 'processing.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROCESSING_H
#define UI_PROCESSING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>

QT_BEGIN_NAMESPACE

class Ui_DialogProcessing
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *labelTimeLeft;
    QLabel *labelSpeed;
    QDialogButtonBox *buttonBox;
    QLabel *label_2;
    QLabel *labelImages_xx;
    QSpacerItem *verticalSpacer_2;
    QLabel *labelImages;
    QProgressBar *progressBar;
    QSpacerItem *verticalSpacer_1;

    void setupUi(QDialog *DialogProcessing)
    {
        if (DialogProcessing->objectName().isEmpty())
            DialogProcessing->setObjectName(QString::fromUtf8("DialogProcessing"));
        DialogProcessing->resize(300, 186);
        gridLayout = new QGridLayout(DialogProcessing);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(DialogProcessing);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        labelTimeLeft = new QLabel(DialogProcessing);
        labelTimeLeft->setObjectName(QString::fromUtf8("labelTimeLeft"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelTimeLeft->sizePolicy().hasHeightForWidth());
        labelTimeLeft->setSizePolicy(sizePolicy);

        gridLayout->addWidget(labelTimeLeft, 0, 1, 1, 1);

        labelSpeed = new QLabel(DialogProcessing);
        labelSpeed->setObjectName(QString::fromUtf8("labelSpeed"));

        gridLayout->addWidget(labelSpeed, 2, 1, 1, 1);

        buttonBox = new QDialogButtonBox(DialogProcessing);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        gridLayout->addWidget(buttonBox, 6, 0, 1, 2);

        label_2 = new QLabel(DialogProcessing);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        labelImages_xx = new QLabel(DialogProcessing);
        labelImages_xx->setObjectName(QString::fromUtf8("labelImages_xx"));

        gridLayout->addWidget(labelImages_xx, 1, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout->addItem(verticalSpacer_2, 5, 0, 1, 1);

        labelImages = new QLabel(DialogProcessing);
        labelImages->setObjectName(QString::fromUtf8("labelImages"));

        gridLayout->addWidget(labelImages, 1, 1, 1, 1);

        progressBar = new QProgressBar(DialogProcessing);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setValue(24);

        gridLayout->addWidget(progressBar, 4, 0, 1, 2);

        verticalSpacer_1 = new QSpacerItem(20, 5, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout->addItem(verticalSpacer_1, 3, 0, 1, 1);


        retranslateUi(DialogProcessing);

        QMetaObject::connectSlotsByName(DialogProcessing);
    } // setupUi

    void retranslateUi(QDialog *DialogProcessing)
    {
        DialogProcessing->setWindowTitle(QCoreApplication::translate("DialogProcessing", "Dialog", nullptr));
        label->setText(QCoreApplication::translate("DialogProcessing", "TimeLeft", nullptr));
        labelTimeLeft->setText(QCoreApplication::translate("DialogProcessing", "00:00:00", nullptr));
        labelSpeed->setText(QCoreApplication::translate("DialogProcessing", "0 fps", nullptr));
        label_2->setText(QCoreApplication::translate("DialogProcessing", "Speed", nullptr));
        labelImages_xx->setText(QCoreApplication::translate("DialogProcessing", "ProcessImages", nullptr));
        labelImages->setText(QCoreApplication::translate("DialogProcessing", "0", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogProcessing: public Ui_DialogProcessing {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PROCESSING_H
