/********************************************************************************
** Form generated from reading UI file 'artDynThreshold.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTDYNTHRESHOLD_H
#define UI_ARTDYNTHRESHOLD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artDynThresholdDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    ADM_SliderIndicator *horizontalSliderLevels;
    QLabel *labelLevels;
    QSpacerItem *horizontalSpacer;
    QLabel *labelOffset;
    ADM_SliderIndicator *horizontalSliderOffset;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artDynThresholdDialog)
    {
        if (artDynThresholdDialog->objectName().isEmpty())
            artDynThresholdDialog->setObjectName(QString::fromUtf8("artDynThresholdDialog"));
        artDynThresholdDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(artDynThresholdDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSliderLevels = new ADM_SliderIndicator(artDynThresholdDialog);
        horizontalSliderLevels->setObjectName(QString::fromUtf8("horizontalSliderLevels"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(horizontalSliderLevels->sizePolicy().hasHeightForWidth());
        horizontalSliderLevels->setSizePolicy(sizePolicy);
        horizontalSliderLevels->setMinimum(2);
        horizontalSliderLevels->setMaximum(16);
        horizontalSliderLevels->setPageStep(1);
        horizontalSliderLevels->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderLevels, 0, 1, 1, 1);

        labelLevels = new QLabel(artDynThresholdDialog);
        labelLevels->setObjectName(QString::fromUtf8("labelLevels"));

        gridLayout->addWidget(labelLevels, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);

        labelOffset = new QLabel(artDynThresholdDialog);
        labelOffset->setObjectName(QString::fromUtf8("labelOffset"));

        gridLayout->addWidget(labelOffset, 1, 0, 1, 1);

        horizontalSliderOffset = new ADM_SliderIndicator(artDynThresholdDialog);
        horizontalSliderOffset->setObjectName(QString::fromUtf8("horizontalSliderOffset"));
        horizontalSliderOffset->setMinimum(-100);
        horizontalSliderOffset->setMaximum(100);
        horizontalSliderOffset->setPageStep(20);
        horizontalSliderOffset->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderOffset, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artDynThresholdDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artDynThresholdDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artDynThresholdDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(artDynThresholdDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artDynThresholdDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artDynThresholdDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artDynThresholdDialog);
    } // setupUi

    void retranslateUi(QDialog *artDynThresholdDialog)
    {
        artDynThresholdDialog->setWindowTitle(QCoreApplication::translate("artDynThresholdDialog", "Dynamic Threshold", nullptr));
        labelLevels->setText(QCoreApplication::translate("artDynThresholdDialog", "Levels", nullptr));
        labelOffset->setText(QCoreApplication::translate("artDynThresholdDialog", "Offset", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artDynThresholdDialog: public Ui_artDynThresholdDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTDYNTHRESHOLD_H
