/********************************************************************************
** Form generated from reading UI file 'artVignette.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTVIGNETTE_H
#define UI_ARTVIGNETTE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artVignetteDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QSlider *horizontalSliderCenter;
    QSlider *horizontalSliderAspect;
    QLabel *labelAspect;
    QSlider *horizontalSliderSoft;
    QLabel *labelSoftness;
    QLabel *labelCenter;
    QSpacerItem *panelSpacer;
    QDoubleSpinBox *doubleSpinBoxAspect;
    QDoubleSpinBox *doubleSpinBoxCenter;
    QDoubleSpinBox *doubleSpinBoxSoft;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artVignetteDialog)
    {
        if (artVignetteDialog->objectName().isEmpty())
            artVignetteDialog->setObjectName(QString::fromUtf8("artVignetteDialog"));
        artVignetteDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(artVignetteDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        horizontalSliderCenter = new QSlider(artVignetteDialog);
        horizontalSliderCenter->setObjectName(QString::fromUtf8("horizontalSliderCenter"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(horizontalSliderCenter->sizePolicy().hasHeightForWidth());
        horizontalSliderCenter->setSizePolicy(sizePolicy);
        horizontalSliderCenter->setMaximum(100);
        horizontalSliderCenter->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderCenter, 1, 1, 1, 1);

        horizontalSliderAspect = new QSlider(artVignetteDialog);
        horizontalSliderAspect->setObjectName(QString::fromUtf8("horizontalSliderAspect"));
        sizePolicy.setHeightForWidth(horizontalSliderAspect->sizePolicy().hasHeightForWidth());
        horizontalSliderAspect->setSizePolicy(sizePolicy);
        horizontalSliderAspect->setMinimum(0);
        horizontalSliderAspect->setMaximum(100);
        horizontalSliderAspect->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderAspect, 0, 1, 1, 1);

        labelAspect = new QLabel(artVignetteDialog);
        labelAspect->setObjectName(QString::fromUtf8("labelAspect"));

        gridLayout->addWidget(labelAspect, 0, 0, 1, 1);

        horizontalSliderSoft = new QSlider(artVignetteDialog);
        horizontalSliderSoft->setObjectName(QString::fromUtf8("horizontalSliderSoft"));
        sizePolicy.setHeightForWidth(horizontalSliderSoft->sizePolicy().hasHeightForWidth());
        horizontalSliderSoft->setSizePolicy(sizePolicy);
        horizontalSliderSoft->setMaximum(100);
        horizontalSliderSoft->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderSoft, 2, 1, 1, 1);

        labelSoftness = new QLabel(artVignetteDialog);
        labelSoftness->setObjectName(QString::fromUtf8("labelSoftness"));

        gridLayout->addWidget(labelSoftness, 2, 0, 1, 1);

        labelCenter = new QLabel(artVignetteDialog);
        labelCenter->setObjectName(QString::fromUtf8("labelCenter"));

        gridLayout->addWidget(labelCenter, 1, 0, 1, 1);

        panelSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(panelSpacer, 0, 3, 1, 1);

        doubleSpinBoxAspect = new QDoubleSpinBox(artVignetteDialog);
        doubleSpinBoxAspect->setObjectName(QString::fromUtf8("doubleSpinBoxAspect"));
        doubleSpinBoxAspect->setMaximum(1.000000000000000);
        doubleSpinBoxAspect->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxAspect, 0, 2, 1, 1);

        doubleSpinBoxCenter = new QDoubleSpinBox(artVignetteDialog);
        doubleSpinBoxCenter->setObjectName(QString::fromUtf8("doubleSpinBoxCenter"));
        doubleSpinBoxCenter->setMaximum(1.000000000000000);
        doubleSpinBoxCenter->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxCenter, 1, 2, 1, 1);

        doubleSpinBoxSoft = new QDoubleSpinBox(artVignetteDialog);
        doubleSpinBoxSoft->setObjectName(QString::fromUtf8("doubleSpinBoxSoft"));
        doubleSpinBoxSoft->setMaximum(1.000000000000000);
        doubleSpinBoxSoft->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxSoft, 2, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artVignetteDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artVignetteDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artVignetteDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(artVignetteDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artVignetteDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artVignetteDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artVignetteDialog);
    } // setupUi

    void retranslateUi(QDialog *artVignetteDialog)
    {
        artVignetteDialog->setWindowTitle(QCoreApplication::translate("artVignetteDialog", "Vignette", nullptr));
        labelAspect->setText(QCoreApplication::translate("artVignetteDialog", "Aspect ratio", nullptr));
        labelSoftness->setText(QCoreApplication::translate("artVignetteDialog", "Softness", nullptr));
        labelCenter->setText(QCoreApplication::translate("artVignetteDialog", "Size of the unaffected center", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artVignetteDialog: public Ui_artVignetteDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTVIGNETTE_H
