/********************************************************************************
** Form generated from reading UI file 'shell.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SHELL_H
#define UI_SHELL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>

QT_BEGIN_NAMESPACE

class Ui_SpiderMonkeyShell
{
public:
    QGridLayout *gridLayout;
    QTextBrowser *textBrowser;
    QSpacerItem *horizontalSpacer;
    QPushButton *clear;
    QSpacerItem *horizontalSpacer_3;
    QTextBrowser *textBrowser_2;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *evalute;
    QSpacerItem *horizontalSpacer_4;

    void setupUi(QDialog *SpiderMonkeyShell)
    {
        if (SpiderMonkeyShell->objectName().isEmpty())
            SpiderMonkeyShell->setObjectName(QString::fromUtf8("SpiderMonkeyShell"));
        SpiderMonkeyShell->setWindowModality(Qt::ApplicationModal);
        SpiderMonkeyShell->resize(619, 384);
        SpiderMonkeyShell->setModal(true);
        gridLayout = new QGridLayout(SpiderMonkeyShell);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        textBrowser = new QTextBrowser(SpiderMonkeyShell);
        textBrowser->setObjectName(QString::fromUtf8("textBrowser"));
        textBrowser->setFocusPolicy(Qt::NoFocus);
        textBrowser->setContextMenuPolicy(Qt::NoContextMenu);

        gridLayout->addWidget(textBrowser, 0, 0, 1, 4);

        horizontalSpacer = new QSpacerItem(259, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);

        clear = new QPushButton(SpiderMonkeyShell);
        clear->setObjectName(QString::fromUtf8("clear"));

        gridLayout->addWidget(clear, 1, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(276, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 1, 2, 1, 2);

        textBrowser_2 = new QTextBrowser(SpiderMonkeyShell);
        textBrowser_2->setObjectName(QString::fromUtf8("textBrowser_2"));
        textBrowser_2->setReadOnly(false);

        gridLayout->addWidget(textBrowser_2, 2, 0, 1, 4);

        horizontalSpacer_2 = new QSpacerItem(259, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 3, 0, 1, 1);

        evalute = new QPushButton(SpiderMonkeyShell);
        evalute->setObjectName(QString::fromUtf8("evalute"));

        gridLayout->addWidget(evalute, 3, 1, 1, 2);

        horizontalSpacer_4 = new QSpacerItem(258, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 3, 3, 1, 1);


        retranslateUi(SpiderMonkeyShell);

        QMetaObject::connectSlotsByName(SpiderMonkeyShell);
    } // setupUi

    void retranslateUi(QDialog *SpiderMonkeyShell)
    {
        SpiderMonkeyShell->setWindowTitle(QCoreApplication::translate("SpiderMonkeyShell", "Shell", nullptr));
        clear->setText(QCoreApplication::translate("SpiderMonkeyShell", "Clear", nullptr));
        evalute->setText(QCoreApplication::translate("SpiderMonkeyShell", "Evaluate", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SpiderMonkeyShell: public Ui_SpiderMonkeyShell {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SHELL_H
