/********************************************************************************
** Form generated from reading UI file 'artGrid.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTGRID_H
#define UI_ARTGRID_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artGridDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QSlider *horizontalSliderSize;
    QLabel *labelHScatter;
    QSpacerItem *horizontalSpacer;
    QSpinBox *spinBoxSize;
    QCheckBox *checkBoxRoll;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artGridDialog)
    {
        if (artGridDialog->objectName().isEmpty())
            artGridDialog->setObjectName(QString::fromUtf8("artGridDialog"));
        artGridDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(artGridDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSliderSize = new QSlider(artGridDialog);
        horizontalSliderSize->setObjectName(QString::fromUtf8("horizontalSliderSize"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(horizontalSliderSize->sizePolicy().hasHeightForWidth());
        horizontalSliderSize->setSizePolicy(sizePolicy);
        horizontalSliderSize->setMinimum(2);
        horizontalSliderSize->setMaximum(8);
        horizontalSliderSize->setPageStep(1);
        horizontalSliderSize->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderSize, 0, 1, 1, 1);

        labelHScatter = new QLabel(artGridDialog);
        labelHScatter->setObjectName(QString::fromUtf8("labelHScatter"));

        gridLayout->addWidget(labelHScatter, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        spinBoxSize = new QSpinBox(artGridDialog);
        spinBoxSize->setObjectName(QString::fromUtf8("spinBoxSize"));
        spinBoxSize->setMinimum(2);
        spinBoxSize->setMaximum(8);

        gridLayout->addWidget(spinBoxSize, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        checkBoxRoll = new QCheckBox(artGridDialog);
        checkBoxRoll->setObjectName(QString::fromUtf8("checkBoxRoll"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(checkBoxRoll->sizePolicy().hasHeightForWidth());
        checkBoxRoll->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(checkBoxRoll);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artGridDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artGridDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artGridDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(artGridDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artGridDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artGridDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artGridDialog);
    } // setupUi

    void retranslateUi(QDialog *artGridDialog)
    {
        artGridDialog->setWindowTitle(QCoreApplication::translate("artGridDialog", "Grid", nullptr));
        labelHScatter->setText(QCoreApplication::translate("artGridDialog", "Grid size", nullptr));
        checkBoxRoll->setText(QCoreApplication::translate("artGridDialog", "Roll previous frames", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artGridDialog: public Ui_artGridDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTGRID_H
