/********************************************************************************
** Form generated from reading UI file 'artMirror.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTMIRROR_H
#define UI_ARTMIRROR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artMirrorDialog
{
public:
    QGridLayout *gridLayout;
    ADM_flyNavSlider *horizontalSlider;
    QDialogButtonBox *buttonBox;
    QGraphicsView *graphicsView;
    QSpacerItem *spacerItem;
    QHBoxLayout *toolboxLayout;
    QGridLayout *gridLayout1;
    ADM_SliderIndicator *horizontalSliderDisplacement;
    QLabel *label_3;
    QComboBox *comboBoxMethod;

    void setupUi(QDialog *artMirrorDialog)
    {
        if (artMirrorDialog->objectName().isEmpty())
            artMirrorDialog->setObjectName(QString::fromUtf8("artMirrorDialog"));
        artMirrorDialog->resize(505, 475);
        gridLayout = new QGridLayout(artMirrorDialog);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        horizontalSlider = new ADM_flyNavSlider(artMirrorDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSlider, 2, 0, 1, 2);

        buttonBox = new QDialogButtonBox(artMirrorDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 5, 0, 1, 2);

        graphicsView = new QGraphicsView(artMirrorDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));

        gridLayout->addWidget(graphicsView, 3, 0, 1, 2);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(spacerItem, 4, 1, 1, 1);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        gridLayout->addLayout(toolboxLayout, 1, 0, 1, 1);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        horizontalSliderDisplacement = new ADM_SliderIndicator(artMirrorDialog);
        horizontalSliderDisplacement->setObjectName(QString::fromUtf8("horizontalSliderDisplacement"));
        horizontalSliderDisplacement->setMinimum(0);
        horizontalSliderDisplacement->setMaximum(100);
        horizontalSliderDisplacement->setOrientation(Qt::Horizontal);

        gridLayout1->addWidget(horizontalSliderDisplacement, 1, 2, 1, 1);

        label_3 = new QLabel(artMirrorDialog);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout1->addWidget(label_3, 1, 1, 1, 1);

        comboBoxMethod = new QComboBox(artMirrorDialog);
        comboBoxMethod->addItem(QString());
        comboBoxMethod->addItem(QString());
        comboBoxMethod->addItem(QString());
        comboBoxMethod->addItem(QString());
        comboBoxMethod->setObjectName(QString::fromUtf8("comboBoxMethod"));

        gridLayout1->addWidget(comboBoxMethod, 1, 0, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 2);

        QWidget::setTabOrder(comboBoxMethod, horizontalSliderDisplacement);
        QWidget::setTabOrder(horizontalSliderDisplacement, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, graphicsView);

        retranslateUi(artMirrorDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artMirrorDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artMirrorDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artMirrorDialog);
    } // setupUi

    void retranslateUi(QDialog *artMirrorDialog)
    {
        artMirrorDialog->setWindowTitle(QCoreApplication::translate("artMirrorDialog", "Mirror", nullptr));
        label_3->setText(QCoreApplication::translate("artMirrorDialog", "Displacement", nullptr));
        comboBoxMethod->setItemText(0, QCoreApplication::translate("artMirrorDialog", "Horizontal - keep left", nullptr));
        comboBoxMethod->setItemText(1, QCoreApplication::translate("artMirrorDialog", "Horizontal - keep right", nullptr));
        comboBoxMethod->setItemText(2, QCoreApplication::translate("artMirrorDialog", "Vertical - keep top", nullptr));
        comboBoxMethod->setItemText(3, QCoreApplication::translate("artMirrorDialog", "Vertical - keep bottom", nullptr));

    } // retranslateUi

};

namespace Ui {
    class artMirrorDialog: public Ui_artMirrorDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTMIRROR_H
