/********************************************************************************
** Form generated from reading UI file 'analyzer.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ANALYZER_H
#define UI_ANALYZER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_analyzerDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGridLayout *gridLayout;
    QGraphicsView *graphicsViewHistograms;
    QGraphicsView *graphicsViewYUVparade;
    QGraphicsView *graphicsViewVectorScope;
    QGraphicsView *graphicsViewRGBparade;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *analyzerDialog)
    {
        if (analyzerDialog->objectName().isEmpty())
            analyzerDialog->setObjectName(QString::fromUtf8("analyzerDialog"));
        analyzerDialog->resize(799, 674);
        verticalLayout = new QVBoxLayout(analyzerDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(analyzerDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        graphicsViewHistograms = new QGraphicsView(analyzerDialog);
        graphicsViewHistograms->setObjectName(QString::fromUtf8("graphicsViewHistograms"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(graphicsViewHistograms->sizePolicy().hasHeightForWidth());
        graphicsViewHistograms->setSizePolicy(sizePolicy);
        graphicsViewHistograms->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewHistograms->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        QBrush brush(QColor(0, 0, 0, 255));
        brush.setStyle(Qt::SolidPattern);
        graphicsViewHistograms->setBackgroundBrush(brush);
        graphicsViewHistograms->setRenderHints(QPainter::TextAntialiasing);

        gridLayout->addWidget(graphicsViewHistograms, 0, 2, 1, 1);

        graphicsViewYUVparade = new QGraphicsView(analyzerDialog);
        graphicsViewYUVparade->setObjectName(QString::fromUtf8("graphicsViewYUVparade"));
        sizePolicy.setHeightForWidth(graphicsViewYUVparade->sizePolicy().hasHeightForWidth());
        graphicsViewYUVparade->setSizePolicy(sizePolicy);
        graphicsViewYUVparade->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewYUVparade->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewYUVparade->setBackgroundBrush(brush);
        graphicsViewYUVparade->setRenderHints(QPainter::Antialiasing|QPainter::SmoothPixmapTransform|QPainter::TextAntialiasing);

        gridLayout->addWidget(graphicsViewYUVparade, 2, 2, 1, 1);

        graphicsViewVectorScope = new QGraphicsView(analyzerDialog);
        graphicsViewVectorScope->setObjectName(QString::fromUtf8("graphicsViewVectorScope"));
        sizePolicy.setHeightForWidth(graphicsViewVectorScope->sizePolicy().hasHeightForWidth());
        graphicsViewVectorScope->setSizePolicy(sizePolicy);
        graphicsViewVectorScope->setMinimumSize(QSize(0, 0));
        graphicsViewVectorScope->setAutoFillBackground(false);
        graphicsViewVectorScope->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewVectorScope->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewVectorScope->setBackgroundBrush(brush);
        graphicsViewVectorScope->setRenderHints(QPainter::Antialiasing|QPainter::SmoothPixmapTransform|QPainter::TextAntialiasing);

        gridLayout->addWidget(graphicsViewVectorScope, 1, 0, 2, 2);

        graphicsViewRGBparade = new QGraphicsView(analyzerDialog);
        graphicsViewRGBparade->setObjectName(QString::fromUtf8("graphicsViewRGBparade"));
        sizePolicy.setHeightForWidth(graphicsViewRGBparade->sizePolicy().hasHeightForWidth());
        graphicsViewRGBparade->setSizePolicy(sizePolicy);
        graphicsViewRGBparade->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewRGBparade->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewRGBparade->setBackgroundBrush(brush);
        graphicsViewRGBparade->setRenderHints(QPainter::Antialiasing|QPainter::SmoothPixmapTransform|QPainter::TextAntialiasing);

        gridLayout->addWidget(graphicsViewRGBparade, 1, 2, 1, 1);

        graphicsView = new QGraphicsView(analyzerDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        sizePolicy.setHeightForWidth(graphicsView->sizePolicy().hasHeightForWidth());
        graphicsView->setSizePolicy(sizePolicy);
        graphicsView->setFocusPolicy(Qt::NoFocus);

        gridLayout->addWidget(graphicsView, 0, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        buttonBox = new QDialogButtonBox(analyzerDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy1);
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(analyzerDialog);
        QObject::connect(buttonBox, SIGNAL(rejected()), analyzerDialog, SLOT(reject()));
        QObject::connect(buttonBox, SIGNAL(accepted()), analyzerDialog, SLOT(accept()));

        QMetaObject::connectSlotsByName(analyzerDialog);
    } // setupUi

    void retranslateUi(QDialog *analyzerDialog)
    {
        analyzerDialog->setWindowTitle(QCoreApplication::translate("analyzerDialog", "Analyzer", nullptr));
    } // retranslateUi

};

namespace Ui {
    class analyzerDialog: public Ui_analyzerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ANALYZER_H
