/********************************************************************************
** Form generated from reading UI file 'artVHS.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTVHS_H
#define UI_ARTVHS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artVHSDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QCheckBox *checkBoxLumaNoDelay;
    QLabel *labelChroma;
    QCheckBox *checkBoxChromaNoDelay;
    ADM_SliderIndicator *horizontalSliderLumaBW;
    ADM_SliderIndicator *horizontalSliderUnSync;
    QSpacerItem *horizontalSpacerPanel;
    ADM_SliderIndicator *horizontalSliderChromaBW;
    QLabel *labelFilter;
    ADM_SliderIndicator *horizontalSliderUnSyncFilter;
    QLabel *labelSync;
    QLabel *labelLuma;
    QLabel *labelNoise;
    ADM_SliderIndicator *horizontalSliderNoise;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artVHSDialog)
    {
        if (artVHSDialog->objectName().isEmpty())
            artVHSDialog->setObjectName(QString::fromUtf8("artVHSDialog"));
        artVHSDialog->resize(708, 485);
        verticalLayout = new QVBoxLayout(artVHSDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        checkBoxLumaNoDelay = new QCheckBox(artVHSDialog);
        checkBoxLumaNoDelay->setObjectName(QString::fromUtf8("checkBoxLumaNoDelay"));

        gridLayout->addWidget(checkBoxLumaNoDelay, 2, 2, 1, 1);

        labelChroma = new QLabel(artVHSDialog);
        labelChroma->setObjectName(QString::fromUtf8("labelChroma"));

        gridLayout->addWidget(labelChroma, 3, 0, 1, 1);

        checkBoxChromaNoDelay = new QCheckBox(artVHSDialog);
        checkBoxChromaNoDelay->setObjectName(QString::fromUtf8("checkBoxChromaNoDelay"));

        gridLayout->addWidget(checkBoxChromaNoDelay, 3, 2, 1, 1);

        horizontalSliderLumaBW = new ADM_SliderIndicator(artVHSDialog);
        horizontalSliderLumaBW->setObjectName(QString::fromUtf8("horizontalSliderLumaBW"));
        horizontalSliderLumaBW->setMinimum(0);
        horizontalSliderLumaBW->setMaximum(100);
        horizontalSliderLumaBW->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderLumaBW, 2, 1, 1, 1);

        horizontalSliderUnSync = new ADM_SliderIndicator(artVHSDialog);
        horizontalSliderUnSync->setObjectName(QString::fromUtf8("horizontalSliderUnSync"));
        horizontalSliderUnSync->setMaximum(160);
        horizontalSliderUnSync->setPageStep(20);
        horizontalSliderUnSync->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderUnSync, 4, 1, 1, 1);

        horizontalSpacerPanel = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacerPanel, 2, 3, 1, 1);

        horizontalSliderChromaBW = new ADM_SliderIndicator(artVHSDialog);
        horizontalSliderChromaBW->setObjectName(QString::fromUtf8("horizontalSliderChromaBW"));
        horizontalSliderChromaBW->setMaximum(100);
        horizontalSliderChromaBW->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderChromaBW, 3, 1, 1, 1);

        labelFilter = new QLabel(artVHSDialog);
        labelFilter->setObjectName(QString::fromUtf8("labelFilter"));

        gridLayout->addWidget(labelFilter, 5, 0, 1, 1);

        horizontalSliderUnSyncFilter = new ADM_SliderIndicator(artVHSDialog);
        horizontalSliderUnSyncFilter->setObjectName(QString::fromUtf8("horizontalSliderUnSyncFilter"));
        horizontalSliderUnSyncFilter->setMaximum(99);
        horizontalSliderUnSyncFilter->setPageStep(10);
        horizontalSliderUnSyncFilter->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderUnSyncFilter, 5, 1, 1, 1);

        labelSync = new QLabel(artVHSDialog);
        labelSync->setObjectName(QString::fromUtf8("labelSync"));

        gridLayout->addWidget(labelSync, 4, 0, 1, 1);

        labelLuma = new QLabel(artVHSDialog);
        labelLuma->setObjectName(QString::fromUtf8("labelLuma"));

        gridLayout->addWidget(labelLuma, 2, 0, 1, 1);

        labelNoise = new QLabel(artVHSDialog);
        labelNoise->setObjectName(QString::fromUtf8("labelNoise"));

        gridLayout->addWidget(labelNoise, 6, 0, 1, 1);

        horizontalSliderNoise = new ADM_SliderIndicator(artVHSDialog);
        horizontalSliderNoise->setObjectName(QString::fromUtf8("horizontalSliderNoise"));
        horizontalSliderNoise->setMaximum(100);
        horizontalSliderNoise->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderNoise, 6, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artVHSDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artVHSDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artVHSDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(artVHSDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artVHSDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artVHSDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artVHSDialog);
    } // setupUi

    void retranslateUi(QDialog *artVHSDialog)
    {
        artVHSDialog->setWindowTitle(QCoreApplication::translate("artVHSDialog", "VHS", nullptr));
        checkBoxLumaNoDelay->setText(QCoreApplication::translate("artVHSDialog", "Use zero delay filter for luma", nullptr));
        labelChroma->setText(QCoreApplication::translate("artVHSDialog", "Chroma bandwidth", nullptr));
        checkBoxChromaNoDelay->setText(QCoreApplication::translate("artVHSDialog", "Use zero delay filter for chroma", nullptr));
        labelFilter->setText(QCoreApplication::translate("artVHSDialog", "Sync error filter", nullptr));
        labelSync->setText(QCoreApplication::translate("artVHSDialog", "Sync error", nullptr));
        labelLuma->setText(QCoreApplication::translate("artVHSDialog", "Luma bandwidth", nullptr));
        labelNoise->setText(QCoreApplication::translate("artVHSDialog", "Noise", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artVHSDialog: public Ui_artVHSDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTVHS_H
