/********************************************************************************
** Form generated from reading UI file 'blackenBorders.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BLACKENBORDERS_H
#define UI_BLACKENBORDERS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_blackenDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QSpinBox *spinBoxRight;
    QSpacerItem *spacerItem;
    QLabel *labelRight;
    QLabel *labelTop;
    QSpinBox *spinBoxLeft;
    QSpacerItem *horizontalSpacer;
    QCheckBox *checkBoxRubber;
    QSpacerItem *spacerItem1;
    QSpinBox *spinBoxBottom;
    QLabel *labelLeft;
    QSpinBox *spinBoxTop;
    QLabel *labelBottom;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *blackenDialog)
    {
        if (blackenDialog->objectName().isEmpty())
            blackenDialog->setObjectName(QString::fromUtf8("blackenDialog"));
        blackenDialog->resize(600, 300);
        vboxLayout = new QVBoxLayout(blackenDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        spinBoxRight = new QSpinBox(blackenDialog);
        spinBoxRight->setObjectName(QString::fromUtf8("spinBoxRight"));
        spinBoxRight->setMaximum(99999);

        gridLayout->addWidget(spinBoxRight, 0, 4, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 1, 7, 1, 1);

        labelRight = new QLabel(blackenDialog);
        labelRight->setObjectName(QString::fromUtf8("labelRight"));

        gridLayout->addWidget(labelRight, 0, 3, 1, 1);

        labelTop = new QLabel(blackenDialog);
        labelTop->setObjectName(QString::fromUtf8("labelTop"));

        gridLayout->addWidget(labelTop, 1, 0, 1, 1);

        spinBoxLeft = new QSpinBox(blackenDialog);
        spinBoxLeft->setObjectName(QString::fromUtf8("spinBoxLeft"));
        spinBoxLeft->setMaximum(99999);

        gridLayout->addWidget(spinBoxLeft, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(26, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 5, 1, 1);

        checkBoxRubber = new QCheckBox(blackenDialog);
        checkBoxRubber->setObjectName(QString::fromUtf8("checkBoxRubber"));

        gridLayout->addWidget(checkBoxRubber, 1, 6, 1, 1);

        spacerItem1 = new QSpacerItem(26, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 2, 1, 1);

        spinBoxBottom = new QSpinBox(blackenDialog);
        spinBoxBottom->setObjectName(QString::fromUtf8("spinBoxBottom"));
        spinBoxBottom->setMaximum(99999);

        gridLayout->addWidget(spinBoxBottom, 1, 4, 1, 1);

        labelLeft = new QLabel(blackenDialog);
        labelLeft->setObjectName(QString::fromUtf8("labelLeft"));

        gridLayout->addWidget(labelLeft, 0, 0, 1, 1);

        spinBoxTop = new QSpinBox(blackenDialog);
        spinBoxTop->setObjectName(QString::fromUtf8("spinBoxTop"));
        spinBoxTop->setMaximum(99999);

        gridLayout->addWidget(spinBoxTop, 1, 1, 1, 1);

        labelBottom = new QLabel(blackenDialog);
        labelBottom->setObjectName(QString::fromUtf8("labelBottom"));

        gridLayout->addWidget(labelBottom, 1, 3, 1, 1);


        vboxLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        vboxLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(blackenDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        vboxLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(blackenDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        vboxLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(blackenDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(blackenDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), blackenDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), blackenDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(blackenDialog);
    } // setupUi

    void retranslateUi(QDialog *blackenDialog)
    {
        blackenDialog->setWindowTitle(QCoreApplication::translate("blackenDialog", "Blacken Borders", nullptr));
        labelRight->setText(QCoreApplication::translate("blackenDialog", "Right:", nullptr));
        labelTop->setText(QCoreApplication::translate("blackenDialog", "Top:", nullptr));
        checkBoxRubber->setText(QCoreApplication::translate("blackenDialog", "&Hide Rubber Band", nullptr));
        labelLeft->setText(QCoreApplication::translate("blackenDialog", "Left:", nullptr));
        labelBottom->setText(QCoreApplication::translate("blackenDialog", "Bottom:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class blackenDialog: public Ui_blackenDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BLACKENBORDERS_H
