/****************************************************************************
** Meta object code from reading C++ file 'Q_fadeThrough.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../avidemux_plugins/ADM_videoFilters6/fadeThrough/qt4/Q_fadeThrough.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Q_fadeThrough.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Ui_fadeThroughWindow_t {
    QByteArrayData data[17];
    char stringdata0[212];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Ui_fadeThroughWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Ui_fadeThroughWindow_t qt_meta_stringdata_Ui_fadeThroughWindow = {
    {
QT_MOC_LITERAL(0, 0, 20), // "Ui_fadeThroughWindow"
QT_MOC_LITERAL(1, 21, 6), // "gather"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 12), // "fadeThrough*"
QT_MOC_LITERAL(4, 42, 5), // "param"
QT_MOC_LITERAL(5, 48, 12), // "sliderUpdate"
QT_MOC_LITERAL(6, 61, 3), // "foo"
QT_MOC_LITERAL(7, 65, 15), // "manualTimeEntry"
QT_MOC_LITERAL(8, 81, 1), // "f"
QT_MOC_LITERAL(9, 83, 16), // "timesFromMarkers"
QT_MOC_LITERAL(10, 100, 24), // "centeredTimesFromMarkers"
QT_MOC_LITERAL(11, 125, 10), // "tabChanged"
QT_MOC_LITERAL(12, 136, 12), // "valueChanged"
QT_MOC_LITERAL(13, 149, 19), // "valueChangedSpinBox"
QT_MOC_LITERAL(14, 169, 16), // "pushedColorBlend"
QT_MOC_LITERAL(15, 186, 19), // "pushedColorVignette"
QT_MOC_LITERAL(16, 206, 5) // "reset"

    },
    "Ui_fadeThroughWindow\0gather\0\0fadeThrough*\0"
    "param\0sliderUpdate\0foo\0manualTimeEntry\0"
    "f\0timesFromMarkers\0centeredTimesFromMarkers\0"
    "tabChanged\0valueChanged\0valueChangedSpinBox\0"
    "pushedColorBlend\0pushedColorVignette\0"
    "reset"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Ui_fadeThroughWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x0a /* Public */,
       5,    1,   72,    2, 0x08 /* Private */,
       7,    1,   75,    2, 0x08 /* Private */,
       9,    1,   78,    2, 0x08 /* Private */,
      10,    1,   81,    2, 0x08 /* Private */,
      11,    1,   84,    2, 0x08 /* Private */,
      12,    1,   87,    2, 0x08 /* Private */,
      13,    1,   90,    2, 0x08 /* Private */,
      14,    0,   93,    2, 0x08 /* Private */,
      15,    0,   94,    2, 0x08 /* Private */,
      16,    1,   95,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Double,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    8,

       0        // eod
};

void Ui_fadeThroughWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Ui_fadeThroughWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->gather((*reinterpret_cast< fadeThrough*(*)>(_a[1]))); break;
        case 1: _t->sliderUpdate((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->manualTimeEntry((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->timesFromMarkers((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->centeredTimesFromMarkers((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->tabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->valueChangedSpinBox((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 8: _t->pushedColorBlend(); break;
        case 9: _t->pushedColorVignette(); break;
        case 10: _t->reset((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Ui_fadeThroughWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_Ui_fadeThroughWindow.data,
    qt_meta_data_Ui_fadeThroughWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Ui_fadeThroughWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ui_fadeThroughWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Ui_fadeThroughWindow.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Ui_fadeThroughWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
