/********************************************************************************
** Form generated from reading UI file 'mpdelogo.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MPDELOGO_H
#define UI_MPDELOGO_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_mpdelogoDialog
{
public:
    QGridLayout *gridLayoutMain;
    QVBoxLayout *main;
    QHBoxLayout *panel;
    QGridLayout *gridLayout;
    QLabel *labelX;
    QSpinBox *spinX;
    QSpinBox *spinW;
    QLabel *labelBorder;
    QLabel *labelWidth;
    QLabel *labelHeight;
    QSpinBox *spinH;
    QLabel *labelY;
    QSpinBox *spinY;
    QSpinBox *spinBand;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *toolboxLayout;
    QHBoxLayout *horizontalLayout_2;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QCheckBox *checkBoxPreview;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *mpdelogoDialog)
    {
        if (mpdelogoDialog->objectName().isEmpty())
            mpdelogoDialog->setObjectName(QString::fromUtf8("mpdelogoDialog"));
        mpdelogoDialog->resize(507, 488);
        gridLayoutMain = new QGridLayout(mpdelogoDialog);
        gridLayoutMain->setObjectName(QString::fromUtf8("gridLayoutMain"));
        main = new QVBoxLayout();
        main->setObjectName(QString::fromUtf8("main"));
        panel = new QHBoxLayout();
        panel->setObjectName(QString::fromUtf8("panel"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        labelX = new QLabel(mpdelogoDialog);
        labelX->setObjectName(QString::fromUtf8("labelX"));

        gridLayout->addWidget(labelX, 0, 0, 1, 1);

        spinX = new QSpinBox(mpdelogoDialog);
        spinX->setObjectName(QString::fromUtf8("spinX"));

        gridLayout->addWidget(spinX, 0, 1, 1, 1);

        spinW = new QSpinBox(mpdelogoDialog);
        spinW->setObjectName(QString::fromUtf8("spinW"));

        gridLayout->addWidget(spinW, 0, 3, 1, 1);

        labelBorder = new QLabel(mpdelogoDialog);
        labelBorder->setObjectName(QString::fromUtf8("labelBorder"));

        gridLayout->addWidget(labelBorder, 0, 4, 1, 1);

        labelWidth = new QLabel(mpdelogoDialog);
        labelWidth->setObjectName(QString::fromUtf8("labelWidth"));

        gridLayout->addWidget(labelWidth, 0, 2, 1, 1);

        labelHeight = new QLabel(mpdelogoDialog);
        labelHeight->setObjectName(QString::fromUtf8("labelHeight"));

        gridLayout->addWidget(labelHeight, 1, 2, 1, 1);

        spinH = new QSpinBox(mpdelogoDialog);
        spinH->setObjectName(QString::fromUtf8("spinH"));

        gridLayout->addWidget(spinH, 1, 3, 1, 1);

        labelY = new QLabel(mpdelogoDialog);
        labelY->setObjectName(QString::fromUtf8("labelY"));

        gridLayout->addWidget(labelY, 1, 0, 1, 1);

        spinY = new QSpinBox(mpdelogoDialog);
        spinY->setObjectName(QString::fromUtf8("spinY"));

        gridLayout->addWidget(spinY, 1, 1, 1, 1);

        spinBand = new QSpinBox(mpdelogoDialog);
        spinBand->setObjectName(QString::fromUtf8("spinBand"));

        gridLayout->addWidget(spinBand, 0, 5, 1, 1);


        panel->addLayout(gridLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        panel->addItem(horizontalSpacer);


        main->addLayout(panel);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        main->addLayout(toolboxLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));

        main->addLayout(horizontalLayout_2);

        horizontalSlider = new ADM_flyNavSlider(mpdelogoDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        main->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(mpdelogoDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        main->addWidget(graphicsView);

        checkBoxPreview = new QCheckBox(mpdelogoDialog);
        checkBoxPreview->setObjectName(QString::fromUtf8("checkBoxPreview"));

        main->addWidget(checkBoxPreview);


        gridLayoutMain->addLayout(main, 0, 0, 1, 2);

        buttonBox = new QDialogButtonBox(mpdelogoDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayoutMain->addWidget(buttonBox, 1, 0, 1, 1);


        retranslateUi(mpdelogoDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), mpdelogoDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), mpdelogoDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(mpdelogoDialog);
    } // setupUi

    void retranslateUi(QDialog *mpdelogoDialog)
    {
        mpdelogoDialog->setWindowTitle(QCoreApplication::translate("mpdelogoDialog", "Mplayer Delogo", nullptr));
        labelX->setText(QCoreApplication::translate("mpdelogoDialog", "X", nullptr));
        labelBorder->setText(QCoreApplication::translate("mpdelogoDialog", "Border Width", nullptr));
        labelWidth->setText(QCoreApplication::translate("mpdelogoDialog", "Width", nullptr));
        labelHeight->setText(QCoreApplication::translate("mpdelogoDialog", "Height", nullptr));
        labelY->setText(QCoreApplication::translate("mpdelogoDialog", "Y", nullptr));
        checkBoxPreview->setText(QCoreApplication::translate("mpdelogoDialog", "Preview", nullptr));
    } // retranslateUi

};

namespace Ui {
    class mpdelogoDialog: public Ui_mpdelogoDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MPDELOGO_H
