/********************************************************************************
** Form generated from reading UI file 'waveletDenoise.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WAVELETDENOISE_H
#define UI_WAVELETDENOISE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_waveletDenoiseDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelThreshold;
    QLabel *labelSoftness;
    QSlider *horizontalSliderThreshold;
    QSlider *horizontalSliderSoftness;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *checkBoxHQ;
    QCheckBox *checkBoxChroma;
    QDoubleSpinBox *doubleSpinBoxThreshold;
    QDoubleSpinBox *doubleSpinBoxSoftness;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *waveletDenoiseDialog)
    {
        if (waveletDenoiseDialog->objectName().isEmpty())
            waveletDenoiseDialog->setObjectName(QString::fromUtf8("waveletDenoiseDialog"));
        waveletDenoiseDialog->resize(553, 401);
        verticalLayout = new QVBoxLayout(waveletDenoiseDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        labelThreshold = new QLabel(waveletDenoiseDialog);
        labelThreshold->setObjectName(QString::fromUtf8("labelThreshold"));

        gridLayout->addWidget(labelThreshold, 1, 0, 1, 1);

        labelSoftness = new QLabel(waveletDenoiseDialog);
        labelSoftness->setObjectName(QString::fromUtf8("labelSoftness"));

        gridLayout->addWidget(labelSoftness, 2, 0, 1, 1);

        horizontalSliderThreshold = new QSlider(waveletDenoiseDialog);
        horizontalSliderThreshold->setObjectName(QString::fromUtf8("horizontalSliderThreshold"));
        horizontalSliderThreshold->setMinimum(0);
        horizontalSliderThreshold->setMaximum(100);
        horizontalSliderThreshold->setPageStep(10);
        horizontalSliderThreshold->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderThreshold, 1, 1, 1, 1);

        horizontalSliderSoftness = new QSlider(waveletDenoiseDialog);
        horizontalSliderSoftness->setObjectName(QString::fromUtf8("horizontalSliderSoftness"));
        horizontalSliderSoftness->setMaximum(100);
        horizontalSliderSoftness->setPageStep(10);
        horizontalSliderSoftness->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderSoftness, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 3, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 3, 1, 1);

        checkBoxHQ = new QCheckBox(waveletDenoiseDialog);
        checkBoxHQ->setObjectName(QString::fromUtf8("checkBoxHQ"));

        gridLayout->addWidget(checkBoxHQ, 3, 0, 1, 2);

        checkBoxChroma = new QCheckBox(waveletDenoiseDialog);
        checkBoxChroma->setObjectName(QString::fromUtf8("checkBoxChroma"));

        gridLayout->addWidget(checkBoxChroma, 4, 0, 1, 2);

        doubleSpinBoxThreshold = new QDoubleSpinBox(waveletDenoiseDialog);
        doubleSpinBoxThreshold->setObjectName(QString::fromUtf8("doubleSpinBoxThreshold"));
        doubleSpinBoxThreshold->setMaximum(1.000000000000000);
        doubleSpinBoxThreshold->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxThreshold, 1, 2, 1, 1);

        doubleSpinBoxSoftness = new QDoubleSpinBox(waveletDenoiseDialog);
        doubleSpinBoxSoftness->setObjectName(QString::fromUtf8("doubleSpinBoxSoftness"));
        doubleSpinBoxSoftness->setMaximum(1.000000000000000);
        doubleSpinBoxSoftness->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxSoftness, 2, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(waveletDenoiseDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(waveletDenoiseDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(waveletDenoiseDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(waveletDenoiseDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), waveletDenoiseDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), waveletDenoiseDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(waveletDenoiseDialog);
    } // setupUi

    void retranslateUi(QDialog *waveletDenoiseDialog)
    {
        waveletDenoiseDialog->setWindowTitle(QCoreApplication::translate("waveletDenoiseDialog", "Wavelet Denoiser", nullptr));
        labelThreshold->setText(QCoreApplication::translate("waveletDenoiseDialog", "Threshold", nullptr));
        labelSoftness->setText(QCoreApplication::translate("waveletDenoiseDialog", "Softness", nullptr));
        checkBoxHQ->setText(QCoreApplication::translate("waveletDenoiseDialog", "High quality", nullptr));
        checkBoxChroma->setText(QCoreApplication::translate("waveletDenoiseDialog", "Denoise chroma", nullptr));
    } // retranslateUi

};

namespace Ui {
    class waveletDenoiseDialog: public Ui_waveletDenoiseDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WAVELETDENOISE_H
