/********************************************************************************
** Form generated from reading UI file 'colorBalance.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORBALANCE_H
#define UI_COLORBALANCE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDial>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_colorBalanceDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QGroupBox *groupBoxHighlight;
    QGridLayout *gridLayout_4;
    ADM_SliderIndicator *sliderHiLuma;
    QDial *dialHiHue;
    QSpacerItem *horizontalSpacer_7;
    QLabel *labelHiSaturation;
    ADM_SliderIndicator *sliderHiChromaShift;
    ADM_SliderIndicator *sliderHiSaturation;
    QLabel *labelHiChromaShift;
    QGroupBox *groupBoxShadow;
    QGridLayout *gridLayout_2;
    ADM_SliderIndicator *sliderLoLuma;
    QDial *dialLoHue;
    QSpacerItem *horizontalSpacer_5;
    ADM_SliderIndicator *sliderLoChromaShift;
    ADM_SliderIndicator *sliderLoSaturation;
    QLabel *labelLoSaturation;
    QLabel *labelLoChromaShift;
    QGroupBox *groupBoxMidtone;
    QGridLayout *gridLayout_3;
    QSpacerItem *horizontalSpacer_6;
    ADM_SliderIndicator *sliderMdLuma;
    QDial *dialMdHue;
    ADM_SliderIndicator *sliderMdChromaShift;
    ADM_SliderIndicator *sliderMdSaturation;
    QLabel *labelMdSaturation;
    QLabel *labelMdChromaShift;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QFrame *line_2;
    QFrame *line;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *colorBalanceDialog)
    {
        if (colorBalanceDialog->objectName().isEmpty())
            colorBalanceDialog->setObjectName(QString::fromUtf8("colorBalanceDialog"));
        colorBalanceDialog->resize(906, 414);
        colorBalanceDialog->setMinimumSize(QSize(0, 0));
        verticalLayout = new QVBoxLayout(colorBalanceDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        groupBoxHighlight = new QGroupBox(colorBalanceDialog);
        groupBoxHighlight->setObjectName(QString::fromUtf8("groupBoxHighlight"));
        gridLayout_4 = new QGridLayout(groupBoxHighlight);
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        sliderHiLuma = new ADM_SliderIndicator(groupBoxHighlight);
        sliderHiLuma->setObjectName(QString::fromUtf8("sliderHiLuma"));
        sliderHiLuma->setMinimum(-100);
        sliderHiLuma->setMaximum(100);
        sliderHiLuma->setOrientation(Qt::Vertical);

        gridLayout_4->addWidget(sliderHiLuma, 0, 0, 2, 1);

        dialHiHue = new QDial(groupBoxHighlight);
        dialHiHue->setObjectName(QString::fromUtf8("dialHiHue"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(dialHiHue->sizePolicy().hasHeightForWidth());
        dialHiHue->setSizePolicy(sizePolicy);
        dialHiHue->setMinimumSize(QSize(125, 125));
        dialHiHue->setMaximum(359);
        dialHiHue->setPageStep(18);
        dialHiHue->setWrapping(true);

        gridLayout_4->addWidget(dialHiHue, 0, 1, 2, 3);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_7, 0, 4, 1, 1);

        labelHiSaturation = new QLabel(groupBoxHighlight);
        labelHiSaturation->setObjectName(QString::fromUtf8("labelHiSaturation"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelHiSaturation->sizePolicy().hasHeightForWidth());
        labelHiSaturation->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(labelHiSaturation, 3, 5, 1, 1);

        sliderHiChromaShift = new ADM_SliderIndicator(groupBoxHighlight);
        sliderHiChromaShift->setObjectName(QString::fromUtf8("sliderHiChromaShift"));
        sliderHiChromaShift->setMinimum(0);
        sliderHiChromaShift->setMaximum(100);
        sliderHiChromaShift->setOrientation(Qt::Horizontal);

        gridLayout_4->addWidget(sliderHiChromaShift, 2, 0, 1, 5);

        sliderHiSaturation = new ADM_SliderIndicator(groupBoxHighlight);
        sliderHiSaturation->setObjectName(QString::fromUtf8("sliderHiSaturation"));
        sliderHiSaturation->setMinimum(-100);
        sliderHiSaturation->setMaximum(100);
        sliderHiSaturation->setOrientation(Qt::Horizontal);

        gridLayout_4->addWidget(sliderHiSaturation, 3, 0, 1, 5);

        labelHiChromaShift = new QLabel(groupBoxHighlight);
        labelHiChromaShift->setObjectName(QString::fromUtf8("labelHiChromaShift"));
        sizePolicy1.setHeightForWidth(labelHiChromaShift->sizePolicy().hasHeightForWidth());
        labelHiChromaShift->setSizePolicy(sizePolicy1);

        gridLayout_4->addWidget(labelHiChromaShift, 2, 5, 1, 1);


        gridLayout->addWidget(groupBoxHighlight, 0, 4, 1, 1);

        groupBoxShadow = new QGroupBox(colorBalanceDialog);
        groupBoxShadow->setObjectName(QString::fromUtf8("groupBoxShadow"));
        gridLayout_2 = new QGridLayout(groupBoxShadow);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        sliderLoLuma = new ADM_SliderIndicator(groupBoxShadow);
        sliderLoLuma->setObjectName(QString::fromUtf8("sliderLoLuma"));
        sliderLoLuma->setMinimum(-100);
        sliderLoLuma->setMaximum(100);
        sliderLoLuma->setOrientation(Qt::Vertical);

        gridLayout_2->addWidget(sliderLoLuma, 0, 0, 2, 1);

        dialLoHue = new QDial(groupBoxShadow);
        dialLoHue->setObjectName(QString::fromUtf8("dialLoHue"));
        sizePolicy.setHeightForWidth(dialLoHue->sizePolicy().hasHeightForWidth());
        dialLoHue->setSizePolicy(sizePolicy);
        dialLoHue->setMinimumSize(QSize(125, 125));
        dialLoHue->setMaximum(359);
        dialLoHue->setPageStep(18);
        dialLoHue->setWrapping(true);

        gridLayout_2->addWidget(dialLoHue, 0, 1, 2, 3);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 0, 4, 1, 1);

        sliderLoChromaShift = new ADM_SliderIndicator(groupBoxShadow);
        sliderLoChromaShift->setObjectName(QString::fromUtf8("sliderLoChromaShift"));
        sliderLoChromaShift->setMaximum(100);
        sliderLoChromaShift->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(sliderLoChromaShift, 2, 0, 1, 5);

        sliderLoSaturation = new ADM_SliderIndicator(groupBoxShadow);
        sliderLoSaturation->setObjectName(QString::fromUtf8("sliderLoSaturation"));
        sliderLoSaturation->setMinimum(-100);
        sliderLoSaturation->setMaximum(100);
        sliderLoSaturation->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(sliderLoSaturation, 3, 0, 1, 5);

        labelLoSaturation = new QLabel(groupBoxShadow);
        labelLoSaturation->setObjectName(QString::fromUtf8("labelLoSaturation"));
        sizePolicy1.setHeightForWidth(labelLoSaturation->sizePolicy().hasHeightForWidth());
        labelLoSaturation->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(labelLoSaturation, 3, 5, 1, 1);

        labelLoChromaShift = new QLabel(groupBoxShadow);
        labelLoChromaShift->setObjectName(QString::fromUtf8("labelLoChromaShift"));
        sizePolicy1.setHeightForWidth(labelLoChromaShift->sizePolicy().hasHeightForWidth());
        labelLoChromaShift->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(labelLoChromaShift, 2, 5, 1, 1);


        gridLayout->addWidget(groupBoxShadow, 0, 0, 1, 1);

        groupBoxMidtone = new QGroupBox(colorBalanceDialog);
        groupBoxMidtone->setObjectName(QString::fromUtf8("groupBoxMidtone"));
        gridLayout_3 = new QGridLayout(groupBoxMidtone);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_6, 0, 4, 1, 1);

        sliderMdLuma = new ADM_SliderIndicator(groupBoxMidtone);
        sliderMdLuma->setObjectName(QString::fromUtf8("sliderMdLuma"));
        sliderMdLuma->setMinimum(-100);
        sliderMdLuma->setMaximum(100);
        sliderMdLuma->setOrientation(Qt::Vertical);

        gridLayout_3->addWidget(sliderMdLuma, 0, 0, 2, 1);

        dialMdHue = new QDial(groupBoxMidtone);
        dialMdHue->setObjectName(QString::fromUtf8("dialMdHue"));
        sizePolicy.setHeightForWidth(dialMdHue->sizePolicy().hasHeightForWidth());
        dialMdHue->setSizePolicy(sizePolicy);
        dialMdHue->setMinimumSize(QSize(125, 125));
        dialMdHue->setMaximum(359);
        dialMdHue->setPageStep(18);
        dialMdHue->setWrapping(true);

        gridLayout_3->addWidget(dialMdHue, 0, 1, 2, 3);

        sliderMdChromaShift = new ADM_SliderIndicator(groupBoxMidtone);
        sliderMdChromaShift->setObjectName(QString::fromUtf8("sliderMdChromaShift"));
        sliderMdChromaShift->setMaximum(100);
        sliderMdChromaShift->setOrientation(Qt::Horizontal);

        gridLayout_3->addWidget(sliderMdChromaShift, 2, 0, 1, 5);

        sliderMdSaturation = new ADM_SliderIndicator(groupBoxMidtone);
        sliderMdSaturation->setObjectName(QString::fromUtf8("sliderMdSaturation"));
        sliderMdSaturation->setMinimum(-100);
        sliderMdSaturation->setMaximum(100);
        sliderMdSaturation->setOrientation(Qt::Horizontal);

        gridLayout_3->addWidget(sliderMdSaturation, 3, 0, 1, 5);

        labelMdSaturation = new QLabel(groupBoxMidtone);
        labelMdSaturation->setObjectName(QString::fromUtf8("labelMdSaturation"));
        sizePolicy1.setHeightForWidth(labelMdSaturation->sizePolicy().hasHeightForWidth());
        labelMdSaturation->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(labelMdSaturation, 3, 5, 1, 1);

        labelMdChromaShift = new QLabel(groupBoxMidtone);
        labelMdChromaShift->setObjectName(QString::fromUtf8("labelMdChromaShift"));
        sizePolicy1.setHeightForWidth(labelMdChromaShift->sizePolicy().hasHeightForWidth());
        labelMdChromaShift->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(labelMdChromaShift, 2, 5, 1, 1);


        gridLayout->addWidget(groupBoxMidtone, 0, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 5, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 1, 4, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 5, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 5, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 0, 1, 1);

        line_2 = new QFrame(colorBalanceDialog);
        line_2->setObjectName(QString::fromUtf8("line_2"));
        line_2->setFrameShape(QFrame::VLine);
        line_2->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(line_2, 0, 3, 1, 1);

        line = new QFrame(colorBalanceDialog);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::VLine);
        line->setFrameShadow(QFrame::Sunken);

        gridLayout->addWidget(line, 0, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(colorBalanceDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(colorBalanceDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(colorBalanceDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(colorBalanceDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), colorBalanceDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), colorBalanceDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(colorBalanceDialog);
    } // setupUi

    void retranslateUi(QDialog *colorBalanceDialog)
    {
        colorBalanceDialog->setWindowTitle(QCoreApplication::translate("colorBalanceDialog", "Color balance", nullptr));
        groupBoxHighlight->setTitle(QCoreApplication::translate("colorBalanceDialog", "Highlight", nullptr));
        labelHiSaturation->setText(QCoreApplication::translate("colorBalanceDialog", "Saturation", nullptr));
        labelHiChromaShift->setText(QCoreApplication::translate("colorBalanceDialog", "Chroma shift", nullptr));
        groupBoxShadow->setTitle(QCoreApplication::translate("colorBalanceDialog", "Shadow", nullptr));
        labelLoSaturation->setText(QCoreApplication::translate("colorBalanceDialog", "Saturation", nullptr));
        labelLoChromaShift->setText(QCoreApplication::translate("colorBalanceDialog", "Chroma shift", nullptr));
        groupBoxMidtone->setTitle(QCoreApplication::translate("colorBalanceDialog", "Midtone", nullptr));
        labelMdSaturation->setText(QCoreApplication::translate("colorBalanceDialog", "Saturation", nullptr));
        labelMdChromaShift->setText(QCoreApplication::translate("colorBalanceDialog", "Chroma shift", nullptr));
    } // retranslateUi

};

namespace Ui {
    class colorBalanceDialog: public Ui_colorBalanceDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COLORBALANCE_H
