/********************************************************************************
** Form generated from reading UI file 'blur.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BLUR_H
#define UI_BLUR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_blurDialog
{
public:
    QGridLayout *gridLayout;
    ADM_flyNavSlider *horizontalSlider;
    QSpacerItem *spacerItem;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;
    QGridLayout *gridLayout_3;
    QLabel *label;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer;
    QSpinBox *spinBoxRight;
    QLabel *labelLeft;
    QSpinBox *spinBoxBottom;
    QLabel *labelTop;
    QSpinBox *spinBoxLeft;
    QLabel *labelBottom;
    QSpinBox *spinBoxTop;
    QLabel *labelRight;
    QCheckBox *checkBoxRubber;
    QComboBox *comboBoxAlgorithm;
    QSlider *horizontalSliderRadius;
    QSpacerItem *horizontalSpacer_3;
    QSpinBox *spinBoxRadius;
    QHBoxLayout *toolboxLayout;

    void setupUi(QDialog *blurDialog)
    {
        if (blurDialog->objectName().isEmpty())
            blurDialog->setObjectName(QString::fromUtf8("blurDialog"));
        blurDialog->resize(720, 475);
        gridLayout = new QGridLayout(blurDialog);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        horizontalSlider = new ADM_flyNavSlider(blurDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSlider, 3, 0, 1, 2);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(spacerItem, 5, 1, 1, 1);

        graphicsView = new QGraphicsView(blurDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));

        gridLayout->addWidget(graphicsView, 4, 0, 1, 2);

        buttonBox = new QDialogButtonBox(blurDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        gridLayout->addWidget(buttonBox, 6, 0, 1, 2);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label = new QLabel(blurDialog);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_3->addWidget(label, 1, 7, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(26, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 0, 5, 1, 1);

        horizontalSpacer = new QSpacerItem(26, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 0, 2, 1, 1);

        spinBoxRight = new QSpinBox(blurDialog);
        spinBoxRight->setObjectName(QString::fromUtf8("spinBoxRight"));
        spinBoxRight->setMaximum(99999);

        gridLayout_3->addWidget(spinBoxRight, 0, 4, 1, 1);

        labelLeft = new QLabel(blurDialog);
        labelLeft->setObjectName(QString::fromUtf8("labelLeft"));

        gridLayout_3->addWidget(labelLeft, 0, 0, 1, 1);

        spinBoxBottom = new QSpinBox(blurDialog);
        spinBoxBottom->setObjectName(QString::fromUtf8("spinBoxBottom"));
        spinBoxBottom->setMaximum(99999);

        gridLayout_3->addWidget(spinBoxBottom, 1, 4, 1, 1);

        labelTop = new QLabel(blurDialog);
        labelTop->setObjectName(QString::fromUtf8("labelTop"));

        gridLayout_3->addWidget(labelTop, 1, 0, 1, 1);

        spinBoxLeft = new QSpinBox(blurDialog);
        spinBoxLeft->setObjectName(QString::fromUtf8("spinBoxLeft"));
        spinBoxLeft->setMaximum(99999);

        gridLayout_3->addWidget(spinBoxLeft, 0, 1, 1, 1);

        labelBottom = new QLabel(blurDialog);
        labelBottom->setObjectName(QString::fromUtf8("labelBottom"));

        gridLayout_3->addWidget(labelBottom, 1, 3, 1, 1);

        spinBoxTop = new QSpinBox(blurDialog);
        spinBoxTop->setObjectName(QString::fromUtf8("spinBoxTop"));
        spinBoxTop->setMaximum(99999);

        gridLayout_3->addWidget(spinBoxTop, 1, 1, 1, 1);

        labelRight = new QLabel(blurDialog);
        labelRight->setObjectName(QString::fromUtf8("labelRight"));

        gridLayout_3->addWidget(labelRight, 0, 3, 1, 1);

        checkBoxRubber = new QCheckBox(blurDialog);
        checkBoxRubber->setObjectName(QString::fromUtf8("checkBoxRubber"));

        gridLayout_3->addWidget(checkBoxRubber, 0, 6, 1, 1);

        comboBoxAlgorithm = new QComboBox(blurDialog);
        comboBoxAlgorithm->addItem(QString());
        comboBoxAlgorithm->addItem(QString());
        comboBoxAlgorithm->addItem(QString());
        comboBoxAlgorithm->setObjectName(QString::fromUtf8("comboBoxAlgorithm"));

        gridLayout_3->addWidget(comboBoxAlgorithm, 1, 6, 1, 1);

        horizontalSliderRadius = new QSlider(blurDialog);
        horizontalSliderRadius->setObjectName(QString::fromUtf8("horizontalSliderRadius"));
        horizontalSliderRadius->setMinimum(1);
        horizontalSliderRadius->setMaximum(200);
        horizontalSliderRadius->setPageStep(20);
        horizontalSliderRadius->setOrientation(Qt::Horizontal);

        gridLayout_3->addWidget(horizontalSliderRadius, 1, 8, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_3, 0, 8, 1, 1);

        spinBoxRadius = new QSpinBox(blurDialog);
        spinBoxRadius->setObjectName(QString::fromUtf8("spinBoxRadius"));
        spinBoxRadius->setMinimum(1);
        spinBoxRadius->setMaximum(200);

        gridLayout_3->addWidget(spinBoxRadius, 1, 9, 1, 1);


        gridLayout->addLayout(gridLayout_3, 0, 0, 2, 2);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        gridLayout->addLayout(toolboxLayout, 2, 0, 1, 2);

        QWidget::setTabOrder(horizontalSlider, graphicsView);

        retranslateUi(blurDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), blurDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), blurDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(blurDialog);
    } // setupUi

    void retranslateUi(QDialog *blurDialog)
    {
        blurDialog->setWindowTitle(QCoreApplication::translate("blurDialog", "Blur", nullptr));
        label->setText(QCoreApplication::translate("blurDialog", "radius", nullptr));
        labelLeft->setText(QCoreApplication::translate("blurDialog", "Left:", nullptr));
        labelTop->setText(QCoreApplication::translate("blurDialog", "Top:", nullptr));
        labelBottom->setText(QCoreApplication::translate("blurDialog", "Bottom:", nullptr));
        labelRight->setText(QCoreApplication::translate("blurDialog", "Right:", nullptr));
        checkBoxRubber->setText(QCoreApplication::translate("blurDialog", "&Hide Rubber Band", nullptr));
        comboBoxAlgorithm->setItemText(0, QCoreApplication::translate("blurDialog", "Box blur", nullptr));
        comboBoxAlgorithm->setItemText(1, QCoreApplication::translate("blurDialog", "Near Gaussian", nullptr));
        comboBoxAlgorithm->setItemText(2, QCoreApplication::translate("blurDialog", "Gaussian 2 pass", nullptr));

    } // retranslateUi

};

namespace Ui {
    class blurDialog: public Ui_blurDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BLUR_H
