/********************************************************************************
** Form generated from reading UI file 'deband.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEBAND_H
#define UI_DEBAND_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_debandDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QSlider *horizontalSliderLumaThreshold;
    QSpinBox *spinBoxRange;
    QLabel *labelChromaThreshold;
    QSpinBox *spinBoxChromaThreshold;
    QLabel *labelLumaThreshold;
    QLabel *labelRange;
    QSlider *horizontalSliderChromaThreshold;
    QSlider *horizontalSliderRange;
    QSpinBox *spinBoxLumaThreshold;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *debandDialog)
    {
        if (debandDialog->objectName().isEmpty())
            debandDialog->setObjectName(QString::fromUtf8("debandDialog"));
        debandDialog->resize(608, 426);
        verticalLayout = new QVBoxLayout(debandDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSliderLumaThreshold = new QSlider(debandDialog);
        horizontalSliderLumaThreshold->setObjectName(QString::fromUtf8("horizontalSliderLumaThreshold"));
        horizontalSliderLumaThreshold->setMaximum(100);
        horizontalSliderLumaThreshold->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderLumaThreshold, 1, 1, 1, 1);

        spinBoxRange = new QSpinBox(debandDialog);
        spinBoxRange->setObjectName(QString::fromUtf8("spinBoxRange"));
        spinBoxRange->setMinimum(1);
        spinBoxRange->setMaximum(100);

        gridLayout->addWidget(spinBoxRange, 0, 2, 1, 1);

        labelChromaThreshold = new QLabel(debandDialog);
        labelChromaThreshold->setObjectName(QString::fromUtf8("labelChromaThreshold"));

        gridLayout->addWidget(labelChromaThreshold, 2, 0, 1, 1);

        spinBoxChromaThreshold = new QSpinBox(debandDialog);
        spinBoxChromaThreshold->setObjectName(QString::fromUtf8("spinBoxChromaThreshold"));
        spinBoxChromaThreshold->setMaximum(100);

        gridLayout->addWidget(spinBoxChromaThreshold, 2, 2, 1, 1);

        labelLumaThreshold = new QLabel(debandDialog);
        labelLumaThreshold->setObjectName(QString::fromUtf8("labelLumaThreshold"));

        gridLayout->addWidget(labelLumaThreshold, 1, 0, 1, 1);

        labelRange = new QLabel(debandDialog);
        labelRange->setObjectName(QString::fromUtf8("labelRange"));

        gridLayout->addWidget(labelRange, 0, 0, 1, 1);

        horizontalSliderChromaThreshold = new QSlider(debandDialog);
        horizontalSliderChromaThreshold->setObjectName(QString::fromUtf8("horizontalSliderChromaThreshold"));
        horizontalSliderChromaThreshold->setMaximum(100);
        horizontalSliderChromaThreshold->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderChromaThreshold, 2, 1, 1, 1);

        horizontalSliderRange = new QSlider(debandDialog);
        horizontalSliderRange->setObjectName(QString::fromUtf8("horizontalSliderRange"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(horizontalSliderRange->sizePolicy().hasHeightForWidth());
        horizontalSliderRange->setSizePolicy(sizePolicy);
        horizontalSliderRange->setMinimum(1);
        horizontalSliderRange->setMaximum(100);
        horizontalSliderRange->setPageStep(10);
        horizontalSliderRange->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderRange, 0, 1, 1, 1);

        spinBoxLumaThreshold = new QSpinBox(debandDialog);
        spinBoxLumaThreshold->setObjectName(QString::fromUtf8("spinBoxLumaThreshold"));
        spinBoxLumaThreshold->setMaximum(100);

        gridLayout->addWidget(spinBoxLumaThreshold, 1, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(debandDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(debandDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(debandDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(debandDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), debandDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), debandDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(debandDialog);
    } // setupUi

    void retranslateUi(QDialog *debandDialog)
    {
        debandDialog->setWindowTitle(QCoreApplication::translate("debandDialog", "Deband", nullptr));
        labelChromaThreshold->setText(QCoreApplication::translate("debandDialog", "Chroma threshold", nullptr));
        labelLumaThreshold->setText(QCoreApplication::translate("debandDialog", "Luma threshold", nullptr));
        labelRange->setText(QCoreApplication::translate("debandDialog", "Range", nullptr));
    } // retranslateUi

};

namespace Ui {
    class debandDialog: public Ui_debandDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DEBAND_H
