/********************************************************************************
** Form generated from reading UI file 'waveletSharp.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WAVELETSHARP_H
#define UI_WAVELETSHARP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_waveletSharpDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QSlider *horizontalSliderStrength;
    QSpacerItem *horizontalSpacer_2;
    QSlider *horizontalSliderRadius;
    QLabel *labelRadius;
    QSpacerItem *horizontalSpacer;
    QCheckBox *checkBoxHQ;
    QDoubleSpinBox *doubleSpinBoxStrength;
    QDoubleSpinBox *doubleSpinBoxRadius;
    QLabel *labelStrength;
    QLabel *labelCutoff;
    QSlider *horizontalSliderCutoff;
    QDoubleSpinBox *doubleSpinBoxCutoff;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *waveletSharpDialog)
    {
        if (waveletSharpDialog->objectName().isEmpty())
            waveletSharpDialog->setObjectName(QString::fromUtf8("waveletSharpDialog"));
        waveletSharpDialog->resize(553, 401);
        verticalLayout = new QVBoxLayout(waveletSharpDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalSliderStrength = new QSlider(waveletSharpDialog);
        horizontalSliderStrength->setObjectName(QString::fromUtf8("horizontalSliderStrength"));
        horizontalSliderStrength->setMinimum(0);
        horizontalSliderStrength->setMaximum(100);
        horizontalSliderStrength->setPageStep(10);
        horizontalSliderStrength->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderStrength, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 3, 1, 1);

        horizontalSliderRadius = new QSlider(waveletSharpDialog);
        horizontalSliderRadius->setObjectName(QString::fromUtf8("horizontalSliderRadius"));
        horizontalSliderRadius->setMaximum(200);
        horizontalSliderRadius->setPageStep(20);
        horizontalSliderRadius->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderRadius, 2, 1, 1, 1);

        labelRadius = new QLabel(waveletSharpDialog);
        labelRadius->setObjectName(QString::fromUtf8("labelRadius"));

        gridLayout->addWidget(labelRadius, 2, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 3, 1, 1);

        checkBoxHQ = new QCheckBox(waveletSharpDialog);
        checkBoxHQ->setObjectName(QString::fromUtf8("checkBoxHQ"));

        gridLayout->addWidget(checkBoxHQ, 4, 0, 1, 1);

        doubleSpinBoxStrength = new QDoubleSpinBox(waveletSharpDialog);
        doubleSpinBoxStrength->setObjectName(QString::fromUtf8("doubleSpinBoxStrength"));
        doubleSpinBoxStrength->setMaximum(1.000000000000000);
        doubleSpinBoxStrength->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxStrength, 1, 2, 1, 1);

        doubleSpinBoxRadius = new QDoubleSpinBox(waveletSharpDialog);
        doubleSpinBoxRadius->setObjectName(QString::fromUtf8("doubleSpinBoxRadius"));
        doubleSpinBoxRadius->setMaximum(2.000000000000000);
        doubleSpinBoxRadius->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxRadius, 2, 2, 1, 1);

        labelStrength = new QLabel(waveletSharpDialog);
        labelStrength->setObjectName(QString::fromUtf8("labelStrength"));

        gridLayout->addWidget(labelStrength, 1, 0, 1, 1);

        labelCutoff = new QLabel(waveletSharpDialog);
        labelCutoff->setObjectName(QString::fromUtf8("labelCutoff"));

        gridLayout->addWidget(labelCutoff, 3, 0, 1, 1);

        horizontalSliderCutoff = new QSlider(waveletSharpDialog);
        horizontalSliderCutoff->setObjectName(QString::fromUtf8("horizontalSliderCutoff"));
        horizontalSliderCutoff->setMaximum(1000);
        horizontalSliderCutoff->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderCutoff, 3, 1, 1, 1);

        doubleSpinBoxCutoff = new QDoubleSpinBox(waveletSharpDialog);
        doubleSpinBoxCutoff->setObjectName(QString::fromUtf8("doubleSpinBoxCutoff"));
        doubleSpinBoxCutoff->setMaximum(10.000000000000000);
        doubleSpinBoxCutoff->setSingleStep(0.010000000000000);

        gridLayout->addWidget(doubleSpinBoxCutoff, 3, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(waveletSharpDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(waveletSharpDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(waveletSharpDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(waveletSharpDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), waveletSharpDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), waveletSharpDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(waveletSharpDialog);
    } // setupUi

    void retranslateUi(QDialog *waveletSharpDialog)
    {
        waveletSharpDialog->setWindowTitle(QCoreApplication::translate("waveletSharpDialog", "Wavelet Sharpener", nullptr));
        labelRadius->setText(QCoreApplication::translate("waveletSharpDialog", "Radius", nullptr));
        checkBoxHQ->setText(QCoreApplication::translate("waveletSharpDialog", "High quality", nullptr));
        labelStrength->setText(QCoreApplication::translate("waveletSharpDialog", "Strength", nullptr));
        labelCutoff->setText(QCoreApplication::translate("waveletSharpDialog", "Noise cutoff", nullptr));
    } // retranslateUi

};

namespace Ui {
    class waveletSharpDialog: public Ui_waveletSharpDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WAVELETSHARP_H
