/********************************************************************************
** Form generated from reading UI file 'flip.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FLIP_H
#define UI_FLIP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_flipDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QComboBox *comboBoxFlipdir;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *flipDialog)
    {
        if (flipDialog->objectName().isEmpty())
            flipDialog->setObjectName(QString::fromUtf8("flipDialog"));
        flipDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(flipDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        comboBoxFlipdir = new QComboBox(flipDialog);
        comboBoxFlipdir->addItem(QString());
        comboBoxFlipdir->addItem(QString());
        comboBoxFlipdir->setObjectName(QString::fromUtf8("comboBoxFlipdir"));

        gridLayout->addWidget(comboBoxFlipdir, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(flipDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(flipDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(flipDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(flipDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), flipDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), flipDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(flipDialog);
    } // setupUi

    void retranslateUi(QDialog *flipDialog)
    {
        flipDialog->setWindowTitle(QCoreApplication::translate("flipDialog", "Flip", nullptr));
        comboBoxFlipdir->setItemText(0, QCoreApplication::translate("flipDialog", "Horizontal flip", nullptr));
        comboBoxFlipdir->setItemText(1, QCoreApplication::translate("flipDialog", "Vertical flip", nullptr));

    } // retranslateUi

};

namespace Ui {
    class flipDialog: public Ui_flipDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FLIP_H
