/********************************************************************************
** Form generated from reading UI file 'artChromaKey.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTCHROMAKEY_H
#define UI_ARTCHROMAKEY_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artChromaKeyDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QPushButton *pushButtonC1;
    QCheckBox *checkBoxC1en;
    ADM_SliderIndicator *horizontalSliderC3slope;
    QLineEdit *lineEditC1;
    QCheckBox *checkBoxC3en;
    QCheckBox *checkBoxC2en;
    ADM_SliderIndicator *horizontalSliderC1slope;
    QPushButton *pushButtonC3;
    QPushButton *pushButtonC2;
    QLineEdit *lineEditC2;
    QLineEdit *lineEditC3;
    QLabel *labelSlope;
    QLabel *labelChroma;
    ADM_SliderIndicator *horizontalSliderC2slope;
    QGraphicsView *graphicsViewUV;
    QPushButton *pushButtonImage;
    QCheckBox *checkBoxTest;
    QComboBox *comboBoxSpill;
    QLineEdit *lineEditImage;
    ADM_SliderIndicator *horizontalSliderC1dist;
    ADM_SliderIndicator *horizontalSliderC2dist;
    ADM_SliderIndicator *horizontalSliderC3dist;
    QLabel *labelDistance;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artChromaKeyDialog)
    {
        if (artChromaKeyDialog->objectName().isEmpty())
            artChromaKeyDialog->setObjectName(QString::fromUtf8("artChromaKeyDialog"));
        artChromaKeyDialog->resize(609, 475);
        verticalLayout = new QVBoxLayout(artChromaKeyDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        pushButtonC1 = new QPushButton(artChromaKeyDialog);
        pushButtonC1->setObjectName(QString::fromUtf8("pushButtonC1"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/color.png"), QSize(), QIcon::Normal, QIcon::Off);
        pushButtonC1->setIcon(icon);

        gridLayout->addWidget(pushButtonC1, 4, 1, 1, 1);

        checkBoxC1en = new QCheckBox(artChromaKeyDialog);
        checkBoxC1en->setObjectName(QString::fromUtf8("checkBoxC1en"));
        checkBoxC1en->setEnabled(true);
        checkBoxC1en->setCheckable(true);
        checkBoxC1en->setChecked(false);

        gridLayout->addWidget(checkBoxC1en, 4, 0, 1, 1);

        horizontalSliderC3slope = new ADM_SliderIndicator(artChromaKeyDialog);
        horizontalSliderC3slope->setObjectName(QString::fromUtf8("horizontalSliderC3slope"));
        horizontalSliderC3slope->setMaximum(100);
        horizontalSliderC3slope->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC3slope, 6, 5, 1, 1);

        lineEditC1 = new QLineEdit(artChromaKeyDialog);
        lineEditC1->setObjectName(QString::fromUtf8("lineEditC1"));
        lineEditC1->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lineEditC1->sizePolicy().hasHeightForWidth());
        lineEditC1->setSizePolicy(sizePolicy);
        lineEditC1->setMaximumSize(QSize(48, 16777215));
        lineEditC1->setAutoFillBackground(true);
        lineEditC1->setFrame(true);
        lineEditC1->setAlignment(Qt::AlignCenter);
        lineEditC1->setReadOnly(true);

        gridLayout->addWidget(lineEditC1, 4, 2, 1, 1);

        checkBoxC3en = new QCheckBox(artChromaKeyDialog);
        checkBoxC3en->setObjectName(QString::fromUtf8("checkBoxC3en"));

        gridLayout->addWidget(checkBoxC3en, 6, 0, 1, 1);

        checkBoxC2en = new QCheckBox(artChromaKeyDialog);
        checkBoxC2en->setObjectName(QString::fromUtf8("checkBoxC2en"));

        gridLayout->addWidget(checkBoxC2en, 5, 0, 1, 1);

        horizontalSliderC1slope = new ADM_SliderIndicator(artChromaKeyDialog);
        horizontalSliderC1slope->setObjectName(QString::fromUtf8("horizontalSliderC1slope"));
        horizontalSliderC1slope->setMaximum(100);
        horizontalSliderC1slope->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC1slope, 4, 5, 1, 1);

        pushButtonC3 = new QPushButton(artChromaKeyDialog);
        pushButtonC3->setObjectName(QString::fromUtf8("pushButtonC3"));
        pushButtonC3->setIcon(icon);

        gridLayout->addWidget(pushButtonC3, 6, 1, 1, 1);

        pushButtonC2 = new QPushButton(artChromaKeyDialog);
        pushButtonC2->setObjectName(QString::fromUtf8("pushButtonC2"));
        pushButtonC2->setIcon(icon);

        gridLayout->addWidget(pushButtonC2, 5, 1, 1, 1);

        lineEditC2 = new QLineEdit(artChromaKeyDialog);
        lineEditC2->setObjectName(QString::fromUtf8("lineEditC2"));
        lineEditC2->setEnabled(false);
        sizePolicy.setHeightForWidth(lineEditC2->sizePolicy().hasHeightForWidth());
        lineEditC2->setSizePolicy(sizePolicy);
        lineEditC2->setMaximumSize(QSize(48, 16777215));
        lineEditC2->setAutoFillBackground(true);

        gridLayout->addWidget(lineEditC2, 5, 2, 1, 1);

        lineEditC3 = new QLineEdit(artChromaKeyDialog);
        lineEditC3->setObjectName(QString::fromUtf8("lineEditC3"));
        lineEditC3->setEnabled(false);
        sizePolicy.setHeightForWidth(lineEditC3->sizePolicy().hasHeightForWidth());
        lineEditC3->setSizePolicy(sizePolicy);
        lineEditC3->setMaximumSize(QSize(48, 16777215));
        lineEditC3->setAutoFillBackground(true);

        gridLayout->addWidget(lineEditC3, 6, 2, 1, 1);

        labelSlope = new QLabel(artChromaKeyDialog);
        labelSlope->setObjectName(QString::fromUtf8("labelSlope"));

        gridLayout->addWidget(labelSlope, 3, 5, 1, 1);

        labelChroma = new QLabel(artChromaKeyDialog);
        labelChroma->setObjectName(QString::fromUtf8("labelChroma"));
        labelChroma->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(labelChroma, 3, 1, 1, 2);

        horizontalSliderC2slope = new ADM_SliderIndicator(artChromaKeyDialog);
        horizontalSliderC2slope->setObjectName(QString::fromUtf8("horizontalSliderC2slope"));
        horizontalSliderC2slope->setMaximum(100);
        horizontalSliderC2slope->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC2slope, 5, 5, 1, 1);

        graphicsViewUV = new QGraphicsView(artChromaKeyDialog);
        graphicsViewUV->setObjectName(QString::fromUtf8("graphicsViewUV"));
        graphicsViewUV->setEnabled(false);
        sizePolicy.setHeightForWidth(graphicsViewUV->sizePolicy().hasHeightForWidth());
        graphicsViewUV->setSizePolicy(sizePolicy);
        graphicsViewUV->setMinimumSize(QSize(128, 128));
        graphicsViewUV->setMaximumSize(QSize(128, 128));
        graphicsViewUV->setFocusPolicy(Qt::NoFocus);
        graphicsViewUV->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewUV->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        gridLayout->addWidget(graphicsViewUV, 4, 6, 3, 1);

        pushButtonImage = new QPushButton(artChromaKeyDialog);
        pushButtonImage->setObjectName(QString::fromUtf8("pushButtonImage"));

        gridLayout->addWidget(pushButtonImage, 1, 0, 1, 1);

        checkBoxTest = new QCheckBox(artChromaKeyDialog);
        checkBoxTest->setObjectName(QString::fromUtf8("checkBoxTest"));

        gridLayout->addWidget(checkBoxTest, 2, 0, 1, 3);

        comboBoxSpill = new QComboBox(artChromaKeyDialog);
        comboBoxSpill->addItem(QString());
        comboBoxSpill->addItem(QString());
        comboBoxSpill->addItem(QString());
        comboBoxSpill->addItem(QString());
        comboBoxSpill->addItem(QString());
        comboBoxSpill->setObjectName(QString::fromUtf8("comboBoxSpill"));

        gridLayout->addWidget(comboBoxSpill, 2, 3, 1, 1);

        lineEditImage = new QLineEdit(artChromaKeyDialog);
        lineEditImage->setObjectName(QString::fromUtf8("lineEditImage"));
        lineEditImage->setEnabled(false);

        gridLayout->addWidget(lineEditImage, 1, 1, 1, 6);

        horizontalSliderC1dist = new ADM_SliderIndicator(artChromaKeyDialog);
        horizontalSliderC1dist->setObjectName(QString::fromUtf8("horizontalSliderC1dist"));
        horizontalSliderC1dist->setMinimum(0);
        horizontalSliderC1dist->setMaximum(100);
        horizontalSliderC1dist->setPageStep(10);
        horizontalSliderC1dist->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC1dist, 4, 3, 1, 2);

        horizontalSliderC2dist = new ADM_SliderIndicator(artChromaKeyDialog);
        horizontalSliderC2dist->setObjectName(QString::fromUtf8("horizontalSliderC2dist"));
        horizontalSliderC2dist->setMaximum(100);
        horizontalSliderC2dist->setPageStep(10);
        horizontalSliderC2dist->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC2dist, 5, 3, 1, 2);

        horizontalSliderC3dist = new ADM_SliderIndicator(artChromaKeyDialog);
        horizontalSliderC3dist->setObjectName(QString::fromUtf8("horizontalSliderC3dist"));
        horizontalSliderC3dist->setMaximum(100);
        horizontalSliderC3dist->setPageStep(10);
        horizontalSliderC3dist->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC3dist, 6, 3, 1, 2);

        labelDistance = new QLabel(artChromaKeyDialog);
        labelDistance->setObjectName(QString::fromUtf8("labelDistance"));

        gridLayout->addWidget(labelDistance, 3, 3, 1, 2);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 4, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 5, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artChromaKeyDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artChromaKeyDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artChromaKeyDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(pushButtonImage, checkBoxTest);
        QWidget::setTabOrder(checkBoxTest, comboBoxSpill);
        QWidget::setTabOrder(comboBoxSpill, checkBoxC1en);
        QWidget::setTabOrder(checkBoxC1en, pushButtonC1);
        QWidget::setTabOrder(pushButtonC1, lineEditC1);
        QWidget::setTabOrder(lineEditC1, horizontalSliderC1dist);
        QWidget::setTabOrder(horizontalSliderC1dist, horizontalSliderC1slope);
        QWidget::setTabOrder(horizontalSliderC1slope, checkBoxC2en);
        QWidget::setTabOrder(checkBoxC2en, pushButtonC2);
        QWidget::setTabOrder(pushButtonC2, lineEditC2);
        QWidget::setTabOrder(lineEditC2, horizontalSliderC2dist);
        QWidget::setTabOrder(horizontalSliderC2dist, horizontalSliderC2slope);
        QWidget::setTabOrder(horizontalSliderC2slope, checkBoxC3en);
        QWidget::setTabOrder(checkBoxC3en, pushButtonC3);
        QWidget::setTabOrder(pushButtonC3, lineEditC3);
        QWidget::setTabOrder(lineEditC3, horizontalSliderC3dist);
        QWidget::setTabOrder(horizontalSliderC3dist, horizontalSliderC3slope);
        QWidget::setTabOrder(horizontalSliderC3slope, graphicsViewUV);
        QWidget::setTabOrder(graphicsViewUV, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, graphicsView);

        retranslateUi(artChromaKeyDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artChromaKeyDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artChromaKeyDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artChromaKeyDialog);
    } // setupUi

    void retranslateUi(QDialog *artChromaKeyDialog)
    {
        artChromaKeyDialog->setWindowTitle(QCoreApplication::translate("artChromaKeyDialog", "Chroma Key", nullptr));
        pushButtonC1->setText(QString());
        checkBoxC1en->setText(QCoreApplication::translate("artChromaKeyDialog", "Primary", nullptr));
        checkBoxC3en->setText(QCoreApplication::translate("artChromaKeyDialog", "Tertiary", nullptr));
        checkBoxC2en->setText(QCoreApplication::translate("artChromaKeyDialog", "Secondary", nullptr));
        pushButtonC3->setText(QString());
        pushButtonC2->setText(QString());
        labelSlope->setText(QCoreApplication::translate("artChromaKeyDialog", "Cutoff slope", nullptr));
        labelChroma->setText(QCoreApplication::translate("artChromaKeyDialog", "Pick Chroma", nullptr));
        pushButtonImage->setText(QCoreApplication::translate("artChromaKeyDialog", "Select image", nullptr));
        checkBoxTest->setText(QCoreApplication::translate("artChromaKeyDialog", "Show calibration background", nullptr));
        comboBoxSpill->setItemText(0, QCoreApplication::translate("artChromaKeyDialog", "No spill control", nullptr));
        comboBoxSpill->setItemText(1, QCoreApplication::translate("artChromaKeyDialog", "Weighted alpha", nullptr));
        comboBoxSpill->setItemText(2, QCoreApplication::translate("artChromaKeyDialog", "AVG alpha", nullptr));
        comboBoxSpill->setItemText(3, QCoreApplication::translate("artChromaKeyDialog", "RMS alpha", nullptr));
        comboBoxSpill->setItemText(4, QCoreApplication::translate("artChromaKeyDialog", "MIN alpha", nullptr));

        labelDistance->setText(QCoreApplication::translate("artChromaKeyDialog", "Distance", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artChromaKeyDialog: public Ui_artChromaKeyDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTCHROMAKEY_H
