/********************************************************************************
** Form generated from reading UI file 'fadeFromImage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FADEFROMIMAGE_H
#define UI_FADEFROMIMAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_fadeFromImageDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *labelTScope;
    QLabel *labelDuration;
    QPushButton *pushButtonTManual;
    QPushButton *pushButtonTMarker;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelEffect;
    QComboBox *comboBoxEffect;
    QComboBox *comboBoxDirection;
    QSpacerItem *horizontalSpacer;
    QLabel *labelInfo;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *fadeFromImageDialog)
    {
        if (fadeFromImageDialog->objectName().isEmpty())
            fadeFromImageDialog->setObjectName(QString::fromUtf8("fadeFromImageDialog"));
        fadeFromImageDialog->resize(451, 299);
        verticalLayout = new QVBoxLayout(fadeFromImageDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        labelTScope = new QLabel(fadeFromImageDialog);
        labelTScope->setObjectName(QString::fromUtf8("labelTScope"));

        horizontalLayout->addWidget(labelTScope);

        labelDuration = new QLabel(fadeFromImageDialog);
        labelDuration->setObjectName(QString::fromUtf8("labelDuration"));

        horizontalLayout->addWidget(labelDuration);

        pushButtonTManual = new QPushButton(fadeFromImageDialog);
        pushButtonTManual->setObjectName(QString::fromUtf8("pushButtonTManual"));

        horizontalLayout->addWidget(pushButtonTManual);

        pushButtonTMarker = new QPushButton(fadeFromImageDialog);
        pushButtonTMarker->setObjectName(QString::fromUtf8("pushButtonTMarker"));

        horizontalLayout->addWidget(pushButtonTMarker);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        labelEffect = new QLabel(fadeFromImageDialog);
        labelEffect->setObjectName(QString::fromUtf8("labelEffect"));

        horizontalLayout_3->addWidget(labelEffect);

        comboBoxEffect = new QComboBox(fadeFromImageDialog);
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->setObjectName(QString::fromUtf8("comboBoxEffect"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboBoxEffect->sizePolicy().hasHeightForWidth());
        comboBoxEffect->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(comboBoxEffect);

        comboBoxDirection = new QComboBox(fadeFromImageDialog);
        comboBoxDirection->addItem(QString());
        comboBoxDirection->addItem(QString());
        comboBoxDirection->addItem(QString());
        comboBoxDirection->addItem(QString());
        comboBoxDirection->setObjectName(QString::fromUtf8("comboBoxDirection"));

        horizontalLayout_3->addWidget(comboBoxDirection);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_3);

        labelInfo = new QLabel(fadeFromImageDialog);
        labelInfo->setObjectName(QString::fromUtf8("labelInfo"));

        verticalLayout->addWidget(labelInfo);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(fadeFromImageDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(fadeFromImageDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(fadeFromImageDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(fadeFromImageDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), fadeFromImageDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), fadeFromImageDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(fadeFromImageDialog);
    } // setupUi

    void retranslateUi(QDialog *fadeFromImageDialog)
    {
        fadeFromImageDialog->setWindowTitle(QCoreApplication::translate("fadeFromImageDialog", "Fade from first image", nullptr));
        labelTScope->setText(QCoreApplication::translate("fadeFromImageDialog", "Time scope: ", nullptr));
        labelDuration->setText(QCoreApplication::translate("fadeFromImageDialog", "Duration: ", nullptr));
        pushButtonTManual->setText(QCoreApplication::translate("fadeFromImageDialog", "Manual time entry", nullptr));
        pushButtonTMarker->setText(QCoreApplication::translate("fadeFromImageDialog", "Set from A-B markers", nullptr));
        labelEffect->setText(QCoreApplication::translate("fadeFromImageDialog", "Effect:", nullptr));
        comboBoxEffect->setItemText(0, QCoreApplication::translate("fadeFromImageDialog", "Linear blend", nullptr));
        comboBoxEffect->setItemText(1, QCoreApplication::translate("fadeFromImageDialog", "Slide", nullptr));
        comboBoxEffect->setItemText(2, QCoreApplication::translate("fadeFromImageDialog", "Wipe", nullptr));
        comboBoxEffect->setItemText(3, QCoreApplication::translate("fadeFromImageDialog", "Push", nullptr));
        comboBoxEffect->setItemText(4, QCoreApplication::translate("fadeFromImageDialog", "Luma dissolve", nullptr));
        comboBoxEffect->setItemText(5, QCoreApplication::translate("fadeFromImageDialog", "Inverse luma dissolve", nullptr));
        comboBoxEffect->setItemText(6, QCoreApplication::translate("fadeFromImageDialog", "Static random dissolve", nullptr));
        comboBoxEffect->setItemText(7, QCoreApplication::translate("fadeFromImageDialog", "Dynamic random dissolve", nullptr));

        comboBoxDirection->setItemText(0, QCoreApplication::translate("fadeFromImageDialog", "Up", nullptr));
        comboBoxDirection->setItemText(1, QCoreApplication::translate("fadeFromImageDialog", "Right", nullptr));
        comboBoxDirection->setItemText(2, QCoreApplication::translate("fadeFromImageDialog", "Down", nullptr));
        comboBoxDirection->setItemText(3, QCoreApplication::translate("fadeFromImageDialog", "Left", nullptr));

        labelInfo->setText(QCoreApplication::translate("fadeFromImageDialog", "Start preview play before time scope, if you see green.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class fadeFromImageDialog: public Ui_fadeFromImageDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FADEFROMIMAGE_H
