/****************************************************************************
** Meta object code from reading C++ file 'Q_gui2.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../avidemux/qt4/ADM_userInterfaces/ADM_gui/Q_gui2.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Q_gui2.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_myQApplication_t {
    QByteArrayData data[4];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_myQApplication_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_myQApplication_t qt_meta_stringdata_myQApplication = {
    {
QT_MOC_LITERAL(0, 0, 14), // "myQApplication"
QT_MOC_LITERAL(1, 15, 8), // "postInit"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 7) // "cleanup"

    },
    "myQApplication\0postInit\0\0cleanup"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_myQApplication[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x0a /* Public */,
       3,    0,   25,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void myQApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<myQApplication *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->postInit(); break;
        case 1: _t->cleanup(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject myQApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<QApplication::staticMetaObject>(),
    qt_meta_stringdata_myQApplication.data,
    qt_meta_data_myQApplication,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *myQApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *myQApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_myQApplication.stringdata0))
        return static_cast<void*>(this);
    return QApplication::qt_metacast(_clname);
}

int myQApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[70];
    char stringdata0[999];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 12), // "actionSignal"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 6), // "Action"
QT_MOC_LITERAL(4, 32, 1), // "a"
QT_MOC_LITERAL(5, 34, 15), // "updateAvailable"
QT_MOC_LITERAL(6, 50, 7), // "version"
QT_MOC_LITERAL(7, 58, 11), // "std::string"
QT_MOC_LITERAL(8, 70, 4), // "date"
QT_MOC_LITERAL(9, 75, 12), // "downloadLink"
QT_MOC_LITERAL(10, 88, 11), // "timeChanged"
QT_MOC_LITERAL(11, 100, 18), // "timeChangeFinished"
QT_MOC_LITERAL(12, 119, 12), // "checkChanged"
QT_MOC_LITERAL(13, 132, 12), // "comboChanged"
QT_MOC_LITERAL(14, 145, 1), // "z"
QT_MOC_LITERAL(15, 147, 13), // "buttonPressed"
QT_MOC_LITERAL(16, 161, 17), // "toolButtonPressed"
QT_MOC_LITERAL(17, 179, 26), // "previewModeChangedFromMenu"
QT_MOC_LITERAL(18, 206, 6), // "status"
QT_MOC_LITERAL(19, 213, 29), // "previewModeChangedFromToolbar"
QT_MOC_LITERAL(20, 243, 18), // "currentTimeChanged"
QT_MOC_LITERAL(21, 262, 18), // "sliderValueChanged"
QT_MOC_LITERAL(22, 281, 1), // "u"
QT_MOC_LITERAL(23, 283, 11), // "sliderMoved"
QT_MOC_LITERAL(24, 295, 5), // "value"
QT_MOC_LITERAL(25, 301, 14), // "sliderReleased"
QT_MOC_LITERAL(26, 316, 13), // "sliderPressed"
QT_MOC_LITERAL(27, 330, 11), // "sliderWheel"
QT_MOC_LITERAL(28, 342, 3), // "way"
QT_MOC_LITERAL(29, 346, 16), // "dragTimerTimeout"
QT_MOC_LITERAL(30, 363, 16), // "busyTimerTimeout"
QT_MOC_LITERAL(31, 380, 32), // "navigateWhilePlayingTimerTimeout"
QT_MOC_LITERAL(32, 413, 10), // "sendAction"
QT_MOC_LITERAL(33, 424, 20), // "navigateWhilePlaying"
QT_MOC_LITERAL(34, 445, 10), // "actionSlot"
QT_MOC_LITERAL(35, 456, 23), // "scriptFileActionHandler"
QT_MOC_LITERAL(36, 480, 28), // "scriptReferenceActionHandler"
QT_MOC_LITERAL(37, 509, 14), // "searchFileMenu"
QT_MOC_LITERAL(38, 524, 8), // "QAction*"
QT_MOC_LITERAL(39, 533, 6), // "action"
QT_MOC_LITERAL(40, 540, 16), // "searchRecentMenu"
QT_MOC_LITERAL(41, 557, 14), // "searchEditMenu"
QT_MOC_LITERAL(42, 572, 15), // "searchVideoMenu"
QT_MOC_LITERAL(43, 588, 15), // "searchAudioMenu"
QT_MOC_LITERAL(44, 604, 14), // "searchHelpMenu"
QT_MOC_LITERAL(45, 619, 14), // "searchToolMenu"
QT_MOC_LITERAL(46, 634, 14), // "searchViewMenu"
QT_MOC_LITERAL(47, 649, 12), // "searchGoMenu"
QT_MOC_LITERAL(48, 662, 17), // "searchRecentFiles"
QT_MOC_LITERAL(49, 680, 20), // "searchRecentProjects"
QT_MOC_LITERAL(50, 701, 13), // "searchToolBar"
QT_MOC_LITERAL(51, 715, 25), // "restoreDefaultWidgetState"
QT_MOC_LITERAL(52, 741, 1), // "b"
QT_MOC_LITERAL(53, 743, 29), // "toolbarOrientationChangedSlot"
QT_MOC_LITERAL(54, 773, 15), // "Qt::Orientation"
QT_MOC_LITERAL(55, 789, 2), // "hv"
QT_MOC_LITERAL(56, 792, 19), // "setDefaultThemeSlot"
QT_MOC_LITERAL(57, 812, 17), // "setLightThemeSlot"
QT_MOC_LITERAL(58, 830, 16), // "setDarkThemeSlot"
QT_MOC_LITERAL(59, 847, 10), // "closeEvent"
QT_MOC_LITERAL(60, 858, 12), // "QCloseEvent*"
QT_MOC_LITERAL(61, 871, 5), // "event"
QT_MOC_LITERAL(62, 877, 19), // "updateAvailableSlot"
QT_MOC_LITERAL(63, 897, 3), // "url"
QT_MOC_LITERAL(64, 901, 13), // "setRefreshCap"
QT_MOC_LITERAL(65, 915, 24), // "setMenuItemsEnabledState"
QT_MOC_LITERAL(66, 940, 12), // "volumeChange"
QT_MOC_LITERAL(67, 953, 12), // "audioToggled"
QT_MOC_LITERAL(68, 966, 7), // "checked"
QT_MOC_LITERAL(69, 974, 24) // "thumbSlider_valueEmitted"

    },
    "MainWindow\0actionSignal\0\0Action\0a\0"
    "updateAvailable\0version\0std::string\0"
    "date\0downloadLink\0timeChanged\0"
    "timeChangeFinished\0checkChanged\0"
    "comboChanged\0z\0buttonPressed\0"
    "toolButtonPressed\0previewModeChangedFromMenu\0"
    "status\0previewModeChangedFromToolbar\0"
    "currentTimeChanged\0sliderValueChanged\0"
    "u\0sliderMoved\0value\0sliderReleased\0"
    "sliderPressed\0sliderWheel\0way\0"
    "dragTimerTimeout\0busyTimerTimeout\0"
    "navigateWhilePlayingTimerTimeout\0"
    "sendAction\0navigateWhilePlaying\0"
    "actionSlot\0scriptFileActionHandler\0"
    "scriptReferenceActionHandler\0"
    "searchFileMenu\0QAction*\0action\0"
    "searchRecentMenu\0searchEditMenu\0"
    "searchVideoMenu\0searchAudioMenu\0"
    "searchHelpMenu\0searchToolMenu\0"
    "searchViewMenu\0searchGoMenu\0"
    "searchRecentFiles\0searchRecentProjects\0"
    "searchToolBar\0restoreDefaultWidgetState\0"
    "b\0toolbarOrientationChangedSlot\0"
    "Qt::Orientation\0hv\0setDefaultThemeSlot\0"
    "setLightThemeSlot\0setDarkThemeSlot\0"
    "closeEvent\0QCloseEvent*\0event\0"
    "updateAvailableSlot\0url\0setRefreshCap\0"
    "setMenuItemsEnabledState\0volumeChange\0"
    "audioToggled\0checked\0thumbSlider_valueEmitted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      48,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  254,    2, 0x06 /* Public */,
       5,    3,  257,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,  264,    2, 0x08 /* Private */,
      11,    0,  267,    2, 0x08 /* Private */,
      12,    1,  268,    2, 0x08 /* Private */,
      13,    1,  271,    2, 0x08 /* Private */,
      15,    0,  274,    2, 0x08 /* Private */,
      16,    1,  275,    2, 0x08 /* Private */,
      17,    1,  278,    2, 0x08 /* Private */,
      19,    1,  281,    2, 0x08 /* Private */,
      20,    0,  284,    2, 0x08 /* Private */,
      21,    1,  285,    2, 0x08 /* Private */,
      23,    1,  288,    2, 0x08 /* Private */,
      25,    0,  291,    2, 0x08 /* Private */,
      26,    0,  292,    2, 0x08 /* Private */,
      27,    1,  293,    2, 0x08 /* Private */,
      29,    0,  296,    2, 0x08 /* Private */,
      30,    0,  297,    2, 0x08 /* Private */,
      31,    0,  298,    2, 0x08 /* Private */,
      32,    1,  299,    2, 0x08 /* Private */,
      33,    1,  302,    2, 0x08 /* Private */,
      34,    1,  305,    2, 0x08 /* Private */,
      35,    0,  308,    2, 0x08 /* Private */,
      36,    0,  309,    2, 0x08 /* Private */,
      37,    1,  310,    2, 0x08 /* Private */,
      40,    1,  313,    2, 0x08 /* Private */,
      41,    1,  316,    2, 0x08 /* Private */,
      42,    1,  319,    2, 0x08 /* Private */,
      43,    1,  322,    2, 0x08 /* Private */,
      44,    1,  325,    2, 0x08 /* Private */,
      45,    1,  328,    2, 0x08 /* Private */,
      46,    1,  331,    2, 0x08 /* Private */,
      47,    1,  334,    2, 0x08 /* Private */,
      48,    1,  337,    2, 0x08 /* Private */,
      49,    1,  340,    2, 0x08 /* Private */,
      50,    1,  343,    2, 0x08 /* Private */,
      51,    1,  346,    2, 0x08 /* Private */,
      53,    1,  349,    2, 0x08 /* Private */,
      56,    1,  352,    2, 0x08 /* Private */,
      57,    1,  355,    2, 0x08 /* Private */,
      58,    1,  358,    2, 0x08 /* Private */,
      59,    1,  361,    2, 0x08 /* Private */,
      62,    3,  364,    2, 0x0a /* Public */,
      64,    0,  371,    2, 0x0a /* Public */,
      65,    0,  372,    2, 0x0a /* Public */,
      66,    1,  373,    2, 0x0a /* Public */,
      67,    1,  376,    2, 0x0a /* Public */,
      69,    1,  379,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 7, 0x80000000 | 7,    6,    8,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Int,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, 0x80000000 | 38,   39,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, 0x80000000 | 54,   55,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, 0x80000000 | 60,   61,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 7, 0x80000000 | 7,    6,    8,   63,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Bool,   68,
    QMetaType::Void, QMetaType::Int,   24,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->actionSignal((*reinterpret_cast< Action(*)>(_a[1]))); break;
        case 1: _t->updateAvailable((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const std::string(*)>(_a[2])),(*reinterpret_cast< const std::string(*)>(_a[3]))); break;
        case 2: _t->timeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->timeChangeFinished(); break;
        case 4: _t->checkChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->comboChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->buttonPressed(); break;
        case 7: _t->toolButtonPressed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->previewModeChangedFromMenu((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->previewModeChangedFromToolbar((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->currentTimeChanged(); break;
        case 11: _t->sliderValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->sliderMoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->sliderReleased(); break;
        case 14: _t->sliderPressed(); break;
        case 15: _t->sliderWheel((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->dragTimerTimeout(); break;
        case 17: _t->busyTimerTimeout(); break;
        case 18: _t->navigateWhilePlayingTimerTimeout(); break;
        case 19: _t->sendAction((*reinterpret_cast< Action(*)>(_a[1]))); break;
        case 20: _t->navigateWhilePlaying((*reinterpret_cast< Action(*)>(_a[1]))); break;
        case 21: _t->actionSlot((*reinterpret_cast< Action(*)>(_a[1]))); break;
        case 22: _t->scriptFileActionHandler(); break;
        case 23: _t->scriptReferenceActionHandler(); break;
        case 24: _t->searchFileMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 25: _t->searchRecentMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 26: _t->searchEditMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 27: _t->searchVideoMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 28: _t->searchAudioMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 29: _t->searchHelpMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 30: _t->searchToolMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 31: _t->searchViewMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 32: _t->searchGoMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 33: _t->searchRecentFiles((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 34: _t->searchRecentProjects((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 35: _t->searchToolBar((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 36: _t->restoreDefaultWidgetState((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 37: _t->toolbarOrientationChangedSlot((*reinterpret_cast< Qt::Orientation(*)>(_a[1]))); break;
        case 38: _t->setDefaultThemeSlot((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->setLightThemeSlot((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 40: _t->setDarkThemeSlot((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 41: _t->closeEvent((*reinterpret_cast< QCloseEvent*(*)>(_a[1]))); break;
        case 42: _t->updateAvailableSlot((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< std::string(*)>(_a[2])),(*reinterpret_cast< std::string(*)>(_a[3]))); break;
        case 43: _t->setRefreshCap(); break;
        case 44: _t->setMenuItemsEnabledState(); break;
        case 45: _t->volumeChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 46: _t->audioToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 47: _t->thumbSlider_valueEmitted((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MainWindow::*)(Action );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::actionSignal)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(int , const std::string , const std::string );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::updateAvailable)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_MainWindow.data,
    qt_meta_data_MainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::actionSignal(Action _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MainWindow::updateAvailable(int _t1, const std::string _t2, const std::string _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
