/********************************************************************************
** Form generated from reading UI file 'uiJobs.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UIJOBS_H
#define UI_UIJOBS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_jobs
{
public:
    QVBoxLayout *verticalLayout;
    QTableWidget *tableWidget;
    QHBoxLayout *horizontalLayout;
    QPushButton *pushButtonRunAll;
    QPushButton *pushButtonCleanup;
    QCheckBox *checkBoxUseQt4;
    QSpacerItem *horizontalSpacer;
    QPushButton *pushButtonQuit;

    void setupUi(QDialog *jobs)
    {
        if (jobs->objectName().isEmpty())
            jobs->setObjectName(QString::fromUtf8("jobs"));
        jobs->setWindowModality(Qt::WindowModal);
        jobs->resize(645, 515);
        verticalLayout = new QVBoxLayout(jobs);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        tableWidget = new QTableWidget(jobs);
        tableWidget->setObjectName(QString::fromUtf8("tableWidget"));

        verticalLayout->addWidget(tableWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        pushButtonRunAll = new QPushButton(jobs);
        pushButtonRunAll->setObjectName(QString::fromUtf8("pushButtonRunAll"));

        horizontalLayout->addWidget(pushButtonRunAll);

        pushButtonCleanup = new QPushButton(jobs);
        pushButtonCleanup->setObjectName(QString::fromUtf8("pushButtonCleanup"));

        horizontalLayout->addWidget(pushButtonCleanup);

        checkBoxUseQt4 = new QCheckBox(jobs);
        checkBoxUseQt4->setObjectName(QString::fromUtf8("checkBoxUseQt4"));

        horizontalLayout->addWidget(checkBoxUseQt4);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        pushButtonQuit = new QPushButton(jobs);
        pushButtonQuit->setObjectName(QString::fromUtf8("pushButtonQuit"));

        horizontalLayout->addWidget(pushButtonQuit);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(jobs);

        QMetaObject::connectSlotsByName(jobs);
    } // setupUi

    void retranslateUi(QDialog *jobs)
    {
        jobs->setWindowTitle(QCoreApplication::translate("jobs", "Avidemux Jobs", nullptr));
#if QT_CONFIG(statustip)
        pushButtonRunAll->setStatusTip(QCoreApplication::translate("jobs", "Run all pending jobs", nullptr));
#endif // QT_CONFIG(statustip)
        pushButtonRunAll->setText(QCoreApplication::translate("jobs", "Run jobs", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonCleanup->setToolTip(QCoreApplication::translate("jobs", "Delete already executed jobs", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonCleanup->setText(QCoreApplication::translate("jobs", "Cleanup", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxUseQt4->setToolTip(QCoreApplication::translate("jobs", "If you use VDPAU you cannot use CLI version", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxUseQt4->setText(QCoreApplication::translate("jobs", "use Qt version", nullptr));
        pushButtonQuit->setText(QCoreApplication::translate("jobs", "Quit", nullptr));
    } // retranslateUi

};

namespace Ui {
    class jobs: public Ui_jobs {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_UIJOBS_H
