/********************************************************************************
** Form generated from reading UI file 'zoom.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ZOOM_H
#define UI_ZOOM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_zoomDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *labelResizeMethod;
    QComboBox *comboBoxAlgo;
    QSpacerItem *horizontalSpacer_1;
    QSpacerItem *horizontalSpacer_3;
    QLabel *labelRight;
    QSpinBox *spinBoxLeft;
    QLabel *labelBottom;
    QLabel *labelLockAR;
    QSpinBox *spinBoxBottom;
    QSpinBox *spinBoxRight;
    QLabel *labelTop;
    QCheckBox *checkBoxRubber;
    QLabel *labelLeft;
    QHBoxLayout *horizontalLayout_2;
    QLabel *labelSize;
    QSpinBox *spinBoxTop;
    QComboBox *comboBoxAspectRatio;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelPadding;
    QComboBox *comboBoxPad;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *zoomDialog)
    {
        if (zoomDialog->objectName().isEmpty())
            zoomDialog->setObjectName(QString::fromUtf8("zoomDialog"));
        zoomDialog->resize(805, 404);
        vboxLayout = new QVBoxLayout(zoomDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        labelResizeMethod = new QLabel(zoomDialog);
        labelResizeMethod->setObjectName(QString::fromUtf8("labelResizeMethod"));

        horizontalLayout->addWidget(labelResizeMethod);

        comboBoxAlgo = new QComboBox(zoomDialog);
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->setObjectName(QString::fromUtf8("comboBoxAlgo"));

        horizontalLayout->addWidget(comboBoxAlgo);


        gridLayout->addLayout(horizontalLayout, 0, 7, 1, 1);

        horizontalSpacer_1 = new QSpacerItem(26, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_1, 0, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(26, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 2, 2, 1, 1);

        labelRight = new QLabel(zoomDialog);
        labelRight->setObjectName(QString::fromUtf8("labelRight"));

        gridLayout->addWidget(labelRight, 0, 3, 1, 1);

        spinBoxLeft = new QSpinBox(zoomDialog);
        spinBoxLeft->setObjectName(QString::fromUtf8("spinBoxLeft"));
        spinBoxLeft->setMaximum(16384);

        gridLayout->addWidget(spinBoxLeft, 0, 1, 1, 1);

        labelBottom = new QLabel(zoomDialog);
        labelBottom->setObjectName(QString::fromUtf8("labelBottom"));

        gridLayout->addWidget(labelBottom, 2, 3, 1, 1);

        labelLockAR = new QLabel(zoomDialog);
        labelLockAR->setObjectName(QString::fromUtf8("labelLockAR"));

        gridLayout->addWidget(labelLockAR, 2, 6, 1, 1);

        spinBoxBottom = new QSpinBox(zoomDialog);
        spinBoxBottom->setObjectName(QString::fromUtf8("spinBoxBottom"));
        spinBoxBottom->setMaximum(16384);

        gridLayout->addWidget(spinBoxBottom, 2, 4, 1, 1);

        spinBoxRight = new QSpinBox(zoomDialog);
        spinBoxRight->setObjectName(QString::fromUtf8("spinBoxRight"));
        spinBoxRight->setMaximum(16384);

        gridLayout->addWidget(spinBoxRight, 0, 4, 1, 1);

        labelTop = new QLabel(zoomDialog);
        labelTop->setObjectName(QString::fromUtf8("labelTop"));

        gridLayout->addWidget(labelTop, 2, 0, 1, 1);

        checkBoxRubber = new QCheckBox(zoomDialog);
        checkBoxRubber->setObjectName(QString::fromUtf8("checkBoxRubber"));
        checkBoxRubber->setEnabled(true);

        gridLayout->addWidget(checkBoxRubber, 0, 6, 1, 1);

        labelLeft = new QLabel(zoomDialog);
        labelLeft->setObjectName(QString::fromUtf8("labelLeft"));

        gridLayout->addWidget(labelLeft, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        labelSize = new QLabel(zoomDialog);
        labelSize->setObjectName(QString::fromUtf8("labelSize"));

        horizontalLayout_2->addWidget(labelSize);


        gridLayout->addLayout(horizontalLayout_2, 2, 8, 1, 1);

        spinBoxTop = new QSpinBox(zoomDialog);
        spinBoxTop->setObjectName(QString::fromUtf8("spinBoxTop"));
        spinBoxTop->setMaximum(16384);

        gridLayout->addWidget(spinBoxTop, 2, 1, 1, 1);

        comboBoxAspectRatio = new QComboBox(zoomDialog);
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->addItem(QString());
        comboBoxAspectRatio->setObjectName(QString::fromUtf8("comboBoxAspectRatio"));

        gridLayout->addWidget(comboBoxAspectRatio, 2, 7, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        labelPadding = new QLabel(zoomDialog);
        labelPadding->setObjectName(QString::fromUtf8("labelPadding"));

        horizontalLayout_3->addWidget(labelPadding);

        comboBoxPad = new QComboBox(zoomDialog);
        comboBoxPad->addItem(QString());
        comboBoxPad->addItem(QString());
        comboBoxPad->addItem(QString());
        comboBoxPad->setObjectName(QString::fromUtf8("comboBoxPad"));

        horizontalLayout_3->addWidget(comboBoxPad);


        gridLayout->addLayout(horizontalLayout_3, 0, 8, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(26, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 5, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 0, 9, 1, 1);


        vboxLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        vboxLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(zoomDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        vboxLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(zoomDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        vboxLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(zoomDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(zoomDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), zoomDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), zoomDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(zoomDialog);
    } // setupUi

    void retranslateUi(QDialog *zoomDialog)
    {
        zoomDialog->setWindowTitle(QCoreApplication::translate("zoomDialog", "Zoom", nullptr));
        labelResizeMethod->setText(QCoreApplication::translate("zoomDialog", "Resize Method:", nullptr));
        comboBoxAlgo->setItemText(0, QCoreApplication::translate("zoomDialog", "Bilinear", nullptr));
        comboBoxAlgo->setItemText(1, QCoreApplication::translate("zoomDialog", "Bicubic", nullptr));
        comboBoxAlgo->setItemText(2, QCoreApplication::translate("zoomDialog", "Lanczos-3", nullptr));
        comboBoxAlgo->setItemText(3, QCoreApplication::translate("zoomDialog", "Spline", nullptr));

        labelRight->setText(QCoreApplication::translate("zoomDialog", "Right:", nullptr));
        labelBottom->setText(QCoreApplication::translate("zoomDialog", "Bottom:", nullptr));
        labelLockAR->setText(QCoreApplication::translate("zoomDialog", "Lock Aspect Ratio:", nullptr));
        labelTop->setText(QCoreApplication::translate("zoomDialog", "Top:", nullptr));
        checkBoxRubber->setText(QCoreApplication::translate("zoomDialog", "&Hide Rubber Band", nullptr));
        labelLeft->setText(QCoreApplication::translate("zoomDialog", "Left:", nullptr));
        labelSize->setText(QCoreApplication::translate("zoomDialog", "Selection: ", nullptr));
        comboBoxAspectRatio->setItemText(0, QCoreApplication::translate("zoomDialog", "Do not lock", nullptr));
        comboBoxAspectRatio->setItemText(1, QCoreApplication::translate("zoomDialog", "Current selection", nullptr));
        comboBoxAspectRatio->setItemText(2, QCoreApplication::translate("zoomDialog", "Source", nullptr));
        comboBoxAspectRatio->setItemText(3, QCoreApplication::translate("zoomDialog", "21:9", nullptr));
        comboBoxAspectRatio->setItemText(4, QCoreApplication::translate("zoomDialog", "18:9", nullptr));
        comboBoxAspectRatio->setItemText(5, QCoreApplication::translate("zoomDialog", "16:9", nullptr));
        comboBoxAspectRatio->setItemText(6, QCoreApplication::translate("zoomDialog", "4:3", nullptr));
        comboBoxAspectRatio->setItemText(7, QCoreApplication::translate("zoomDialog", "1:1", nullptr));
        comboBoxAspectRatio->setItemText(8, QCoreApplication::translate("zoomDialog", "9:16", nullptr));

        comboBoxAspectRatio->setCurrentText(QCoreApplication::translate("zoomDialog", "Do not lock", nullptr));
        labelPadding->setText(QCoreApplication::translate("zoomDialog", "Padding:", nullptr));
        comboBoxPad->setItemText(0, QCoreApplication::translate("zoomDialog", "black bars", nullptr));
        comboBoxPad->setItemText(1, QCoreApplication::translate("zoomDialog", "echo", nullptr));
        comboBoxPad->setItemText(2, QCoreApplication::translate("zoomDialog", "none (stretch)", nullptr));

    } // retranslateUi

};

namespace Ui {
    class zoomDialog: public Ui_zoomDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ZOOM_H
