static const AVCodecParser * const parser_list[] = {
    &ff_ac3_parser,
    &ff_h263_parser,
    &ff_h264_parser,
    &ff_hevc_parser,
    &ff_mlp_parser,
    &ff_mpeg4video_parser,
    &ff_vp9_parser,
    NULL };
