/********************************************************************************
** Form generated from reading UI file 'gui2.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GUI2_H
#define UI_GUI2_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "ADM_mwNavSlider.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QAction *actionOpen;
    QAction *actionProperties;
    QAction *actionSave_video;
    QAction *actionPlayFiltered;
    QAction *actionHDRSettings;
    QAction *actionLoad_run_project;
    QAction *actionSave_project;
    QAction *actionPreviewInput;
    QAction *actionPreviewOutput;
    QAction *actionViewCodecOptions;
    QAction *actionViewNavigation;
    QAction *actionViewSelection;
    QAction *actionViewVolume;
    QAction *actionViewToolBar;
    QAction *actionViewAudioMetre;
    QAction *actionPreviewSeparate;
    QAction *actionPreviewTop;
    QAction *actionPreviewSide;
    QWidget *centralwidget;
    QHBoxLayout *horizontalLayout_3;
    QHBoxLayout *_10;
    QFrame *frame_video;
    QSpacerItem *spacerItem;
    QMenuBar *menubar;
    QMenu *menuHelp;
    QMenu *menuVideo;
    QMenu *menuEdit;
    QMenu *menuView;
    QMenu *menuToolbars;
    QMenu *menuThemes;
    QMenu *menuAuto;
    QMenu *menuCustom;
    QMenu *menuGo;
    QMenu *menuTools;
    QMenu *menuAudio;
    QMenu *menuFile;
    QMenu *menuRecent;
    QToolBar *toolBar;
    QDockWidget *codecWidget;
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout_9;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_7;
    QSpacerItem *verticalSpacer_7;
    QHBoxLayout *videoLayout_2;
    QSpacerItem *spacerItem1;
    QVBoxLayout *_6;
    QHBoxLayout *horizontalLayout_4;
    QLabel *labelVideoDecoder;
    QLabel *labelDisplay;
    QPushButton *pushButtonDecoderConf;
    QSpacerItem *verticalSpacer_11;
    QLabel *label_3;
    QSpacerItem *verticalSpacer_8;
    QHBoxLayout *videoLayout;
    QSpacerItem *spacerItem2;
    QVBoxLayout *_7;
    QComboBox *comboBoxVideo;
    QPushButton *pushButtonVideoConf;
    QPushButton *pushButtonVideoFilter;
    QSpacerItem *verticalSpacer_12;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_5;
    QLabel *TrackCountLabel;
    QSpacerItem *verticalSpacer_9;
    QHBoxLayout *AudioLayout;
    QSpacerItem *spacerItem3;
    QVBoxLayout *_8;
    QComboBox *comboBoxAudio;
    QPushButton *pushButtonAudioConf;
    QPushButton *pushButtonAudioFilter;
    QHBoxLayout *_9;
    QCheckBox *checkBox_TimeShift;
    QSpinBox *spinBox_TimeValue;
    QLabel *label_11;
    QSpacerItem *verticalSpacer_13;
    QLabel *label_4;
    QSpacerItem *verticalSpacer_10;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *spacerItem4;
    QVBoxLayout *verticalLayout_2;
    QComboBox *comboBoxFormat;
    QPushButton *pushButtonFormatConfigure;
    QSpacerItem *verticalSpacer_3;
    QDockWidget *navigationWidget;
    QWidget *dockWidgetContents_2;
    QVBoxLayout *verticalLayout_8;
    ADM_mwNavSlider *horizontalSlider;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *navButtonsLayout;
    QToolButton *toolButtonPlay;
    QToolButton *toolButtonPreviousFrame;
    QToolButton *toolButtonNextFrame;
    QToolButton *toolButtonPreviousIntraFrame;
    QToolButton *toolButtonNextIntraFrame;
    QToolButton *toolButtonSetMarkerA;
    QToolButton *toolButtonDeleteSelection;
    QToolButton *toolButtonSetMarkerB;
    QToolButton *toolButtonPreviousCutPoint;
    QToolButton *toolButtonNextCutPoint;
    QToolButton *toolButtonPreviousBlackFrame;
    QToolButton *toolButtonNextBlackFrame;
    QToolButton *toolButtonFirstFrame;
    QToolButton *toolButtonLastFrame;
    QToolButton *toolButtonBackOneMinute;
    QToolButton *toolButtonForwardOneMinute;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *_4;
    QPushButton *pushButtonTime;
    QLineEdit *currentTime;
    QLabel *totalTime;
    QSpacerItem *spacerItem5;
    QLabel *label_10;
    QLabel *label_8;
    QSpacerItem *spacerItem6;
    QDockWidget *selectionWidget;
    QWidget *dockWidgetContents_7;
    QVBoxLayout *verticalLayout_7;
    QWidget *sliderPlaceHolder;
    QVBoxLayout *verticalLayout_6;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLabel *label_9;
    QPushButton *pushButtonJumpToMarkerA;
    QPushButton *pushButtonJumpToMarkerB;
    QLabel *selectionDuration;
    QDockWidget *volumeWidget;
    QWidget *dockWidgetContents_5;
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *volumeWidgetHorizLayout_1;
    QToolButton *toolButtonAudioToggle;
    QHBoxLayout *volumeWidgetHorizLayout_2;
    QSlider *horizontalSlider_2;
    QDockWidget *audioMetreWidget;
    QWidget *dockWidgetContents_3;
    QVBoxLayout *verticalLayout_5;
    QFrame *frameVU;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName(QString::fromUtf8("MainWindow"));
        MainWindow->resize(800, 600);
        actionOpen = new QAction(MainWindow);
        actionOpen->setObjectName(QString::fromUtf8("actionOpen"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/new/prefix1/pics/fileopen.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionOpen->setIcon(icon);
        actionProperties = new QAction(MainWindow);
        actionProperties->setObjectName(QString::fromUtf8("actionProperties"));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/new/prefix1/pics/info.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionProperties->setIcon(icon1);
        actionSave_video = new QAction(MainWindow);
        actionSave_video->setObjectName(QString::fromUtf8("actionSave_video"));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/new/prefix1/pics/filesave.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionSave_video->setIcon(icon2);
        actionPlayFiltered = new QAction(MainWindow);
        actionPlayFiltered->setObjectName(QString::fromUtf8("actionPlayFiltered"));
        actionPlayFiltered->setCheckable(true);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/new/prefix1/pics/play_filtered.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionPlayFiltered->setIcon(icon3);
        actionHDRSettings = new QAction(MainWindow);
        actionHDRSettings->setObjectName(QString::fromUtf8("actionHDRSettings"));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/new/prefix1/pics/hdr.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionHDRSettings->setIcon(icon4);
        actionHDRSettings->setVisible(false);
        actionLoad_run_project = new QAction(MainWindow);
        actionLoad_run_project->setObjectName(QString::fromUtf8("actionLoad_run_project"));
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/new/prefix1/pics/project_open.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionLoad_run_project->setIcon(icon5);
        actionSave_project = new QAction(MainWindow);
        actionSave_project->setObjectName(QString::fromUtf8("actionSave_project"));
        actionSave_project->setIcon(icon2);
        actionPreviewInput = new QAction(MainWindow);
        actionPreviewInput->setObjectName(QString::fromUtf8("actionPreviewInput"));
        actionPreviewInput->setCheckable(true);
        actionPreviewInput->setChecked(true);
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/new/prefix1/pics/preview_input.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionPreviewInput->setIcon(icon6);
        actionPreviewOutput = new QAction(MainWindow);
        actionPreviewOutput->setObjectName(QString::fromUtf8("actionPreviewOutput"));
        actionPreviewOutput->setCheckable(true);
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/new/prefix1/pics/preview_output.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionPreviewOutput->setIcon(icon7);
        actionViewCodecOptions = new QAction(MainWindow);
        actionViewCodecOptions->setObjectName(QString::fromUtf8("actionViewCodecOptions"));
        actionViewCodecOptions->setCheckable(true);
        actionViewCodecOptions->setChecked(true);
        actionViewNavigation = new QAction(MainWindow);
        actionViewNavigation->setObjectName(QString::fromUtf8("actionViewNavigation"));
        actionViewNavigation->setCheckable(true);
        actionViewNavigation->setChecked(true);
        actionViewSelection = new QAction(MainWindow);
        actionViewSelection->setObjectName(QString::fromUtf8("actionViewSelection"));
        actionViewSelection->setCheckable(true);
        actionViewSelection->setChecked(true);
        actionViewVolume = new QAction(MainWindow);
        actionViewVolume->setObjectName(QString::fromUtf8("actionViewVolume"));
        actionViewVolume->setCheckable(true);
        actionViewVolume->setChecked(true);
        actionViewToolBar = new QAction(MainWindow);
        actionViewToolBar->setObjectName(QString::fromUtf8("actionViewToolBar"));
        actionViewToolBar->setCheckable(true);
        actionViewToolBar->setChecked(true);
        actionViewAudioMetre = new QAction(MainWindow);
        actionViewAudioMetre->setObjectName(QString::fromUtf8("actionViewAudioMetre"));
        actionViewAudioMetre->setCheckable(true);
        actionViewAudioMetre->setChecked(true);
        actionPreviewSeparate = new QAction(MainWindow);
        actionPreviewSeparate->setObjectName(QString::fromUtf8("actionPreviewSeparate"));
        actionPreviewSeparate->setCheckable(true);
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/new/prefix1/pics/preview_separate.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionPreviewSeparate->setIcon(icon8);
        actionPreviewTop = new QAction(MainWindow);
        actionPreviewTop->setObjectName(QString::fromUtf8("actionPreviewTop"));
        actionPreviewTop->setCheckable(true);
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/new/prefix1/pics/preview_top.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionPreviewTop->setIcon(icon9);
        actionPreviewSide = new QAction(MainWindow);
        actionPreviewSide->setObjectName(QString::fromUtf8("actionPreviewSide"));
        actionPreviewSide->setCheckable(true);
        QIcon icon10;
        icon10.addFile(QString::fromUtf8(":/new/prefix1/pics/preview_side.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionPreviewSide->setIcon(icon10);
        centralwidget = new QWidget(MainWindow);
        centralwidget->setObjectName(QString::fromUtf8("centralwidget"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(centralwidget->sizePolicy().hasHeightForWidth());
        centralwidget->setSizePolicy(sizePolicy);
        centralwidget->setMinimumSize(QSize(200, 200));
        horizontalLayout_3 = new QHBoxLayout(centralwidget);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        _10 = new QHBoxLayout();
        _10->setSpacing(6);
        _10->setObjectName(QString::fromUtf8("_10"));
        _10->setContentsMargins(0, 0, 0, 0);
        frame_video = new QFrame(centralwidget);
        frame_video->setObjectName(QString::fromUtf8("frame_video"));
        QSizePolicy sizePolicy1(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(frame_video->sizePolicy().hasHeightForWidth());
        frame_video->setSizePolicy(sizePolicy1);
        frame_video->setMinimumSize(QSize(100, 100));
        frame_video->setAutoFillBackground(false);
        frame_video->setFrameShape(QFrame::NoFrame);
        frame_video->setFrameShadow(QFrame::Raised);
        frame_video->setLineWidth(0);

        _10->addWidget(frame_video);

        spacerItem = new QSpacerItem(13, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _10->addItem(spacerItem);


        horizontalLayout_3->addLayout(_10);

        MainWindow->setCentralWidget(centralwidget);
        menubar = new QMenuBar(MainWindow);
        menubar->setObjectName(QString::fromUtf8("menubar"));
        menubar->setGeometry(QRect(0, 0, 800, 22));
        menubar->setContextMenuPolicy(Qt::PreventContextMenu);
        menuHelp = new QMenu(menubar);
        menuHelp->setObjectName(QString::fromUtf8("menuHelp"));
        menuVideo = new QMenu(menubar);
        menuVideo->setObjectName(QString::fromUtf8("menuVideo"));
        menuEdit = new QMenu(menubar);
        menuEdit->setObjectName(QString::fromUtf8("menuEdit"));
        menuView = new QMenu(menubar);
        menuView->setObjectName(QString::fromUtf8("menuView"));
        menuToolbars = new QMenu(menuView);
        menuToolbars->setObjectName(QString::fromUtf8("menuToolbars"));
        menuThemes = new QMenu(menuView);
        menuThemes->setObjectName(QString::fromUtf8("menuThemes"));
        menuAuto = new QMenu(menubar);
        menuAuto->setObjectName(QString::fromUtf8("menuAuto"));
        menuCustom = new QMenu(menubar);
        menuCustom->setObjectName(QString::fromUtf8("menuCustom"));
        menuGo = new QMenu(menubar);
        menuGo->setObjectName(QString::fromUtf8("menuGo"));
        menuTools = new QMenu(menubar);
        menuTools->setObjectName(QString::fromUtf8("menuTools"));
        menuAudio = new QMenu(menubar);
        menuAudio->setObjectName(QString::fromUtf8("menuAudio"));
        menuFile = new QMenu(menubar);
        menuFile->setObjectName(QString::fromUtf8("menuFile"));
        menuRecent = new QMenu(menubar);
        menuRecent->setObjectName(QString::fromUtf8("menuRecent"));
        MainWindow->setMenuBar(menubar);
        toolBar = new QToolBar(MainWindow);
        toolBar->setObjectName(QString::fromUtf8("toolBar"));
        toolBar->setContextMenuPolicy(Qt::PreventContextMenu);
        toolBar->setOrientation(Qt::Horizontal);
        MainWindow->addToolBar(Qt::TopToolBarArea, toolBar);
        codecWidget = new QDockWidget(MainWindow);
        codecWidget->setObjectName(QString::fromUtf8("codecWidget"));
        codecWidget->setStyleSheet(QString::fromUtf8(""));
        codecWidget->setFeatures(QDockWidget::NoDockWidgetFeatures);
        codecWidget->setAllowedAreas(Qt::LeftDockWidgetArea|Qt::RightDockWidgetArea);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName(QString::fromUtf8("dockWidgetContents"));
        verticalLayout_9 = new QVBoxLayout(dockWidgetContents);
        verticalLayout_9->setSpacing(0);
        verticalLayout_9->setObjectName(QString::fromUtf8("verticalLayout_9"));
        verticalLayout_9->setContentsMargins(9, 9, 0, 9);
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setSpacing(0);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        verticalLayout_3->setSizeConstraint(QLayout::SetDefaultConstraint);
        label_7 = new QLabel(dockWidgetContents);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        verticalLayout_3->addWidget(label_7);

        verticalSpacer_7 = new QSpacerItem(20, 13, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_7);

        videoLayout_2 = new QHBoxLayout();
        videoLayout_2->setSpacing(0);
        videoLayout_2->setObjectName(QString::fromUtf8("videoLayout_2"));
        videoLayout_2->setContentsMargins(0, 0, 0, 0);
        spacerItem1 = new QSpacerItem(13, 53, QSizePolicy::Fixed, QSizePolicy::Minimum);

        videoLayout_2->addItem(spacerItem1);

        _6 = new QVBoxLayout();
        _6->setSpacing(6);
        _6->setObjectName(QString::fromUtf8("_6"));
        _6->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        labelVideoDecoder = new QLabel(dockWidgetContents);
        labelVideoDecoder->setObjectName(QString::fromUtf8("labelVideoDecoder"));

        horizontalLayout_4->addWidget(labelVideoDecoder);

        labelDisplay = new QLabel(dockWidgetContents);
        labelDisplay->setObjectName(QString::fromUtf8("labelDisplay"));

        horizontalLayout_4->addWidget(labelDisplay);


        _6->addLayout(horizontalLayout_4);

        pushButtonDecoderConf = new QPushButton(dockWidgetContents);
        pushButtonDecoderConf->setObjectName(QString::fromUtf8("pushButtonDecoderConf"));
        pushButtonDecoderConf->setEnabled(true);
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(pushButtonDecoderConf->sizePolicy().hasHeightForWidth());
        pushButtonDecoderConf->setSizePolicy(sizePolicy2);

        _6->addWidget(pushButtonDecoderConf);


        videoLayout_2->addLayout(_6);


        verticalLayout_3->addLayout(videoLayout_2);

        verticalSpacer_11 = new QSpacerItem(20, 13, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_11);

        label_3 = new QLabel(dockWidgetContents);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        QSizePolicy sizePolicy3(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy3);
        label_3->setMaximumSize(QSize(180, 16777215));
        label_3->setTextFormat(Qt::AutoText);

        verticalLayout_3->addWidget(label_3);

        verticalSpacer_8 = new QSpacerItem(20, 13, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_8);

        videoLayout = new QHBoxLayout();
        videoLayout->setSpacing(0);
        videoLayout->setObjectName(QString::fromUtf8("videoLayout"));
        videoLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem2 = new QSpacerItem(12, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        videoLayout->addItem(spacerItem2);

        _7 = new QVBoxLayout();
        _7->setSpacing(6);
        _7->setObjectName(QString::fromUtf8("_7"));
        _7->setSizeConstraint(QLayout::SetDefaultConstraint);
        _7->setContentsMargins(0, 0, 0, 0);
        comboBoxVideo = new QComboBox(dockWidgetContents);
        comboBoxVideo->addItem(QString());
        comboBoxVideo->setObjectName(QString::fromUtf8("comboBoxVideo"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(comboBoxVideo->sizePolicy().hasHeightForWidth());
        comboBoxVideo->setSizePolicy(sizePolicy4);

        _7->addWidget(comboBoxVideo);

        pushButtonVideoConf = new QPushButton(dockWidgetContents);
        pushButtonVideoConf->setObjectName(QString::fromUtf8("pushButtonVideoConf"));
        pushButtonVideoConf->setEnabled(true);
        sizePolicy2.setHeightForWidth(pushButtonVideoConf->sizePolicy().hasHeightForWidth());
        pushButtonVideoConf->setSizePolicy(sizePolicy2);

        _7->addWidget(pushButtonVideoConf);

        pushButtonVideoFilter = new QPushButton(dockWidgetContents);
        pushButtonVideoFilter->setObjectName(QString::fromUtf8("pushButtonVideoFilter"));
        pushButtonVideoFilter->setEnabled(true);
        sizePolicy2.setHeightForWidth(pushButtonVideoFilter->sizePolicy().hasHeightForWidth());
        pushButtonVideoFilter->setSizePolicy(sizePolicy2);

        _7->addWidget(pushButtonVideoFilter);


        videoLayout->addLayout(_7);


        verticalLayout_3->addLayout(videoLayout);

        verticalSpacer_12 = new QSpacerItem(20, 13, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_12);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_5 = new QLabel(dockWidgetContents);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        sizePolicy3.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy3);
        label_5->setMaximumSize(QSize(180, 16777215));
        label_5->setTextFormat(Qt::AutoText);

        horizontalLayout_2->addWidget(label_5);

        TrackCountLabel = new QLabel(dockWidgetContents);
        TrackCountLabel->setObjectName(QString::fromUtf8("TrackCountLabel"));

        horizontalLayout_2->addWidget(TrackCountLabel);


        verticalLayout_3->addLayout(horizontalLayout_2);

        verticalSpacer_9 = new QSpacerItem(20, 13, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_9);

        AudioLayout = new QHBoxLayout();
        AudioLayout->setSpacing(0);
        AudioLayout->setObjectName(QString::fromUtf8("AudioLayout"));
        AudioLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem3 = new QSpacerItem(12, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        AudioLayout->addItem(spacerItem3);

        _8 = new QVBoxLayout();
        _8->setSpacing(6);
        _8->setObjectName(QString::fromUtf8("_8"));
        _8->setSizeConstraint(QLayout::SetDefaultConstraint);
        _8->setContentsMargins(0, 0, 0, 0);
        comboBoxAudio = new QComboBox(dockWidgetContents);
        comboBoxAudio->addItem(QString());
        comboBoxAudio->setObjectName(QString::fromUtf8("comboBoxAudio"));
        QSizePolicy sizePolicy5(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(comboBoxAudio->sizePolicy().hasHeightForWidth());
        comboBoxAudio->setSizePolicy(sizePolicy5);

        _8->addWidget(comboBoxAudio);

        pushButtonAudioConf = new QPushButton(dockWidgetContents);
        pushButtonAudioConf->setObjectName(QString::fromUtf8("pushButtonAudioConf"));
        pushButtonAudioConf->setEnabled(true);
        sizePolicy2.setHeightForWidth(pushButtonAudioConf->sizePolicy().hasHeightForWidth());
        pushButtonAudioConf->setSizePolicy(sizePolicy2);

        _8->addWidget(pushButtonAudioConf);

        pushButtonAudioFilter = new QPushButton(dockWidgetContents);
        pushButtonAudioFilter->setObjectName(QString::fromUtf8("pushButtonAudioFilter"));
        pushButtonAudioFilter->setEnabled(true);
        sizePolicy2.setHeightForWidth(pushButtonAudioFilter->sizePolicy().hasHeightForWidth());
        pushButtonAudioFilter->setSizePolicy(sizePolicy2);

        _8->addWidget(pushButtonAudioFilter);

        _9 = new QHBoxLayout();
        _9->setSpacing(6);
        _9->setObjectName(QString::fromUtf8("_9"));
        _9->setSizeConstraint(QLayout::SetDefaultConstraint);
        _9->setContentsMargins(0, 0, 0, 0);
        checkBox_TimeShift = new QCheckBox(dockWidgetContents);
        checkBox_TimeShift->setObjectName(QString::fromUtf8("checkBox_TimeShift"));

        _9->addWidget(checkBox_TimeShift);

        spinBox_TimeValue = new QSpinBox(dockWidgetContents);
        spinBox_TimeValue->setObjectName(QString::fromUtf8("spinBox_TimeValue"));
        spinBox_TimeValue->setEnabled(false);
        sizePolicy2.setHeightForWidth(spinBox_TimeValue->sizePolicy().hasHeightForWidth());
        spinBox_TimeValue->setSizePolicy(sizePolicy2);
        spinBox_TimeValue->setMinimum(-99999);
        spinBox_TimeValue->setMaximum(99999);

        _9->addWidget(spinBox_TimeValue);

        label_11 = new QLabel(dockWidgetContents);
        label_11->setObjectName(QString::fromUtf8("label_11"));
        sizePolicy3.setHeightForWidth(label_11->sizePolicy().hasHeightForWidth());
        label_11->setSizePolicy(sizePolicy3);

        _9->addWidget(label_11);


        _8->addLayout(_9);


        AudioLayout->addLayout(_8);


        verticalLayout_3->addLayout(AudioLayout);

        verticalSpacer_13 = new QSpacerItem(20, 13, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_13);

        label_4 = new QLabel(dockWidgetContents);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        sizePolicy3.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy3);
        label_4->setTextFormat(Qt::AutoText);

        verticalLayout_3->addWidget(label_4);

        verticalSpacer_10 = new QSpacerItem(20, 13, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_3->addItem(verticalSpacer_10);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        spacerItem4 = new QSpacerItem(12, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacerItem4);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        comboBoxFormat = new QComboBox(dockWidgetContents);
        comboBoxFormat->setObjectName(QString::fromUtf8("comboBoxFormat"));
        sizePolicy4.setHeightForWidth(comboBoxFormat->sizePolicy().hasHeightForWidth());
        comboBoxFormat->setSizePolicy(sizePolicy4);

        verticalLayout_2->addWidget(comboBoxFormat);

        pushButtonFormatConfigure = new QPushButton(dockWidgetContents);
        pushButtonFormatConfigure->setObjectName(QString::fromUtf8("pushButtonFormatConfigure"));
        pushButtonFormatConfigure->setEnabled(true);
        sizePolicy2.setHeightForWidth(pushButtonFormatConfigure->sizePolicy().hasHeightForWidth());
        pushButtonFormatConfigure->setSizePolicy(sizePolicy2);

        verticalLayout_2->addWidget(pushButtonFormatConfigure);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout_3->addLayout(horizontalLayout);


        verticalLayout_9->addLayout(verticalLayout_3);

        verticalSpacer_3 = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_9->addItem(verticalSpacer_3);

        codecWidget->setWidget(dockWidgetContents);
        MainWindow->addDockWidget(Qt::LeftDockWidgetArea, codecWidget);
        navigationWidget = new QDockWidget(MainWindow);
        navigationWidget->setObjectName(QString::fromUtf8("navigationWidget"));
        QSizePolicy sizePolicy6(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(navigationWidget->sizePolicy().hasHeightForWidth());
        navigationWidget->setSizePolicy(sizePolicy6);
        navigationWidget->setMinimumSize(QSize(543, 120));
        navigationWidget->setMaximumSize(QSize(524287, 120));
        navigationWidget->setFeatures(QDockWidget::NoDockWidgetFeatures);
        navigationWidget->setAllowedAreas(Qt::BottomDockWidgetArea);
        dockWidgetContents_2 = new QWidget();
        dockWidgetContents_2->setObjectName(QString::fromUtf8("dockWidgetContents_2"));
        QSizePolicy sizePolicy7(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(dockWidgetContents_2->sizePolicy().hasHeightForWidth());
        dockWidgetContents_2->setSizePolicy(sizePolicy7);
        verticalLayout_8 = new QVBoxLayout(dockWidgetContents_2);
        verticalLayout_8->setSpacing(0);
        verticalLayout_8->setObjectName(QString::fromUtf8("verticalLayout_8"));
        verticalLayout_8->setContentsMargins(9, 1, 9, 9);
        horizontalSlider = new ADM_mwNavSlider(dockWidgetContents_2);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        sizePolicy6.setHeightForWidth(horizontalSlider->sizePolicy().hasHeightForWidth());
        horizontalSlider->setSizePolicy(sizePolicy6);
        horizontalSlider->setMinimumSize(QSize(0, 22));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout_8->addWidget(horizontalSlider);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(12);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(-1, 0, -1, -1);
        navButtonsLayout = new QHBoxLayout();
        navButtonsLayout->setSpacing(0);
        navButtonsLayout->setObjectName(QString::fromUtf8("navButtonsLayout"));
        navButtonsLayout->setContentsMargins(0, 0, 0, 0);
        toolButtonPlay = new QToolButton(dockWidgetContents_2);
        toolButtonPlay->setObjectName(QString::fromUtf8("toolButtonPlay"));
        QIcon icon11;
        icon11.addFile(QString::fromUtf8(":/new/prefix1/pics/player_play.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonPlay->setIcon(icon11);
        toolButtonPlay->setIconSize(QSize(24, 24));
        toolButtonPlay->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonPlay);

        toolButtonPreviousFrame = new QToolButton(dockWidgetContents_2);
        toolButtonPreviousFrame->setObjectName(QString::fromUtf8("toolButtonPreviousFrame"));
        QIcon icon12;
        icon12.addFile(QString::fromUtf8(":/new/prefix1/pics/back.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonPreviousFrame->setIcon(icon12);
        toolButtonPreviousFrame->setIconSize(QSize(24, 24));
        toolButtonPreviousFrame->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonPreviousFrame);

        toolButtonNextFrame = new QToolButton(dockWidgetContents_2);
        toolButtonNextFrame->setObjectName(QString::fromUtf8("toolButtonNextFrame"));
        QIcon icon13;
        icon13.addFile(QString::fromUtf8(":/new/prefix1/pics/forward.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonNextFrame->setIcon(icon13);
        toolButtonNextFrame->setIconSize(QSize(24, 24));
        toolButtonNextFrame->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonNextFrame);

        toolButtonPreviousIntraFrame = new QToolButton(dockWidgetContents_2);
        toolButtonPreviousIntraFrame->setObjectName(QString::fromUtf8("toolButtonPreviousIntraFrame"));
        QIcon icon14;
        icon14.addFile(QString::fromUtf8(":/new/prefix1/pics/player_rew.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonPreviousIntraFrame->setIcon(icon14);
        toolButtonPreviousIntraFrame->setIconSize(QSize(24, 24));
        toolButtonPreviousIntraFrame->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonPreviousIntraFrame);

        toolButtonNextIntraFrame = new QToolButton(dockWidgetContents_2);
        toolButtonNextIntraFrame->setObjectName(QString::fromUtf8("toolButtonNextIntraFrame"));
        QIcon icon15;
        icon15.addFile(QString::fromUtf8(":/new/prefix1/pics/player_fwd.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonNextIntraFrame->setIcon(icon15);
        toolButtonNextIntraFrame->setIconSize(QSize(24, 24));
        toolButtonNextIntraFrame->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonNextIntraFrame);

        toolButtonSetMarkerA = new QToolButton(dockWidgetContents_2);
        toolButtonSetMarkerA->setObjectName(QString::fromUtf8("toolButtonSetMarkerA"));
        QIcon icon16;
        icon16.addFile(QString::fromUtf8(":/new/prefix1/pics/markA.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonSetMarkerA->setIcon(icon16);
        toolButtonSetMarkerA->setIconSize(QSize(27, 24));
        toolButtonSetMarkerA->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonSetMarkerA);

        toolButtonDeleteSelection = new QToolButton(dockWidgetContents_2);
        toolButtonDeleteSelection->setObjectName(QString::fromUtf8("toolButtonDeleteSelection"));
        QIcon icon17;
        icon17.addFile(QString::fromUtf8(":/new/prefix1/pics/delete_selection.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonDeleteSelection->setIcon(icon17);
        toolButtonDeleteSelection->setIconSize(QSize(24, 24));
        toolButtonDeleteSelection->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonDeleteSelection);

        toolButtonSetMarkerB = new QToolButton(dockWidgetContents_2);
        toolButtonSetMarkerB->setObjectName(QString::fromUtf8("toolButtonSetMarkerB"));
        QIcon icon18;
        icon18.addFile(QString::fromUtf8(":/new/prefix1/pics/markB.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonSetMarkerB->setIcon(icon18);
        toolButtonSetMarkerB->setIconSize(QSize(27, 24));
        toolButtonSetMarkerB->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonSetMarkerB);

        toolButtonPreviousCutPoint = new QToolButton(dockWidgetContents_2);
        toolButtonPreviousCutPoint->setObjectName(QString::fromUtf8("toolButtonPreviousCutPoint"));
        QIcon icon19;
        icon19.addFile(QString::fromUtf8(":/new/prefix1/pics/prev_cut.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonPreviousCutPoint->setIcon(icon19);
        toolButtonPreviousCutPoint->setIconSize(QSize(24, 24));
        toolButtonPreviousCutPoint->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonPreviousCutPoint);

        toolButtonNextCutPoint = new QToolButton(dockWidgetContents_2);
        toolButtonNextCutPoint->setObjectName(QString::fromUtf8("toolButtonNextCutPoint"));
        QIcon icon20;
        icon20.addFile(QString::fromUtf8(":/new/prefix1/pics/next_cut.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonNextCutPoint->setIcon(icon20);
        toolButtonNextCutPoint->setIconSize(QSize(24, 24));
        toolButtonNextCutPoint->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonNextCutPoint);

        toolButtonPreviousBlackFrame = new QToolButton(dockWidgetContents_2);
        toolButtonPreviousBlackFrame->setObjectName(QString::fromUtf8("toolButtonPreviousBlackFrame"));
        QIcon icon21;
        icon21.addFile(QString::fromUtf8(":/new/prefix1/pics/prev_black.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonPreviousBlackFrame->setIcon(icon21);
        toolButtonPreviousBlackFrame->setIconSize(QSize(24, 24));
        toolButtonPreviousBlackFrame->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonPreviousBlackFrame);

        toolButtonNextBlackFrame = new QToolButton(dockWidgetContents_2);
        toolButtonNextBlackFrame->setObjectName(QString::fromUtf8("toolButtonNextBlackFrame"));
        QIcon icon22;
        icon22.addFile(QString::fromUtf8(":/new/prefix1/pics/next_black.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonNextBlackFrame->setIcon(icon22);
        toolButtonNextBlackFrame->setIconSize(QSize(24, 24));
        toolButtonNextBlackFrame->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonNextBlackFrame);

        toolButtonFirstFrame = new QToolButton(dockWidgetContents_2);
        toolButtonFirstFrame->setObjectName(QString::fromUtf8("toolButtonFirstFrame"));
        QIcon icon23;
        icon23.addFile(QString::fromUtf8(":/new/prefix1/pics/player_start.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonFirstFrame->setIcon(icon23);
        toolButtonFirstFrame->setIconSize(QSize(24, 24));
        toolButtonFirstFrame->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonFirstFrame);

        toolButtonLastFrame = new QToolButton(dockWidgetContents_2);
        toolButtonLastFrame->setObjectName(QString::fromUtf8("toolButtonLastFrame"));
        QIcon icon24;
        icon24.addFile(QString::fromUtf8(":/new/prefix1/pics/player_end.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonLastFrame->setIcon(icon24);
        toolButtonLastFrame->setIconSize(QSize(24, 24));
        toolButtonLastFrame->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonLastFrame);

        toolButtonBackOneMinute = new QToolButton(dockWidgetContents_2);
        toolButtonBackOneMinute->setObjectName(QString::fromUtf8("toolButtonBackOneMinute"));
        QIcon icon25;
        icon25.addFile(QString::fromUtf8(":/new/prefix1/pics/backward1mn.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonBackOneMinute->setIcon(icon25);
        toolButtonBackOneMinute->setIconSize(QSize(24, 24));
        toolButtonBackOneMinute->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonBackOneMinute);

        toolButtonForwardOneMinute = new QToolButton(dockWidgetContents_2);
        toolButtonForwardOneMinute->setObjectName(QString::fromUtf8("toolButtonForwardOneMinute"));
        QIcon icon26;
        icon26.addFile(QString::fromUtf8(":/new/prefix1/pics/forward1mn.png"), QSize(), QIcon::Normal, QIcon::Off);
        toolButtonForwardOneMinute->setIcon(icon26);
        toolButtonForwardOneMinute->setIconSize(QSize(24, 24));
        toolButtonForwardOneMinute->setAutoRaise(true);

        navButtonsLayout->addWidget(toolButtonForwardOneMinute);

        horizontalSpacer_3 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        navButtonsLayout->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(navButtonsLayout);

        _4 = new QHBoxLayout();
        _4->setSpacing(6);
        _4->setObjectName(QString::fromUtf8("_4"));
        _4->setContentsMargins(0, 0, 0, 0);
        pushButtonTime = new QPushButton(dockWidgetContents_2);
        pushButtonTime->setObjectName(QString::fromUtf8("pushButtonTime"));

        _4->addWidget(pushButtonTime);

        currentTime = new QLineEdit(dockWidgetContents_2);
        currentTime->setObjectName(QString::fromUtf8("currentTime"));
        QSizePolicy sizePolicy8(QSizePolicy::Minimum, QSizePolicy::Maximum);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(currentTime->sizePolicy().hasHeightForWidth());
        currentTime->setSizePolicy(sizePolicy8);
        currentTime->setMinimumSize(QSize(100, 0));
        currentTime->setMaxLength(12);
        currentTime->setAlignment(Qt::AlignCenter);
        currentTime->setReadOnly(true);

        _4->addWidget(currentTime);

        totalTime = new QLabel(dockWidgetContents_2);
        totalTime->setObjectName(QString::fromUtf8("totalTime"));
        sizePolicy8.setHeightForWidth(totalTime->sizePolicy().hasHeightForWidth());
        totalTime->setSizePolicy(sizePolicy8);

        _4->addWidget(totalTime);

        spacerItem5 = new QSpacerItem(24, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        _4->addItem(spacerItem5);

        label_10 = new QLabel(dockWidgetContents_2);
        label_10->setObjectName(QString::fromUtf8("label_10"));
        sizePolicy4.setHeightForWidth(label_10->sizePolicy().hasHeightForWidth());
        label_10->setSizePolicy(sizePolicy4);

        _4->addWidget(label_10);

        label_8 = new QLabel(dockWidgetContents_2);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        sizePolicy2.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy2);

        _4->addWidget(label_8);

        spacerItem6 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _4->addItem(spacerItem6);


        verticalLayout->addLayout(_4);


        verticalLayout_8->addLayout(verticalLayout);

        navigationWidget->setWidget(dockWidgetContents_2);
        MainWindow->addDockWidget(Qt::BottomDockWidgetArea, navigationWidget);
        selectionWidget = new QDockWidget(MainWindow);
        selectionWidget->setObjectName(QString::fromUtf8("selectionWidget"));
        sizePolicy2.setHeightForWidth(selectionWidget->sizePolicy().hasHeightForWidth());
        selectionWidget->setSizePolicy(sizePolicy2);
        selectionWidget->setMinimumSize(QSize(182, 120));
        selectionWidget->setMaximumSize(QSize(182, 120));
        selectionWidget->setFeatures(QDockWidget::NoDockWidgetFeatures);
        dockWidgetContents_7 = new QWidget();
        dockWidgetContents_7->setObjectName(QString::fromUtf8("dockWidgetContents_7"));
        QSizePolicy sizePolicy9(QSizePolicy::Fixed, QSizePolicy::Preferred);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(dockWidgetContents_7->sizePolicy().hasHeightForWidth());
        dockWidgetContents_7->setSizePolicy(sizePolicy9);
        verticalLayout_7 = new QVBoxLayout(dockWidgetContents_7);
        verticalLayout_7->setSpacing(2);
        verticalLayout_7->setObjectName(QString::fromUtf8("verticalLayout_7"));
        verticalLayout_7->setContentsMargins(9, 9, 9, 9);
        sliderPlaceHolder = new QWidget(dockWidgetContents_7);
        sliderPlaceHolder->setObjectName(QString::fromUtf8("sliderPlaceHolder"));
        sizePolicy4.setHeightForWidth(sliderPlaceHolder->sizePolicy().hasHeightForWidth());
        sliderPlaceHolder->setSizePolicy(sizePolicy4);
        sliderPlaceHolder->setMinimumSize(QSize(160, 20));

        verticalLayout_7->addWidget(sliderPlaceHolder);

        verticalLayout_6 = new QVBoxLayout();
        verticalLayout_6->setSpacing(9);
        verticalLayout_6->setObjectName(QString::fromUtf8("verticalLayout_6"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setVerticalSpacing(4);
        label_2 = new QLabel(dockWidgetContents_7);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        label_9 = new QLabel(dockWidgetContents_7);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout->addWidget(label_9, 1, 0, 1, 1);

        pushButtonJumpToMarkerA = new QPushButton(dockWidgetContents_7);
        pushButtonJumpToMarkerA->setObjectName(QString::fromUtf8("pushButtonJumpToMarkerA"));
        QSizePolicy sizePolicy10(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy10.setHorizontalStretch(0);
        sizePolicy10.setVerticalStretch(0);
        sizePolicy10.setHeightForWidth(pushButtonJumpToMarkerA->sizePolicy().hasHeightForWidth());
        pushButtonJumpToMarkerA->setSizePolicy(sizePolicy10);

        gridLayout->addWidget(pushButtonJumpToMarkerA, 0, 1, 1, 1);

        pushButtonJumpToMarkerB = new QPushButton(dockWidgetContents_7);
        pushButtonJumpToMarkerB->setObjectName(QString::fromUtf8("pushButtonJumpToMarkerB"));
        sizePolicy10.setHeightForWidth(pushButtonJumpToMarkerB->sizePolicy().hasHeightForWidth());
        pushButtonJumpToMarkerB->setSizePolicy(sizePolicy10);

        gridLayout->addWidget(pushButtonJumpToMarkerB, 1, 1, 1, 1);

        selectionDuration = new QLabel(dockWidgetContents_7);
        selectionDuration->setObjectName(QString::fromUtf8("selectionDuration"));
        sizePolicy10.setHeightForWidth(selectionDuration->sizePolicy().hasHeightForWidth());
        selectionDuration->setSizePolicy(sizePolicy10);
        selectionDuration->setMinimumSize(QSize(160, 0));

        gridLayout->addWidget(selectionDuration, 2, 0, 1, 2);


        verticalLayout_6->addLayout(gridLayout);


        verticalLayout_7->addLayout(verticalLayout_6);

        selectionWidget->setWidget(dockWidgetContents_7);
        MainWindow->addDockWidget(Qt::BottomDockWidgetArea, selectionWidget);
        volumeWidget = new QDockWidget(MainWindow);
        volumeWidget->setObjectName(QString::fromUtf8("volumeWidget"));
        sizePolicy1.setHeightForWidth(volumeWidget->sizePolicy().hasHeightForWidth());
        volumeWidget->setSizePolicy(sizePolicy1);
        volumeWidget->setMinimumSize(QSize(42, 120));
        volumeWidget->setMaximumSize(QSize(42, 120));
        volumeWidget->setFeatures(QDockWidget::NoDockWidgetFeatures);
        volumeWidget->setAllowedAreas(Qt::BottomDockWidgetArea);
        dockWidgetContents_5 = new QWidget();
        dockWidgetContents_5->setObjectName(QString::fromUtf8("dockWidgetContents_5"));
        verticalLayout_4 = new QVBoxLayout(dockWidgetContents_5);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        volumeWidgetHorizLayout_1 = new QHBoxLayout();
        volumeWidgetHorizLayout_1->setObjectName(QString::fromUtf8("volumeWidgetHorizLayout_1"));
        toolButtonAudioToggle = new QToolButton(dockWidgetContents_5);
        toolButtonAudioToggle->setObjectName(QString::fromUtf8("toolButtonAudioToggle"));
        toolButtonAudioToggle->setEnabled(true);
        sizePolicy1.setHeightForWidth(toolButtonAudioToggle->sizePolicy().hasHeightForWidth());
        toolButtonAudioToggle->setSizePolicy(sizePolicy1);
        toolButtonAudioToggle->setMinimumSize(QSize(22, 22));
        toolButtonAudioToggle->setMaximumSize(QSize(22, 22));
        QIcon icon27;
        icon27.addFile(QString::fromUtf8(":/new/prefix1/pics/volume_off.png"), QSize(), QIcon::Normal, QIcon::Off);
        icon27.addFile(QString::fromUtf8(":/new/prefix1/pics/volume.png"), QSize(), QIcon::Normal, QIcon::On);
        toolButtonAudioToggle->setIcon(icon27);
        toolButtonAudioToggle->setCheckable(true);
        toolButtonAudioToggle->setChecked(true);

        volumeWidgetHorizLayout_1->addWidget(toolButtonAudioToggle);


        verticalLayout_4->addLayout(volumeWidgetHorizLayout_1);

        volumeWidgetHorizLayout_2 = new QHBoxLayout();
        volumeWidgetHorizLayout_2->setObjectName(QString::fromUtf8("volumeWidgetHorizLayout_2"));
        horizontalSlider_2 = new QSlider(dockWidgetContents_5);
        horizontalSlider_2->setObjectName(QString::fromUtf8("horizontalSlider_2"));
        QSizePolicy sizePolicy11(QSizePolicy::Fixed, QSizePolicy::Minimum);
        sizePolicy11.setHorizontalStretch(0);
        sizePolicy11.setVerticalStretch(0);
        sizePolicy11.setHeightForWidth(horizontalSlider_2->sizePolicy().hasHeightForWidth());
        horizontalSlider_2->setSizePolicy(sizePolicy11);
        horizontalSlider_2->setMinimumSize(QSize(22, 50));
        horizontalSlider_2->setMaximumSize(QSize(22, 16777215));
        horizontalSlider_2->setMaximum(100);
        horizontalSlider_2->setValue(100);
        horizontalSlider_2->setOrientation(Qt::Vertical);

        volumeWidgetHorizLayout_2->addWidget(horizontalSlider_2);


        verticalLayout_4->addLayout(volumeWidgetHorizLayout_2);

        volumeWidget->setWidget(dockWidgetContents_5);
        MainWindow->addDockWidget(Qt::BottomDockWidgetArea, volumeWidget);
        audioMetreWidget = new QDockWidget(MainWindow);
        audioMetreWidget->setObjectName(QString::fromUtf8("audioMetreWidget"));
        sizePolicy1.setHeightForWidth(audioMetreWidget->sizePolicy().hasHeightForWidth());
        audioMetreWidget->setSizePolicy(sizePolicy1);
        audioMetreWidget->setMinimumSize(QSize(82, 120));
        audioMetreWidget->setMaximumSize(QSize(82, 120));
        audioMetreWidget->setFeatures(QDockWidget::NoDockWidgetFeatures);
        audioMetreWidget->setAllowedAreas(Qt::BottomDockWidgetArea);
        dockWidgetContents_3 = new QWidget();
        dockWidgetContents_3->setObjectName(QString::fromUtf8("dockWidgetContents_3"));
        sizePolicy9.setHeightForWidth(dockWidgetContents_3->sizePolicy().hasHeightForWidth());
        dockWidgetContents_3->setSizePolicy(sizePolicy9);
        verticalLayout_5 = new QVBoxLayout(dockWidgetContents_3);
        verticalLayout_5->setSpacing(9);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        frameVU = new QFrame(dockWidgetContents_3);
        frameVU->setObjectName(QString::fromUtf8("frameVU"));
        sizePolicy1.setHeightForWidth(frameVU->sizePolicy().hasHeightForWidth());
        frameVU->setSizePolicy(sizePolicy1);
        frameVU->setMinimumSize(QSize(64, 88));
        frameVU->setMaximumSize(QSize(64, 16777215));

        verticalLayout_5->addWidget(frameVU);

        audioMetreWidget->setWidget(dockWidgetContents_3);
        MainWindow->addDockWidget(Qt::BottomDockWidgetArea, audioMetreWidget);
        QWidget::setTabOrder(pushButtonDecoderConf, comboBoxVideo);
        QWidget::setTabOrder(comboBoxVideo, pushButtonVideoConf);
        QWidget::setTabOrder(pushButtonVideoConf, pushButtonVideoFilter);
        QWidget::setTabOrder(pushButtonVideoFilter, comboBoxAudio);
        QWidget::setTabOrder(comboBoxAudio, pushButtonAudioConf);
        QWidget::setTabOrder(pushButtonAudioConf, pushButtonAudioFilter);
        QWidget::setTabOrder(pushButtonAudioFilter, checkBox_TimeShift);
        QWidget::setTabOrder(checkBox_TimeShift, spinBox_TimeValue);
        QWidget::setTabOrder(spinBox_TimeValue, comboBoxFormat);
        QWidget::setTabOrder(comboBoxFormat, pushButtonFormatConfigure);
        QWidget::setTabOrder(pushButtonFormatConfigure, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, toolButtonPlay);
        QWidget::setTabOrder(toolButtonPlay, toolButtonPreviousFrame);
        QWidget::setTabOrder(toolButtonPreviousFrame, toolButtonNextFrame);
        QWidget::setTabOrder(toolButtonNextFrame, toolButtonPreviousIntraFrame);
        QWidget::setTabOrder(toolButtonPreviousIntraFrame, toolButtonNextIntraFrame);
        QWidget::setTabOrder(toolButtonNextIntraFrame, toolButtonSetMarkerA);
        QWidget::setTabOrder(toolButtonSetMarkerA, toolButtonDeleteSelection);
        QWidget::setTabOrder(toolButtonDeleteSelection, toolButtonSetMarkerB);
        QWidget::setTabOrder(toolButtonSetMarkerB, toolButtonPreviousCutPoint);
        QWidget::setTabOrder(toolButtonPreviousCutPoint, toolButtonNextCutPoint);
        QWidget::setTabOrder(toolButtonNextCutPoint, toolButtonPreviousBlackFrame);
        QWidget::setTabOrder(toolButtonPreviousBlackFrame, toolButtonNextBlackFrame);
        QWidget::setTabOrder(toolButtonNextBlackFrame, toolButtonFirstFrame);
        QWidget::setTabOrder(toolButtonFirstFrame, toolButtonLastFrame);
        QWidget::setTabOrder(toolButtonLastFrame, pushButtonTime);
        QWidget::setTabOrder(pushButtonTime, currentTime);
        QWidget::setTabOrder(currentTime, pushButtonJumpToMarkerA);
        QWidget::setTabOrder(pushButtonJumpToMarkerA, pushButtonJumpToMarkerB);
        QWidget::setTabOrder(pushButtonJumpToMarkerB, toolButtonAudioToggle);
        QWidget::setTabOrder(toolButtonAudioToggle, horizontalSlider_2);

        menubar->addAction(menuFile->menuAction());
        menubar->addAction(menuRecent->menuAction());
        menubar->addAction(menuEdit->menuAction());
        menubar->addAction(menuView->menuAction());
        menubar->addAction(menuVideo->menuAction());
        menubar->addAction(menuAudio->menuAction());
        menubar->addAction(menuAuto->menuAction());
        menubar->addAction(menuTools->menuAction());
        menubar->addAction(menuGo->menuAction());
        menubar->addAction(menuCustom->menuAction());
        menubar->addAction(menuHelp->menuAction());
        menuView->addAction(menuToolbars->menuAction());
        menuView->addAction(menuThemes->menuAction());
        menuToolbars->addAction(actionViewAudioMetre);
        menuToolbars->addAction(actionViewCodecOptions);
        menuToolbars->addAction(actionViewNavigation);
        menuToolbars->addAction(actionViewSelection);
        menuToolbars->addAction(actionViewVolume);
        menuToolbars->addAction(actionViewToolBar);
        toolBar->addSeparator();
        toolBar->addAction(actionOpen);
        toolBar->addAction(actionSave_video);
        toolBar->addAction(actionProperties);
        toolBar->addSeparator();
        toolBar->addAction(actionPlayFiltered);
        toolBar->addAction(actionHDRSettings);

        retranslateUi(MainWindow);
        QObject::connect(actionViewAudioMetre, SIGNAL(toggled(bool)), audioMetreWidget, SLOT(setVisible(bool)));
        QObject::connect(actionViewCodecOptions, SIGNAL(toggled(bool)), codecWidget, SLOT(setVisible(bool)));
        QObject::connect(actionViewNavigation, SIGNAL(toggled(bool)), navigationWidget, SLOT(setVisible(bool)));
        QObject::connect(actionViewSelection, SIGNAL(toggled(bool)), selectionWidget, SLOT(setVisible(bool)));
        QObject::connect(actionViewVolume, SIGNAL(toggled(bool)), volumeWidget, SLOT(setVisible(bool)));
        QObject::connect(actionViewToolBar, SIGNAL(toggled(bool)), toolBar, SLOT(setVisible(bool)));

        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QCoreApplication::translate("MainWindow", "Avidemux", nullptr));
        actionOpen->setText(QCoreApplication::translate("MainWindow", "&Open...", nullptr));
#if QT_CONFIG(tooltip)
        actionOpen->setToolTip(QCoreApplication::translate("MainWindow", "Open Video", nullptr));
#endif // QT_CONFIG(tooltip)
        actionProperties->setText(QCoreApplication::translate("MainWindow", "&Information...", nullptr));
        actionSave_video->setText(QCoreApplication::translate("MainWindow", "Save &Video...", nullptr));
        actionSave_video->setIconText(QCoreApplication::translate("MainWindow", "Save Video", nullptr));
#if QT_CONFIG(tooltip)
        actionSave_video->setToolTip(QCoreApplication::translate("MainWindow", "Save Video", nullptr));
#endif // QT_CONFIG(tooltip)
        actionPlayFiltered->setText(QCoreApplication::translate("MainWindow", "Play filtered", nullptr));
        actionHDRSettings->setText(QCoreApplication::translate("MainWindow", "HDR tone mapping", nullptr));
        actionLoad_run_project->setText(QCoreApplication::translate("MainWindow", "&Load/Run Project...", nullptr));
        actionLoad_run_project->setIconText(QCoreApplication::translate("MainWindow", "Load/Run Project", nullptr));
#if QT_CONFIG(tooltip)
        actionLoad_run_project->setToolTip(QCoreApplication::translate("MainWindow", "Load/Run Project", nullptr));
#endif // QT_CONFIG(tooltip)
        actionSave_project->setText(QCoreApplication::translate("MainWindow", "Save &Project", nullptr));
        actionSave_project->setIconText(QCoreApplication::translate("MainWindow", "Save Project", nullptr));
#if QT_CONFIG(tooltip)
        actionSave_project->setToolTip(QCoreApplication::translate("MainWindow", "Save Project", nullptr));
#endif // QT_CONFIG(tooltip)
        actionPreviewInput->setText(QCoreApplication::translate("MainWindow", "&Input", nullptr));
        actionPreviewOutput->setText(QCoreApplication::translate("MainWindow", "&Output", nullptr));
        actionViewCodecOptions->setText(QCoreApplication::translate("MainWindow", "&Codec Options", nullptr));
#if QT_CONFIG(shortcut)
        actionViewCodecOptions->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+C", nullptr));
#endif // QT_CONFIG(shortcut)
        actionViewNavigation->setText(QCoreApplication::translate("MainWindow", "&Navigation", nullptr));
#if QT_CONFIG(shortcut)
        actionViewNavigation->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+N", nullptr));
#endif // QT_CONFIG(shortcut)
        actionViewSelection->setText(QCoreApplication::translate("MainWindow", "&Selection", nullptr));
#if QT_CONFIG(shortcut)
        actionViewSelection->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionViewVolume->setText(QCoreApplication::translate("MainWindow", "&Volume", nullptr));
#if QT_CONFIG(shortcut)
        actionViewVolume->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+V", nullptr));
#endif // QT_CONFIG(shortcut)
        actionViewToolBar->setText(QCoreApplication::translate("MainWindow", "&Toolbar", nullptr));
#if QT_CONFIG(shortcut)
        actionViewToolBar->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+B", nullptr));
#endif // QT_CONFIG(shortcut)
        actionViewAudioMetre->setText(QCoreApplication::translate("MainWindow", "&Audio Metre", nullptr));
#if QT_CONFIG(shortcut)
        actionViewAudioMetre->setShortcut(QCoreApplication::translate("MainWindow", "Ctrl+Alt+M", nullptr));
#endif // QT_CONFIG(shortcut)
        actionPreviewSeparate->setText(QCoreApplication::translate("MainWindow", "&Separate", nullptr));
        actionPreviewTop->setText(QCoreApplication::translate("MainWindow", "&Top", nullptr));
        actionPreviewSide->setText(QCoreApplication::translate("MainWindow", "Si&de", nullptr));
        menuHelp->setTitle(QCoreApplication::translate("MainWindow", "&Help", nullptr));
        menuVideo->setTitle(QCoreApplication::translate("MainWindow", "Vi&deo", nullptr));
        menuEdit->setTitle(QCoreApplication::translate("MainWindow", "&Edit", nullptr));
        menuView->setTitle(QCoreApplication::translate("MainWindow", "&View", nullptr));
        menuToolbars->setTitle(QCoreApplication::translate("MainWindow", "&Toolbars", nullptr));
        menuThemes->setTitle(QCoreApplication::translate("MainWindow", "T&heme", nullptr));
        menuAuto->setTitle(QCoreApplication::translate("MainWindow", "&Auto", nullptr));
        menuCustom->setTitle(QCoreApplication::translate("MainWindow", "&Custom", nullptr));
        menuGo->setTitle(QCoreApplication::translate("MainWindow", "&Go", nullptr));
        menuTools->setTitle(QCoreApplication::translate("MainWindow", "&Tools", nullptr));
        menuAudio->setTitle(QCoreApplication::translate("MainWindow", "&Audio", nullptr));
        menuFile->setTitle(QCoreApplication::translate("MainWindow", "&File", nullptr));
        menuRecent->setTitle(QCoreApplication::translate("MainWindow", "&Recent", nullptr));
        codecWidget->setWindowTitle(QCoreApplication::translate("MainWindow", "Codec O&ptions", nullptr));
        label_7->setText(QCoreApplication::translate("MainWindow", "<b>Video Decoder</b>", nullptr));
        labelVideoDecoder->setText(QCoreApplication::translate("MainWindow", "XXXX", nullptr));
        labelDisplay->setText(QCoreApplication::translate("MainWindow", "XXXX", nullptr));
        pushButtonDecoderConf->setText(QCoreApplication::translate("MainWindow", "Configure", nullptr));
        label_3->setText(QCoreApplication::translate("MainWindow", "<b>Video Output</b>", nullptr));
        comboBoxVideo->setItemText(0, QCoreApplication::translate("MainWindow", "Copy", nullptr));

        pushButtonVideoConf->setText(QCoreApplication::translate("MainWindow", "Configure", nullptr));
        pushButtonVideoFilter->setText(QCoreApplication::translate("MainWindow", "Filters", nullptr));
        label_5->setText(QCoreApplication::translate("MainWindow", "<b>Audio Output</b>", nullptr));
        TrackCountLabel->setText(QCoreApplication::translate("MainWindow", " (0 tracks)", nullptr));
        comboBoxAudio->setItemText(0, QCoreApplication::translate("MainWindow", "Copy", nullptr));

        pushButtonAudioConf->setText(QCoreApplication::translate("MainWindow", "Configure", nullptr));
        pushButtonAudioFilter->setText(QCoreApplication::translate("MainWindow", "Filters", nullptr));
        checkBox_TimeShift->setText(QCoreApplication::translate("MainWindow", "&Shift:", nullptr));
        label_11->setText(QCoreApplication::translate("MainWindow", "ms", nullptr));
        label_4->setText(QCoreApplication::translate("MainWindow", "<b>Output Format</b>", nullptr));
        pushButtonFormatConfigure->setText(QCoreApplication::translate("MainWindow", "Configure", nullptr));
        navigationWidget->setWindowTitle(QCoreApplication::translate("MainWindow", "&Navigation", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonPlay->setToolTip(QCoreApplication::translate("MainWindow", "Play [SPACE]", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        toolButtonPlay->setStatusTip(QCoreApplication::translate("MainWindow", "Play", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        toolButtonPlay->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        toolButtonPlay->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonPreviousFrame->setToolTip(QCoreApplication::translate("MainWindow", "Go to previous frame [LEFT]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonPreviousFrame->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonNextFrame->setToolTip(QCoreApplication::translate("MainWindow", "Go to next frame [RIGHT]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonNextFrame->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonPreviousIntraFrame->setToolTip(QCoreApplication::translate("MainWindow", "Go to previous keyframe [DOWN]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonPreviousIntraFrame->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonNextIntraFrame->setToolTip(QCoreApplication::translate("MainWindow", "Go to next keyframe [UP]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonNextIntraFrame->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonSetMarkerA->setToolTip(QCoreApplication::translate("MainWindow", "Set start marker [CTRL+PAGEUP]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonSetMarkerA->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonDeleteSelection->setToolTip(QCoreApplication::translate("MainWindow", "Delete selection [DEL]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonDeleteSelection->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonSetMarkerB->setToolTip(QCoreApplication::translate("MainWindow", "Set end marker [CTRL+PAGEDOWN]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonSetMarkerB->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonPreviousCutPoint->setToolTip(QCoreApplication::translate("MainWindow", "Go to previous cut point [SHIFT+DOWN]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonPreviousCutPoint->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonNextCutPoint->setToolTip(QCoreApplication::translate("MainWindow", "Go to next cut point [SHIFT+UP]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonNextCutPoint->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonPreviousBlackFrame->setToolTip(QCoreApplication::translate("MainWindow", "Search previous black frame", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonPreviousBlackFrame->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonNextBlackFrame->setToolTip(QCoreApplication::translate("MainWindow", "Search next black frame", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonNextBlackFrame->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonFirstFrame->setToolTip(QCoreApplication::translate("MainWindow", "Go to first frame [HOME]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonFirstFrame->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonLastFrame->setToolTip(QCoreApplication::translate("MainWindow", "Go to last frame [END]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonLastFrame->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonBackOneMinute->setToolTip(QCoreApplication::translate("MainWindow", "Backward one minute [CTRL+DOWN]", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonBackOneMinute->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonForwardOneMinute->setToolTip(QCoreApplication::translate("MainWindow", "Forward one minute [CTRL+UP]", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(accessibility)
        toolButtonForwardOneMinute->setAccessibleDescription(QCoreApplication::translate("MainWindow", "Forward one minute", nullptr));
#endif // QT_CONFIG(accessibility)
        toolButtonForwardOneMinute->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
        pushButtonTime->setText(QCoreApplication::translate("MainWindow", "Time:", nullptr));
        currentTime->setText(QCoreApplication::translate("MainWindow", "00:00:00.000", nullptr));
        totalTime->setText(QCoreApplication::translate("MainWindow", "/ 00:00:00.000", nullptr));
        label_10->setText(QCoreApplication::translate("MainWindow", "Frame type:", nullptr));
        label_8->setText(QCoreApplication::translate("MainWindow", "?", nullptr));
        selectionWidget->setWindowTitle(QCoreApplication::translate("MainWindow", "Se&lection", nullptr));
        label_2->setText(QCoreApplication::translate("MainWindow", "A:", nullptr));
        label_9->setText(QCoreApplication::translate("MainWindow", "B:", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonJumpToMarkerA->setToolTip(QCoreApplication::translate("MainWindow", "Go to marker A [PAGE UP]", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonJumpToMarkerA->setText(QCoreApplication::translate("MainWindow", "000000", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonJumpToMarkerB->setToolTip(QCoreApplication::translate("MainWindow", "Go to Marker B [PAGE DOWN]", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonJumpToMarkerB->setText(QCoreApplication::translate("MainWindow", "000000", nullptr));
        selectionDuration->setText(QCoreApplication::translate("MainWindow", "Selection: 000000", nullptr));
        volumeWidget->setWindowTitle(QCoreApplication::translate("MainWindow", "Vol&ume", nullptr));
        toolButtonAudioToggle->setText(QCoreApplication::translate("MainWindow", "...", nullptr));
        audioMetreWidget->setWindowTitle(QCoreApplication::translate("MainWindow", "Audio &Metre", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_GUI2_H
