/********************************************************************************
** Form generated from reading UI file 'quadTrans.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUADTRANS_H
#define UI_QUADTRANS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_quadTransDialog
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *toolboxLayout;
    QDialogButtonBox *buttonBox;
    QGridLayout *gridLayout_3;
    QDoubleSpinBox *doubleSpinBoxZoom;
    QComboBox *comboBoxAlgo;
    QSpacerItem *horizontalSpacer_3;
    QLabel *labelInterpolation;
    QLabel *labelZoom;
    ADM_flyNavSlider *horizontalSlider;
    QSpacerItem *spacerItem;
    QGridLayout *gridLayout1;
    QLabel *label_3;
    QDoubleSpinBox *doubleSpinBoxDy2;
    QGraphicsView *graphicsView;
    QLabel *label_4;
    QLabel *label_5;
    QLabel *label_2;
    QDoubleSpinBox *doubleSpinBoxDx1;
    QDoubleSpinBox *doubleSpinBoxDx2;
    QDoubleSpinBox *doubleSpinBoxDy1;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_6;
    QDoubleSpinBox *doubleSpinBoxDx3;
    QLabel *label_7;
    QDoubleSpinBox *doubleSpinBoxDy3;
    QLabel *label_8;
    QDoubleSpinBox *doubleSpinBoxDx4;
    QLabel *label_9;
    QDoubleSpinBox *doubleSpinBoxDy4;

    void setupUi(QDialog *quadTransDialog)
    {
        if (quadTransDialog->objectName().isEmpty())
            quadTransDialog->setObjectName(QString::fromUtf8("quadTransDialog"));
        quadTransDialog->resize(579, 379);
        gridLayout = new QGridLayout(quadTransDialog);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(9, 9, 9, 9);
        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        gridLayout->addLayout(toolboxLayout, 2, 0, 1, 2);

        buttonBox = new QDialogButtonBox(quadTransDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        gridLayout->addWidget(buttonBox, 7, 0, 1, 2);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        doubleSpinBoxZoom = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxZoom->setObjectName(QString::fromUtf8("doubleSpinBoxZoom"));
        doubleSpinBoxZoom->setDecimals(2);
        doubleSpinBoxZoom->setMinimum(0.100000000000000);
        doubleSpinBoxZoom->setMaximum(10.000000000000000);
        doubleSpinBoxZoom->setSingleStep(0.010000000000000);

        gridLayout_3->addWidget(doubleSpinBoxZoom, 0, 3, 1, 1);

        comboBoxAlgo = new QComboBox(quadTransDialog);
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->setObjectName(QString::fromUtf8("comboBoxAlgo"));

        gridLayout_3->addWidget(comboBoxAlgo, 0, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_3, 0, 4, 1, 1);

        labelInterpolation = new QLabel(quadTransDialog);
        labelInterpolation->setObjectName(QString::fromUtf8("labelInterpolation"));

        gridLayout_3->addWidget(labelInterpolation, 0, 0, 1, 1);

        labelZoom = new QLabel(quadTransDialog);
        labelZoom->setObjectName(QString::fromUtf8("labelZoom"));

        gridLayout_3->addWidget(labelZoom, 0, 2, 1, 1);


        gridLayout->addLayout(gridLayout_3, 0, 0, 2, 2);

        horizontalSlider = new ADM_flyNavSlider(quadTransDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSlider, 3, 0, 1, 2);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(spacerItem, 6, 1, 1, 1);

        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        label_3 = new QLabel(quadTransDialog);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout1->addWidget(label_3, 0, 2, 1, 1);

        doubleSpinBoxDy2 = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxDy2->setObjectName(QString::fromUtf8("doubleSpinBoxDy2"));
        doubleSpinBoxDy2->setMinimum(-9999.000000000000000);
        doubleSpinBoxDy2->setMaximum(9999.000000000000000);

        gridLayout1->addWidget(doubleSpinBoxDy2, 0, 8, 1, 1);

        graphicsView = new QGraphicsView(quadTransDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));

        gridLayout1->addWidget(graphicsView, 2, 0, 1, 9);

        label_4 = new QLabel(quadTransDialog);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout1->addWidget(label_4, 0, 5, 1, 1);

        label_5 = new QLabel(quadTransDialog);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout1->addWidget(label_5, 0, 7, 1, 1);

        label_2 = new QLabel(quadTransDialog);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout1->addWidget(label_2, 0, 0, 1, 1);

        doubleSpinBoxDx1 = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxDx1->setObjectName(QString::fromUtf8("doubleSpinBoxDx1"));
        doubleSpinBoxDx1->setMinimum(-9999.000000000000000);
        doubleSpinBoxDx1->setMaximum(9999.000000000000000);

        gridLayout1->addWidget(doubleSpinBoxDx1, 0, 1, 1, 1);

        doubleSpinBoxDx2 = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxDx2->setObjectName(QString::fromUtf8("doubleSpinBoxDx2"));
        doubleSpinBoxDx2->setMinimum(-9999.000000000000000);
        doubleSpinBoxDx2->setMaximum(9999.000000000000000);

        gridLayout1->addWidget(doubleSpinBoxDx2, 0, 6, 1, 1);

        doubleSpinBoxDy1 = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxDy1->setObjectName(QString::fromUtf8("doubleSpinBoxDy1"));
        doubleSpinBoxDy1->setMinimum(-9999.000000000000000);
        doubleSpinBoxDy1->setMaximum(9999.000000000000000);

        gridLayout1->addWidget(doubleSpinBoxDy1, 0, 3, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(horizontalSpacer_4, 0, 4, 1, 1);

        label_6 = new QLabel(quadTransDialog);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout1->addWidget(label_6, 3, 0, 1, 1);

        doubleSpinBoxDx3 = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxDx3->setObjectName(QString::fromUtf8("doubleSpinBoxDx3"));
        doubleSpinBoxDx3->setMinimum(-9999.000000000000000);
        doubleSpinBoxDx3->setMaximum(9999.000000000000000);

        gridLayout1->addWidget(doubleSpinBoxDx3, 3, 1, 1, 1);

        label_7 = new QLabel(quadTransDialog);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout1->addWidget(label_7, 3, 2, 1, 1);

        doubleSpinBoxDy3 = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxDy3->setObjectName(QString::fromUtf8("doubleSpinBoxDy3"));
        doubleSpinBoxDy3->setMinimum(-9999.000000000000000);
        doubleSpinBoxDy3->setMaximum(9999.000000000000000);

        gridLayout1->addWidget(doubleSpinBoxDy3, 3, 3, 1, 1);

        label_8 = new QLabel(quadTransDialog);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout1->addWidget(label_8, 3, 5, 1, 1);

        doubleSpinBoxDx4 = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxDx4->setObjectName(QString::fromUtf8("doubleSpinBoxDx4"));
        doubleSpinBoxDx4->setMinimum(-9999.000000000000000);
        doubleSpinBoxDx4->setMaximum(9999.000000000000000);

        gridLayout1->addWidget(doubleSpinBoxDx4, 3, 6, 1, 1);

        label_9 = new QLabel(quadTransDialog);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout1->addWidget(label_9, 3, 7, 1, 1);

        doubleSpinBoxDy4 = new QDoubleSpinBox(quadTransDialog);
        doubleSpinBoxDy4->setObjectName(QString::fromUtf8("doubleSpinBoxDy4"));
        doubleSpinBoxDy4->setMinimum(-9999.000000000000000);
        doubleSpinBoxDy4->setMaximum(9999.000000000000000);

        gridLayout1->addWidget(doubleSpinBoxDy4, 3, 8, 1, 1);


        gridLayout->addLayout(gridLayout1, 4, 0, 1, 2);


        retranslateUi(quadTransDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), quadTransDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), quadTransDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(quadTransDialog);
    } // setupUi

    void retranslateUi(QDialog *quadTransDialog)
    {
        quadTransDialog->setWindowTitle(QCoreApplication::translate("quadTransDialog", "Quadrilateral transformation", nullptr));
        comboBoxAlgo->setItemText(0, QCoreApplication::translate("quadTransDialog", "Bilinear", nullptr));
        comboBoxAlgo->setItemText(1, QCoreApplication::translate("quadTransDialog", "Bicubic", nullptr));

        labelInterpolation->setText(QCoreApplication::translate("quadTransDialog", "Interpolation:", nullptr));
        labelZoom->setText(QCoreApplication::translate("quadTransDialog", "Zoom:", nullptr));
        label_3->setText(QCoreApplication::translate("quadTransDialog", "\316\224y:", nullptr));
        label_4->setText(QCoreApplication::translate("quadTransDialog", "\316\224x:", nullptr));
        label_5->setText(QCoreApplication::translate("quadTransDialog", "\316\224y:", nullptr));
        label_2->setText(QCoreApplication::translate("quadTransDialog", "\316\224x:", nullptr));
        label_6->setText(QCoreApplication::translate("quadTransDialog", "\316\224x:", nullptr));
        label_7->setText(QCoreApplication::translate("quadTransDialog", "\316\224y:", nullptr));
        label_8->setText(QCoreApplication::translate("quadTransDialog", "\316\224x:", nullptr));
        label_9->setText(QCoreApplication::translate("quadTransDialog", "\316\224y:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class quadTransDialog: public Ui_quadTransDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QUADTRANS_H
