/********************************************************************************
** Form generated from reading UI file 'contrast.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONTRAST_H
#define UI_CONTRAST_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDial>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_contrastDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayoutContrast;
    QLabel *labelContrast;
    QSpacerItem *verticalSpacerContrast;
    QDial *dialContrast;
    QVBoxLayout *verticalLayoutBrightness;
    QLabel *labelBrightness;
    QSpacerItem *verticalSpacerBrightness;
    QDial *dialBrightness;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QCheckBox *checkBoxV;
    QCheckBox *checkBoxU;
    QCheckBox *checkBoxY;
    QToolButton *toolButton__DVD2PC;
    QSpacerItem *horizontalSpacer;
    QGraphicsView *graphicsViewHistogram;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *contrastDialog)
    {
        if (contrastDialog->objectName().isEmpty())
            contrastDialog->setObjectName(QString::fromUtf8("contrastDialog"));
        contrastDialog->resize(721, 494);
        verticalLayout_2 = new QVBoxLayout(contrastDialog);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        verticalLayoutContrast = new QVBoxLayout();
        verticalLayoutContrast->setObjectName(QString::fromUtf8("verticalLayoutContrast"));
        labelContrast = new QLabel(contrastDialog);
        labelContrast->setObjectName(QString::fromUtf8("labelContrast"));

        verticalLayoutContrast->addWidget(labelContrast);

        verticalSpacerContrast = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayoutContrast->addItem(verticalSpacerContrast);

        dialContrast = new QDial(contrastDialog);
        dialContrast->setObjectName(QString::fromUtf8("dialContrast"));
        dialContrast->setMinimum(50);
        dialContrast->setMaximum(150);
        dialContrast->setSingleStep(1);
        dialContrast->setValue(50);
        dialContrast->setOrientation(Qt::Vertical);
        dialContrast->setNotchTarget(2.000000000000000);
        dialContrast->setNotchesVisible(true);

        verticalLayoutContrast->addWidget(dialContrast);


        horizontalLayout->addLayout(verticalLayoutContrast);

        verticalLayoutBrightness = new QVBoxLayout();
        verticalLayoutBrightness->setObjectName(QString::fromUtf8("verticalLayoutBrightness"));
        labelBrightness = new QLabel(contrastDialog);
        labelBrightness->setObjectName(QString::fromUtf8("labelBrightness"));

        verticalLayoutBrightness->addWidget(labelBrightness);

        verticalSpacerBrightness = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayoutBrightness->addItem(verticalSpacerBrightness);

        dialBrightness = new QDial(contrastDialog);
        dialBrightness->setObjectName(QString::fromUtf8("dialBrightness"));
        dialBrightness->setMinimum(-127);
        dialBrightness->setMaximum(127);
        dialBrightness->setNotchesVisible(true);

        verticalLayoutBrightness->addWidget(dialBrightness);


        horizontalLayout->addLayout(verticalLayoutBrightness);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        checkBoxV = new QCheckBox(contrastDialog);
        checkBoxV->setObjectName(QString::fromUtf8("checkBoxV"));

        gridLayout->addWidget(checkBoxV, 3, 0, 1, 1);

        checkBoxU = new QCheckBox(contrastDialog);
        checkBoxU->setObjectName(QString::fromUtf8("checkBoxU"));

        gridLayout->addWidget(checkBoxU, 2, 0, 1, 1);

        checkBoxY = new QCheckBox(contrastDialog);
        checkBoxY->setObjectName(QString::fromUtf8("checkBoxY"));

        gridLayout->addWidget(checkBoxY, 1, 0, 1, 1);

        toolButton__DVD2PC = new QToolButton(contrastDialog);
        toolButton__DVD2PC->setObjectName(QString::fromUtf8("toolButton__DVD2PC"));

        gridLayout->addWidget(toolButton__DVD2PC, 0, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);


        horizontalLayout->addLayout(verticalLayout);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        graphicsViewHistogram = new QGraphicsView(contrastDialog);
        graphicsViewHistogram->setObjectName(QString::fromUtf8("graphicsViewHistogram"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(graphicsViewHistogram->sizePolicy().hasHeightForWidth());
        graphicsViewHistogram->setSizePolicy(sizePolicy);
        graphicsViewHistogram->setMinimumSize(QSize(256, 128));
        graphicsViewHistogram->setMaximumSize(QSize(256, 128));
        graphicsViewHistogram->setFocusPolicy(Qt::NoFocus);
        graphicsViewHistogram->setProperty("sizeHint", QVariant(QSize(256, 192)));
        graphicsViewHistogram->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewHistogram->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        horizontalLayout->addWidget(graphicsViewHistogram);


        verticalLayout_2->addLayout(horizontalLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout_2->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(contrastDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout_2->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(contrastDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(graphicsView->sizePolicy().hasHeightForWidth());
        graphicsView->setSizePolicy(sizePolicy1);
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout_2->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(contrastDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(contrastDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), contrastDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), contrastDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(contrastDialog);
    } // setupUi

    void retranslateUi(QDialog *contrastDialog)
    {
        contrastDialog->setWindowTitle(QCoreApplication::translate("contrastDialog", "Contrast", nullptr));
        labelContrast->setText(QCoreApplication::translate("contrastDialog", "Contrast  ", nullptr));
#if QT_CONFIG(tooltip)
        dialContrast->setToolTip(QCoreApplication::translate("contrastDialog", "Contrast", nullptr));
#endif // QT_CONFIG(tooltip)
        labelBrightness->setText(QCoreApplication::translate("contrastDialog", "Brightness  ", nullptr));
#if QT_CONFIG(tooltip)
        dialBrightness->setToolTip(QCoreApplication::translate("contrastDialog", "Brightness", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxV->setText(QCoreApplication::translate("contrastDialog", "ChromaV", nullptr));
        checkBoxU->setText(QCoreApplication::translate("contrastDialog", "ChromaU", nullptr));
        checkBoxY->setText(QCoreApplication::translate("contrastDialog", "Luma", nullptr));
        toolButton__DVD2PC->setText(QCoreApplication::translate("contrastDialog", "MPEG2->PC", nullptr));
    } // retranslateUi

};

namespace Ui {
    class contrastDialog: public Ui_contrastDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONTRAST_H
