/********************************************************************************
** Form generated from reading UI file 'working.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WORKING_H
#define UI_WORKING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>

QT_BEGIN_NAMESPACE

class Ui_workingDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *label_2;
    QProgressBar *progressBar;
    QLabel *label_1;
    QLabel *labelElapsed;
    QSpacerItem *verticalSpacer_2;
    QLabel *labelTimeLeft;
    QDialogButtonBox *buttonBox;
    QSpacerItem *verticalSpacer_1;

    void setupUi(QDialog *workingDialog)
    {
        if (workingDialog->objectName().isEmpty())
            workingDialog->setObjectName(QString::fromUtf8("workingDialog"));
        workingDialog->resize(300, 166);
        gridLayout = new QGridLayout(workingDialog);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_2 = new QLabel(workingDialog);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        progressBar = new QProgressBar(workingDialog);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(progressBar, 3, 0, 1, 2);

        label_1 = new QLabel(workingDialog);
        label_1->setObjectName(QString::fromUtf8("label_1"));

        gridLayout->addWidget(label_1, 1, 0, 1, 1);

        labelElapsed = new QLabel(workingDialog);
        labelElapsed->setObjectName(QString::fromUtf8("labelElapsed"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelElapsed->sizePolicy().hasHeightForWidth());
        labelElapsed->setSizePolicy(sizePolicy);

        gridLayout->addWidget(labelElapsed, 0, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout->addItem(verticalSpacer_2, 4, 0, 1, 1);

        labelTimeLeft = new QLabel(workingDialog);
        labelTimeLeft->setObjectName(QString::fromUtf8("labelTimeLeft"));
        sizePolicy.setHeightForWidth(labelTimeLeft->sizePolicy().hasHeightForWidth());
        labelTimeLeft->setSizePolicy(sizePolicy);

        gridLayout->addWidget(labelTimeLeft, 1, 1, 1, 1);

        buttonBox = new QDialogButtonBox(workingDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel);

        gridLayout->addWidget(buttonBox, 5, 0, 1, 2);

        verticalSpacer_1 = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        gridLayout->addItem(verticalSpacer_1, 2, 0, 1, 1);


        retranslateUi(workingDialog);

        QMetaObject::connectSlotsByName(workingDialog);
    } // setupUi

    void retranslateUi(QDialog *workingDialog)
    {
        workingDialog->setWindowTitle(QCoreApplication::translate("workingDialog", "Processing", nullptr));
        label_2->setText(QCoreApplication::translate("workingDialog", "Elapsed:", nullptr));
        label_1->setText(QCoreApplication::translate("workingDialog", "Time Remaining:", nullptr));
        labelElapsed->setText(QCoreApplication::translate("workingDialog", "00:00:00", nullptr));
        labelTimeLeft->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class workingDialog: public Ui_workingDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WORKING_H
