/********************************************************************************
** Form generated from reading UI file 'artCartoon.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTCARTOON_H
#define UI_ARTCARTOON_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artCartoonDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelThreshold;
    QSpacerItem *spacerItem;
    ADM_SliderIndicator *horizontalSliderThreshold;
    QLabel *labelScatter;
    ADM_SliderIndicator *horizontalSliderScatter;
    QLabel *labelLevel;
    ADM_SliderIndicator *horizontalSliderColor;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artCartoonDialog)
    {
        if (artCartoonDialog->objectName().isEmpty())
            artCartoonDialog->setObjectName(QString::fromUtf8("artCartoonDialog"));
        artCartoonDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(artCartoonDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        labelThreshold = new QLabel(artCartoonDialog);
        labelThreshold->setObjectName(QString::fromUtf8("labelThreshold"));

        gridLayout->addWidget(labelThreshold, 0, 0, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 0, 2, 1, 1);

        horizontalSliderThreshold = new ADM_SliderIndicator(artCartoonDialog);
        horizontalSliderThreshold->setObjectName(QString::fromUtf8("horizontalSliderThreshold"));
        horizontalSliderThreshold->setMinimum(0);
        horizontalSliderThreshold->setMaximum(100);
        horizontalSliderThreshold->setPageStep(10);
        horizontalSliderThreshold->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderThreshold, 0, 1, 1, 1);

        labelScatter = new QLabel(artCartoonDialog);
        labelScatter->setObjectName(QString::fromUtf8("labelScatter"));

        gridLayout->addWidget(labelScatter, 1, 0, 1, 1);

        horizontalSliderScatter = new ADM_SliderIndicator(artCartoonDialog);
        horizontalSliderScatter->setObjectName(QString::fromUtf8("horizontalSliderScatter"));
        horizontalSliderScatter->setMinimum(1);
        horizontalSliderScatter->setMaximum(16);
        horizontalSliderScatter->setPageStep(1);
        horizontalSliderScatter->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderScatter, 1, 1, 1, 1);

        labelLevel = new QLabel(artCartoonDialog);
        labelLevel->setObjectName(QString::fromUtf8("labelLevel"));

        gridLayout->addWidget(labelLevel, 2, 0, 1, 1);

        horizontalSliderColor = new ADM_SliderIndicator(artCartoonDialog);
        horizontalSliderColor->setObjectName(QString::fromUtf8("horizontalSliderColor"));
        horizontalSliderColor->setMinimum(2);
        horizontalSliderColor->setMaximum(32);
        horizontalSliderColor->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderColor, 2, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artCartoonDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artCartoonDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artCartoonDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(horizontalSliderThreshold, horizontalSliderScatter);
        QWidget::setTabOrder(horizontalSliderScatter, horizontalSliderColor);
        QWidget::setTabOrder(horizontalSliderColor, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, graphicsView);

        retranslateUi(artCartoonDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artCartoonDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artCartoonDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artCartoonDialog);
    } // setupUi

    void retranslateUi(QDialog *artCartoonDialog)
    {
        artCartoonDialog->setWindowTitle(QCoreApplication::translate("artCartoonDialog", "Cartoon", nullptr));
        labelThreshold->setText(QCoreApplication::translate("artCartoonDialog", "Threshold", nullptr));
        labelScatter->setText(QCoreApplication::translate("artCartoonDialog", "Scatter", nullptr));
        labelLevel->setText(QCoreApplication::translate("artCartoonDialog", "Color level", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artCartoonDialog: public Ui_artCartoonDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTCARTOON_H
