/********************************************************************************
** Form generated from reading UI file 'about.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUT_H
#define UI_ABOUT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_aboutDialog
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QSpacerItem *spacerItem;
    QLabel *labelIcon;
    QSpacerItem *spacerItem1;
    QLabel *labelVersion;
    QLabel *labelCategory;
    QLabel *labelCopy;
    QLabel *labelUrl;
    QSpacerItem *spacerItem2;
    QHBoxLayout *hboxLayout;
    QPushButton *licenseButton;
    QSpacerItem *spacerItem3;
    QPushButton *okButton;

    void setupUi(QDialog *aboutDialog)
    {
        if (aboutDialog->objectName().isEmpty())
            aboutDialog->setObjectName(QString::fromUtf8("aboutDialog"));
        aboutDialog->resize(372, 235);
        vboxLayout = new QVBoxLayout(aboutDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setSpacing(6);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Fixed);

        vboxLayout1->addItem(spacerItem);

        labelIcon = new QLabel(aboutDialog);
        labelIcon->setObjectName(QString::fromUtf8("labelIcon"));
        labelIcon->setPixmap(QPixmap(QString::fromUtf8(":/new/prefix1/resources/avidemux_icon.png")));
        labelIcon->setAlignment(Qt::AlignCenter);

        vboxLayout1->addWidget(labelIcon);

        spacerItem1 = new QSpacerItem(20, 5, QSizePolicy::Minimum, QSizePolicy::Fixed);

        vboxLayout1->addItem(spacerItem1);

        labelVersion = new QLabel(aboutDialog);
        labelVersion->setObjectName(QString::fromUtf8("labelVersion"));
        QFont font;
        font.setPointSize(18);
        font.setBold(true);
        font.setItalic(false);
        font.setUnderline(false);
        font.setStrikeOut(false);
        labelVersion->setFont(font);
        labelVersion->setAlignment(Qt::AlignCenter);

        vboxLayout1->addWidget(labelVersion);

        labelCategory = new QLabel(aboutDialog);
        labelCategory->setObjectName(QString::fromUtf8("labelCategory"));
        QFont font1;
        font1.setBold(false);
        font1.setItalic(false);
        font1.setUnderline(false);
        font1.setStrikeOut(false);
        labelCategory->setFont(font1);
        labelCategory->setAlignment(Qt::AlignCenter);

        vboxLayout1->addWidget(labelCategory);

        labelCopy = new QLabel(aboutDialog);
        labelCopy->setObjectName(QString::fromUtf8("labelCopy"));
        labelCopy->setAlignment(Qt::AlignCenter);

        vboxLayout1->addWidget(labelCopy);

        labelUrl = new QLabel(aboutDialog);
        labelUrl->setObjectName(QString::fromUtf8("labelUrl"));
        labelUrl->setFont(font1);
        labelUrl->setTextFormat(Qt::RichText);
        labelUrl->setAlignment(Qt::AlignCenter);
        labelUrl->setOpenExternalLinks(true);

        vboxLayout1->addWidget(labelUrl);


        vboxLayout->addLayout(vboxLayout1);

        spacerItem2 = new QSpacerItem(20, 5, QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);

        vboxLayout->addItem(spacerItem2);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        licenseButton = new QPushButton(aboutDialog);
        licenseButton->setObjectName(QString::fromUtf8("licenseButton"));

        hboxLayout->addWidget(licenseButton);

        spacerItem3 = new QSpacerItem(131, 31, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem3);

        okButton = new QPushButton(aboutDialog);
        okButton->setObjectName(QString::fromUtf8("okButton"));

        hboxLayout->addWidget(okButton);


        vboxLayout->addLayout(hboxLayout);

        QWidget::setTabOrder(okButton, licenseButton);

        retranslateUi(aboutDialog);
        QObject::connect(okButton, SIGNAL(clicked()), aboutDialog, SLOT(accept()));

        okButton->setDefault(true);


        QMetaObject::connectSlotsByName(aboutDialog);
    } // setupUi

    void retranslateUi(QDialog *aboutDialog)
    {
        aboutDialog->setWindowTitle(QCoreApplication::translate("aboutDialog", "About Avidemux", nullptr));
        labelIcon->setText(QString());
        labelVersion->setText(QCoreApplication::translate("aboutDialog", "Avidemux", nullptr));
        labelCategory->setText(QCoreApplication::translate("aboutDialog", "Multi-platform Video Editor", nullptr));
        labelCopy->setText(QCoreApplication::translate("aboutDialog", "\302\251 2001 - 2021  Mean / eumagga0x2a", nullptr));
        licenseButton->setText(QCoreApplication::translate("aboutDialog", "&License", nullptr));
        okButton->setText(QCoreApplication::translate("aboutDialog", "OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class aboutDialog: public Ui_aboutDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUT_H
