/********************************************************************************
** Form generated from reading UI file 'artCharcoal.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTCHARCOAL_H
#define UI_ARTCHARCOAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artCharcoalDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelIntensity;
    ADM_SliderIndicator *horizontalSliderColor;
    QLabel *labelColor;
    ADM_SliderIndicator *horizontalSliderScatterX;
    QLabel *labelVScatter;
    QLabel *labelHScatter;
    ADM_SliderIndicator *horizontalSliderScatterY;
    ADM_SliderIndicator *horizontalSliderIntensity;
    QSpacerItem *horizontalSpacer;
    QCheckBox *checkBoxInvert;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artCharcoalDialog)
    {
        if (artCharcoalDialog->objectName().isEmpty())
            artCharcoalDialog->setObjectName(QString::fromUtf8("artCharcoalDialog"));
        artCharcoalDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(artCharcoalDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        labelIntensity = new QLabel(artCharcoalDialog);
        labelIntensity->setObjectName(QString::fromUtf8("labelIntensity"));

        gridLayout->addWidget(labelIntensity, 2, 0, 1, 1);

        horizontalSliderColor = new ADM_SliderIndicator(artCharcoalDialog);
        horizontalSliderColor->setObjectName(QString::fromUtf8("horizontalSliderColor"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(horizontalSliderColor->sizePolicy().hasHeightForWidth());
        horizontalSliderColor->setSizePolicy(sizePolicy);
        horizontalSliderColor->setMaximum(100);
        horizontalSliderColor->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderColor, 3, 1, 1, 1);

        labelColor = new QLabel(artCharcoalDialog);
        labelColor->setObjectName(QString::fromUtf8("labelColor"));

        gridLayout->addWidget(labelColor, 3, 0, 1, 1);

        horizontalSliderScatterX = new ADM_SliderIndicator(artCharcoalDialog);
        horizontalSliderScatterX->setObjectName(QString::fromUtf8("horizontalSliderScatterX"));
        sizePolicy.setHeightForWidth(horizontalSliderScatterX->sizePolicy().hasHeightForWidth());
        horizontalSliderScatterX->setSizePolicy(sizePolicy);
        horizontalSliderScatterX->setMinimum(0);
        horizontalSliderScatterX->setMaximum(10);
        horizontalSliderScatterX->setPageStep(1);
        horizontalSliderScatterX->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderScatterX, 0, 1, 1, 1);

        labelVScatter = new QLabel(artCharcoalDialog);
        labelVScatter->setObjectName(QString::fromUtf8("labelVScatter"));

        gridLayout->addWidget(labelVScatter, 1, 0, 1, 1);

        labelHScatter = new QLabel(artCharcoalDialog);
        labelHScatter->setObjectName(QString::fromUtf8("labelHScatter"));

        gridLayout->addWidget(labelHScatter, 0, 0, 1, 1);

        horizontalSliderScatterY = new ADM_SliderIndicator(artCharcoalDialog);
        horizontalSliderScatterY->setObjectName(QString::fromUtf8("horizontalSliderScatterY"));
        sizePolicy.setHeightForWidth(horizontalSliderScatterY->sizePolicy().hasHeightForWidth());
        horizontalSliderScatterY->setSizePolicy(sizePolicy);
        horizontalSliderScatterY->setMinimum(0);
        horizontalSliderScatterY->setMaximum(10);
        horizontalSliderScatterY->setPageStep(1);
        horizontalSliderScatterY->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderScatterY, 1, 1, 1, 1);

        horizontalSliderIntensity = new ADM_SliderIndicator(artCharcoalDialog);
        horizontalSliderIntensity->setObjectName(QString::fromUtf8("horizontalSliderIntensity"));
        sizePolicy.setHeightForWidth(horizontalSliderIntensity->sizePolicy().hasHeightForWidth());
        horizontalSliderIntensity->setSizePolicy(sizePolicy);
        horizontalSliderIntensity->setMaximum(100);
        horizontalSliderIntensity->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderIntensity, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        checkBoxInvert = new QCheckBox(artCharcoalDialog);
        checkBoxInvert->setObjectName(QString::fromUtf8("checkBoxInvert"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(checkBoxInvert->sizePolicy().hasHeightForWidth());
        checkBoxInvert->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(checkBoxInvert);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artCharcoalDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artCharcoalDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artCharcoalDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(artCharcoalDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artCharcoalDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artCharcoalDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artCharcoalDialog);
    } // setupUi

    void retranslateUi(QDialog *artCharcoalDialog)
    {
        artCharcoalDialog->setWindowTitle(QCoreApplication::translate("artCharcoalDialog", "Charcoal / Chalkboard", nullptr));
        labelIntensity->setText(QCoreApplication::translate("artCharcoalDialog", "Intensity", nullptr));
        labelColor->setText(QCoreApplication::translate("artCharcoalDialog", "Color", nullptr));
        labelVScatter->setText(QCoreApplication::translate("artCharcoalDialog", "Vertical scatter", nullptr));
        labelHScatter->setText(QCoreApplication::translate("artCharcoalDialog", "Horizontal scatter", nullptr));
        checkBoxInvert->setText(QCoreApplication::translate("artCharcoalDialog", "Chalkboard", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artCharcoalDialog: public Ui_artCharcoalDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTCHARCOAL_H
