/********************************************************************************
** Form generated from reading UI file 'seekablePreview.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEEKABLEPREVIEW_H
#define UI_SEEKABLEPREVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_seekablePreviewDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QGraphicsView *graphicsView;
    QHBoxLayout *horizontalLayout_2;
    ADM_flyNavSlider *horizontalSlider;
    QHBoxLayout *toolLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *seekablePreviewDialog)
    {
        if (seekablePreviewDialog->objectName().isEmpty())
            seekablePreviewDialog->setObjectName(QString::fromUtf8("seekablePreviewDialog"));
        seekablePreviewDialog->resize(500, 130);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(seekablePreviewDialog->sizePolicy().hasHeightForWidth());
        seekablePreviewDialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(seekablePreviewDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        graphicsView = new QGraphicsView(seekablePreviewDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));

        horizontalLayout_3->addWidget(graphicsView);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSlider = new ADM_flyNavSlider(seekablePreviewDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        horizontalLayout_2->addWidget(horizontalSlider);


        verticalLayout->addLayout(horizontalLayout_2);

        toolLayout = new QHBoxLayout();
        toolLayout->setObjectName(QString::fromUtf8("toolLayout"));

        verticalLayout->addLayout(toolLayout);

        buttonBox = new QDialogButtonBox(seekablePreviewDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(seekablePreviewDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), seekablePreviewDialog, SLOT(accept()));

        QMetaObject::connectSlotsByName(seekablePreviewDialog);
    } // setupUi

    void retranslateUi(QDialog *seekablePreviewDialog)
    {
        seekablePreviewDialog->setWindowTitle(QCoreApplication::translate("seekablePreviewDialog", "Preview", nullptr));
    } // retranslateUi

};

namespace Ui {
    class seekablePreviewDialog: public Ui_seekablePreviewDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SEEKABLEPREVIEW_H
