/********************************************************************************
** Form generated from reading UI file 'hue.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HUE_H
#define UI_HUE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_hueDialog
{
public:
    QVBoxLayout *mainLayout;
    QHBoxLayout *horizontalLayoutSliders;
    QVBoxLayout *controlPanel;
    QLabel *labelHue;
    ADM_SliderIndicator *horizontalSliderHue;
    QLabel *labelSaturation;
    ADM_SliderIndicator *horizontalSliderSaturation;
    QSpacerItem *panelSpacer;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *hueDialog)
    {
        if (hueDialog->objectName().isEmpty())
            hueDialog->setObjectName(QString::fromUtf8("hueDialog"));
        hueDialog->resize(505, 475);
        mainLayout = new QVBoxLayout(hueDialog);
        mainLayout->setObjectName(QString::fromUtf8("mainLayout"));
        horizontalLayoutSliders = new QHBoxLayout();
        horizontalLayoutSliders->setObjectName(QString::fromUtf8("horizontalLayoutSliders"));
        controlPanel = new QVBoxLayout();
        controlPanel->setSpacing(6);
        controlPanel->setObjectName(QString::fromUtf8("controlPanel"));
        controlPanel->setContentsMargins(0, 0, 0, 0);
        labelHue = new QLabel(hueDialog);
        labelHue->setObjectName(QString::fromUtf8("labelHue"));

        controlPanel->addWidget(labelHue);

        horizontalSliderHue = new ADM_SliderIndicator(hueDialog);
        horizontalSliderHue->setObjectName(QString::fromUtf8("horizontalSliderHue"));
        horizontalSliderHue->setMinimum(-90);
        horizontalSliderHue->setMaximum(90);
        horizontalSliderHue->setOrientation(Qt::Horizontal);

        controlPanel->addWidget(horizontalSliderHue);

        labelSaturation = new QLabel(hueDialog);
        labelSaturation->setObjectName(QString::fromUtf8("labelSaturation"));

        controlPanel->addWidget(labelSaturation);

        horizontalSliderSaturation = new ADM_SliderIndicator(hueDialog);
        horizontalSliderSaturation->setObjectName(QString::fromUtf8("horizontalSliderSaturation"));
        horizontalSliderSaturation->setMinimum(-100);
        horizontalSliderSaturation->setMaximum(100);
        horizontalSliderSaturation->setOrientation(Qt::Horizontal);

        controlPanel->addWidget(horizontalSliderSaturation);


        horizontalLayoutSliders->addLayout(controlPanel);

        panelSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayoutSliders->addItem(panelSpacer);


        mainLayout->addLayout(horizontalLayoutSliders);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        mainLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(hueDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        mainLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(hueDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        mainLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(hueDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        mainLayout->addWidget(buttonBox);


        retranslateUi(hueDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), hueDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), hueDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(hueDialog);
    } // setupUi

    void retranslateUi(QDialog *hueDialog)
    {
        hueDialog->setWindowTitle(QCoreApplication::translate("hueDialog", "Hue", nullptr));
        labelHue->setText(QCoreApplication::translate("hueDialog", "Hue", nullptr));
        labelSaturation->setText(QCoreApplication::translate("hueDialog", "Saturation", nullptr));
    } // retranslateUi

};

namespace Ui {
    class hueDialog: public Ui_hueDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HUE_H
