/****************************************************************************
** Meta object code from reading C++ file 'Q_audioTrackClass.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../avidemux/qt4/ADM_userInterfaces/ADM_dialog/Q_audioTrackClass.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Q_audioTrackClass.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_audioTrackQt4_t {
    QByteArrayData data[12];
    char stringdata0[129];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_audioTrackQt4_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_audioTrackQt4_t qt_meta_stringdata_audioTrackQt4 = {
    {
QT_MOC_LITERAL(0, 0, 13), // "audioTrackQt4"
QT_MOC_LITERAL(1, 14, 14), // "filtersClicked"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 1), // "a"
QT_MOC_LITERAL(4, 32, 16), // "codecConfClicked"
QT_MOC_LITERAL(5, 49, 19), // "enabledStateChanged"
QT_MOC_LITERAL(6, 69, 5), // "state"
QT_MOC_LITERAL(7, 75, 12), // "inputChanged"
QT_MOC_LITERAL(8, 88, 6), // "signal"
QT_MOC_LITERAL(9, 95, 12), // "codecChanged"
QT_MOC_LITERAL(10, 108, 3), // "idx"
QT_MOC_LITERAL(11, 112, 16) // "dupConfigClicked"

    },
    "audioTrackQt4\0filtersClicked\0\0a\0"
    "codecConfClicked\0enabledStateChanged\0"
    "state\0inputChanged\0signal\0codecChanged\0"
    "idx\0dupConfigClicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_audioTrackQt4[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x08 /* Private */,
       4,    1,   47,    2, 0x08 /* Private */,
       5,    1,   50,    2, 0x08 /* Private */,
       7,    1,   53,    2, 0x08 /* Private */,
       9,    1,   56,    2, 0x08 /* Private */,
      11,    1,   59,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Bool, QMetaType::Bool,    3,
    QMetaType::Bool, QMetaType::Bool,    3,
    QMetaType::Bool, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Bool, QMetaType::Bool,    3,

       0        // eod
};

void audioTrackQt4::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<audioTrackQt4 *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->filtersClicked((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->codecConfClicked((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->enabledStateChanged((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->inputChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->codecChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: { bool _r = _t->dupConfigClicked((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject audioTrackQt4::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_audioTrackQt4.data,
    qt_meta_data_audioTrackQt4,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *audioTrackQt4::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *audioTrackQt4::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_audioTrackQt4.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DIA_audioTrackBase"))
        return static_cast< DIA_audioTrackBase*>(this);
    return QObject::qt_metacast(_clname);
}

int audioTrackQt4::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
