/********************************************************************************
** Form generated from reading UI file 'chromashift.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHROMASHIFT_H
#define UI_CHROMASHIFT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_chromashiftDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QSpinBox *spinBoxU;
    QSpinBox *spinBoxV;
    QLabel *labelU;
    QLabel *labelV;
    QSpacerItem *spacerItem;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *chromashiftDialog)
    {
        if (chromashiftDialog->objectName().isEmpty())
            chromashiftDialog->setObjectName(QString::fromUtf8("chromashiftDialog"));
        chromashiftDialog->resize(480, 400);
        verticalLayout = new QVBoxLayout(chromashiftDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        spinBoxU = new QSpinBox(chromashiftDialog);
        spinBoxU->setObjectName(QString::fromUtf8("spinBoxU"));

        gridLayout->addWidget(spinBoxU, 0, 1, 1, 1);

        spinBoxV = new QSpinBox(chromashiftDialog);
        spinBoxV->setObjectName(QString::fromUtf8("spinBoxV"));

        gridLayout->addWidget(spinBoxV, 1, 1, 1, 1);

        labelU = new QLabel(chromashiftDialog);
        labelU->setObjectName(QString::fromUtf8("labelU"));

        gridLayout->addWidget(labelU, 0, 0, 1, 1);

        labelV = new QLabel(chromashiftDialog);
        labelV->setObjectName(QString::fromUtf8("labelV"));

        gridLayout->addWidget(labelV, 1, 0, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 0, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(chromashiftDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(chromashiftDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(chromashiftDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(chromashiftDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), chromashiftDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), chromashiftDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(chromashiftDialog);
    } // setupUi

    void retranslateUi(QDialog *chromashiftDialog)
    {
        chromashiftDialog->setWindowTitle(QCoreApplication::translate("chromashiftDialog", "ChromaShift", nullptr));
        labelU->setText(QCoreApplication::translate("chromashiftDialog", "U Shift", nullptr));
        labelV->setText(QCoreApplication::translate("chromashiftDialog", "V Shift", nullptr));
    } // retranslateUi

};

namespace Ui {
    class chromashiftDialog: public Ui_chromashiftDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHROMASHIFT_H
