/********************************************************************************
** Form generated from reading UI file 'audioTracks.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUDIOTRACKS_H
#define UI_AUDIOTRACKS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>

QT_BEGIN_NAMESPACE

class Ui_DialogAudioTracks
{
public:
    QFormLayout *formLayout;
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DialogAudioTracks)
    {
        if (DialogAudioTracks->objectName().isEmpty())
            DialogAudioTracks->setObjectName(QString::fromUtf8("DialogAudioTracks"));
        DialogAudioTracks->resize(202, 60);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DialogAudioTracks->sizePolicy().hasHeightForWidth());
        DialogAudioTracks->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(DialogAudioTracks);
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));

        formLayout->setLayout(0, QFormLayout::LabelRole, gridLayout);

        buttonBox = new QDialogButtonBox(DialogAudioTracks);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        formLayout->setWidget(1, QFormLayout::LabelRole, buttonBox);


        retranslateUi(DialogAudioTracks);
        QObject::connect(buttonBox, SIGNAL(accepted()), DialogAudioTracks, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), DialogAudioTracks, SLOT(reject()));

        QMetaObject::connectSlotsByName(DialogAudioTracks);
    } // setupUi

    void retranslateUi(QDialog *DialogAudioTracks)
    {
        DialogAudioTracks->setWindowTitle(QCoreApplication::translate("DialogAudioTracks", "Audio Tracks Configuration", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogAudioTracks: public Ui_DialogAudioTracks {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUDIOTRACKS_H
