/********************************************************************************
** Form generated from reading UI file 'artChromaHold.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTCHROMAHOLD_H
#define UI_ARTCHROMAHOLD_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artChromaHoldDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QPushButton *pushButtonC1;
    ADM_SliderIndicator *horizontalSliderC3slope;
    ADM_SliderIndicator *horizontalSliderC1slope;
    QLineEdit *lineEditC1;
    QCheckBox *checkBoxC3en;
    QCheckBox *checkBoxC2en;
    QCheckBox *checkBoxC1en;
    QPushButton *pushButtonC2;
    QPushButton *pushButtonC3;
    QLineEdit *lineEditC2;
    QLineEdit *lineEditC3;
    ADM_SliderIndicator *horizontalSliderC1dist;
    ADM_SliderIndicator *horizontalSliderC2dist;
    QLabel *labelDistance;
    QLabel *labelSlope;
    QLabel *labelChroma;
    ADM_SliderIndicator *horizontalSliderC2slope;
    ADM_SliderIndicator *horizontalSliderC3dist;
    QGraphicsView *graphicsViewUV;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artChromaHoldDialog)
    {
        if (artChromaHoldDialog->objectName().isEmpty())
            artChromaHoldDialog->setObjectName(QString::fromUtf8("artChromaHoldDialog"));
        artChromaHoldDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(artChromaHoldDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        pushButtonC1 = new QPushButton(artChromaHoldDialog);
        pushButtonC1->setObjectName(QString::fromUtf8("pushButtonC1"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/color.png"), QSize(), QIcon::Normal, QIcon::Off);
        pushButtonC1->setIcon(icon);

        gridLayout->addWidget(pushButtonC1, 1, 1, 1, 1);

        horizontalSliderC3slope = new ADM_SliderIndicator(artChromaHoldDialog);
        horizontalSliderC3slope->setObjectName(QString::fromUtf8("horizontalSliderC3slope"));
        horizontalSliderC3slope->setMaximum(100);
        horizontalSliderC3slope->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC3slope, 3, 4, 1, 1);

        horizontalSliderC1slope = new ADM_SliderIndicator(artChromaHoldDialog);
        horizontalSliderC1slope->setObjectName(QString::fromUtf8("horizontalSliderC1slope"));
        horizontalSliderC1slope->setMaximum(100);
        horizontalSliderC1slope->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC1slope, 1, 4, 1, 1);

        lineEditC1 = new QLineEdit(artChromaHoldDialog);
        lineEditC1->setObjectName(QString::fromUtf8("lineEditC1"));
        lineEditC1->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lineEditC1->sizePolicy().hasHeightForWidth());
        lineEditC1->setSizePolicy(sizePolicy);
        lineEditC1->setMaximumSize(QSize(48, 16777215));
        lineEditC1->setAutoFillBackground(true);
        lineEditC1->setFrame(true);
        lineEditC1->setAlignment(Qt::AlignCenter);
        lineEditC1->setReadOnly(true);

        gridLayout->addWidget(lineEditC1, 1, 2, 1, 1);

        checkBoxC3en = new QCheckBox(artChromaHoldDialog);
        checkBoxC3en->setObjectName(QString::fromUtf8("checkBoxC3en"));

        gridLayout->addWidget(checkBoxC3en, 3, 0, 1, 1);

        checkBoxC2en = new QCheckBox(artChromaHoldDialog);
        checkBoxC2en->setObjectName(QString::fromUtf8("checkBoxC2en"));

        gridLayout->addWidget(checkBoxC2en, 2, 0, 1, 1);

        checkBoxC1en = new QCheckBox(artChromaHoldDialog);
        checkBoxC1en->setObjectName(QString::fromUtf8("checkBoxC1en"));
        checkBoxC1en->setEnabled(true);
        checkBoxC1en->setCheckable(true);
        checkBoxC1en->setChecked(false);

        gridLayout->addWidget(checkBoxC1en, 1, 0, 1, 1);

        pushButtonC2 = new QPushButton(artChromaHoldDialog);
        pushButtonC2->setObjectName(QString::fromUtf8("pushButtonC2"));
        pushButtonC2->setIcon(icon);

        gridLayout->addWidget(pushButtonC2, 2, 1, 1, 1);

        pushButtonC3 = new QPushButton(artChromaHoldDialog);
        pushButtonC3->setObjectName(QString::fromUtf8("pushButtonC3"));
        pushButtonC3->setIcon(icon);

        gridLayout->addWidget(pushButtonC3, 3, 1, 1, 1);

        lineEditC2 = new QLineEdit(artChromaHoldDialog);
        lineEditC2->setObjectName(QString::fromUtf8("lineEditC2"));
        lineEditC2->setEnabled(false);
        sizePolicy.setHeightForWidth(lineEditC2->sizePolicy().hasHeightForWidth());
        lineEditC2->setSizePolicy(sizePolicy);
        lineEditC2->setMaximumSize(QSize(48, 16777215));
        lineEditC2->setAutoFillBackground(true);

        gridLayout->addWidget(lineEditC2, 2, 2, 1, 1);

        lineEditC3 = new QLineEdit(artChromaHoldDialog);
        lineEditC3->setObjectName(QString::fromUtf8("lineEditC3"));
        lineEditC3->setEnabled(false);
        sizePolicy.setHeightForWidth(lineEditC3->sizePolicy().hasHeightForWidth());
        lineEditC3->setSizePolicy(sizePolicy);
        lineEditC3->setMaximumSize(QSize(48, 16777215));
        lineEditC3->setAutoFillBackground(true);

        gridLayout->addWidget(lineEditC3, 3, 2, 1, 1);

        horizontalSliderC1dist = new ADM_SliderIndicator(artChromaHoldDialog);
        horizontalSliderC1dist->setObjectName(QString::fromUtf8("horizontalSliderC1dist"));
        horizontalSliderC1dist->setMinimum(0);
        horizontalSliderC1dist->setMaximum(100);
        horizontalSliderC1dist->setPageStep(10);
        horizontalSliderC1dist->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC1dist, 1, 3, 1, 1);

        horizontalSliderC2dist = new ADM_SliderIndicator(artChromaHoldDialog);
        horizontalSliderC2dist->setObjectName(QString::fromUtf8("horizontalSliderC2dist"));
        horizontalSliderC2dist->setMaximum(100);
        horizontalSliderC2dist->setPageStep(10);
        horizontalSliderC2dist->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC2dist, 2, 3, 1, 1);

        labelDistance = new QLabel(artChromaHoldDialog);
        labelDistance->setObjectName(QString::fromUtf8("labelDistance"));
        labelDistance->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(labelDistance, 0, 3, 1, 1);

        labelSlope = new QLabel(artChromaHoldDialog);
        labelSlope->setObjectName(QString::fromUtf8("labelSlope"));
        labelSlope->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(labelSlope, 0, 4, 1, 1);

        labelChroma = new QLabel(artChromaHoldDialog);
        labelChroma->setObjectName(QString::fromUtf8("labelChroma"));
        labelChroma->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(labelChroma, 0, 1, 1, 2);

        horizontalSliderC2slope = new ADM_SliderIndicator(artChromaHoldDialog);
        horizontalSliderC2slope->setObjectName(QString::fromUtf8("horizontalSliderC2slope"));
        horizontalSliderC2slope->setMaximum(100);
        horizontalSliderC2slope->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC2slope, 2, 4, 1, 1);

        horizontalSliderC3dist = new ADM_SliderIndicator(artChromaHoldDialog);
        horizontalSliderC3dist->setObjectName(QString::fromUtf8("horizontalSliderC3dist"));
        horizontalSliderC3dist->setMaximum(100);
        horizontalSliderC3dist->setPageStep(10);
        horizontalSliderC3dist->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderC3dist, 3, 3, 1, 1);

        graphicsViewUV = new QGraphicsView(artChromaHoldDialog);
        graphicsViewUV->setObjectName(QString::fromUtf8("graphicsViewUV"));
        graphicsViewUV->setEnabled(false);
        sizePolicy.setHeightForWidth(graphicsViewUV->sizePolicy().hasHeightForWidth());
        graphicsViewUV->setSizePolicy(sizePolicy);
        graphicsViewUV->setMinimumSize(QSize(128, 128));
        graphicsViewUV->setMaximumSize(QSize(128, 128));
        graphicsViewUV->setFocusPolicy(Qt::NoFocus);
        graphicsViewUV->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewUV->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        gridLayout->addWidget(graphicsViewUV, 1, 5, 3, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artChromaHoldDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artChromaHoldDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artChromaHoldDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(checkBoxC1en, pushButtonC1);
        QWidget::setTabOrder(pushButtonC1, lineEditC1);
        QWidget::setTabOrder(lineEditC1, horizontalSliderC1dist);
        QWidget::setTabOrder(horizontalSliderC1dist, horizontalSliderC1slope);
        QWidget::setTabOrder(horizontalSliderC1slope, checkBoxC2en);
        QWidget::setTabOrder(checkBoxC2en, pushButtonC2);
        QWidget::setTabOrder(pushButtonC2, lineEditC2);
        QWidget::setTabOrder(lineEditC2, horizontalSliderC2dist);
        QWidget::setTabOrder(horizontalSliderC2dist, horizontalSliderC2slope);
        QWidget::setTabOrder(horizontalSliderC2slope, checkBoxC3en);
        QWidget::setTabOrder(checkBoxC3en, pushButtonC3);
        QWidget::setTabOrder(pushButtonC3, lineEditC3);
        QWidget::setTabOrder(lineEditC3, horizontalSliderC3dist);
        QWidget::setTabOrder(horizontalSliderC3dist, horizontalSliderC3slope);
        QWidget::setTabOrder(horizontalSliderC3slope, horizontalSlider);
        QWidget::setTabOrder(horizontalSlider, graphicsView);

        retranslateUi(artChromaHoldDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artChromaHoldDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artChromaHoldDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artChromaHoldDialog);
    } // setupUi

    void retranslateUi(QDialog *artChromaHoldDialog)
    {
        artChromaHoldDialog->setWindowTitle(QCoreApplication::translate("artChromaHoldDialog", "Chroma Hold", nullptr));
        pushButtonC1->setText(QString());
        checkBoxC3en->setText(QCoreApplication::translate("artChromaHoldDialog", "Tertiary", nullptr));
        checkBoxC2en->setText(QCoreApplication::translate("artChromaHoldDialog", "Secondary", nullptr));
        checkBoxC1en->setText(QCoreApplication::translate("artChromaHoldDialog", "Primary", nullptr));
        pushButtonC2->setText(QString());
        pushButtonC3->setText(QString());
        labelDistance->setText(QCoreApplication::translate("artChromaHoldDialog", "Distance", nullptr));
        labelSlope->setText(QCoreApplication::translate("artChromaHoldDialog", "Cutoff slope", nullptr));
        labelChroma->setText(QCoreApplication::translate("artChromaHoldDialog", "Pick Chroma", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artChromaHoldDialog: public Ui_artChromaHoldDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTCHROMAHOLD_H
