// automatically generated by admSerialization.py do not edit
#include "string"
#pragma once
typedef struct {
COMPRES_PARAMS ratectl;
uint32_t nbThreads;
bool autoThreads;
uint32_t speed;
uint32_t deadline;
uint32_t keyint;
bool fullrange;
}vp9_encoder;
