/********************************************************************************
** Form generated from reading UI file 'asharp.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ASHARP_H
#define UI_ASHARP_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_asharpDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelThreshold;
    QSlider *horizontalSliderThreshold;
    QCheckBox *checkBoxStrength;
    QSlider *horizontalSliderStrength;
    QDoubleSpinBox *doubleSpinBoxStrength;
    QDoubleSpinBox *doubleSpinBoxThreshold;
    QSpacerItem *topGridSpacer;
    QDoubleSpinBox *doubleSpinBoxBlock;
    QSlider *horizontalSliderBlock;
    QCheckBox *checkBoxBlock;
    QHBoxLayout *horizontalLayout;
    QCheckBox *checkBoxHQBF;
    QSpacerItem *fullPreviewSpacer;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *asharpDialog)
    {
        if (asharpDialog->objectName().isEmpty())
            asharpDialog->setObjectName(QString::fromUtf8("asharpDialog"));
        asharpDialog->resize(645, 450);
        verticalLayout = new QVBoxLayout(asharpDialog);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        labelThreshold = new QLabel(asharpDialog);
        labelThreshold->setObjectName(QString::fromUtf8("labelThreshold"));

        gridLayout->addWidget(labelThreshold, 0, 0, 1, 1);

        horizontalSliderThreshold = new QSlider(asharpDialog);
        horizontalSliderThreshold->setObjectName(QString::fromUtf8("horizontalSliderThreshold"));
        horizontalSliderThreshold->setMaximum(3200);
        horizontalSliderThreshold->setSingleStep(32);
        horizontalSliderThreshold->setPageStep(320);
        horizontalSliderThreshold->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderThreshold, 0, 1, 1, 1);

        checkBoxStrength = new QCheckBox(asharpDialog);
        checkBoxStrength->setObjectName(QString::fromUtf8("checkBoxStrength"));

        gridLayout->addWidget(checkBoxStrength, 1, 0, 1, 1);

        horizontalSliderStrength = new QSlider(asharpDialog);
        horizontalSliderStrength->setObjectName(QString::fromUtf8("horizontalSliderStrength"));
        horizontalSliderStrength->setMinimum(0);
        horizontalSliderStrength->setMaximum(1600);
        horizontalSliderStrength->setSingleStep(16);
        horizontalSliderStrength->setPageStep(160);
        horizontalSliderStrength->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderStrength, 1, 1, 1, 1);

        doubleSpinBoxStrength = new QDoubleSpinBox(asharpDialog);
        doubleSpinBoxStrength->setObjectName(QString::fromUtf8("doubleSpinBoxStrength"));
        doubleSpinBoxStrength->setMaximum(16.000000000000000);
        doubleSpinBoxStrength->setSingleStep(0.100000000000000);

        gridLayout->addWidget(doubleSpinBoxStrength, 1, 2, 1, 1);

        doubleSpinBoxThreshold = new QDoubleSpinBox(asharpDialog);
        doubleSpinBoxThreshold->setObjectName(QString::fromUtf8("doubleSpinBoxThreshold"));
        doubleSpinBoxThreshold->setMaximum(32.000000000000000);
        doubleSpinBoxThreshold->setSingleStep(0.100000000000000);

        gridLayout->addWidget(doubleSpinBoxThreshold, 0, 2, 1, 1);

        topGridSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(topGridSpacer, 0, 3, 1, 1);

        doubleSpinBoxBlock = new QDoubleSpinBox(asharpDialog);
        doubleSpinBoxBlock->setObjectName(QString::fromUtf8("doubleSpinBoxBlock"));
        doubleSpinBoxBlock->setMaximum(4.000000000000000);
        doubleSpinBoxBlock->setSingleStep(0.100000000000000);

        gridLayout->addWidget(doubleSpinBoxBlock, 2, 2, 1, 1);

        horizontalSliderBlock = new QSlider(asharpDialog);
        horizontalSliderBlock->setObjectName(QString::fromUtf8("horizontalSliderBlock"));
        horizontalSliderBlock->setMaximum(400);
        horizontalSliderBlock->setSingleStep(4);
        horizontalSliderBlock->setPageStep(40);
        horizontalSliderBlock->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderBlock, 2, 1, 1, 1);

        checkBoxBlock = new QCheckBox(asharpDialog);
        checkBoxBlock->setObjectName(QString::fromUtf8("checkBoxBlock"));

        gridLayout->addWidget(checkBoxBlock, 2, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        checkBoxHQBF = new QCheckBox(asharpDialog);
        checkBoxHQBF->setObjectName(QString::fromUtf8("checkBoxHQBF"));

        horizontalLayout->addWidget(checkBoxHQBF);

        fullPreviewSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(fullPreviewSpacer);


        verticalLayout->addLayout(horizontalLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(asharpDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(asharpDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(asharpDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(asharpDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), asharpDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), asharpDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(asharpDialog);
    } // setupUi

    void retranslateUi(QDialog *asharpDialog)
    {
        asharpDialog->setWindowTitle(QCoreApplication::translate("asharpDialog", "ASharp", nullptr));
        labelThreshold->setText(QCoreApplication::translate("asharpDialog", "Threshold", nullptr));
        checkBoxStrength->setText(QCoreApplication::translate("asharpDialog", "Adaptive strength", nullptr));
        checkBoxBlock->setText(QCoreApplication::translate("asharpDialog", "Block adaptive", nullptr));
        checkBoxHQBF->setText(QCoreApplication::translate("asharpDialog", "High quality block filtering", nullptr));
    } // retranslateUi

};

namespace Ui {
    class asharpDialog: public Ui_asharpDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ASHARP_H
