/****************************************************************************
** Meta object code from reading C++ file 'Q_resize.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../avidemux_plugins/ADM_videoFilters6/resize/qt4/Q_resize.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Q_resize.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_resizeWindow_t {
    QByteArrayData data[16];
    char stringdata0[202];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_resizeWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_resizeWindow_t qt_meta_stringdata_resizeWindow = {
    {
QT_MOC_LITERAL(0, 0, 12), // "resizeWindow"
QT_MOC_LITERAL(1, 13, 6), // "gather"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 15), // "okButtonClicked"
QT_MOC_LITERAL(4, 37, 13), // "sliderChanged"
QT_MOC_LITERAL(5, 51, 5), // "value"
QT_MOC_LITERAL(6, 57, 24), // "percentageSpinBoxChanged"
QT_MOC_LITERAL(7, 82, 19), // "widthSpinBoxChanged"
QT_MOC_LITERAL(8, 102, 20), // "heightSpinBoxChanged"
QT_MOC_LITERAL(9, 123, 13), // "lockArToggled"
QT_MOC_LITERAL(10, 137, 7), // "toggled"
QT_MOC_LITERAL(11, 145, 14), // "roundupChanged"
QT_MOC_LITERAL(12, 160, 5), // "index"
QT_MOC_LITERAL(13, 166, 18), // "aspectRatioChanged"
QT_MOC_LITERAL(14, 185, 14), // "setPreferences"
QT_MOC_LITERAL(15, 200, 1) // "f"

    },
    "resizeWindow\0gather\0\0okButtonClicked\0"
    "sliderChanged\0value\0percentageSpinBoxChanged\0"
    "widthSpinBoxChanged\0heightSpinBoxChanged\0"
    "lockArToggled\0toggled\0roundupChanged\0"
    "index\0aspectRatioChanged\0setPreferences\0"
    "f"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_resizeWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x0a /* Public */,
       3,    0,   65,    2, 0x0a /* Public */,
       4,    1,   66,    2, 0x0a /* Public */,
       6,    1,   69,    2, 0x0a /* Public */,
       7,    1,   72,    2, 0x0a /* Public */,
       8,    1,   75,    2, 0x0a /* Public */,
       9,    1,   78,    2, 0x0a /* Public */,
      11,    1,   81,    2, 0x0a /* Public */,
      13,    1,   84,    2, 0x0a /* Public */,
      14,    1,   87,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Bool,   15,

       0        // eod
};

void resizeWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<resizeWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->gather(); break;
        case 1: _t->okButtonClicked(); break;
        case 2: _t->sliderChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->percentageSpinBoxChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->widthSpinBoxChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->heightSpinBoxChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->lockArToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->roundupChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->aspectRatioChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->setPreferences((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject resizeWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_resizeWindow.data,
    qt_meta_data_resizeWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *resizeWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *resizeWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_resizeWindow.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int resizeWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
