/********************************************************************************
** Form generated from reading UI file 'fadeThrough.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FADETHROUGH_H
#define UI_FADETHROUGH_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_fadeThroughDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *labelTScope;
    QLabel *labelCenter;
    QLabel *labelDuration;
    QPushButton *pushButtonTManual;
    QPushButton *pushButtonTMarker;
    QPushButton *pushButtonTCenter;
    QSpacerItem *horizontalSpacer_1;
    QGridLayout *gridLayout;
    QTabWidget *tabEffects;
    QWidget *tabBright;
    QVBoxLayout *verticalLayoutBright;
    QHBoxLayout *horizontalLayout_20;
    QCheckBox *checkBoxEnableBright;
    QHBoxLayout *horizontalLayout_21;
    QLabel *labelBright;
    QDoubleSpinBox *doubleSpinBoxPeakBright;
    ADM_QSlider *horizontalSliderPeakBright;
    QHBoxLayout *horizontalLayout_22;
    QLabel *labelTransientBright;
    QComboBox *comboBoxTransientBright;
    QLabel *labelTransientDurationBright;
    QDoubleSpinBox *doubleSpinBoxTransientDurationBright;
    ADM_QSlider *horizontalSliderTransientDurationBright;
    QWidget *tabSat;
    QVBoxLayout *verticalLayoutSat;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *checkBoxEnableSat;
    QHBoxLayout *horizontalLayout_6;
    QLabel *labelSat;
    QDoubleSpinBox *doubleSpinBoxPeakSat;
    ADM_QSlider *horizontalSliderPeakSat;
    QHBoxLayout *horizontalLayout_7;
    QLabel *labelTransientSat;
    QComboBox *comboBoxTransientSat;
    QLabel *labelTransientDurationSat;
    QDoubleSpinBox *doubleSpinBoxTransientDurationSat;
    ADM_QSlider *horizontalSliderTransientDurationSat;
    QWidget *tabBlend;
    QVBoxLayout *verticalLayoutBlend;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *checkBoxEnableBlend;
    QSpacerItem *horizontalSpacer_2;
    QLabel *labelPickColorBlend;
    QPushButton *pushButtonColorBlend;
    QLineEdit *lineEditColorBlend;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelPeakBlend;
    QDoubleSpinBox *doubleSpinBoxPeakBlend;
    ADM_QSlider *horizontalSliderPeakBlend;
    QHBoxLayout *horizontalLayout_4;
    QLabel *labelTransientBlend;
    QComboBox *comboBoxTransientBlend;
    QLabel *labelTransientDurationBlend;
    QDoubleSpinBox *doubleSpinBoxTransientDurationBlend;
    ADM_QSlider *horizontalSliderTransientDurationBlend;
    QWidget *tabBlur;
    QVBoxLayout *verticalLayoutBlur;
    QHBoxLayout *horizontalLayout_8;
    QCheckBox *checkBoxEnableBlur;
    QHBoxLayout *horizontalLayout_9;
    QLabel *labelPeakBlur;
    QDoubleSpinBox *doubleSpinBoxPeakBlur;
    ADM_QSlider *horizontalSliderPeakBlur;
    QHBoxLayout *horizontalLayout_10;
    QLabel *labelTransientBlur;
    QComboBox *comboBoxTransientBlur;
    QLabel *labelTransientDurationBlur;
    QDoubleSpinBox *doubleSpinBoxTransientDurationBlur;
    ADM_QSlider *horizontalSliderTransientDurationBlur;
    QWidget *tabRot;
    QVBoxLayout *verticalLayoutRot;
    QHBoxLayout *horizontalLayout_11;
    QCheckBox *checkBoxEnableRot;
    QHBoxLayout *horizontalLayout_12;
    QLabel *labelPeakRot;
    QDoubleSpinBox *doubleSpinBoxPeakRot;
    ADM_QSlider *horizontalSliderPeakRot;
    QHBoxLayout *horizontalLayout_13;
    QLabel *labelTransientRot;
    QComboBox *comboBoxTransientRot;
    QLabel *labelTransientDurationRot;
    QDoubleSpinBox *doubleSpinBoxTransientDurationRot;
    ADM_QSlider *horizontalSliderTransientDurationRot;
    QWidget *tabZoom;
    QVBoxLayout *verticalLayoutZoom;
    QHBoxLayout *horizontalLayout_14;
    QCheckBox *checkBoxEnableZoom;
    QHBoxLayout *horizontalLayout_15;
    QLabel *labelPeakZoom;
    QDoubleSpinBox *doubleSpinBoxPeakZoom;
    ADM_QSlider *horizontalSliderPeakZoom;
    QHBoxLayout *horizontalLayout_16;
    QLabel *labelTransientZoom;
    QComboBox *comboBoxTransientZoom;
    QLabel *labelTransientDurationZoom;
    QDoubleSpinBox *doubleSpinBoxTransientDurationZoom;
    ADM_QSlider *horizontalSliderTransientDurationZoom;
    QWidget *tabVignette;
    QVBoxLayout *verticalLayoutVignette;
    QHBoxLayout *horizontalLayout_17;
    QCheckBox *checkBoxEnableVignette;
    QSpacerItem *horizontalSpacer_4;
    QLabel *labelPickColorVignette;
    QPushButton *pushButtonColorVignette;
    QLineEdit *lineEditColorVignette;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *horizontalLayout_18;
    QLabel *labelPeakVignette;
    QDoubleSpinBox *doubleSpinBoxPeakVignette;
    ADM_QSlider *horizontalSliderPeakVignette;
    QHBoxLayout *horizontalLayout_19;
    QLabel *labelTransientVignette;
    QComboBox *comboBoxTransientVignette;
    QLabel *labelTransientDurationVignette;
    QDoubleSpinBox *doubleSpinBoxTransientDurationVignette;
    ADM_QSlider *horizontalSliderTransientDurationVignette;
    QVBoxLayout *verticalLayout_2;
    QGraphicsView *graphicsViewTransient;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *fadeThroughDialog)
    {
        if (fadeThroughDialog->objectName().isEmpty())
            fadeThroughDialog->setObjectName(QString::fromUtf8("fadeThroughDialog"));
        fadeThroughDialog->resize(795, 464);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fadeThroughDialog->sizePolicy().hasHeightForWidth());
        fadeThroughDialog->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(fadeThroughDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        labelTScope = new QLabel(fadeThroughDialog);
        labelTScope->setObjectName(QString::fromUtf8("labelTScope"));

        horizontalLayout->addWidget(labelTScope);

        labelCenter = new QLabel(fadeThroughDialog);
        labelCenter->setObjectName(QString::fromUtf8("labelCenter"));

        horizontalLayout->addWidget(labelCenter);

        labelDuration = new QLabel(fadeThroughDialog);
        labelDuration->setObjectName(QString::fromUtf8("labelDuration"));

        horizontalLayout->addWidget(labelDuration);

        pushButtonTManual = new QPushButton(fadeThroughDialog);
        pushButtonTManual->setObjectName(QString::fromUtf8("pushButtonTManual"));

        horizontalLayout->addWidget(pushButtonTManual);

        pushButtonTMarker = new QPushButton(fadeThroughDialog);
        pushButtonTMarker->setObjectName(QString::fromUtf8("pushButtonTMarker"));

        horizontalLayout->addWidget(pushButtonTMarker);

        pushButtonTCenter = new QPushButton(fadeThroughDialog);
        pushButtonTCenter->setObjectName(QString::fromUtf8("pushButtonTCenter"));

        horizontalLayout->addWidget(pushButtonTCenter);

        horizontalSpacer_1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_1);


        verticalLayout->addLayout(horizontalLayout);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        tabEffects = new QTabWidget(fadeThroughDialog);
        tabEffects->setObjectName(QString::fromUtf8("tabEffects"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tabEffects->sizePolicy().hasHeightForWidth());
        tabEffects->setSizePolicy(sizePolicy1);
        tabBright = new QWidget();
        tabBright->setObjectName(QString::fromUtf8("tabBright"));
        verticalLayoutBright = new QVBoxLayout(tabBright);
        verticalLayoutBright->setObjectName(QString::fromUtf8("verticalLayoutBright"));
        horizontalLayout_20 = new QHBoxLayout();
        horizontalLayout_20->setObjectName(QString::fromUtf8("horizontalLayout_20"));
        checkBoxEnableBright = new QCheckBox(tabBright);
        checkBoxEnableBright->setObjectName(QString::fromUtf8("checkBoxEnableBright"));

        horizontalLayout_20->addWidget(checkBoxEnableBright);


        verticalLayoutBright->addLayout(horizontalLayout_20);

        horizontalLayout_21 = new QHBoxLayout();
        horizontalLayout_21->setObjectName(QString::fromUtf8("horizontalLayout_21"));
        labelBright = new QLabel(tabBright);
        labelBright->setObjectName(QString::fromUtf8("labelBright"));

        horizontalLayout_21->addWidget(labelBright);

        doubleSpinBoxPeakBright = new QDoubleSpinBox(tabBright);
        doubleSpinBoxPeakBright->setObjectName(QString::fromUtf8("doubleSpinBoxPeakBright"));
        doubleSpinBoxPeakBright->setMinimum(0.000000000000000);
        doubleSpinBoxPeakBright->setMaximum(2.000000000000000);
        doubleSpinBoxPeakBright->setSingleStep(0.010000000000000);

        horizontalLayout_21->addWidget(doubleSpinBoxPeakBright);

        horizontalSliderPeakBright = new ADM_QSlider(tabBright);
        horizontalSliderPeakBright->setObjectName(QString::fromUtf8("horizontalSliderPeakBright"));
        horizontalSliderPeakBright->setMinimum(0);
        horizontalSliderPeakBright->setMaximum(200);
        horizontalSliderPeakBright->setOrientation(Qt::Horizontal);

        horizontalLayout_21->addWidget(horizontalSliderPeakBright);


        verticalLayoutBright->addLayout(horizontalLayout_21);

        horizontalLayout_22 = new QHBoxLayout();
        horizontalLayout_22->setObjectName(QString::fromUtf8("horizontalLayout_22"));
        labelTransientBright = new QLabel(tabBright);
        labelTransientBright->setObjectName(QString::fromUtf8("labelTransientBright"));

        horizontalLayout_22->addWidget(labelTransientBright);

        comboBoxTransientBright = new QComboBox(tabBright);
        comboBoxTransientBright->addItem(QString());
        comboBoxTransientBright->addItem(QString());
        comboBoxTransientBright->addItem(QString());
        comboBoxTransientBright->addItem(QString());
        comboBoxTransientBright->addItem(QString());
        comboBoxTransientBright->setObjectName(QString::fromUtf8("comboBoxTransientBright"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(comboBoxTransientBright->sizePolicy().hasHeightForWidth());
        comboBoxTransientBright->setSizePolicy(sizePolicy2);

        horizontalLayout_22->addWidget(comboBoxTransientBright);

        labelTransientDurationBright = new QLabel(tabBright);
        labelTransientDurationBright->setObjectName(QString::fromUtf8("labelTransientDurationBright"));

        horizontalLayout_22->addWidget(labelTransientDurationBright);

        doubleSpinBoxTransientDurationBright = new QDoubleSpinBox(tabBright);
        doubleSpinBoxTransientDurationBright->setObjectName(QString::fromUtf8("doubleSpinBoxTransientDurationBright"));
        doubleSpinBoxTransientDurationBright->setMaximum(0.500000000000000);
        doubleSpinBoxTransientDurationBright->setSingleStep(0.010000000000000);

        horizontalLayout_22->addWidget(doubleSpinBoxTransientDurationBright);

        horizontalSliderTransientDurationBright = new ADM_QSlider(tabBright);
        horizontalSliderTransientDurationBright->setObjectName(QString::fromUtf8("horizontalSliderTransientDurationBright"));
        horizontalSliderTransientDurationBright->setMaximum(50);
        horizontalSliderTransientDurationBright->setOrientation(Qt::Horizontal);

        horizontalLayout_22->addWidget(horizontalSliderTransientDurationBright);


        verticalLayoutBright->addLayout(horizontalLayout_22);

        tabEffects->addTab(tabBright, QString());
        tabSat = new QWidget();
        tabSat->setObjectName(QString::fromUtf8("tabSat"));
        verticalLayoutSat = new QVBoxLayout(tabSat);
        verticalLayoutSat->setObjectName(QString::fromUtf8("verticalLayoutSat"));
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        checkBoxEnableSat = new QCheckBox(tabSat);
        checkBoxEnableSat->setObjectName(QString::fromUtf8("checkBoxEnableSat"));

        horizontalLayout_5->addWidget(checkBoxEnableSat);


        verticalLayoutSat->addLayout(horizontalLayout_5);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        labelSat = new QLabel(tabSat);
        labelSat->setObjectName(QString::fromUtf8("labelSat"));

        horizontalLayout_6->addWidget(labelSat);

        doubleSpinBoxPeakSat = new QDoubleSpinBox(tabSat);
        doubleSpinBoxPeakSat->setObjectName(QString::fromUtf8("doubleSpinBoxPeakSat"));
        doubleSpinBoxPeakSat->setMinimum(0.000000000000000);
        doubleSpinBoxPeakSat->setMaximum(10.000000000000000);
        doubleSpinBoxPeakSat->setSingleStep(0.010000000000000);

        horizontalLayout_6->addWidget(doubleSpinBoxPeakSat);

        horizontalSliderPeakSat = new ADM_QSlider(tabSat);
        horizontalSliderPeakSat->setObjectName(QString::fromUtf8("horizontalSliderPeakSat"));
        horizontalSliderPeakSat->setMinimum(0);
        horizontalSliderPeakSat->setMaximum(1000);
        horizontalSliderPeakSat->setOrientation(Qt::Horizontal);

        horizontalLayout_6->addWidget(horizontalSliderPeakSat);


        verticalLayoutSat->addLayout(horizontalLayout_6);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QString::fromUtf8("horizontalLayout_7"));
        labelTransientSat = new QLabel(tabSat);
        labelTransientSat->setObjectName(QString::fromUtf8("labelTransientSat"));

        horizontalLayout_7->addWidget(labelTransientSat);

        comboBoxTransientSat = new QComboBox(tabSat);
        comboBoxTransientSat->addItem(QString());
        comboBoxTransientSat->addItem(QString());
        comboBoxTransientSat->addItem(QString());
        comboBoxTransientSat->addItem(QString());
        comboBoxTransientSat->addItem(QString());
        comboBoxTransientSat->setObjectName(QString::fromUtf8("comboBoxTransientSat"));
        sizePolicy2.setHeightForWidth(comboBoxTransientSat->sizePolicy().hasHeightForWidth());
        comboBoxTransientSat->setSizePolicy(sizePolicy2);

        horizontalLayout_7->addWidget(comboBoxTransientSat);

        labelTransientDurationSat = new QLabel(tabSat);
        labelTransientDurationSat->setObjectName(QString::fromUtf8("labelTransientDurationSat"));

        horizontalLayout_7->addWidget(labelTransientDurationSat);

        doubleSpinBoxTransientDurationSat = new QDoubleSpinBox(tabSat);
        doubleSpinBoxTransientDurationSat->setObjectName(QString::fromUtf8("doubleSpinBoxTransientDurationSat"));
        doubleSpinBoxTransientDurationSat->setMaximum(0.500000000000000);
        doubleSpinBoxTransientDurationSat->setSingleStep(0.010000000000000);

        horizontalLayout_7->addWidget(doubleSpinBoxTransientDurationSat);

        horizontalSliderTransientDurationSat = new ADM_QSlider(tabSat);
        horizontalSliderTransientDurationSat->setObjectName(QString::fromUtf8("horizontalSliderTransientDurationSat"));
        horizontalSliderTransientDurationSat->setMaximum(50);
        horizontalSliderTransientDurationSat->setOrientation(Qt::Horizontal);

        horizontalLayout_7->addWidget(horizontalSliderTransientDurationSat);


        verticalLayoutSat->addLayout(horizontalLayout_7);

        tabEffects->addTab(tabSat, QString());
        tabBlend = new QWidget();
        tabBlend->setObjectName(QString::fromUtf8("tabBlend"));
        verticalLayoutBlend = new QVBoxLayout(tabBlend);
        verticalLayoutBlend->setObjectName(QString::fromUtf8("verticalLayoutBlend"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        checkBoxEnableBlend = new QCheckBox(tabBlend);
        checkBoxEnableBlend->setObjectName(QString::fromUtf8("checkBoxEnableBlend"));

        horizontalLayout_2->addWidget(checkBoxEnableBlend);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        labelPickColorBlend = new QLabel(tabBlend);
        labelPickColorBlend->setObjectName(QString::fromUtf8("labelPickColorBlend"));

        horizontalLayout_2->addWidget(labelPickColorBlend);

        pushButtonColorBlend = new QPushButton(tabBlend);
        pushButtonColorBlend->setObjectName(QString::fromUtf8("pushButtonColorBlend"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/color.png"), QSize(), QIcon::Normal, QIcon::Off);
        pushButtonColorBlend->setIcon(icon);

        horizontalLayout_2->addWidget(pushButtonColorBlend);

        lineEditColorBlend = new QLineEdit(tabBlend);
        lineEditColorBlend->setObjectName(QString::fromUtf8("lineEditColorBlend"));
        lineEditColorBlend->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lineEditColorBlend->sizePolicy().hasHeightForWidth());
        lineEditColorBlend->setSizePolicy(sizePolicy3);
        lineEditColorBlend->setMaximumSize(QSize(48, 16777215));
        lineEditColorBlend->setAutoFillBackground(true);
        lineEditColorBlend->setFrame(true);
        lineEditColorBlend->setAlignment(Qt::AlignCenter);
        lineEditColorBlend->setReadOnly(true);

        horizontalLayout_2->addWidget(lineEditColorBlend);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayoutBlend->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        labelPeakBlend = new QLabel(tabBlend);
        labelPeakBlend->setObjectName(QString::fromUtf8("labelPeakBlend"));

        horizontalLayout_3->addWidget(labelPeakBlend);

        doubleSpinBoxPeakBlend = new QDoubleSpinBox(tabBlend);
        doubleSpinBoxPeakBlend->setObjectName(QString::fromUtf8("doubleSpinBoxPeakBlend"));
        doubleSpinBoxPeakBlend->setMaximum(1.000000000000000);
        doubleSpinBoxPeakBlend->setSingleStep(0.010000000000000);

        horizontalLayout_3->addWidget(doubleSpinBoxPeakBlend);

        horizontalSliderPeakBlend = new ADM_QSlider(tabBlend);
        horizontalSliderPeakBlend->setObjectName(QString::fromUtf8("horizontalSliderPeakBlend"));
        horizontalSliderPeakBlend->setMaximum(100);
        horizontalSliderPeakBlend->setOrientation(Qt::Horizontal);

        horizontalLayout_3->addWidget(horizontalSliderPeakBlend);


        verticalLayoutBlend->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        labelTransientBlend = new QLabel(tabBlend);
        labelTransientBlend->setObjectName(QString::fromUtf8("labelTransientBlend"));

        horizontalLayout_4->addWidget(labelTransientBlend);

        comboBoxTransientBlend = new QComboBox(tabBlend);
        comboBoxTransientBlend->addItem(QString());
        comboBoxTransientBlend->addItem(QString());
        comboBoxTransientBlend->addItem(QString());
        comboBoxTransientBlend->addItem(QString());
        comboBoxTransientBlend->addItem(QString());
        comboBoxTransientBlend->setObjectName(QString::fromUtf8("comboBoxTransientBlend"));
        sizePolicy2.setHeightForWidth(comboBoxTransientBlend->sizePolicy().hasHeightForWidth());
        comboBoxTransientBlend->setSizePolicy(sizePolicy2);

        horizontalLayout_4->addWidget(comboBoxTransientBlend);

        labelTransientDurationBlend = new QLabel(tabBlend);
        labelTransientDurationBlend->setObjectName(QString::fromUtf8("labelTransientDurationBlend"));

        horizontalLayout_4->addWidget(labelTransientDurationBlend);

        doubleSpinBoxTransientDurationBlend = new QDoubleSpinBox(tabBlend);
        doubleSpinBoxTransientDurationBlend->setObjectName(QString::fromUtf8("doubleSpinBoxTransientDurationBlend"));
        doubleSpinBoxTransientDurationBlend->setMaximum(0.500000000000000);
        doubleSpinBoxTransientDurationBlend->setSingleStep(0.010000000000000);

        horizontalLayout_4->addWidget(doubleSpinBoxTransientDurationBlend);

        horizontalSliderTransientDurationBlend = new ADM_QSlider(tabBlend);
        horizontalSliderTransientDurationBlend->setObjectName(QString::fromUtf8("horizontalSliderTransientDurationBlend"));
        horizontalSliderTransientDurationBlend->setMaximum(50);
        horizontalSliderTransientDurationBlend->setOrientation(Qt::Horizontal);

        horizontalLayout_4->addWidget(horizontalSliderTransientDurationBlend);


        verticalLayoutBlend->addLayout(horizontalLayout_4);

        tabEffects->addTab(tabBlend, QString());
        tabBlur = new QWidget();
        tabBlur->setObjectName(QString::fromUtf8("tabBlur"));
        verticalLayoutBlur = new QVBoxLayout(tabBlur);
        verticalLayoutBlur->setObjectName(QString::fromUtf8("verticalLayoutBlur"));
        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName(QString::fromUtf8("horizontalLayout_8"));
        checkBoxEnableBlur = new QCheckBox(tabBlur);
        checkBoxEnableBlur->setObjectName(QString::fromUtf8("checkBoxEnableBlur"));

        horizontalLayout_8->addWidget(checkBoxEnableBlur);


        verticalLayoutBlur->addLayout(horizontalLayout_8);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName(QString::fromUtf8("horizontalLayout_9"));
        labelPeakBlur = new QLabel(tabBlur);
        labelPeakBlur->setObjectName(QString::fromUtf8("labelPeakBlur"));

        horizontalLayout_9->addWidget(labelPeakBlur);

        doubleSpinBoxPeakBlur = new QDoubleSpinBox(tabBlur);
        doubleSpinBoxPeakBlur->setObjectName(QString::fromUtf8("doubleSpinBoxPeakBlur"));
        doubleSpinBoxPeakBlur->setDecimals(0);
        doubleSpinBoxPeakBlur->setMaximum(255.000000000000000);
        doubleSpinBoxPeakBlur->setSingleStep(1.000000000000000);

        horizontalLayout_9->addWidget(doubleSpinBoxPeakBlur);

        horizontalSliderPeakBlur = new ADM_QSlider(tabBlur);
        horizontalSliderPeakBlur->setObjectName(QString::fromUtf8("horizontalSliderPeakBlur"));
        horizontalSliderPeakBlur->setMaximum(255);
        horizontalSliderPeakBlur->setOrientation(Qt::Horizontal);

        horizontalLayout_9->addWidget(horizontalSliderPeakBlur);


        verticalLayoutBlur->addLayout(horizontalLayout_9);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName(QString::fromUtf8("horizontalLayout_10"));
        labelTransientBlur = new QLabel(tabBlur);
        labelTransientBlur->setObjectName(QString::fromUtf8("labelTransientBlur"));

        horizontalLayout_10->addWidget(labelTransientBlur);

        comboBoxTransientBlur = new QComboBox(tabBlur);
        comboBoxTransientBlur->addItem(QString());
        comboBoxTransientBlur->addItem(QString());
        comboBoxTransientBlur->addItem(QString());
        comboBoxTransientBlur->addItem(QString());
        comboBoxTransientBlur->addItem(QString());
        comboBoxTransientBlur->setObjectName(QString::fromUtf8("comboBoxTransientBlur"));
        sizePolicy2.setHeightForWidth(comboBoxTransientBlur->sizePolicy().hasHeightForWidth());
        comboBoxTransientBlur->setSizePolicy(sizePolicy2);

        horizontalLayout_10->addWidget(comboBoxTransientBlur);

        labelTransientDurationBlur = new QLabel(tabBlur);
        labelTransientDurationBlur->setObjectName(QString::fromUtf8("labelTransientDurationBlur"));

        horizontalLayout_10->addWidget(labelTransientDurationBlur);

        doubleSpinBoxTransientDurationBlur = new QDoubleSpinBox(tabBlur);
        doubleSpinBoxTransientDurationBlur->setObjectName(QString::fromUtf8("doubleSpinBoxTransientDurationBlur"));
        doubleSpinBoxTransientDurationBlur->setMaximum(0.500000000000000);
        doubleSpinBoxTransientDurationBlur->setSingleStep(0.010000000000000);

        horizontalLayout_10->addWidget(doubleSpinBoxTransientDurationBlur);

        horizontalSliderTransientDurationBlur = new ADM_QSlider(tabBlur);
        horizontalSliderTransientDurationBlur->setObjectName(QString::fromUtf8("horizontalSliderTransientDurationBlur"));
        horizontalSliderTransientDurationBlur->setMaximum(50);
        horizontalSliderTransientDurationBlur->setOrientation(Qt::Horizontal);

        horizontalLayout_10->addWidget(horizontalSliderTransientDurationBlur);


        verticalLayoutBlur->addLayout(horizontalLayout_10);

        tabEffects->addTab(tabBlur, QString());
        tabRot = new QWidget();
        tabRot->setObjectName(QString::fromUtf8("tabRot"));
        verticalLayoutRot = new QVBoxLayout(tabRot);
        verticalLayoutRot->setObjectName(QString::fromUtf8("verticalLayoutRot"));
        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName(QString::fromUtf8("horizontalLayout_11"));
        checkBoxEnableRot = new QCheckBox(tabRot);
        checkBoxEnableRot->setObjectName(QString::fromUtf8("checkBoxEnableRot"));

        horizontalLayout_11->addWidget(checkBoxEnableRot);


        verticalLayoutRot->addLayout(horizontalLayout_11);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName(QString::fromUtf8("horizontalLayout_12"));
        labelPeakRot = new QLabel(tabRot);
        labelPeakRot->setObjectName(QString::fromUtf8("labelPeakRot"));

        horizontalLayout_12->addWidget(labelPeakRot);

        doubleSpinBoxPeakRot = new QDoubleSpinBox(tabRot);
        doubleSpinBoxPeakRot->setObjectName(QString::fromUtf8("doubleSpinBoxPeakRot"));
        doubleSpinBoxPeakRot->setMinimum(-720.000000000000000);
        doubleSpinBoxPeakRot->setMaximum(720.000000000000000);
        doubleSpinBoxPeakRot->setSingleStep(0.010000000000000);

        horizontalLayout_12->addWidget(doubleSpinBoxPeakRot);

        horizontalSliderPeakRot = new ADM_QSlider(tabRot);
        horizontalSliderPeakRot->setObjectName(QString::fromUtf8("horizontalSliderPeakRot"));
        horizontalSliderPeakRot->setMinimum(-72000);
        horizontalSliderPeakRot->setMaximum(72000);
        horizontalSliderPeakRot->setPageStep(100);
        horizontalSliderPeakRot->setOrientation(Qt::Horizontal);

        horizontalLayout_12->addWidget(horizontalSliderPeakRot);


        verticalLayoutRot->addLayout(horizontalLayout_12);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName(QString::fromUtf8("horizontalLayout_13"));
        labelTransientRot = new QLabel(tabRot);
        labelTransientRot->setObjectName(QString::fromUtf8("labelTransientRot"));

        horizontalLayout_13->addWidget(labelTransientRot);

        comboBoxTransientRot = new QComboBox(tabRot);
        comboBoxTransientRot->addItem(QString());
        comboBoxTransientRot->addItem(QString());
        comboBoxTransientRot->addItem(QString());
        comboBoxTransientRot->addItem(QString());
        comboBoxTransientRot->setObjectName(QString::fromUtf8("comboBoxTransientRot"));
        sizePolicy2.setHeightForWidth(comboBoxTransientRot->sizePolicy().hasHeightForWidth());
        comboBoxTransientRot->setSizePolicy(sizePolicy2);

        horizontalLayout_13->addWidget(comboBoxTransientRot);

        labelTransientDurationRot = new QLabel(tabRot);
        labelTransientDurationRot->setObjectName(QString::fromUtf8("labelTransientDurationRot"));

        horizontalLayout_13->addWidget(labelTransientDurationRot);

        doubleSpinBoxTransientDurationRot = new QDoubleSpinBox(tabRot);
        doubleSpinBoxTransientDurationRot->setObjectName(QString::fromUtf8("doubleSpinBoxTransientDurationRot"));
        doubleSpinBoxTransientDurationRot->setMaximum(0.500000000000000);
        doubleSpinBoxTransientDurationRot->setSingleStep(0.010000000000000);

        horizontalLayout_13->addWidget(doubleSpinBoxTransientDurationRot);

        horizontalSliderTransientDurationRot = new ADM_QSlider(tabRot);
        horizontalSliderTransientDurationRot->setObjectName(QString::fromUtf8("horizontalSliderTransientDurationRot"));
        horizontalSliderTransientDurationRot->setMaximum(50);
        horizontalSliderTransientDurationRot->setOrientation(Qt::Horizontal);

        horizontalLayout_13->addWidget(horizontalSliderTransientDurationRot);


        verticalLayoutRot->addLayout(horizontalLayout_13);

        tabEffects->addTab(tabRot, QString());
        tabZoom = new QWidget();
        tabZoom->setObjectName(QString::fromUtf8("tabZoom"));
        verticalLayoutZoom = new QVBoxLayout(tabZoom);
        verticalLayoutZoom->setObjectName(QString::fromUtf8("verticalLayoutZoom"));
        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName(QString::fromUtf8("horizontalLayout_14"));
        checkBoxEnableZoom = new QCheckBox(tabZoom);
        checkBoxEnableZoom->setObjectName(QString::fromUtf8("checkBoxEnableZoom"));

        horizontalLayout_14->addWidget(checkBoxEnableZoom);


        verticalLayoutZoom->addLayout(horizontalLayout_14);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName(QString::fromUtf8("horizontalLayout_15"));
        labelPeakZoom = new QLabel(tabZoom);
        labelPeakZoom->setObjectName(QString::fromUtf8("labelPeakZoom"));

        horizontalLayout_15->addWidget(labelPeakZoom);

        doubleSpinBoxPeakZoom = new QDoubleSpinBox(tabZoom);
        doubleSpinBoxPeakZoom->setObjectName(QString::fromUtf8("doubleSpinBoxPeakZoom"));
        doubleSpinBoxPeakZoom->setMinimum(1.000000000000000);
        doubleSpinBoxPeakZoom->setMaximum(100.000000000000000);
        doubleSpinBoxPeakZoom->setSingleStep(0.010000000000000);

        horizontalLayout_15->addWidget(doubleSpinBoxPeakZoom);

        horizontalSliderPeakZoom = new ADM_QSlider(tabZoom);
        horizontalSliderPeakZoom->setObjectName(QString::fromUtf8("horizontalSliderPeakZoom"));
        horizontalSliderPeakZoom->setMinimum(100);
        horizontalSliderPeakZoom->setMaximum(10000);
        horizontalSliderPeakZoom->setPageStep(1000);
        horizontalSliderPeakZoom->setOrientation(Qt::Horizontal);

        horizontalLayout_15->addWidget(horizontalSliderPeakZoom);


        verticalLayoutZoom->addLayout(horizontalLayout_15);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName(QString::fromUtf8("horizontalLayout_16"));
        labelTransientZoom = new QLabel(tabZoom);
        labelTransientZoom->setObjectName(QString::fromUtf8("labelTransientZoom"));

        horizontalLayout_16->addWidget(labelTransientZoom);

        comboBoxTransientZoom = new QComboBox(tabZoom);
        comboBoxTransientZoom->addItem(QString());
        comboBoxTransientZoom->addItem(QString());
        comboBoxTransientZoom->addItem(QString());
        comboBoxTransientZoom->addItem(QString());
        comboBoxTransientZoom->addItem(QString());
        comboBoxTransientZoom->setObjectName(QString::fromUtf8("comboBoxTransientZoom"));
        sizePolicy2.setHeightForWidth(comboBoxTransientZoom->sizePolicy().hasHeightForWidth());
        comboBoxTransientZoom->setSizePolicy(sizePolicy2);

        horizontalLayout_16->addWidget(comboBoxTransientZoom);

        labelTransientDurationZoom = new QLabel(tabZoom);
        labelTransientDurationZoom->setObjectName(QString::fromUtf8("labelTransientDurationZoom"));

        horizontalLayout_16->addWidget(labelTransientDurationZoom);

        doubleSpinBoxTransientDurationZoom = new QDoubleSpinBox(tabZoom);
        doubleSpinBoxTransientDurationZoom->setObjectName(QString::fromUtf8("doubleSpinBoxTransientDurationZoom"));
        doubleSpinBoxTransientDurationZoom->setMaximum(0.500000000000000);
        doubleSpinBoxTransientDurationZoom->setSingleStep(0.010000000000000);

        horizontalLayout_16->addWidget(doubleSpinBoxTransientDurationZoom);

        horizontalSliderTransientDurationZoom = new ADM_QSlider(tabZoom);
        horizontalSliderTransientDurationZoom->setObjectName(QString::fromUtf8("horizontalSliderTransientDurationZoom"));
        horizontalSliderTransientDurationZoom->setMaximum(50);
        horizontalSliderTransientDurationZoom->setOrientation(Qt::Horizontal);

        horizontalLayout_16->addWidget(horizontalSliderTransientDurationZoom);


        verticalLayoutZoom->addLayout(horizontalLayout_16);

        tabEffects->addTab(tabZoom, QString());
        tabVignette = new QWidget();
        tabVignette->setObjectName(QString::fromUtf8("tabVignette"));
        verticalLayoutVignette = new QVBoxLayout(tabVignette);
        verticalLayoutVignette->setObjectName(QString::fromUtf8("verticalLayoutVignette"));
        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName(QString::fromUtf8("horizontalLayout_17"));
        checkBoxEnableVignette = new QCheckBox(tabVignette);
        checkBoxEnableVignette->setObjectName(QString::fromUtf8("checkBoxEnableVignette"));

        horizontalLayout_17->addWidget(checkBoxEnableVignette);

        horizontalSpacer_4 = new QSpacerItem(10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_4);

        labelPickColorVignette = new QLabel(tabVignette);
        labelPickColorVignette->setObjectName(QString::fromUtf8("labelPickColorVignette"));

        horizontalLayout_17->addWidget(labelPickColorVignette);

        pushButtonColorVignette = new QPushButton(tabVignette);
        pushButtonColorVignette->setObjectName(QString::fromUtf8("pushButtonColorVignette"));
        pushButtonColorVignette->setIcon(icon);

        horizontalLayout_17->addWidget(pushButtonColorVignette);

        lineEditColorVignette = new QLineEdit(tabVignette);
        lineEditColorVignette->setObjectName(QString::fromUtf8("lineEditColorVignette"));
        lineEditColorVignette->setEnabled(false);
        sizePolicy3.setHeightForWidth(lineEditColorVignette->sizePolicy().hasHeightForWidth());
        lineEditColorVignette->setSizePolicy(sizePolicy3);
        lineEditColorVignette->setMaximumSize(QSize(48, 16777215));
        lineEditColorVignette->setAutoFillBackground(true);
        lineEditColorVignette->setFrame(true);
        lineEditColorVignette->setAlignment(Qt::AlignCenter);
        lineEditColorVignette->setReadOnly(true);

        horizontalLayout_17->addWidget(lineEditColorVignette);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_5);


        verticalLayoutVignette->addLayout(horizontalLayout_17);

        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName(QString::fromUtf8("horizontalLayout_18"));
        labelPeakVignette = new QLabel(tabVignette);
        labelPeakVignette->setObjectName(QString::fromUtf8("labelPeakVignette"));

        horizontalLayout_18->addWidget(labelPeakVignette);

        doubleSpinBoxPeakVignette = new QDoubleSpinBox(tabVignette);
        doubleSpinBoxPeakVignette->setObjectName(QString::fromUtf8("doubleSpinBoxPeakVignette"));
        doubleSpinBoxPeakVignette->setMaximum(1.000000000000000);
        doubleSpinBoxPeakVignette->setSingleStep(0.010000000000000);

        horizontalLayout_18->addWidget(doubleSpinBoxPeakVignette);

        horizontalSliderPeakVignette = new ADM_QSlider(tabVignette);
        horizontalSliderPeakVignette->setObjectName(QString::fromUtf8("horizontalSliderPeakVignette"));
        horizontalSliderPeakVignette->setMaximum(100);
        horizontalSliderPeakVignette->setOrientation(Qt::Horizontal);

        horizontalLayout_18->addWidget(horizontalSliderPeakVignette);


        verticalLayoutVignette->addLayout(horizontalLayout_18);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName(QString::fromUtf8("horizontalLayout_19"));
        labelTransientVignette = new QLabel(tabVignette);
        labelTransientVignette->setObjectName(QString::fromUtf8("labelTransientVignette"));

        horizontalLayout_19->addWidget(labelTransientVignette);

        comboBoxTransientVignette = new QComboBox(tabVignette);
        comboBoxTransientVignette->addItem(QString());
        comboBoxTransientVignette->addItem(QString());
        comboBoxTransientVignette->addItem(QString());
        comboBoxTransientVignette->addItem(QString());
        comboBoxTransientVignette->addItem(QString());
        comboBoxTransientVignette->setObjectName(QString::fromUtf8("comboBoxTransientVignette"));
        sizePolicy2.setHeightForWidth(comboBoxTransientVignette->sizePolicy().hasHeightForWidth());
        comboBoxTransientVignette->setSizePolicy(sizePolicy2);

        horizontalLayout_19->addWidget(comboBoxTransientVignette);

        labelTransientDurationVignette = new QLabel(tabVignette);
        labelTransientDurationVignette->setObjectName(QString::fromUtf8("labelTransientDurationVignette"));

        horizontalLayout_19->addWidget(labelTransientDurationVignette);

        doubleSpinBoxTransientDurationVignette = new QDoubleSpinBox(tabVignette);
        doubleSpinBoxTransientDurationVignette->setObjectName(QString::fromUtf8("doubleSpinBoxTransientDurationVignette"));
        doubleSpinBoxTransientDurationVignette->setMaximum(0.500000000000000);
        doubleSpinBoxTransientDurationVignette->setSingleStep(0.010000000000000);

        horizontalLayout_19->addWidget(doubleSpinBoxTransientDurationVignette);

        horizontalSliderTransientDurationVignette = new ADM_QSlider(tabVignette);
        horizontalSliderTransientDurationVignette->setObjectName(QString::fromUtf8("horizontalSliderTransientDurationVignette"));
        horizontalSliderTransientDurationVignette->setMaximum(50);
        horizontalSliderTransientDurationVignette->setOrientation(Qt::Horizontal);

        horizontalLayout_19->addWidget(horizontalSliderTransientDurationVignette);


        verticalLayoutVignette->addLayout(horizontalLayout_19);

        tabEffects->addTab(tabVignette, QString());

        gridLayout->addWidget(tabEffects, 0, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        graphicsViewTransient = new QGraphicsView(fadeThroughDialog);
        graphicsViewTransient->setObjectName(QString::fromUtf8("graphicsViewTransient"));
        sizePolicy3.setHeightForWidth(graphicsViewTransient->sizePolicy().hasHeightForWidth());
        graphicsViewTransient->setSizePolicy(sizePolicy3);
        graphicsViewTransient->setMinimumSize(QSize(260, 132));
        graphicsViewTransient->setMaximumSize(QSize(260, 132));
        graphicsViewTransient->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        graphicsViewTransient->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        verticalLayout_2->addWidget(graphicsViewTransient);


        gridLayout->addLayout(verticalLayout_2, 0, 2, 2, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(fadeThroughDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(fadeThroughDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(fadeThroughDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(fadeThroughDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), fadeThroughDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), fadeThroughDialog, SLOT(reject()));

        tabEffects->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(fadeThroughDialog);
    } // setupUi

    void retranslateUi(QDialog *fadeThroughDialog)
    {
        fadeThroughDialog->setWindowTitle(QCoreApplication::translate("fadeThroughDialog", "Fade through", nullptr));
        labelTScope->setText(QCoreApplication::translate("fadeThroughDialog", "Time scope: ", nullptr));
        labelCenter->setText(QCoreApplication::translate("fadeThroughDialog", "Center: ", nullptr));
        labelDuration->setText(QCoreApplication::translate("fadeThroughDialog", "Duration: ", nullptr));
        pushButtonTManual->setText(QCoreApplication::translate("fadeThroughDialog", "Manual time entry", nullptr));
        pushButtonTMarker->setText(QCoreApplication::translate("fadeThroughDialog", "Set from A-B markers", nullptr));
        pushButtonTCenter->setText(QCoreApplication::translate("fadeThroughDialog", "Set center as A marker, duration is 2\303\227|A-B|", nullptr));
        checkBoxEnableBright->setText(QCoreApplication::translate("fadeThroughDialog", "Enable", nullptr));
        labelBright->setText(QCoreApplication::translate("fadeThroughDialog", "Brightness", nullptr));
        labelTransientBright->setText(QCoreApplication::translate("fadeThroughDialog", "Transient", nullptr));
        comboBoxTransientBright->setItemText(0, QCoreApplication::translate("fadeThroughDialog", "Raised cosine", nullptr));
        comboBoxTransientBright->setItemText(1, QCoreApplication::translate("fadeThroughDialog", "Ramp", nullptr));
        comboBoxTransientBright->setItemText(2, QCoreApplication::translate("fadeThroughDialog", "Quadratic", nullptr));
        comboBoxTransientBright->setItemText(3, QCoreApplication::translate("fadeThroughDialog", "Inverse quadratic", nullptr));
        comboBoxTransientBright->setItemText(4, QCoreApplication::translate("fadeThroughDialog", "Exponential", nullptr));

        labelTransientDurationBright->setText(QCoreApplication::translate("fadeThroughDialog", "duration", nullptr));
        tabEffects->setTabText(tabEffects->indexOf(tabBright), QCoreApplication::translate("fadeThroughDialog", "Brightness", nullptr));
        checkBoxEnableSat->setText(QCoreApplication::translate("fadeThroughDialog", "Enable", nullptr));
        labelSat->setText(QCoreApplication::translate("fadeThroughDialog", "Saturation", nullptr));
        labelTransientSat->setText(QCoreApplication::translate("fadeThroughDialog", "Transient", nullptr));
        comboBoxTransientSat->setItemText(0, QCoreApplication::translate("fadeThroughDialog", "Raised cosine", nullptr));
        comboBoxTransientSat->setItemText(1, QCoreApplication::translate("fadeThroughDialog", "Ramp", nullptr));
        comboBoxTransientSat->setItemText(2, QCoreApplication::translate("fadeThroughDialog", "Quadratic", nullptr));
        comboBoxTransientSat->setItemText(3, QCoreApplication::translate("fadeThroughDialog", "Inverse quadratic", nullptr));
        comboBoxTransientSat->setItemText(4, QCoreApplication::translate("fadeThroughDialog", "Exponential", nullptr));

        labelTransientDurationSat->setText(QCoreApplication::translate("fadeThroughDialog", "duration", nullptr));
        tabEffects->setTabText(tabEffects->indexOf(tabSat), QCoreApplication::translate("fadeThroughDialog", "Saturation", nullptr));
        checkBoxEnableBlend->setText(QCoreApplication::translate("fadeThroughDialog", "Enable", nullptr));
        labelPickColorBlend->setText(QCoreApplication::translate("fadeThroughDialog", "Pick color", nullptr));
        pushButtonColorBlend->setText(QString());
        labelPeakBlend->setText(QCoreApplication::translate("fadeThroughDialog", "Peak amount", nullptr));
        labelTransientBlend->setText(QCoreApplication::translate("fadeThroughDialog", "Transient", nullptr));
        comboBoxTransientBlend->setItemText(0, QCoreApplication::translate("fadeThroughDialog", "Raised cosine", nullptr));
        comboBoxTransientBlend->setItemText(1, QCoreApplication::translate("fadeThroughDialog", "Ramp", nullptr));
        comboBoxTransientBlend->setItemText(2, QCoreApplication::translate("fadeThroughDialog", "Quadratic", nullptr));
        comboBoxTransientBlend->setItemText(3, QCoreApplication::translate("fadeThroughDialog", "Inverse quadratic", nullptr));
        comboBoxTransientBlend->setItemText(4, QCoreApplication::translate("fadeThroughDialog", "Exponential", nullptr));

        labelTransientDurationBlend->setText(QCoreApplication::translate("fadeThroughDialog", "duration", nullptr));
        tabEffects->setTabText(tabEffects->indexOf(tabBlend), QCoreApplication::translate("fadeThroughDialog", "Color blend", nullptr));
        checkBoxEnableBlur->setText(QCoreApplication::translate("fadeThroughDialog", "Enable", nullptr));
        labelPeakBlur->setText(QCoreApplication::translate("fadeThroughDialog", "Blur radius", nullptr));
        labelTransientBlur->setText(QCoreApplication::translate("fadeThroughDialog", "Transient", nullptr));
        comboBoxTransientBlur->setItemText(0, QCoreApplication::translate("fadeThroughDialog", "Raised cosine", nullptr));
        comboBoxTransientBlur->setItemText(1, QCoreApplication::translate("fadeThroughDialog", "Ramp", nullptr));
        comboBoxTransientBlur->setItemText(2, QCoreApplication::translate("fadeThroughDialog", "Quadratic", nullptr));
        comboBoxTransientBlur->setItemText(3, QCoreApplication::translate("fadeThroughDialog", "Inverse quadratic", nullptr));
        comboBoxTransientBlur->setItemText(4, QCoreApplication::translate("fadeThroughDialog", "Exponential", nullptr));

        labelTransientDurationBlur->setText(QCoreApplication::translate("fadeThroughDialog", "duration", nullptr));
        tabEffects->setTabText(tabEffects->indexOf(tabBlur), QCoreApplication::translate("fadeThroughDialog", "Blur", nullptr));
        checkBoxEnableRot->setText(QCoreApplication::translate("fadeThroughDialog", "Enable", nullptr));
        labelPeakRot->setText(QCoreApplication::translate("fadeThroughDialog", "Peak angle", nullptr));
        labelTransientRot->setText(QCoreApplication::translate("fadeThroughDialog", "Transient", nullptr));
        comboBoxTransientRot->setItemText(0, QCoreApplication::translate("fadeThroughDialog", "Raised cosine", nullptr));
        comboBoxTransientRot->setItemText(1, QCoreApplication::translate("fadeThroughDialog", "Ramp", nullptr));
        comboBoxTransientRot->setItemText(2, QCoreApplication::translate("fadeThroughDialog", "Quadratic", nullptr));
        comboBoxTransientRot->setItemText(3, QCoreApplication::translate("fadeThroughDialog", "Inverse quadratic", nullptr));

        labelTransientDurationRot->setText(QCoreApplication::translate("fadeThroughDialog", "duration", nullptr));
        tabEffects->setTabText(tabEffects->indexOf(tabRot), QCoreApplication::translate("fadeThroughDialog", "Rotate", nullptr));
        checkBoxEnableZoom->setText(QCoreApplication::translate("fadeThroughDialog", "Enable", nullptr));
        labelPeakZoom->setText(QCoreApplication::translate("fadeThroughDialog", "Peak zoom", nullptr));
        labelTransientZoom->setText(QCoreApplication::translate("fadeThroughDialog", "Transient", nullptr));
        comboBoxTransientZoom->setItemText(0, QCoreApplication::translate("fadeThroughDialog", "Raised cosine", nullptr));
        comboBoxTransientZoom->setItemText(1, QCoreApplication::translate("fadeThroughDialog", "Ramp", nullptr));
        comboBoxTransientZoom->setItemText(2, QCoreApplication::translate("fadeThroughDialog", "Quadratic", nullptr));
        comboBoxTransientZoom->setItemText(3, QCoreApplication::translate("fadeThroughDialog", "Inverse quadratic", nullptr));
        comboBoxTransientZoom->setItemText(4, QCoreApplication::translate("fadeThroughDialog", "Exponential", nullptr));

        labelTransientDurationZoom->setText(QCoreApplication::translate("fadeThroughDialog", "duration", nullptr));
        tabEffects->setTabText(tabEffects->indexOf(tabZoom), QCoreApplication::translate("fadeThroughDialog", "Zoom", nullptr));
        checkBoxEnableVignette->setText(QCoreApplication::translate("fadeThroughDialog", "Enable", nullptr));
        labelPickColorVignette->setText(QCoreApplication::translate("fadeThroughDialog", "Pick color", nullptr));
        pushButtonColorVignette->setText(QString());
        labelPeakVignette->setText(QCoreApplication::translate("fadeThroughDialog", "Peak opening", nullptr));
        labelTransientVignette->setText(QCoreApplication::translate("fadeThroughDialog", "Transient", nullptr));
        comboBoxTransientVignette->setItemText(0, QCoreApplication::translate("fadeThroughDialog", "Raised cosine", nullptr));
        comboBoxTransientVignette->setItemText(1, QCoreApplication::translate("fadeThroughDialog", "Ramp", nullptr));
        comboBoxTransientVignette->setItemText(2, QCoreApplication::translate("fadeThroughDialog", "Quadratic", nullptr));
        comboBoxTransientVignette->setItemText(3, QCoreApplication::translate("fadeThroughDialog", "Inverse quadratic", nullptr));
        comboBoxTransientVignette->setItemText(4, QCoreApplication::translate("fadeThroughDialog", "Exponential", nullptr));

        labelTransientDurationVignette->setText(QCoreApplication::translate("fadeThroughDialog", "duration", nullptr));
        tabEffects->setTabText(tabEffects->indexOf(tabVignette), QCoreApplication::translate("fadeThroughDialog", "Vignette", nullptr));
    } // retranslateUi

};

namespace Ui {
    class fadeThroughDialog: public Ui_fadeThroughDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FADETHROUGH_H
