/********************************************************************************
** Form generated from reading UI file 'quickfilter.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUICKFILTER_H
#define UI_QUICKFILTER_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_quickFilterDialog
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *listsGrid;
    QLabel *labelAvailable;
    QListWidget *listWidgetAvailable;
    QSpacerItem *bottomSpacer;
    QHBoxLayout *bottomBox;
    QLineEdit *lineEditSearch;
    QSpacerItem *bboxSpacer;
    QPushButton *buttonClose;

    void setupUi(QDialog *quickFilterDialog)
    {
        if (quickFilterDialog->objectName().isEmpty())
            quickFilterDialog->setObjectName(QString::fromUtf8("quickFilterDialog"));
        quickFilterDialog->resize(360, 463);
        quickFilterDialog->setMinimumSize(QSize(0, 0));
        vboxLayout = new QVBoxLayout(quickFilterDialog);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        listsGrid = new QGridLayout();
        listsGrid->setSpacing(6);
        listsGrid->setObjectName(QString::fromUtf8("listsGrid"));
        listsGrid->setContentsMargins(0, 0, 0, 0);
        labelAvailable = new QLabel(quickFilterDialog);
        labelAvailable->setObjectName(QString::fromUtf8("labelAvailable"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelAvailable->sizePolicy().hasHeightForWidth());
        labelAvailable->setSizePolicy(sizePolicy);
        labelAvailable->setTextFormat(Qt::RichText);

        listsGrid->addWidget(labelAvailable, 0, 0, 1, 1);

        listWidgetAvailable = new QListWidget(quickFilterDialog);
        listWidgetAvailable->setObjectName(QString::fromUtf8("listWidgetAvailable"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(listWidgetAvailable->sizePolicy().hasHeightForWidth());
        listWidgetAvailable->setSizePolicy(sizePolicy1);
        listWidgetAvailable->setMinimumSize(QSize(340, 360));
        listWidgetAvailable->setSpacing(2);

        listsGrid->addWidget(listWidgetAvailable, 1, 0, 2, 2);


        vboxLayout->addLayout(listsGrid);

        bottomSpacer = new QSpacerItem(16, 16, QSizePolicy::Minimum, QSizePolicy::Fixed);

        vboxLayout->addItem(bottomSpacer);

        bottomBox = new QHBoxLayout();
        bottomBox->setSpacing(6);
        bottomBox->setObjectName(QString::fromUtf8("bottomBox"));
        bottomBox->setContentsMargins(0, 0, 0, 0);
        lineEditSearch = new QLineEdit(quickFilterDialog);
        lineEditSearch->setObjectName(QString::fromUtf8("lineEditSearch"));

        bottomBox->addWidget(lineEditSearch);

        bboxSpacer = new QSpacerItem(40, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        bottomBox->addItem(bboxSpacer);

        buttonClose = new QPushButton(quickFilterDialog);
        buttonClose->setObjectName(QString::fromUtf8("buttonClose"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/new/prefix1/common/ADM_icons/videoFilter/close.png"), QSize(), QIcon::Normal, QIcon::Off);
        buttonClose->setIcon(icon);

        bottomBox->addWidget(buttonClose);


        vboxLayout->addLayout(bottomBox);

        QWidget::setTabOrder(listWidgetAvailable, buttonClose);

        retranslateUi(quickFilterDialog);

        buttonClose->setDefault(true);


        QMetaObject::connectSlotsByName(quickFilterDialog);
    } // setupUi

    void retranslateUi(QDialog *quickFilterDialog)
    {
        quickFilterDialog->setWindowTitle(QCoreApplication::translate("quickFilterDialog", "Add Partial Video Filter", nullptr));
        labelAvailable->setText(QCoreApplication::translate("quickFilterDialog", "<big><b>Available Filters</b></big>", nullptr));
        lineEditSearch->setPlaceholderText(QCoreApplication::translate("quickFilterDialog", "Type to narrow the list", nullptr));
        buttonClose->setText(QCoreApplication::translate("quickFilterDialog", "&Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class quickFilterDialog: public Ui_quickFilterDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QUICKFILTER_H
