/********************************************************************************
** Form generated from reading UI file 'imageStab.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGESTAB_H
#define UI_IMAGESTAB_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_imageStabDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *labelFilterSmoothing;
    ADM_SliderIndicator *horizontalSliderSmoothing;
    QLabel *labelGravity;
    ADM_SliderIndicator *horizontalSliderGravity;
    QHBoxLayout *horizontalLayout_2;
    QLabel *labelInterpolation;
    QComboBox *comboBoxAlgo;
    QLabel *labelMotionEstimation;
    QComboBox *comboBoxMotionEstimation;
    QSpacerItem *horizontalSpacer;
    QCheckBox *checkBoxAutoGravity;
    QGridLayout *gridLayout;
    ADM_SliderIndicator *horizontalSliderSceneThreshold;
    QLabel *labelChromaShiftAngle;
    QLabel *labelZoom;
    QProgressBar *progressBarScene;
    ADM_SliderIndicator *horizontalSliderZoom;
    QLineEdit *lineEditNewScene;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *imageStabDialog)
    {
        if (imageStabDialog->objectName().isEmpty())
            imageStabDialog->setObjectName(QString::fromUtf8("imageStabDialog"));
        imageStabDialog->resize(523, 364);
        verticalLayout = new QVBoxLayout(imageStabDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        labelFilterSmoothing = new QLabel(imageStabDialog);
        labelFilterSmoothing->setObjectName(QString::fromUtf8("labelFilterSmoothing"));

        horizontalLayout->addWidget(labelFilterSmoothing);

        horizontalSliderSmoothing = new ADM_SliderIndicator(imageStabDialog);
        horizontalSliderSmoothing->setObjectName(QString::fromUtf8("horizontalSliderSmoothing"));
        horizontalSliderSmoothing->setMaximum(100);
        horizontalSliderSmoothing->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(horizontalSliderSmoothing);

        labelGravity = new QLabel(imageStabDialog);
        labelGravity->setObjectName(QString::fromUtf8("labelGravity"));

        horizontalLayout->addWidget(labelGravity);

        horizontalSliderGravity = new ADM_SliderIndicator(imageStabDialog);
        horizontalSliderGravity->setObjectName(QString::fromUtf8("horizontalSliderGravity"));
        horizontalSliderGravity->setMaximum(100);
        horizontalSliderGravity->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(horizontalSliderGravity);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        labelInterpolation = new QLabel(imageStabDialog);
        labelInterpolation->setObjectName(QString::fromUtf8("labelInterpolation"));

        horizontalLayout_2->addWidget(labelInterpolation);

        comboBoxAlgo = new QComboBox(imageStabDialog);
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->addItem(QString());
        comboBoxAlgo->setObjectName(QString::fromUtf8("comboBoxAlgo"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboBoxAlgo->sizePolicy().hasHeightForWidth());
        comboBoxAlgo->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(comboBoxAlgo);

        labelMotionEstimation = new QLabel(imageStabDialog);
        labelMotionEstimation->setObjectName(QString::fromUtf8("labelMotionEstimation"));

        horizontalLayout_2->addWidget(labelMotionEstimation);

        comboBoxMotionEstimation = new QComboBox(imageStabDialog);
        comboBoxMotionEstimation->addItem(QString());
        comboBoxMotionEstimation->addItem(QString());
        comboBoxMotionEstimation->setObjectName(QString::fromUtf8("comboBoxMotionEstimation"));

        horizontalLayout_2->addWidget(comboBoxMotionEstimation);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        checkBoxAutoGravity = new QCheckBox(imageStabDialog);
        checkBoxAutoGravity->setObjectName(QString::fromUtf8("checkBoxAutoGravity"));

        horizontalLayout_2->addWidget(checkBoxAutoGravity);


        verticalLayout->addLayout(horizontalLayout_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        horizontalSliderSceneThreshold = new ADM_SliderIndicator(imageStabDialog);
        horizontalSliderSceneThreshold->setObjectName(QString::fromUtf8("horizontalSliderSceneThreshold"));
        horizontalSliderSceneThreshold->setMaximum(100);
        horizontalSliderSceneThreshold->setPageStep(10);
        horizontalSliderSceneThreshold->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderSceneThreshold, 1, 1, 1, 1);

        labelChromaShiftAngle = new QLabel(imageStabDialog);
        labelChromaShiftAngle->setObjectName(QString::fromUtf8("labelChromaShiftAngle"));

        gridLayout->addWidget(labelChromaShiftAngle, 1, 0, 1, 1);

        labelZoom = new QLabel(imageStabDialog);
        labelZoom->setObjectName(QString::fromUtf8("labelZoom"));

        gridLayout->addWidget(labelZoom, 0, 0, 1, 1);

        progressBarScene = new QProgressBar(imageStabDialog);
        progressBarScene->setObjectName(QString::fromUtf8("progressBarScene"));
        progressBarScene->setEnabled(false);
        progressBarScene->setValue(24);
        progressBarScene->setFormat(QString::fromUtf8(""));

        gridLayout->addWidget(progressBarScene, 2, 1, 1, 1);

        horizontalSliderZoom = new ADM_SliderIndicator(imageStabDialog);
        horizontalSliderZoom->setObjectName(QString::fromUtf8("horizontalSliderZoom"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(horizontalSliderZoom->sizePolicy().hasHeightForWidth());
        horizontalSliderZoom->setSizePolicy(sizePolicy1);
        horizontalSliderZoom->setMinimum(100);
        horizontalSliderZoom->setMaximum(250);
        horizontalSliderZoom->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(horizontalSliderZoom, 0, 1, 1, 1);

        lineEditNewScene = new QLineEdit(imageStabDialog);
        lineEditNewScene->setObjectName(QString::fromUtf8("lineEditNewScene"));
        lineEditNewScene->setEnabled(false);
        QSizePolicy sizePolicy2(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lineEditNewScene->sizePolicy().hasHeightForWidth());
        lineEditNewScene->setSizePolicy(sizePolicy2);
        lineEditNewScene->setMaximumSize(QSize(48, 16777215));

        gridLayout->addWidget(lineEditNewScene, 2, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(imageStabDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(imageStabDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(imageStabDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(imageStabDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), imageStabDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), imageStabDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(imageStabDialog);
    } // setupUi

    void retranslateUi(QDialog *imageStabDialog)
    {
        imageStabDialog->setWindowTitle(QCoreApplication::translate("imageStabDialog", "Image stabilizer", nullptr));
        labelFilterSmoothing->setText(QCoreApplication::translate("imageStabDialog", "Smoothing", nullptr));
        labelGravity->setText(QCoreApplication::translate("imageStabDialog", "Gravity", nullptr));
        labelInterpolation->setText(QCoreApplication::translate("imageStabDialog", "Interpolation", nullptr));
        comboBoxAlgo->setItemText(0, QCoreApplication::translate("imageStabDialog", "Bilinear", nullptr));
        comboBoxAlgo->setItemText(1, QCoreApplication::translate("imageStabDialog", "Bicubic", nullptr));

        labelMotionEstimation->setText(QCoreApplication::translate("imageStabDialog", "Motion estimation", nullptr));
        comboBoxMotionEstimation->setItemText(0, QCoreApplication::translate("imageStabDialog", "accurate", nullptr));
        comboBoxMotionEstimation->setItemText(1, QCoreApplication::translate("imageStabDialog", "fast", nullptr));

        checkBoxAutoGravity->setText(QCoreApplication::translate("imageStabDialog", "Auto Gravity", nullptr));
        labelChromaShiftAngle->setText(QCoreApplication::translate("imageStabDialog", "Scene threshold", nullptr));
        labelZoom->setText(QCoreApplication::translate("imageStabDialog", "Zoom", nullptr));
    } // retranslateUi

};

namespace Ui {
    class imageStabDialog: public Ui_imageStabDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IMAGESTAB_H
