/********************************************************************************
** Form generated from reading UI file 'msharpen.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MSHARPEN_H
#define UI_MSHARPEN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_msharpenDialog
{
public:
    QGridLayout *gridLayout_2;
    QHBoxLayout *toolboxLayout;
    QDialogButtonBox *buttonBox;
    QGraphicsView *graphicsView;
    QGridLayout *mainControls;
    QCheckBox *checkBoxChroma;
    QLabel *labelStrength;
    QCheckBox *checkBoxHQ;
    QLabel *labelThreshold;
    QCheckBox *checkBoxMask;
    QSpinBox *spinBoxStrength;
    QSpinBox *spinBoxThreshold;
    QSpacerItem *spacerItem;
    QSlider *horizontalSliderStrength;
    QSlider *horizontalSliderThreshold;
    QSpacerItem *horizontalSpacer;
    ADM_flyNavSlider *horizontalSlider;

    void setupUi(QDialog *msharpenDialog)
    {
        if (msharpenDialog->objectName().isEmpty())
            msharpenDialog->setObjectName(QString::fromUtf8("msharpenDialog"));
        msharpenDialog->resize(551, 382);
        msharpenDialog->setModal(true);
        gridLayout_2 = new QGridLayout(msharpenDialog);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        gridLayout_2->addLayout(toolboxLayout, 2, 0, 4, 2);

        buttonBox = new QDialogButtonBox(msharpenDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        gridLayout_2->addWidget(buttonBox, 9, 0, 1, 2);

        graphicsView = new QGraphicsView(msharpenDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        gridLayout_2->addWidget(graphicsView, 7, 0, 1, 2);

        mainControls = new QGridLayout();
        mainControls->setObjectName(QString::fromUtf8("mainControls"));
        checkBoxChroma = new QCheckBox(msharpenDialog);
        checkBoxChroma->setObjectName(QString::fromUtf8("checkBoxChroma"));

        mainControls->addWidget(checkBoxChroma, 3, 1, 1, 1);

        labelStrength = new QLabel(msharpenDialog);
        labelStrength->setObjectName(QString::fromUtf8("labelStrength"));

        mainControls->addWidget(labelStrength, 0, 0, 1, 1);

        checkBoxHQ = new QCheckBox(msharpenDialog);
        checkBoxHQ->setObjectName(QString::fromUtf8("checkBoxHQ"));

        mainControls->addWidget(checkBoxHQ, 3, 0, 1, 1);

        labelThreshold = new QLabel(msharpenDialog);
        labelThreshold->setObjectName(QString::fromUtf8("labelThreshold"));

        mainControls->addWidget(labelThreshold, 1, 0, 1, 1);

        checkBoxMask = new QCheckBox(msharpenDialog);
        checkBoxMask->setObjectName(QString::fromUtf8("checkBoxMask"));

        mainControls->addWidget(checkBoxMask, 3, 2, 1, 1);

        spinBoxStrength = new QSpinBox(msharpenDialog);
        spinBoxStrength->setObjectName(QString::fromUtf8("spinBoxStrength"));
        spinBoxStrength->setMinimum(0);
        spinBoxStrength->setMaximum(255);

        mainControls->addWidget(spinBoxStrength, 0, 4, 1, 1);

        spinBoxThreshold = new QSpinBox(msharpenDialog);
        spinBoxThreshold->setObjectName(QString::fromUtf8("spinBoxThreshold"));
        spinBoxThreshold->setMinimum(0);
        spinBoxThreshold->setMaximum(255);

        mainControls->addWidget(spinBoxThreshold, 1, 4, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        mainControls->addItem(spacerItem, 0, 5, 1, 1);

        horizontalSliderStrength = new QSlider(msharpenDialog);
        horizontalSliderStrength->setObjectName(QString::fromUtf8("horizontalSliderStrength"));
        horizontalSliderStrength->setMaximum(255);
        horizontalSliderStrength->setOrientation(Qt::Horizontal);

        mainControls->addWidget(horizontalSliderStrength, 0, 1, 1, 3);

        horizontalSliderThreshold = new QSlider(msharpenDialog);
        horizontalSliderThreshold->setObjectName(QString::fromUtf8("horizontalSliderThreshold"));
        horizontalSliderThreshold->setMaximum(255);
        horizontalSliderThreshold->setOrientation(Qt::Horizontal);

        mainControls->addWidget(horizontalSliderThreshold, 1, 1, 1, 3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        mainControls->addItem(horizontalSpacer, 3, 3, 1, 1);


        gridLayout_2->addLayout(mainControls, 0, 0, 1, 1);

        horizontalSlider = new ADM_flyNavSlider(msharpenDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        gridLayout_2->addWidget(horizontalSlider, 6, 0, 1, 1);


        retranslateUi(msharpenDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), msharpenDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), msharpenDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(msharpenDialog);
    } // setupUi

    void retranslateUi(QDialog *msharpenDialog)
    {
        msharpenDialog->setWindowTitle(QCoreApplication::translate("msharpenDialog", "MSharpen", nullptr));
        checkBoxChroma->setText(QCoreApplication::translate("msharpenDialog", "Process chroma", nullptr));
        labelStrength->setText(QCoreApplication::translate("msharpenDialog", "Strength", nullptr));
        checkBoxHQ->setText(QCoreApplication::translate("msharpenDialog", "HighQuality", nullptr));
        labelThreshold->setText(QCoreApplication::translate("msharpenDialog", "Threshold", nullptr));
        checkBoxMask->setText(QCoreApplication::translate("msharpenDialog", "Mask", nullptr));
    } // retranslateUi

};

namespace Ui {
    class msharpenDialog: public Ui_msharpenDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MSHARPEN_H
