/********************************************************************************
** Form generated from reading UI file 'artPixelize.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTPIXELIZE_H
#define UI_ARTPIXELIZE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artPixelizeDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *labelPSize;
    QSpinBox *spinBoxPW;
    QLabel *labelMult;
    QSpinBox *spinBoxPH;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artPixelizeDialog)
    {
        if (artPixelizeDialog->objectName().isEmpty())
            artPixelizeDialog->setObjectName(QString::fromUtf8("artPixelizeDialog"));
        artPixelizeDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(artPixelizeDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        labelPSize = new QLabel(artPixelizeDialog);
        labelPSize->setObjectName(QString::fromUtf8("labelPSize"));

        horizontalLayout->addWidget(labelPSize);

        spinBoxPW = new QSpinBox(artPixelizeDialog);
        spinBoxPW->setObjectName(QString::fromUtf8("spinBoxPW"));
        spinBoxPW->setMinimum(2);
        spinBoxPW->setMaximum(256);
        spinBoxPW->setSingleStep(2);

        horizontalLayout->addWidget(spinBoxPW);

        labelMult = new QLabel(artPixelizeDialog);
        labelMult->setObjectName(QString::fromUtf8("labelMult"));

        horizontalLayout->addWidget(labelMult);

        spinBoxPH = new QSpinBox(artPixelizeDialog);
        spinBoxPH->setObjectName(QString::fromUtf8("spinBoxPH"));
        spinBoxPH->setMinimum(2);
        spinBoxPH->setMaximum(256);
        spinBoxPH->setSingleStep(2);

        horizontalLayout->addWidget(spinBoxPH);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artPixelizeDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artPixelizeDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artPixelizeDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(artPixelizeDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artPixelizeDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artPixelizeDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artPixelizeDialog);
    } // setupUi

    void retranslateUi(QDialog *artPixelizeDialog)
    {
        artPixelizeDialog->setWindowTitle(QCoreApplication::translate("artPixelizeDialog", "Pixelize", nullptr));
        labelPSize->setText(QCoreApplication::translate("artPixelizeDialog", "Pixel size", nullptr));
        labelMult->setText(QCoreApplication::translate("artPixelizeDialog", "x", nullptr));
    } // retranslateUi

};

namespace Ui {
    class artPixelizeDialog: public Ui_artPixelizeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTPIXELIZE_H
