static const AVOutputFormat * const muxer_list[] = {
    &ff_adts_muxer,
    &ff_flv_muxer,
    &ff_latm_muxer,
    &ff_matroska_muxer,
    &ff_mov_muxer,
    &ff_mp4_muxer,
    &ff_mpeg1vcd_muxer,
    &ff_mpeg2dvd_muxer,
    &ff_mpeg2svcd_muxer,
    &ff_mpegts_muxer,
    &ff_psp_muxer,
    &ff_webm_muxer,
    NULL };
