/********************************************************************************
** Form generated from reading UI file 'uiProgress.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UIPROGRESS_H
#define UI_UIPROGRESS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DialogProgress
{
public:
    QHBoxLayout *horizontalLayout;
    QSplitter *splitter;
    QWidget *widget;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLabel *labelJobCount;
    QLabel *label;
    QLabel *labelOutputFile_2;
    QProgressBar *progressBar;

    void setupUi(QDialog *DialogProgress)
    {
        if (DialogProgress->objectName().isEmpty())
            DialogProgress->setObjectName(QString::fromUtf8("DialogProgress"));
        DialogProgress->setWindowModality(Qt::ApplicationModal);
        DialogProgress->resize(286, 110);
        horizontalLayout = new QHBoxLayout(DialogProgress);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        splitter = new QSplitter(DialogProgress);
        splitter->setObjectName(QString::fromUtf8("splitter"));
        splitter->setOrientation(Qt::Vertical);
        widget = new QWidget(splitter);
        widget->setObjectName(QString::fromUtf8("widget"));
        gridLayout = new QGridLayout(widget);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(widget);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        labelJobCount = new QLabel(widget);
        labelJobCount->setObjectName(QString::fromUtf8("labelJobCount"));

        gridLayout->addWidget(labelJobCount, 0, 1, 1, 1);

        label = new QLabel(widget);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 1, 0, 1, 1);

        labelOutputFile_2 = new QLabel(widget);
        labelOutputFile_2->setObjectName(QString::fromUtf8("labelOutputFile_2"));

        gridLayout->addWidget(labelOutputFile_2, 1, 1, 1, 1);

        splitter->addWidget(widget);
        progressBar = new QProgressBar(splitter);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setValue(24);
        splitter->addWidget(progressBar);

        horizontalLayout->addWidget(splitter);


        retranslateUi(DialogProgress);

        QMetaObject::connectSlotsByName(DialogProgress);
    } // setupUi

    void retranslateUi(QDialog *DialogProgress)
    {
        DialogProgress->setWindowTitle(QCoreApplication::translate("DialogProgress", "Progress", nullptr));
        label_2->setText(QCoreApplication::translate("DialogProgress", "Current job", nullptr));
        labelJobCount->setText(QCoreApplication::translate("DialogProgress", "1/1", nullptr));
        label->setText(QCoreApplication::translate("DialogProgress", "File being written ", nullptr));
        labelOutputFile_2->setText(QCoreApplication::translate("DialogProgress", "...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogProgress: public Ui_DialogProgress {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_UIPROGRESS_H
