static const AVCodec * const codec_list[] = {
    &ff_dvvideo_encoder,
    &ff_ffv1_encoder,
    &ff_ffvhuff_encoder,
    &ff_flv_encoder,
    &ff_h263_encoder,
    &ff_huffyuv_encoder,
    &ff_mjpeg_encoder,
    &ff_mpeg1video_encoder,
    &ff_mpeg2video_encoder,
    &ff_mpeg4_encoder,
    &ff_png_encoder,
    &ff_snow_encoder,
    &ff_utvideo_encoder,
    &ff_aac_encoder,
    &ff_ac3_encoder,
    &ff_flac_encoder,
    &ff_mp2_encoder,
    &ff_h264_vaapi_encoder,
    &ff_hevc_vaapi_encoder,
    &ff_amv_decoder,
    &ff_cinepak_decoder,
    &ff_cscd_decoder,
    &ff_cyuv_decoder,
    &ff_dnxhd_decoder,
    &ff_dvvideo_decoder,
    &ff_ffv1_decoder,
    &ff_ffvhuff_decoder,
    &ff_fic_decoder,
    &ff_flv_decoder,
    &ff_fraps_decoder,
    &ff_h263_decoder,
    &ff_h264_decoder,
    &ff_hevc_decoder,
    &ff_huffyuv_decoder,
    &ff_lagarith_decoder,
    &ff_mjpeg_decoder,
    &ff_mjpegb_decoder,
    &ff_mpeg1video_decoder,
    &ff_mpeg2video_decoder,
    &ff_mpeg4_decoder,
    &ff_msmpeg4v2_decoder,
    &ff_msmpeg4v3_decoder,
    &ff_msvideo1_decoder,
    &ff_png_decoder,
    &ff_prores_decoder,
    &ff_rawvideo_decoder,
    &ff_snow_decoder,
    &ff_sp5x_decoder,
    &ff_svq3_decoder,
    &ff_theora_decoder,
    &ff_tscc_decoder,
    &ff_utvideo_decoder,
    &ff_v210_decoder,
    &ff_vc1_decoder,
    &ff_vp3_decoder,
    &ff_vp6_decoder,
    &ff_vp6a_decoder,
    &ff_vp6f_decoder,
    &ff_vp8_decoder,
    &ff_vp9_decoder,
    &ff_wmv1_decoder,
    &ff_wmv2_decoder,
    &ff_wmv3_decoder,
    &ff_aac_decoder,
    &ff_ac3_decoder,
    &ff_dca_decoder,
    &ff_eac3_decoder,
    &ff_flac_decoder,
    &ff_mp2_decoder,
    &ff_mp3_decoder,
    &ff_nellymoser_decoder,
    &ff_qdm2_decoder,
    &ff_truehd_decoder,
    &ff_vorbis_decoder,
    &ff_wmalossless_decoder,
    &ff_wmapro_decoder,
    &ff_wmav2_decoder,
    &ff_adpcm_ima_amv_decoder,
    &ff_av1_decoder,
    NULL };
