/********************************************************************************
** Form generated from reading UI file 'artColorEffect.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARTCOLOREFFECT_H
#define UI_ARTCOLOREFFECT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "ADM_toolkitQt.h"

QT_BEGIN_NAMESPACE

class Ui_artColorEffectDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *comboBoxEffect;
    QSpacerItem *spacerItem;
    QHBoxLayout *toolboxLayout;
    ADM_flyNavSlider *horizontalSlider;
    QGraphicsView *graphicsView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *artColorEffectDialog)
    {
        if (artColorEffectDialog->objectName().isEmpty())
            artColorEffectDialog->setObjectName(QString::fromUtf8("artColorEffectDialog"));
        artColorEffectDialog->resize(505, 475);
        verticalLayout = new QVBoxLayout(artColorEffectDialog);
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(9, 9, 9, 9);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(artColorEffectDialog);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        comboBoxEffect = new QComboBox(artColorEffectDialog);
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->addItem(QString());
        comboBoxEffect->setObjectName(QString::fromUtf8("comboBoxEffect"));

        horizontalLayout->addWidget(comboBoxEffect);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacerItem);


        verticalLayout->addLayout(horizontalLayout);

        toolboxLayout = new QHBoxLayout();
        toolboxLayout->setObjectName(QString::fromUtf8("toolboxLayout"));

        verticalLayout->addLayout(toolboxLayout);

        horizontalSlider = new ADM_flyNavSlider(artColorEffectDialog);
        horizontalSlider->setObjectName(QString::fromUtf8("horizontalSlider"));
        horizontalSlider->setOrientation(Qt::Horizontal);

        verticalLayout->addWidget(horizontalSlider);

        graphicsView = new QGraphicsView(artColorEffectDialog);
        graphicsView->setObjectName(QString::fromUtf8("graphicsView"));
        graphicsView->setFocusPolicy(Qt::NoFocus);

        verticalLayout->addWidget(graphicsView);

        buttonBox = new QDialogButtonBox(artColorEffectDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(artColorEffectDialog);
        QObject::connect(buttonBox, SIGNAL(accepted()), artColorEffectDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), artColorEffectDialog, SLOT(reject()));

        QMetaObject::connectSlotsByName(artColorEffectDialog);
    } // setupUi

    void retranslateUi(QDialog *artColorEffectDialog)
    {
        artColorEffectDialog->setWindowTitle(QCoreApplication::translate("artColorEffectDialog", "Color Effect", nullptr));
        label->setText(QCoreApplication::translate("artColorEffectDialog", "Effect", nullptr));
        comboBoxEffect->setItemText(0, QCoreApplication::translate("artColorEffectDialog", "Sepia", nullptr));
        comboBoxEffect->setItemText(1, QCoreApplication::translate("artColorEffectDialog", "Vivid", nullptr));
        comboBoxEffect->setItemText(2, QCoreApplication::translate("artColorEffectDialog", "RGB", nullptr));
        comboBoxEffect->setItemText(3, QCoreApplication::translate("artColorEffectDialog", "Heat", nullptr));
        comboBoxEffect->setItemText(4, QCoreApplication::translate("artColorEffectDialog", "Radium", nullptr));
        comboBoxEffect->setItemText(5, QCoreApplication::translate("artColorEffectDialog", "Red-green", nullptr));
        comboBoxEffect->setItemText(6, QCoreApplication::translate("artColorEffectDialog", "Monochrome", nullptr));
        comboBoxEffect->setItemText(7, QCoreApplication::translate("artColorEffectDialog", "Old photo", nullptr));
        comboBoxEffect->setItemText(8, QCoreApplication::translate("artColorEffectDialog", "Night vision", nullptr));
        comboBoxEffect->setItemText(9, QCoreApplication::translate("artColorEffectDialog", "X-ray", nullptr));
        comboBoxEffect->setItemText(10, QCoreApplication::translate("artColorEffectDialog", "Shades", nullptr));
        comboBoxEffect->setItemText(11, QCoreApplication::translate("artColorEffectDialog", "XPRO", nullptr));
        comboBoxEffect->setItemText(12, QCoreApplication::translate("artColorEffectDialog", "Yellow-blue", nullptr));
        comboBoxEffect->setItemText(13, QCoreApplication::translate("artColorEffectDialog", "Yellow-bluish", nullptr));
        comboBoxEffect->setItemText(14, QCoreApplication::translate("artColorEffectDialog", "Chrome", nullptr));
        comboBoxEffect->setItemText(15, QCoreApplication::translate("artColorEffectDialog", "Esses", nullptr));

    } // retranslateUi

};

namespace Ui {
    class artColorEffectDialog: public Ui_artColorEffectDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ARTCOLOREFFECT_H
